@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #       Licensed to the Apache Software Foundation (ASF) under one
 #       or more contributor license agreements.  See the NOTICE file
 #       distributed with this work for additional information
@@ -18,6 +16,6 @@
 #       under the License.
 
 """The allura package"""
-from paste.registry import StackedObjectProxy
+from tg.support.registry import StackedObjectProxy
 
 credentials = StackedObjectProxy(name='credentials')
