@@ -24,6 +24,7 @@ from xml.etree import ElementTree as ET
 from copy import copy
 
 import pkg_resources
+from markupsafe import Markup
 from tg import expose, redirect, flash, validate
 from tg.decorators import without_trailing_slash
 from tg import config as tg_config
@@ -494,7 +495,7 @@ class Application(ActivityObject):
         :rtype: bool
 
         """
-        return has_access(self, 'read')(user=user)
+        return has_access(self, 'read', user)
 
     def subscribe_admins(self):
         """Subscribe all project Admins (for this Application's project) to the
@@ -619,13 +620,13 @@ class Application(ActivityObject):
         """
         return []
 
-    def sidebar_menu_js(self):
+    def sidebar_menu_js(self) -> Markup:
         """Return Javascript needed by the sidebar menu of this Application.
 
-        :return: a string of Javascript code
+        :return: Markup string of Javascript code
 
         """
-        return ""
+        return Markup("")
 
     @LazyProperty
     def _webhooks(self):
@@ -661,7 +662,7 @@ class Application(ActivityObject):
         admin_url = c.project.url() + 'admin/' + \
             self.config.options.mount_point + '/'
         links = []
-        if self.permissions and has_access(c.project, 'admin')():
+        if self.permissions and has_access(c.project, 'admin'):
             links.append(
                 SitemapEntry('Permissions', admin_url + 'permissions'))
         if force_options or len(self.config_options) > 3:
@@ -800,7 +801,7 @@ class Application(ActivityObject):
 
     def make_dir_for_attachments(self, path):
         if not os.path.exists(path):
-                os.makedirs(path)
+            os.makedirs(path)
 
     def save_attachments(self, path, attachments):
         self.make_dir_for_attachments(path)
@@ -834,6 +835,7 @@ class Application(ActivityObject):
 
 class AdminControllerMixin:
     """Provides common functionality admin controllers need"""
+
     def _before(self, *remainder, **params):
         # Display app's sidebar on admin page, instead of :class:`AdminApp`'s
         c.app = self.app
@@ -942,7 +944,7 @@ class DefaultAdminController(BaseController, AdminControllerMixin):
                     block_list[ace.permission].append((role.user, ace.reason))
         return dict(
             app=self.app,
-            allow_config=has_access(c.project, 'admin')(),
+            allow_config=has_access(c.project, 'admin'),
             permissions=permissions,
             block_list=block_list)
 
@@ -953,7 +955,7 @@ class DefaultAdminController(BaseController, AdminControllerMixin):
         """
         return dict(
             app=self.app,
-            allow_config=has_access(self.app, 'configure')())
+            allow_config=has_access(self.app, 'configure'))
 
     @expose()
     @require_post()
@@ -978,7 +980,7 @@ class DefaultAdminController(BaseController, AdminControllerMixin):
         """
         return dict(
             app=self.app,
-            allow_config=has_access(self.app, 'configure')())
+            allow_config=has_access(self.app, 'configure'))
 
     @expose('jinja:allura:templates/app_admin_delete.html')
     def delete(self):
@@ -1005,20 +1007,20 @@ class DefaultAdminController(BaseController, AdminControllerMixin):
                     # skip base options (mount_point, mount_label, ordinal)
                     continue
                 val = kw.get(opt.name, '')
-                if opt.ming_type == bool:
+                if opt.ming_type is bool:
                     val = asbool(val or False)
-                elif opt.ming_type == int:
+                elif opt.ming_type is int:
                     val = asint(val or 0)
                 try:
                     val = opt.validate(val)
                 except fev.Invalid as e:
                     flash(f'{opt.name}: {str(e)}', 'error')
                     continue
-                if self.app.config.options[opt.name] != val:
+                if self.app.config.options.get(opt.name) != val:
                     M.AuditLog.log('{}: set option "{}" {} => {}'.format(
                         self.app.config.options['mount_point'],
                         opt.name,
-                        self.app.config.options[opt.name],
+                        self.app.config.options.get(opt.name, '(not set)'),
                         val
                     ))
                 self.app.config.options[opt.name] = val
