@@ -18,7 +18,6 @@
 import os
 import logging
 
-import six
 import tg
 from paste.script import command
 from paste.deploy import appconfig
@@ -87,7 +86,7 @@ class Command(command.Command, metaclass=MetaParserDocstring):
         return tg.config
 
     def basic_setup(self):
-        global log, M
+        global log, M  # noqa: PLW0603
         if self.args[0]:
             # Probably being called from the command line - load the config
             # file
@@ -112,7 +111,10 @@ class Command(command.Command, metaclass=MetaParserDocstring):
             # Probably being called from another script (websetup, perhaps?)
             log = logging.getLogger('allura.command')
             conf = tg.config
+
         self.tools = list(tg.app_globals.entry_points['tool'].values())
+
+        conf['allura_command'] = self
         for ep in h.iter_entry_points('allura.command_init'):
             log.info('Running command_init for %s', ep.name)
             ep.load()(conf)
