@@ -18,7 +18,6 @@
 import sys
 import os.path
 import cProfile
-import warnings
 
 from tg import tmpl_context as c
 import tg
@@ -38,33 +37,39 @@ class ScriptCommand(base.Command):
     parser = base.Command.standard_parser(verbose=True)
     parser.add_option('--profile', action='store_true', dest='profile',
                       help='Dump profiling data to <script>.profile')
+    parser.add_option('--profile-output', dest='profile_output',
+                      help='full path to store profiling results')
     parser.add_option('--pdb', action='store_true', dest='pdb',
                       help='Drop to a debugger on error')
 
     def command(self):
-        with warnings.catch_warnings():
-            try:
-                from sqlalchemy import exc
-            except ImportError:
-                pass
-            else:
-                warnings.simplefilter("ignore", category=exc.SAWarning)
-            self.basic_setup()
-            request = webob.Request.blank('--script--', environ={
-                'paste.registry': self.registry})
-            tg.request_local.context.request = request
-            if self.options.pdb:
-                base.log.info('Installing exception hook')
-                sys.excepthook = utils.postmortem_hook
-            filename = self.args[1]
-            with open(filename) as fp:
-                ns = dict(__name__='__main__')
-                sys.argv = self.args[1:]
-                if self.options.profile:
-                    cProfile.run(fp.read(), '%s.profile' %
-                                 os.path.basename(filename))
-                else:
-                    exec(compile(fp.read(), filename, 'exec'), ns)
+        self.basic_setup()
+        request = webob.Request.blank('--script--', environ={
+            'paste.registry': self.registry})
+        tg.request_local.context.request = request
+        if self.options.pdb:
+            base.log.info('Installing exception hook')
+            sys.excepthook = utils.postmortem_hook
+        filename = self.args[1]
+        with open(filename) as fp:
+            ns = dict(__name__='__main__')
+            sys.argv = self.args[1:]
+            code = compile(fp.read(), filename, 'exec')
+
+            if self.options.profile:
+                profile_output_file = self.options.profile_output or '%s.profile' % os.path.basename(filename)
+                if not os.access(os.path.dirname(profile_output_file), os.W_OK):
+                    raise OSError(f'no write permission to dir for {profile_output_file}. '
+                                  f'Specify a different path with --profile-output')
+                # https://stackoverflow.com/a/48622889
+                pr = cProfile.Profile()
+                pr.enable()
+
+            exec(code, ns)  # noqa: S102
+
+            if self.options.profile:
+                pr.disable()
+                pr.dump_stats(profile_output_file)
 
 
 class SetToolAccessCommand(base.Command):
@@ -82,8 +87,8 @@ class SetToolAccessCommand(base.Command):
         for s in self.args[3:]:
             s = s.lower()
             if s == 'production':
-                print ('All projects always have access to prodcution tools,'
-                       ' so removing from list.')
+                print('All projects always have access to prodcution tools,'
+                      ' so removing from list.')
                 continue
             if s not in ('alpha', 'beta'):
                 print('Unknown tool status %s' % s)
