@@ -15,10 +15,10 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-import sys
 from collections import defaultdict
 from contextlib import contextmanager
 from itertools import groupby
+import sys
 
 from paste.deploy.converters import asbool
 from tg import tmpl_context as c, app_globals as g
@@ -26,13 +26,13 @@ from pymongo.errors import DuplicateKeyError, InvalidDocument, OperationFailure
 
 from ming.odm import mapper, session, Mapper
 from ming.odm.declarative import MappedClass
+import ming.mim
 
 from allura.tasks.index_tasks import add_artifacts
 from allura.lib.exceptions import CompoundError
 from allura.lib import helpers as h
 from allura.lib import utils
 from . import base
-import six
 
 
 class ShowModelsCommand(base.Command):
@@ -79,6 +79,8 @@ class ReindexCommand(base.Command):
                            'which are needed for some markdown macros to run properly')
     parser.add_option('--solr-hosts', dest='solr_hosts',
                       help='Override the solr host(s) to post to.  Comma-separated list of solr server URLs')
+    parser.add_option('--solr-creds', dest='solr_creds',
+                      help='Creds for the solr host(s).  Comma-separated list of user:pwd strings')
     parser.add_option(
         '--max-chunk', dest='max_chunk', type=int, default=100 * 1000,
         help='Max number of artifacts to index in one Solr update command')
@@ -148,9 +150,13 @@ class ReindexCommand(base.Command):
 
     @property
     def add_artifact_kwargs(self):
+        kwargs = {}
         if self.options.solr_hosts:
-            return {'solr_hosts': self.options.solr_hosts.split(',')}
-        return {}
+            kwargs['solr_hosts'] = self.options.solr_hosts.split(',')
+        if self.options.solr_creds:
+            kwargs['solr_creds'] = [cred.split(':')
+                                    for cred in self.options.solr_creds.split(',')]
+        return kwargs
 
     def _chunked_add_artifacts(self, ref_ids):
         # ref_ids contains solr index ids which can easily be over
@@ -209,6 +215,8 @@ class EnsureIndexCommand(base.Command):
     parser = base.Command.standard_parser(verbose=True)
     parser.add_option('--clean', action='store_true', dest='clean',
                       help='Drop any unneeded indexes')
+    parser.add_option('--delete-duplicate-key-records', action='store_true', dest='delete_dupes',
+                      help='Delete records that violate unique indexes')
 
     def command(self):
         from allura import model as M
@@ -289,22 +297,26 @@ class EnsureIndexCommand(base.Command):
         # Ensure all indexes
         for keys, idx in uindexes.items():
             base.log.info('...... ensure %s:%s', collection.name, idx)
-            while True:
+            while True:  # loop in case de-duping takes multiple attempts
+                index_options = idx.index_options.copy()
+                if idx.fields == ('_id',):
+                    # as of mongo 3.4 _id fields can't have these options set
+                    # _id is always non-sparse and unique anyway
+                    del index_options['sparse']
+                    del index_options['unique']
                 try:
-                    index_options = idx.index_options.copy()
-                    if idx.fields == ('_id',):
-                        # as of mongo 3.4 _id fields can't have these options set
-                        # _id is always non-sparse and unique anyway
-                        del index_options['sparse']
-                        del index_options['unique']
-                    collection.ensure_index(idx.index_spec, **index_options)
+                    collection.create_index(idx.index_spec, **index_options)
                     break
                 except DuplicateKeyError as err:
-                    base.log.info('Found dupe key(%s), eliminating dupes', err)
-                    self._remove_dupes(collection, idx.index_spec)
+                    if self.options.delete_dupes:
+                        base.log.warning('Found dupe key(%s), eliminating dupes', err)
+                        self._remove_dupes(collection, idx.index_spec, index_options)
+                    else:
+                        print('Error creating unique index.  Run with --delete-duplicate-key-records if you want to delete records that violate this index', file=sys.stderr)
+                        raise
         for keys, idx in indexes.items():
             base.log.info('...... ensure %s:%s', collection.name, idx)
-            collection.ensure_index(idx.index_spec, background=True, **idx.index_options)
+            collection.create_index(idx.index_spec, background=True, **idx.index_options)
         # Drop obsolete indexes
         for iname, keys in prev_indexes.items():
             if keys not in indexes:
@@ -329,23 +341,29 @@ class EnsureIndexCommand(base.Command):
         superset_keys = keys + [('temporary_extra_field_for_indexing', 1)]
         base.log.info('...... ensure index %s:%s',
                       collection.name, superset_keys)
-        superset_index = collection.ensure_index(superset_keys)
+        superset_index = collection.create_index(superset_keys)
         base.log.info('...... drop index %s:%s', collection.name, iname)
         collection.drop_index(iname)
         base.log.info('...... ensure index %s:%s %s',
                       collection.name, keys, creation_options)
-        collection.ensure_index(keys, **creation_options)
+        collection.create_index(keys, **creation_options)
         base.log.info('...... drop index %s:%s',
                       collection.name, superset_index)
         collection.drop_index(superset_index)
 
-    def _remove_dupes(self, collection, spec):
-        iname = collection.create_index(spec)
+    def _remove_dupes(self, collection, spec, index_options: dict):
+        iname = collection.create_index(spec)  # create it but not unique
         fields = [f[0] for f in spec]
-        q = collection.find({}, projection=fields).sort(spec)
+        query = {}
+        if index_options.get('sparse'):
+            # sparse indexes only apply if the field(s) exist
+            query = {
+                '$or': [{f: {'$exists': True}} for f in fields]
+            }
+        q = collection.find(query, projection=fields).sort(spec)
 
         def keyfunc(doc):
-            return tuple(doc.get(f, None) for f in fields)
+            return tuple(list(ming.mim._lookup(doc, f, None)) for f in fields)
         dupes = []
         for key, doc_iter in groupby(q, key=keyfunc):
             docs = list(doc_iter)
