@@ -15,18 +15,18 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-import smtpd
-import asyncore
-
 import faulthandler
 import tg
 from paste.script import command
 
 import allura.tasks
 from allura.command import base
+from allura.command.base import EmptyClass, Command
 from allura.lib import helpers as h
-
 from paste.deploy.converters import asint
+from aiosmtpd.controller import Controller
+from tg.wsgiapp import RequestLocals
+import time
 
 
 class SMTPServerCommand(base.Command):
@@ -38,25 +38,39 @@ class SMTPServerCommand(base.Command):
     parser.add_option('-c', '--context', dest='context',
                       help=('The context of the message (path to the project'
                             ' and/or tool'))
-
+    
     def command(self):
         faulthandler.enable()
         self.basic_setup()
-        MailServer((tg.config.get('forgemail.host', '0.0.0.0'),
-                    asint(tg.config.get('forgemail.port', 8825))),
-                   None)
-        asyncore.loop()
-
-
-class MailServer(smtpd.SMTPServer):
-
-    def process_message(self, peer, mailfrom, rcpttos, data, **kwargs):
+        handler = MailServer()
+        hostname = tg.config.get('forgemail.host', '0.0.0.0')
+        port = asint(tg.config.get('forgemail.port', 8825))
+        controller = Controller(handler, hostname=hostname, port=port)
+        controller.start()
+        while True:
+            time.sleep(100000)
+            
+        
+class MailServer:
+    async def handle_DATA(self, server, session, envelope):
         try:
+            peer = session.peer
+            mailfrom = envelope.mail_from
+            rcpttos = envelope.rcpt_tos
+            data = envelope.content
             base.log.info('Msg Received from %s for %s', mailfrom, rcpttos)
             base.log.info(' (%d bytes)', len(data))
-            task = allura.tasks.mail_tasks.route_email.post(
-                peer=peer, mailfrom=mailfrom, rcpttos=rcpttos,
-                data=h.really_unicode(data))
+            # pass the app_globals into the request context again because it's in a different thread
+            tgl = RequestLocals()
+            tgl.tmpl_context = EmptyClass()
+            tgl.app_globals = tg.app_globals
+            tg.request_local.context._push_object(tgl)
+            task = allura.tasks.mail_tasks.route_email.post(peer=peer, mailfrom=mailfrom, rcpttos=rcpttos,
+                                                            data=h.really_unicode(data))
             base.log.info(f'Msg passed along as task {task._id}')
-        except Exception:
-            base.log.exception('Error handling msg')
+        except Exception as error:
+            base.log.exception(f'Error handling msg - {error}')
+            return '500 Could not process your message'
+
+        return '250 OK'
+
