@@ -20,7 +20,6 @@ import re
 import logging
 import os
 import time
-import six.moves.queue
 from contextlib import contextmanager
 from datetime import datetime, timedelta
 import signal
@@ -136,11 +135,11 @@ class TaskdCommand(base.Command):
                         waitfunc=waitfunc,
                         only=only)
                     if self.task:
-                        with(proctitle("taskd:{}:{}".format(
+                        with (proctitle("taskd:{}:{}".format(
                                 self.task.task_name, self.task._id))):
                             # Build the (fake) request
                             request_path = '/--{}--/{}/'.format(self.task.task_name,
-                                                            self.task._id)
+                                                                self.task._id)
                             r = Request.blank(request_path,
                                               base_url=tg.config['base_url'].rstrip(
                                                   '/') + request_path,
@@ -160,7 +159,7 @@ class TaskdCommand(base.Command):
 
         if self.restart_when_done:
             base.log.info('taskd pid %s restarting itself' % os.getpid())
-            os.execv(sys.argv[0], sys.argv)
+            os.execv(sys.argv[0], sys.argv)  # noqa: S606
 
 
 class TaskCommand(base.Command):
