@@ -50,7 +50,7 @@ from tg.support.converters import asint
 
 import allura
 # needed for tg.configuration to work
-from allura.lib import app_globals, helpers
+from allura.lib import helpers
 from allura.lib.package_path_loader import PackagePathLoader
 
 log = logging.getLogger(__name__)
@@ -61,6 +61,7 @@ class MinimalApplicationConfiguratorNoRegistry(ApplicationConfigurator):
     Copied from tg.MinimalApplicationConfigurator but without the registry
     since we use RegistryManager in a specific part of our middleware already
     """
+
     def __init__(self):
         super().__init__()
         self.register(MimeTypesConfigurationComponent, after=False)
@@ -104,6 +105,22 @@ class AlluraTemplateConfig(TemplateRenderingConfigurationComponent):
         self.register_engine(AlluraJinjaRenderer)
 
 
+class InMemoryBytecodeCache(jinja2.BytecodeCache):
+    def __init__(self):
+        self.cache = {}
+
+    def load_bytecode(self, bucket):
+        key = bucket.key
+        if key in self.cache:
+            bucket.code = self.cache[key]
+
+    def dump_bytecode(self, bucket):
+        key = bucket.key
+        self.cache[key] = bucket.code
+
+long_term_in_memory_bytecode_cache = InMemoryBytecodeCache()
+
+
 class AlluraJinjaRenderer(JinjaRenderer):
 
     @classmethod
@@ -111,7 +128,10 @@ class AlluraJinjaRenderer(JinjaRenderer):
         cache_type = config.get('jinja_bytecode_cache_type')
         bcc = None
         try:
-            if cache_type == 'memcached' and config.get('memcached_host'):
+            if 'pytest' in sys.modules:
+                # speedup for tests: avoid memcache, avoid loading/dumping bytecode to strings.  Use same one for all tests
+                bcc = long_term_in_memory_bytecode_cache
+            elif cache_type == 'memcached' and config.get('memcached_host'):
                 import pylibmc
                 from jinja2 import MemcachedBytecodeCache
                 client = pylibmc.Client([config['memcached_host']])
@@ -138,12 +158,12 @@ class AlluraJinjaRenderer(JinjaRenderer):
             autoescape=True,
             bytecode_cache=bcc,
             cache_size=asint(config.get('jinja_cache_size', -1)),
-            extensions=['jinja2.ext.do', 'jinja2.ext.i18n'])
-        jinja2_env.install_gettext_translations(tg.i18n)
+            extensions=['jinja2.ext.do'])
         jinja2_env.filters['datetimeformat'] = helpers.datetimeformat
         jinja2_env.filters['filter'] = lambda s, t=None: list(filter(t and jinja2_env.tests[t], s))
         jinja2_env.filters['nl2br'] = helpers.nl2br_jinja_filter
         jinja2_env.filters['subrender'] = helpers.subrender_jinja_filter
+        jinja2_env.filters['safe_html'] = helpers.clean_html
         jinja2_env.globals.update({
             'hasattr': hasattr,
             'h': helpers,
@@ -174,7 +194,7 @@ class JinjaEngine(ew.TemplateEngine):
         context = self.context(context)
         with ew.utils.push_context(ew.widget_context, render_context=context):
             text = template.render(**context)
-            return Markup(text)
+            return Markup(text)  # noqa: S704
 
 
 base_config = ForgeConfig()
