@@ -21,8 +21,9 @@ import ast
 import importlib
 import mimetypes
 import pickle
-import six
-import tg
+import re
+import warnings
+
 import pkg_resources
 from tg import config
 from paste.deploy.converters import asbool, aslist, asint
@@ -35,11 +36,12 @@ from werkzeug.debug import DebuggedApplication
 import activitystream
 import ew
 import formencode
-import ming
 from ming.odm.middleware import MingMiddleware
+from beaker_session_jwt import JWTCookieSession
 
 # Must apply patches before other Allura imports to ensure all the patches are effective.
 # This file gets imported from paste/deploy/loadwsgi.py pretty early in the app execution
+# ruff: noqa: E402
 from allura.lib import patches
 patches.apply()
 try:
@@ -86,7 +88,7 @@ def make_app(global_conf: dict, **app_conf):
 class BeakerPickleSerializerWithLatin1(PickleSerializer):
     def loads(self, data_string):
         # need latin1 to decode py2 timestamps in py  https://docs.python.org/3/library/pickle.html#pickle.Unpickler
-        return pickle.loads(data_string, **{'encoding': 'latin1'} if six.PY3 else {})
+        return pickle.loads(data_string, encoding='latin1')  # noqa: S301
 
 
 def _make_core_app(root, global_conf: dict, **app_conf):
@@ -135,7 +137,14 @@ def _make_core_app(root, global_conf: dict, **app_conf):
     # broswer permissions policy
     app = SetHeadersMiddleware(app, config)
     # Required for sessions
-    app = SessionMiddleware(app, config, data_serializer=BeakerPickleSerializerWithLatin1())
+    with warnings.catch_warnings():
+        # the session_class= arg triggers this warning but is the only way it works, so suppress warning
+        warnings.filterwarnings('ignore',
+                                re.escape('Session options should start with session. instead of session_.'),
+                                DeprecationWarning)
+        app = SessionMiddleware(app, config,
+                                original_format_data_serializer=BeakerPickleSerializerWithLatin1(),
+                                session_class=JWTCookieSession)
     # Handle "Remember me" functionality
     app = RememberLoginMiddleware(app, config)
     # Redirect 401 to the login page
@@ -144,7 +153,7 @@ def _make_core_app(root, global_conf: dict, **app_conf):
     app = AlluraTimerMiddleware(app, app_conf)
     # Clear cookies when the CSRF field isn't posted
     if not app_conf.get('disable_csrf_protection'):
-        app = CSRFMiddleware(app, '_session_id')
+        app = CSRFMiddleware(app, '_csrf_token')
     if asbool(config.get('cors.enabled', False)):
         # Handle CORS requests
         allowed_methods = aslist(config.get('cors.methods'))
@@ -194,6 +203,7 @@ def _make_core_app(root, global_conf: dict, **app_conf):
         if asbool(config['debug']):
             # Converts exceptions to HTTP errors, shows traceback in debug mode
             app = DebuggedApplication(app, evalex=True)
+            app.trusted_hosts += [config['domain']]
         else:
             app = ErrorMiddleware(app, config)
 
