@@ -14,14 +14,15 @@
 #       KIND, either express or implied.  See the License for the
 #       specific language governing permissions and limitations
 #       under the License.
+from __future__ import annotations
 
 import logging
+import json
 import os
 from base64 import b32encode
 from datetime import datetime
 import re
-import warnings
-from urllib.parse import urlparse, urljoin
+from urllib.parse import urlparse, urljoin, urlunparse
 
 import bson
 import formencode as fe
@@ -32,9 +33,7 @@ from tg import tmpl_context as c, app_globals as g
 from tg import request, response
 from webob import exc as wexc
 from paste.deploy.converters import asbool
-with warnings.catch_warnings():  # ignore py2 CryptographyDeprecationWarning
-    warnings.filterwarnings('ignore')
-    from cryptography.hazmat.primitives.twofactor import InvalidToken
+from cryptography.hazmat.primitives.twofactor import InvalidToken
 from beaker.session import _session_id
 
 import allura.tasks.repo_tasks
@@ -44,23 +43,26 @@ from allura.lib import helpers as h
 from allura.lib import plugin
 from allura.lib import validators as V
 from allura.lib.decorators import require_post, reconfirm_auth
-from allura.lib.exceptions import InvalidRecoveryCode, MultifactorRateLimitError
+from allura.lib.exceptions import InvalidRecoveryCode, MultifactorRateLimitError, InvalidEmailAuthCode
 from allura.lib.repository import RepositoryApp
 from allura.lib.security import HIBPClient, HIBPCompromisedCredentials, HIBPClientError
 from allura.lib.widgets import (
     SubscriptionForm,
     OAuthApplicationForm,
+    OAuth2ApplicationForm,
     OAuthRevocationForm,
     LoginForm,
     ForgottenPasswordForm,
     DisableAccountForm)
 from allura.lib.widgets import forms, form_fields as ffw
 from allura.lib import mail_util
-from allura.lib.multifactor import TotpService, RecoveryCodeService
+from allura.lib.multifactor import TotpService, RecoveryCodeService, EmailCodeAuthenticationService
 from allura.lib import utils
 from allura.controllers import BaseController
 from allura.tasks.mail_tasks import send_system_mail_to_user
 import six
+import oauthlib.oauth2
+
 
 log = logging.getLogger(__name__)
 
@@ -74,6 +76,7 @@ class F:
     subscription_form = SubscriptionForm()
     registration_form = forms.RegistrationForm(action='/auth/save_new')
     oauth_application_form = OAuthApplicationForm(action='register')
+    oauth2_application_form = OAuth2ApplicationForm(action='register2')
     oauth_revocation_form = OAuthRevocationForm(
         action='/auth/preferences/revoke_oauth')
     change_personal_data_form = forms.PersonalDataForm()
@@ -112,6 +115,10 @@ class AuthController(BaseController):
         self.user_info = UserInfoController()
         self.subscriptions = SubscriptionsController()
         self.oauth = OAuthController()
+
+        if asbool(config.get('auth.oauth2.enabled', False)):
+            self.oauth2 = OAuth2AuthorizationController()
+
         if asbool(config.get('auth.allow_user_to_disable_account', False)):
             self.disable = DisableAccountController()
 
@@ -143,9 +150,22 @@ class AuthController(BaseController):
             if request.referer is not None and six.ensure_text(request.referer).split('/')[-1] == 'neighborhood':
                 return_to = '/'
             elif request.referer:
-                return_to = six.ensure_text(request.referer)
+                parsed_referer = urlparse(request.referer)
+                # Fix return_to url path upon clicking Cancel in multifactor authentication
+                if parsed_referer.path in plugin.AuthenticationProvider.multifactor_allowed_urls:
+                    new_url = parsed_referer._replace(path='/')
+                    return_to = six.ensure_text(urlunparse(new_url))
+                else:
+                    return_to = six.ensure_text(request.referer)
             else:
                 return_to = None
+
+        if return_to and return_to.endswith('/auth/'):
+            return_to = None
+
+        if not c.user.is_anonymous():  # already logged in
+            redirect(self._verify_return_to(return_to))
+
         c.form = F.login_form
         return dict(return_to=return_to)
 
@@ -160,7 +180,7 @@ class AuthController(BaseController):
         c.form = F.registration_form
         return dict()
 
-    def _validate_hash(self, hash):
+    def _validate_hash(self, hash) -> M.User:
         login_url = config.get('auth.login_url', '/auth/')
         if not hash:
             redirect(login_url)
@@ -199,7 +219,12 @@ class AuthController(BaseController):
         if not provider.forgotten_password_process:
             raise wexc.HTTPNotFound()
         user = self._validate_hash(hash)
-        enforce_hibp_password_check(provider, pw, f'/auth/forgotten_password/{hash}')
+        restart_url = f'/auth/forgotten_password/{hash}'
+        enforce_hibp_password_check(provider, pw, restart_url)
+
+        if provider._validate_password(user, pw):
+            flash('Your old and new password should not be the same', 'error')
+            redirect(restart_url)
 
         user.set_password(pw)
         user.set_tool_data('AuthPasswordReset', hash='', hash_expiry='')  # Clear password reset token
@@ -223,6 +248,11 @@ class AuthController(BaseController):
             redirect('/')
 
         user_record = M.User.by_email_address(email, only_confirmed=False)
+        if not user_record and email != email.lower():
+            # try again lowercase
+            email = email.lower()
+            user_record = M.User.by_email_address(email, only_confirmed=False)
+
         allow_non_primary_email_reset = asbool(config.get('auth.allow_non_primary_email_password_reset', True))
 
         if not re.match(r"[^@]+@[^@]+\.[^@]+", email):
@@ -345,8 +375,10 @@ class AuthController(BaseController):
         redirect('/auth/preferences/')
 
     @expose()
-    def logout(self):
+    def logout(self, return_to=None):
         plugin.AuthenticationProvider.get(request).logout()
+        if return_to:
+            redirect(self._verify_return_to(return_to))
         redirect(config.get('auth.post_logout_url', '/'))
 
     @staticmethod
@@ -367,7 +399,6 @@ class AuthController(BaseController):
     @utils.AntiSpam.validate('Spambot protection engaged')
     def do_login(self, return_to=None, **kw):
         location = '/'
-
         if session.get('multifactor-username'):
             location = tg.url('/auth/multifactor', dict(return_to=return_to))
         elif session.get('expired-username'):
@@ -385,6 +416,13 @@ class AuthController(BaseController):
         if not asbool(config.get('auth.multifactor.totp', False)):
             raise wexc.HTTPNotFound
 
+        if not c.user.is_anonymous():
+            # already logged in, no need to do this form
+            redirect(self._verify_return_to(return_to))
+        # currently only email_code mode is set via session
+        if session.get('mode') == 'email_code':
+            mode = 'email_code'
+
         return dict(
             return_to=return_to,
             mode=mode,
@@ -396,6 +434,10 @@ class AuthController(BaseController):
         if not asbool(config.get('auth.multifactor.totp', False)):
             raise wexc.HTTPNotFound
 
+        if not c.user.is_anonymous():
+            # already logged in, no need to do this form (it would say it was "disrupted")
+            redirect(self._verify_return_to(kwargs.get('return_to')))
+
         if 'multifactor-username' not in session:
             tg.flash('Your multifactor login was disrupted, please start over.', 'error')
             plugin.AuthenticationProvider.get(request).logout()  # clears all cookies that might be interfering
@@ -411,6 +453,10 @@ class AuthController(BaseController):
                 recovery = RecoveryCodeService.get()
                 recovery.verify_and_remove_code(user, code)
                 h.auditlog_user('Logged in using a multifactor recovery code', user=user)
+            elif mode == 'email_code':
+                email_code_service = EmailCodeAuthenticationService()
+                email_code_service.validate_code(user, code)
+                h.auditlog_user('Logged in using email authentication code', user=user)
         except (InvalidToken, InvalidRecoveryCode):
             request.validation.errors['code'] = 'Invalid code, please try again.'
             h.auditlog_user('Multifactor login - invalid code', user=user)
@@ -419,6 +465,10 @@ class AuthController(BaseController):
             request.validation.errors['code'] = 'Multifactor rate limit exceeded, slow down and try again later.'
             h.auditlog_user('Multifactor login - rate limit', user=user)
             return self.multifactor(mode=mode, **kwargs)
+        except InvalidEmailAuthCode:
+            request.validation.errors['code'] = 'Invalid code, please try again.'
+            h.auditlog_user('Email code login - invalid code', user=user)
+            return self.multifactor(mode=mode, **kwargs)
         else:
             plugin.AuthenticationProvider.get(request).login(user=user, multifactor_success=True)
             return_to = self._verify_return_to(kwargs.get('return_to'))
@@ -452,8 +502,8 @@ class AuthController(BaseController):
             return '.'.join(reversed(parts))
 
         repos = []
-        for p in user.my_projects():
-            for p in [p] + p.direct_subprojects:
+        for up in user.my_projects():
+            for p in [up] + up.direct_subprojects:
                 for app in p.app_configs:
                     if not issubclass(g.entry_points["tool"][app.tool_name], RepositoryApp):
                         continue
@@ -508,9 +558,9 @@ class AuthController(BaseController):
             log.info("Can't find repo at %s on repo_path %s",
                      rest[0], repo_path)
             return disallow
-        return dict(allow_read=has_access(c.app, 'read')(user=user),
-                    allow_write=has_access(c.app, 'write')(user=user),
-                    allow_create=has_access(c.app, 'create')(user=user))
+        return dict(allow_read=has_access(c.app, 'read', user),
+                    allow_write=has_access(c.app, 'write', user),
+                    allow_create=has_access(c.app, 'create', user))
 
     @expose('jinja:allura:templates/pwd_expired.html')
     @without_trailing_slash
@@ -612,7 +662,7 @@ class PreferencesController(BaseController):
                     flash('You must provide your current password to delete an email', 'error')
                     return
                 if primary_addr == user.email_addresses[i]:
-                    if select_new_primary_addr(user, ignore_emails=primary_addr) is None \
+                    if select_new_primary_addr(user, ignore_emails=[primary_addr]) is None \
                             and asbool(config.get('auth.require_email_addr', False)):
                         flash('You must have at least one verified email address.', 'error')
                         return
@@ -1318,13 +1368,52 @@ class OAuthController(BaseController):
     @expose('jinja:allura:templates/oauth_applications.html')
     def index(self, **kw):
         c.form = F.oauth_application_form
+        c.form2 = F.oauth2_application_form
+
         consumer_tokens = M.OAuthConsumerToken.for_user(c.user)
-        access_tokens = M.OAuthAccessToken.for_user(c.user)
+        access_tokens: list[dict] = []  # simple dict format to work for both OAuth1 and OAuth2 tokens
+        for oauth1_tok in M.OAuthAccessToken.for_user(c.user):
+            access_tokens.append({
+                'type': 1,
+                'app': oauth1_tok.consumer_token,
+                'is_bearer': oauth1_tok.is_bearer,
+                'api_key': oauth1_tok.api_key,
+                'last_access': oauth1_tok.last_access,
+                '_id': oauth1_tok._id,
+            })
+        if asbool(config.get('auth.oauth2.enabled', False)):
+            oauth2_client_apps = M.OAuth2ClientApp.for_user(c.user)
+            for oauth2_tok in M.OAuth2AccessToken.query.find({'user_id': c.user._id}):
+                access_tokens.append({
+                    'type': 2,
+                    'app': M.OAuth2ClientApp.query.get(client_id=oauth2_tok.client_id),
+                    'is_bearer': oauth2_tok.is_bearer,
+                    'api_key': oauth2_tok.access_token if oauth2_tok.is_bearer else None,
+                    'last_access': oauth2_tok.last_access,
+                    '_id': oauth2_tok._id,
+                })
+
+            # include auth codes too, but only if they're not already listed via an access/refresh token
+            for oauth2_auth in M.OAuth2AuthorizationCode.query.find({'user_id': c.user._id}):
+                client_app = M.OAuth2ClientApp.query.get(client_id=oauth2_auth.client_id)
+                if client_app not in (app['app'] for app in access_tokens):
+                    access_tokens.append({
+                        'type': '2authcode',
+                        'app': client_app,
+                        'is_bearer': False,
+                        'api_key': None,
+                        'last_access': None,
+                        '_id': oauth2_auth._id,
+                    })
+        else:
+            oauth2_client_apps = []
+
         provider = plugin.AuthenticationProvider.get(request)
         return dict(
             menu=provider.account_navigation(),
             consumer_tokens=consumer_tokens,
             access_tokens=access_tokens,
+            oauth2_client_apps=oauth2_client_apps,
         )
 
     @expose()
@@ -1336,6 +1425,24 @@ class OAuthController(BaseController):
         flash('OAuth Application registered')
         redirect('.')
 
+    @expose()
+    @require_post()
+    @validate(F.oauth2_application_form, error_handler=index)
+    def register2(self, application_name=None, application_description=None, **kw):
+        if not asbool(config.get('auth.oauth2.enabled', False)):
+            raise wexc.HTTPNotFound
+
+        redirect_urls = [
+            v for k, v in kw.items()
+            if k.startswith('redirect_url_') and v
+        ]
+        M.OAuth2ClientApp(name=application_name,
+                          description=application_description,
+                          redirect_uris=redirect_urls,
+                          user_id=c.user._id)
+        flash('OAuth2 Client registered')
+        redirect('.')
+
     @expose()
     @require_post()
     def deregister(self, _id=None):
@@ -1352,6 +1459,37 @@ class OAuthController(BaseController):
         flash('Application deleted')
         redirect('.')
 
+    def _check_perm_and_revoke_all2(self, client_id: str):
+        """
+        Revokes the authorization code and access tokens for a given client for all its users
+        """
+        if not asbool(config.get('auth.oauth2.enabled', False)):
+            raise wexc.HTTPNotFound
+
+        client = M.OAuth2ClientApp.query.get(client_id=client_id)
+        if client is None or client.user_id != c.user._id:
+            flash('Invalid client ID', 'error')
+            redirect('.')
+
+        M.OAuth2AuthorizationCode.query.remove({'client_id': client_id})
+        M.OAuth2AccessToken.query.remove({'client_id': client_id})
+        return client
+
+    @expose()
+    @require_post()
+    def deregister2(self, client_id):
+        client = self._check_perm_and_revoke_all2(client_id)
+        client.delete()
+        flash('Client deleted and all access tokens revoked.')
+        redirect('.')
+
+    @expose()
+    @require_post()
+    def revoke_all_access_tokens2(self, client_id):
+        self._check_perm_and_revoke_all2(client_id)
+        flash('Access tokens revoked.')
+        redirect('.')
+
     @expose()
     @require_post()
     def generate_access_token(self, _id):
@@ -1384,20 +1522,117 @@ class OAuthController(BaseController):
         )
         redirect('.')
 
-    @expose()
-    @require_post()
-    def revoke_access_token(self, _id):
-        access_token = M.OAuthAccessToken.query.get(_id=bson.ObjectId(_id))
+    def _check_revoke_perm(self, access_token):
         if access_token is None:
             flash('Invalid token ID', 'error')
             redirect('.')
         if access_token.user_id != c.user._id:
             flash('Invalid token ID', 'error')
             redirect('.')
-        access_token.delete()
-        flash('Token revoked')
+
+    @expose()
+    @require_post()
+    def generate_bearer_token(self, client_id):
+        """
+        Manually generates an OAuth2 access token without needing to go through the OAuth2 flow.
+        """
+        M.OAuth2AccessToken(
+            client_id=client_id,
+            user_id=c.user._id,
+            access_token=h.nonce(40),
+            is_bearer=True,
+            expires_at=datetime.max
+        )
+
         redirect('.')
 
+    @expose()
+    @require_post()
+    def revoke_access_token(self, _id):
+        access_token = M.OAuthAccessToken.query.get(_id=bson.ObjectId(_id))
+        self._check_revoke_perm(access_token)
+        access_token.delete()
+        flash('Authorization revoked')
+        redirect('.')
+
+    @expose()
+    @require_post()
+    def revoke_access_token2(self, _id):
+        if not asbool(config.get('auth.oauth2.enabled', False)):
+            raise wexc.HTTPNotFound
+
+        tok = M.OAuth2AccessToken.query.get(_id=bson.ObjectId(_id))
+        self._check_revoke_perm(tok)
+        # also any auth codes associated
+        M.OAuth2AuthorizationCode.query.remove({'client_id': tok.client_id, 'user_id': c.user._id})
+        tok.delete()
+        flash('Authorization revoked')
+        redirect('.')
+
+    @expose()
+    @require_post()
+    def revoke_access_token2authcode(self, _id):
+        if not asbool(config.get('auth.oauth2.enabled', False)):
+            raise wexc.HTTPNotFound
+
+        auth = M.OAuth2AuthorizationCode.query.get(_id=bson.ObjectId(_id))
+        self._check_revoke_perm(auth)
+        # also any access tokens associated
+        M.OAuth2AccessToken.query.remove({'client_id': auth.client_id, 'user_id': c.user._id})
+        auth.delete()
+        flash('Authorization revoked')
+        redirect('.')
+
+
+class OAuth2AuthorizationController(BaseController):
+    def _check_security(self):
+        require_authenticated()
+
+    @property
+    def server(self):
+        from allura.controllers.rest import Oauth2Validator
+        return oauthlib.oauth2.WebApplicationServer(Oauth2Validator())
+
+    @expose('jinja:allura:templates/oauth2_authorize.html')
+    @without_trailing_slash
+    def authorize(self, **kwargs):
+        json_body = None
+        if request.body:
+            # We need to decode the request body and convert it to a dict because Turbogears creates it as bytes
+            # and oauthlib will treat it as x-www-form-urlencoded format.
+            decoded_body = str(request.body, 'utf-8')
+            json_body = json.loads(decoded_body)
+
+        scopes, credentials = self.server.validate_authorization_request(uri=request.url, http_method=request.method, headers=request.headers, body=json_body)
+
+        client_id = request.params.get('client_id')
+        client = M.OAuth2ClientApp.query.get(client_id=client_id)
+
+        # The credentials object has a request object that it's too big to be serialized,
+        # so we remove it because we don't need it for the rest of the authorization workflow
+        del credentials['request']
+
+        return dict(client=client, credentials=json.dumps(credentials))
+
+    @expose()
+    @require_post()
+    def do_authorize(self, yes=None, no=None):
+        client_id = request.params['client_id']
+        client = M.OAuth2ClientApp.query.get(client_id=client_id)
+
+        if no:
+            flash(f'{client.name} NOT AUTHORIZED', 'error')
+            redirect('/auth/oauth/')
+
+        credentials = json.loads(request.params['credentials'])
+        headers, body, status = self.server.create_authorization_response(
+            uri=request.url, http_method=request.method, body=request.body, headers=request.headers, scopes=[], credentials=credentials
+        )
+
+        response.status_int = status
+        response.headers.update(headers)
+        return body
+
 
 class DisableAccountController(BaseController):
 
