@@ -15,14 +15,13 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-from urllib.parse import unquote, urlsplit, parse_qs
+from urllib.parse import unquote
 from datetime import datetime
 import logging
 
 import pymongo
 from tg import expose, redirect, validate, request, flash, response
-from tg.decorators import with_trailing_slash, without_trailing_slash, before_render, before_validate
-from decorator import decorator
+from tg.decorators import with_trailing_slash, without_trailing_slash
 
 from tg import tmpl_context as c, app_globals as g
 from webob import exc
@@ -44,10 +43,10 @@ from allura.lib.widgets import discuss as DW
 from allura.lib.widgets import form_fields as ffw
 
 from allura.model.auth import User
-from allura.model.artifact import ArtifactReference
 from .attachments import AttachmentsController, AttachmentController
 from .feed import FeedArgs, FeedController
 import six
+from jinja2.filters import do_truncate as truncate
 
 log = logging.getLogger(__name__)
 
@@ -204,6 +203,8 @@ class ThreadController(BaseController, FeedController, metaclass=h.ProxiedAttrMe
         c.thread_header = self.W.thread_header
         limit, page, start = g.handle_paging(limit, page)
         self.thread.num_views += 1
+        h1_text = self.thread.subject or c.app.config.options.mount_label
+        h1_text = truncate(None, h1_text, 80, end="...", leeway=3)
         # the update to num_views shouldn't affect it
         M.session.artifact_orm_session._get().skip_mod_date = True
         M.session.artifact_orm_session._get().skip_last_updated = True
@@ -216,7 +217,7 @@ class ThreadController(BaseController, FeedController, metaclass=h.ProxiedAttrMe
                     thread=self.thread,
                     page=int(page),
                     count=int(count),
-                    limit=int(limit),
+                    limit=int(limit), h1_text=h1_text,
                     show_moderate=kw.get('show_moderate'))
 
     def error_handler(self, *args, **kwargs):
@@ -556,12 +557,12 @@ class ModerationController(BaseController, metaclass=h.ProxiedAttrMeta):
 
             if posted:
                 if delete:
+                    count += 1
                     # full, for real, delete since this is post was never visible and denied by admin.
                     posted.delete()
                     # If we just deleted the last post in the
                     # thread, delete the thread.
                     if posted.thread and posted.thread.num_replies == 0:
-                        count += 1
                         posted.thread.delete()
                 elif spam and posted.status != 'spam':
                     count += 1
