@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #       Licensed to the Apache Software Foundation (ASF) under one
 #       or more contributor license agreements.  See the NOTICE file
 #       distributed with this work for additional information
@@ -24,17 +22,15 @@ from tg import request, expose
 __all__ = ['ErrorController']
 
 
-class ErrorController(object):
+class ErrorController:
 
     @expose('jinja:allura:templates/error.html')
     def document(self, *args, **kwargs):
         """Render the error document"""
-        resp = request.environ.get('pylons.original_response')
+        resp = request.environ.get('tg.original_response')
         code = -1
         if resp:
             code = resp.status_int
-        default_message = ("<p>We're sorry but we weren't able to process "
-                           " this request.</p>")
+        default_message = "We're sorry but we weren't able to process this request."
         message = request.environ.get('error_message', default_message)
-        message += '<pre>%r</pre>' % resp
         return dict(code=code, message=message)
