@@ -28,7 +28,6 @@ from tg.decorators import with_trailing_slash, without_trailing_slash
 from tg import tmpl_context as c, app_globals as g
 from paste.deploy.converters import asbool
 from webob import exc
-import jinja2
 import markupsafe
 import pymongo
 
@@ -49,7 +48,6 @@ from allura.lib.widgets import form_fields as ffw
 from allura.lib.widgets import project_list as plw
 from allura.lib import plugin, exceptions
 from .search import ProjectBrowseController
-from allura.ext.user_profile.user_main import UserProfileApp
 
 log = logging.getLogger(__name__)
 
@@ -132,7 +130,7 @@ class NeighborhoodController:
         categories = M.ProjectCategory.query.find(
             {'parent_id': None}).sort('name').all()
         c.custom_sidebar_menu = []
-        if h.has_access(self.neighborhood, 'register')() and (nb_max_projects is None or count < nb_max_projects):
+        if h.has_access(self.neighborhood, 'register') and (nb_max_projects is None or count < nb_max_projects):
             c.custom_sidebar_menu += [
                 SitemapEntry('Add a Project', self.neighborhood.url()
                              + 'add_project', ui_icon=g.icons['add']),
@@ -564,7 +562,7 @@ class NeighborhoodAdminController:
         set_nav(self.neighborhood)
         c.overview_form = W.neighborhood_overview_form
         allow_undelete = asbool(config.get('allow_project_undelete', True))
-        allow_wiki_as_root = True if get_default_wiki_page() else False
+        allow_wiki_as_root = bool(get_default_wiki_page())
 
         return dict(
             neighborhood=self.neighborhood,
@@ -687,7 +685,7 @@ class NeighborhoodAdminController:
         if icon is not None and icon != b'':
             if self.neighborhood.icon:
                 self.neighborhood.icon.delete()
-                M.ProjectFile.query.remove(dict(project_id=c.project._id, category=re.compile(r'^icon')))
+                M.ProjectFile.query.remove(dict(project_id=c.project._id, category={'$regex': r'^icon'}))
             save_icon = c.project.save_icon(icon.filename, icon.file, content_type=icon.type)
             if save_icon:
                 M.AuditLog.log('update neighborhood icon')
