@@ -15,13 +15,11 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-import os
 import logging
 import difflib
 
 from allura.lib.utils import permanent_redirect
-from datetime import datetime
-from urllib.parse import quote, unquote
+from urllib.parse import unquote
 from collections import defaultdict, OrderedDict
 
 
@@ -91,7 +89,7 @@ class RepoRootController(BaseController, FeedController):
     def index(self, offset=0, branch=None, **kw):
         if branch is None:
             branch = c.app.default_branch_name
-        permanent_redirect(c.app.repo.url_for_commit(branch, url_type='ref'))
+        permanent_redirect(h.urlquote(c.app.repo.url_for_commit(branch, url_type='ref')))
 
     @with_trailing_slash
     @expose('jinja:allura:templates/repo/forks.html')
@@ -628,6 +626,7 @@ class RefsController:
     def _lookup(self, ref=None, *remainder):
         if ref is None:
             raise exc.HTTPNotFound
+        ref = unquote(ref)
         EOR = c.app.END_OF_REF_ESCAPE
         if EOR in remainder:
             i = remainder.index(EOR)
@@ -736,7 +735,7 @@ class CommitBrowser(BaseController):
         # ('removed', u'bbb.txt', 'tree', None),
         # ('removed', u'ddd.txt', 'tree', None),
         # ('changed', u'ccc.txt', 'blob', True)]
-        result['artifacts'].sort(key=lambda x: x[1]['old'] if(isinstance(x[1], dict)) else x[1])
+        result['artifacts'].sort(key=lambda x: x[1]['old'] if (isinstance(x[1], dict)) else x[1])
         return result
 
     @expose('jinja:allura:templates/repo/commit_basic.html')
