@@ -16,11 +16,14 @@
 #       under the License.
 
 """REST Controller"""
+from __future__ import annotations
 import json
 import logging
-from urllib.parse import unquote, urlparse, parse_qs
+from datetime import datetime, timedelta
+from urllib.parse import unquote, parse_qs
 
 import oauthlib.oauth1
+import oauthlib.oauth2
 import oauthlib.common
 from paste.util.converters import asbool
 from webob import exc
@@ -41,7 +44,7 @@ from allura.lib.decorators import require_post
 from allura.lib.project_create_helpers import make_newproject_schema, deserialize_project, create_project_with_attrs
 from allura.lib.security import has_access
 import six
-from datetime import datetime
+
 
 log = logging.getLogger(__name__)
 
@@ -52,8 +55,14 @@ class RestController:
         self.oauth = OAuthNegotiator()
         self.auth = AuthRestController()
 
+        if self._is_oauth2_enabled():
+            self.oauth2 = Oauth2Negotiator()
+
+    def _is_oauth2_enabled(self):
+        return asbool(config.get('auth.oauth2.enabled', False))
+
     def _check_security(self):
-        if not request.path.startswith('/rest/oauth/'):  # everything but OAuthNegotiator
+        if not request.path.startswith(('/rest/oauth/', '/rest/oauth2/')):  # everything but OAuthNegotiators
             c.api_token = self._authenticate_request()
             if c.api_token:
                 c.user = c.api_token.user
@@ -64,7 +73,20 @@ class RestController:
         params_auth = 'oauth_token' in request.params
         params_auth = params_auth or 'access_token' in request.params
         if headers_auth or params_auth:
-            return self.oauth._authenticate()
+            try:
+                access_token = self.oauth._authenticate()
+            except exc.HTTPUnauthorized:
+                if not self._is_oauth2_enabled():
+                    raise
+
+                if params_auth:
+                    raise exc.HTTPUnauthorized('Do not use tokens in URL, instead use header Authorization: Bearer $TOKEN')
+
+                access_token = self.oauth2._authenticate()
+                if not access_token:
+                    raise
+
+            return access_token
         else:
             return None
 
@@ -234,6 +256,124 @@ class Oauth1Validator(oauthlib.oauth1.RequestValidator):
         return 'dummy-access-token-for-oauthlib'
 
 
+class Oauth2Validator(oauthlib.oauth2.RequestValidator):
+    def __init__(self):
+        super().__init__()
+        if asbool(tg.config.get('debug')):
+            oauthlib.set_debug(True)
+
+    def validate_client_id(self, client_id: str, request: oauthlib.common.Request, *args, **kwargs) -> bool:
+        return M.OAuth2ClientApp.query.get(client_id=client_id) is not None
+
+    def validate_redirect_uri(self, client_id, redirect_uri, request, *args, **kwargs):
+        if redirect_uri.startswith('http:'):
+            return False
+        client = M.OAuth2ClientApp.query.get(client_id=client_id)
+        return redirect_uri in client.redirect_uris
+
+    def validate_response_type(self, client_id: str, response_type: str, client: oauthlib.oauth2.Client, request: oauthlib.common.Request, *args, **kwargs) -> bool:
+        res_type = M.OAuth2ClientApp.query.get(client_id=client_id).response_type
+        return res_type == response_type
+
+    def validate_scopes(self, client_id: str, scopes, client: oauthlib.oauth2.Client, request: oauthlib.common.Request, *args, **kwargs) -> bool:
+        return True
+
+    def validate_grant_type(self, client_id: str, grant_type: str, client: oauthlib.oauth2.Client, request: oauthlib.common.Request, *args, **kwargs) -> bool:
+        return grant_type in ['authorization_code', 'refresh_token']
+
+    def get_default_scopes(self, client_id: str, request: oauthlib.common.Request, *args, **kwargs):
+        return []
+
+    def get_original_scopes(self, refresh_token: str, request: oauthlib.common.Request, *args, **kwargs) -> list[str]:
+        return None
+
+    def get_default_redirect_uri(self, client_id: str, request: oauthlib.common.Request, *args, **kwargs) -> str:
+        client = M.OAuth2ClientApp.query.get(client_id=client_id)
+        return client.redirect_uris[0] if client.redirect_uris else None
+
+    def is_pkce_required(self, client_id: str, request: oauthlib.common.Request) -> bool:
+        return False
+
+    def get_code_challenge(self, code: str, request: oauthlib.common.Request) -> str:
+        authorization_code = M.OAuth2AuthorizationCode.query.get(authorization_code=code)
+        return authorization_code.code_challenge
+
+    def get_code_challenge_method(self, code: str, request: oauthlib.common.Request) -> str:
+        authorization_code = M.OAuth2AuthorizationCode.query.get(authorization_code=code)
+        return authorization_code.code_challenge_method
+
+    def invalidate_authorization_code(self, client_id: str, code: str, request: oauthlib.common.Request, *args, **kwargs) -> None:
+        M.OAuth2AuthorizationCode.query.remove({'client_id': client_id, 'authorization_code': code})
+
+    def authenticate_client(self, request: oauthlib.common.Request, *args, **kwargs) -> bool:
+        request.client = M.OAuth2ClientApp.query.get(client_id=request.client_id, client_secret=request.client_secret)
+        return request.client is not None
+
+    def validate_code(self, client_id: str, code: str, client: oauthlib.oauth2.Client, request: oauthlib.common.Request, *args, **kwargs) -> bool:
+        authorization = M.OAuth2AuthorizationCode.query.get(client_id=client_id, authorization_code=code)
+        return authorization.expires_at >= datetime.utcnow() if authorization else False
+
+    def validate_bearer_token(self, token: str, scopes: list[str], request: oauthlib.common.Request) -> bool:
+        access_token = M.OAuth2AccessToken.query.get(access_token=token)
+        if access_token and access_token.expires_at >= datetime.utcnow():
+            request.access_token = access_token
+            return True
+        else:
+            return False
+
+    def validate_refresh_token(self, refresh_token: str, client: oauthlib.oauth2.Client, request: oauthlib.common.Request, *args, **kwargs) -> bool:
+        return M.OAuth2AccessToken.query.get(refresh_token=refresh_token, client_id=client.client_id) is not None
+
+    def confirm_redirect_uri(self, client_id: str, code: str, redirect_uri: str, client: oauthlib.oauth2.Client, request: oauthlib.common.Request, *args, **kwargs) -> bool:
+        # This method is called when the client is exchanging the authorization code for an access token.
+        # If a redirect uri was provided when the authorization code was created, it must match the redirect uri provided here.
+        authorization = M.OAuth2AuthorizationCode.query.get(client_id=client_id, authorization_code=code)
+        return authorization.redirect_uri == redirect_uri
+
+    def save_authorization_code(self, client_id: str, code, request: oauthlib.common.Request, *args, **kwargs) -> None:
+        authorization = M.OAuth2AuthorizationCode.query.get(client_id=client_id, user_id=c.user._id)
+
+        # Remove the existing authorization code if it exists and create a new record
+        if authorization:
+            M.OAuth2AuthorizationCode.query.remove({'client_id': client_id, 'user_id': c.user._id})
+
+        log.info('Saving authorization code for client: %s', client_id)
+        auth_code = M.OAuth2AuthorizationCode(
+            client_id=client_id,
+            authorization_code=code['code'],
+            expires_at=datetime.utcnow() + timedelta(minutes=10),
+            redirect_uri=request.redirect_uri,
+            user_id=c.user._id,
+            code_challenge=request.code_challenge,
+            code_challenge_method=request.code_challenge_method
+        )
+        session(auth_code).flush()
+        log.info(f'Saving new authorization code for client: {client_id}')
+
+    def save_bearer_token(self, token, request: oauthlib.common.Request, *args, **kwargs) -> object:
+        if request.grant_type == 'authorization_code':
+            user_id = M.OAuth2AuthorizationCode.query.get(client_id=request.client_id, authorization_code=request.code).user_id
+        elif request.grant_type == 'refresh_token':
+            user_id = M.OAuth2AccessToken.query.get(client_id=request.client_id, refresh_token=request.refresh_token).user_id
+
+        current_token = M.OAuth2AccessToken.query.get(client_id=request.client_id, user_id=user_id, is_bearer=False)
+
+        if current_token:
+            M.OAuth2AccessToken.query.remove({'client_id': request.client_id, 'user_id': user_id, 'is_bearer': False})
+
+        bearer_token = M.OAuth2AccessToken(
+            client_id=request.client_id,
+            scopes=token.get('scope', []),
+            access_token=token.get('access_token'),
+            refresh_token=token.get('refresh_token'),
+            expires_at=datetime.utcnow() + timedelta(seconds=token.get('expires_in')),
+            user_id=user_id
+        )
+
+        session(bearer_token).flush()
+        log.info(f'Saving new bearer token for client: {request.client_id}')
+
+
 class AlluraOauth1Server(oauthlib.oauth1.WebApplicationServer):
     def validate_request_token_request(self, request):
         # this is NOT standard OAuth1 (spec requires the param)
@@ -251,7 +391,7 @@ class OAuthNegotiator:
         return AlluraOauth1Server(Oauth1Validator())
 
     def _authenticate(self):
-        bearer_token_prefix = 'Bearer '
+        bearer_token_prefix = 'Bearer '  # noqa: S105
         auth = request.headers.get('Authorization')
         if auth and auth.startswith(bearer_token_prefix):
             access_token = auth[len(bearer_token_prefix):]
@@ -299,7 +439,7 @@ class OAuthNegotiator:
             http_method=request.method,
             body=request.body,
             headers=request.headers)
-        response.headers = headers
+        response.headers.update(headers)
         response.status_int = status
         return body
 
@@ -354,7 +494,7 @@ class OAuthNegotiator:
             rtok.validation_pin = verifier
             return dict(rtok=rtok)
         else:
-            response.headers = headers
+            response.headers.update(headers)
             response.status_int = status
             return body
 
@@ -365,7 +505,44 @@ class OAuthNegotiator:
             http_method=request.method,
             body=request.body,
             headers=request.headers)
-        response.headers = headers
+        response.headers.update(headers)
+        response.status_int = status
+        return body
+
+
+class Oauth2Negotiator:
+    @property
+    def server(self):
+        return oauthlib.oauth2.WebApplicationServer(Oauth2Validator())
+
+    def _authenticate(self):
+        valid, req = self.server.verify_request(
+            request.url,
+            http_method=request.method,
+            body=request.body,
+            headers=request.headers)
+
+        if not valid:
+            raise exc.HTTPUnauthorized
+
+        token = req.access_token  # set by validate_bearer_token
+        token.last_access = datetime.utcnow()
+        return token
+
+    @expose('json:')
+    @require_post()
+    def token(self, **kwargs):
+        decoded_body = str(request.body, 'utf-8')
+
+        # We try to parse the request body as JSON, if it fails we just use the body as is
+        # so it's treated as x-www-form-urlencoded
+        try:
+            request_body = json.loads(decoded_body)
+        except json.decoder.JSONDecodeError:
+            request_body = decoded_body
+
+        headers, body, status = self.server.create_token_response(uri=request.url, http_method=request.method, body=request_body, headers=request.headers)
+        response.headers.update(headers)
         response.status_int = status
         return body
 
@@ -378,7 +555,7 @@ def rest_has_access(obj, user, perm):
     resp = {'result': False}
     user = M.User.by_username(user)
     if user:
-        resp['result'] = security.has_access(obj, perm, user=user)()
+        resp['result'] = security.has_access(obj, perm, user=user)
     return resp
 
 
@@ -451,7 +628,7 @@ def nbhd_lookup_first_path(nbhd, name, current_user, remainder, api=False):
             project.configure_project(is_user_project=True)
         else:
             raise exc.HTTPNotFound(pname)
-    if project is None or (project.deleted and not has_access(project, 'update')()):
+    if project is None or (project.deleted and not has_access(project, 'update')):
         raise exc.HTTPNotFound(pname)
     return project, remainder
 
