@@ -18,9 +18,9 @@
 import re
 import logging
 from datetime import datetime, timedelta
-import pipes
+import shlex
 
-from tg import expose, validate, flash, config, redirect
+from tg import expose, validate, flash, redirect
 from tg.decorators import with_trailing_slash, without_trailing_slash
 import bson
 import tg
@@ -51,6 +51,7 @@ import allura
 from urllib.parse import urlparse
 import six
 
+from ming.odm.icollection import deinstrument
 
 log = logging.getLogger(__name__)
 
@@ -184,7 +185,7 @@ class SiteAdminController:
         try:
             end_dt = datetime.strptime(end_dt, '%Y/%m/%d %H:%M:%S')
         except ValueError:
-            end_dt = start_dt - timedelta(days=3) if not end_dt else end_dt
+            end_dt = end_dt if end_dt else start_dt - timedelta(days=3)
         start = bson.ObjectId.from_datetime(start_dt)
         end = bson.ObjectId.from_datetime(end_dt)
         nb = M.Neighborhood.query.get(name='Users')
@@ -212,6 +213,18 @@ class SiteAdminController:
             'window_end': end_dt,
         }
 
+    @expose('json:')
+    @require_post()
+    def save_project_note(self, **kwargs):
+        shortname = kwargs.get('shortname')
+        note = kwargs.get('note')
+        nbhd = M.Neighborhood.query.get(name='Projects')
+        c.project = M.Project.query.get(shortname=shortname, neighborhood_id=nbhd._id)
+        if c.project:
+            c.project.set_tool_data('notes', note=note)
+            return {'status': 'ok', 'message': 'Project note updated'}
+        return {'status': 'error', 'message': 'Project note not updated'}
+
     @expose('jinja:allura:templates/site_admin_reclone_repo.html')
     @without_trailing_slash
     @validate(dict(prefix=validators.NotEmpty(),
@@ -288,7 +301,7 @@ class SiteAdminController:
         def convert_fields(obj):
             # throw the type away (e.g. '_s' from 'url_s')
             result = {}
-            for k,val in obj.items():
+            for k, val in obj.items():
                 name = k.rsplit('_', 1)
                 if len(name) == 2:
                     name = name[0]
@@ -413,7 +426,7 @@ class DeleteProjectsController:
             redirect('.')
         task_params = ' '.join(task_params)
         if reason:
-            task_params = f'-r {pipes.quote(reason)} {task_params}'
+            task_params = f'-r {shlex.quote(reason)} {task_params}'
         if disable_users:
             task_params = f'--disable-users {task_params}'
         DeleteProjects.post(task_params)
@@ -542,9 +555,9 @@ class TaskManagerController:
         if state:
             query['state'] = state
         if task_name:
-            query['task_name'] = re.compile(re.escape(task_name))
+            query['task_name'] = {'$regex': re.escape(task_name)}
         if host:
-            query['process'] = re.compile(re.escape(host))
+            query['process'] = {'$regex': re.escape(host)}
 
         tasks = list(M.monq_model.MonQTask.query.find(query).sort('_id', -1))
         for task in tasks:
@@ -576,7 +589,12 @@ class TaskManagerController:
             task.app_config = M.AppConfig.query.get(
                 _id=task.context.app_config_id)
             task.user = M.User.query.get(_id=task.context.user_id)
-        return dict(task=task)
+            task_args = [deinstrument(a) for a in task.args]
+            task_kwargs = {k: deinstrument(v) for k,v in task.kwargs.items()}
+        else:
+            task_args = []
+            task_kwargs = {}
+        return dict(task=task, task_args=task_args, task_kwargs=task_kwargs)
 
     @expose('jinja:allura:templates/site_admin_task_new.html')
     @without_trailing_slash
@@ -776,4 +794,4 @@ class StatsSiteAdminExtension(SiteAdminExtension):
 
     def update_sidebar_menu(self, links):
         links.append(SitemapEntry('Stats', '/nf/admin/stats',
-            ui_icon=g.icons['stats']))
+                                  ui_icon=g.icons['stats']))
