@@ -18,7 +18,6 @@
 import logging
 import re
 import os
-from random import randint
 from collections import OrderedDict
 from datetime import datetime
 from urllib.parse import urlparse
@@ -26,7 +25,7 @@ import json
 from operator import itemgetter, attrgetter
 import pkg_resources
 
-from tg import tmpl_context as c, app_globals as g, response
+from tg import tmpl_context as c, app_globals as g
 from tg import request
 from paste.deploy.converters import asbool, aslist
 from tg import expose, redirect, flash, validate, config, jsonify
@@ -35,13 +34,12 @@ from webob import exc
 from bson import ObjectId
 from ming.odm.odmsession import ThreadLocalODMSession
 from ming.odm import session
-import PIL
 
 from allura.app import Application, DefaultAdminController, SitemapEntry
 from allura.lib import helpers as h
 from allura import version
 from allura import model as M
-from allura.lib.security import has_access, require_access, is_site_admin
+from allura.lib.security import has_access, require_access
 from allura.lib.widgets import form_fields as ffw
 from allura.lib import exceptions as forge_exc
 from allura.lib import plugin
@@ -97,7 +95,7 @@ class AdminApp(Application):
 
     def is_visible_to(self, user):
         '''Whether the user can view the app.'''
-        return has_access(c.project, 'create')(user=user)
+        return has_access(c.project, 'create', user)
 
     @staticmethod
     def installable_tools_for(project):
@@ -155,10 +153,10 @@ class AdminApp(Application):
             links.append(SitemapEntry('Tools', admin_url + 'tools_moved'))
         if asbool(config.get('bulk_export_enabled', True)):
             links.append(SitemapEntry('Export', admin_url + 'export'))
-        if c.project.is_root and has_access(c.project, 'admin')():
+        if c.project.is_root and has_access(c.project, 'admin'):
             links.append(
                 SitemapEntry('User Permissions', admin_url + 'groups/', className="admin-nav-user-perms"))
-        if not c.project.is_root and has_access(c.project, 'admin')():
+        if not c.project.is_root and has_access(c.project, 'admin'):
             links.append(
                 SitemapEntry('Permissions', admin_url + 'permissions/'))
         if len(c.project.neighborhood_invitations):
@@ -172,7 +170,7 @@ class AdminApp(Application):
 
         for ep_name in sorted(g.entry_points['admin'].keys()):
             admin_extension = g.entry_points['admin'][ep_name]
-            admin_extension().update_project_sidebar_menu(links)
+            links = (admin_extension().update_project_sidebar_menu(links) or links)
 
         return links
 
@@ -300,11 +298,6 @@ class ProjectAdminController(BaseController):
             raise exc.HTTPNotFound(name)
         return app.admin, remainder
 
-    @without_trailing_slash
-    @expose('jinja:allura.ext.admin:templates/project_permissions.html')
-    def groups(self, **kw):
-        return dict()
-
     @expose()
     @require_post()
     @validate(W.metadata_admin, error_handler=overview)
@@ -336,7 +329,7 @@ class ProjectAdminController(BaseController):
             c.project.removal = removal
             c.project.removal_changed_date = datetime.utcnow()
         if 'delete_icon' in kw:
-            M.ProjectFile.query.remove(dict(project_id=c.project._id, category=re.compile(r'^icon')))
+            M.ProjectFile.query.remove(dict(project_id=c.project._id, category={'$regex': r'^icon'}))
             c.project.set_tool_data('allura', icon_original_size=None, icon_sha256=None)
             M.AuditLog.log('remove project icon')
             g.post_event('project_updated')
@@ -415,7 +408,7 @@ class ProjectAdminController(BaseController):
 
         if icon is not None and icon != b'':
             if c.project.icon:
-                M.ProjectFile.query.remove(dict(project_id=c.project._id, category=re.compile(r'^icon')))
+                M.ProjectFile.query.remove(dict(project_id=c.project._id, category={'$regex': r'^icon'}))
             save_icon = c.project.save_icon(icon.filename, icon.file, content_type=icon.type)
             if not save_icon:
                 M.AuditLog.log('could not update project icon')
@@ -1089,6 +1082,14 @@ class GroupsController(BaseController):
     def _check_security(self):
         require_access(c.project, 'admin')
 
+    @expose()
+    def _lookup(self, *remainder):
+        # if a forum/wiki/etc is installed at mount_point 'groups', this allows its tool admin pages to still work
+        # could expand this to other ProjectAdminController paths too.
+        app = c.project.app_instance('groups')
+        if app:
+            return app.admin, remainder
+
     def _index_permissions(self):
         permissions = {
             p: [] for p in c.project.permissions}
