@@ -14,7 +14,6 @@
 #       KIND, either express or implied.  See the License for the
 #       specific language governing permissions and limitations
 #       under the License.
-import tg
 from tg import tmpl_context as c
 
 import ew as ew_core
@@ -28,7 +27,6 @@ from allura.lib.widgets import forms as ff
 from allura.lib.widgets import form_fields as ffw
 
 from bson import ObjectId
-from paste.deploy.converters import aslist
 
 
 class CardField(ew._Jinja2Widget):
@@ -127,7 +125,7 @@ class ScreenshotAdmin(ff.ForgeFormResponsive):
         ff.ForgeForm.defaults,
         enctype='multipart/form-data',
         submit_text='Upload',
-        )
+    )
 
     @property
     def fields(self):
@@ -137,7 +135,7 @@ class ScreenshotAdmin(ff.ForgeFormResponsive):
                           attrs={
                               'accept': 'image/*',
                               'required': 'true',
-                              }),
+                          }),
             ew.InputField(name='caption',
                           field_type="text",
                           label='Caption',
@@ -155,8 +153,8 @@ class FeaturesField(ew.CompoundField):
     fields = [ew.TextField(name='feature', attrs={'style': 'width:89%'})]
 
     def resources(self):
-        yield ew.JSLink('allura/js/jquery-ui-1.13.2.min.js', location='body_top_js')
-        yield ew.CSSLink('allura/css/smoothness/jquery-ui-1.13.2.min.css', compress=False)  # compress will also serve from a different location, breaking image refs
+        yield ew.JSLink('allura/js/jquery-ui.min.js', location='body_top_js')
+        yield ew.CSSLink('allura/css/smoothness/jquery-ui.min.css', compress=False)  # compress will also serve from a different location, breaking image refs
 
 
 class MetadataAdmin(ff.AdminForm):
@@ -222,7 +220,7 @@ class MetadataAdmin(ff.AdminForm):
             field_type="text", label="Google Analytics ID",
             attrs=(dict(placeholder='UA-123456-0', pattern='UA-[0-9]+-[0-9]+')))
         twitter_handle = ew.InputField(
-            field_type="text", label='Twitter Handle',
+            field_type="text", label='X Handle',
             validator=V.TwitterValidator)
 
         facebook_page = ew.InputField(field_type="text", label='Facebook page',
