@@ -17,15 +17,10 @@
 from __future__ import annotations
 
 import re
-
-"""The application's Globals object"""
-
 import logging
-import html
 import hashlib
 import json
 import datetime
-from urllib.parse import urlencode
 from subprocess import Popen, PIPE
 import os
 import time
@@ -66,9 +61,10 @@ from allura.lib.macro import uncacheable_macros_names
 from allura.lib.widgets import analytics
 from allura.lib.security import Credentials
 from allura.lib.solr import MockSOLR, make_solr_from_config
-from allura.model.session import artifact_orm_session
 import six
 
+"""The application's Globals object"""
+
 __all__ = ['Globals']
 
 log = logging.getLogger(__name__)
@@ -95,29 +91,26 @@ class ForgeMarkdown:
                         'markdown_checklist.extension'],
             output_format='html')
 
-    def convert(self, source, render_limit=True):
+    def convert(self, source, render_limit=True) -> Markup:
         if render_limit and len(source) > asint(config.get('markdown_render_max_length', 80000)):
             # if text is too big, markdown can take a long time to process it,
             # so we return it as a plain text
             log.info('Text is too big. Skipping markdown processing')
-            escaped = html.escape(h.really_unicode(source))
-            return Markup('<pre>%s</pre>' % escaped)
+            return Markup('<pre>{}</pre>').format(h.really_unicode(source))
         try:
             return self.make_markdown_instance(**self.forge_ext_kwargs).convert(source)
         except Exception:
             log.info('Invalid markdown: %s  Upwards trace is %s', source,
                      ''.join(traceback.format_stack()), exc_info=True)
-            escaped = h.really_unicode(source)
-            escaped = html.escape(escaped)
             return Markup("""<p><strong>ERROR!</strong> The markdown supplied could not be parsed correctly.
-            Did you forget to surround a code snippet with "~~~~"?</p><pre>%s</pre>""" % escaped)
+            Did you forget to surround a code snippet with "~~~~"?</p><pre>%s</pre>""") % h.really_unicode(source)
 
     @LazyProperty
     def uncacheable_macro_regex(self):
         regex_names = '|'.join(uncacheable_macros_names())
         return re.compile(rf"\[\[\s*({regex_names})\b")
 
-    def cached_convert(self, artifact: MappedClass, field_name: str) -> str:
+    def cached_convert(self, artifact: MappedClass, field_name: str) -> Markup:
         """
         Convert ``artifact.field_name`` markdown source to html, caching
         the result if the render time is greater than the defined threshold.
@@ -139,7 +132,7 @@ class ForgeMarkdown:
         if cache.md5 is not None:
             md5 = hashlib.md5(source_text.encode('utf-8')).hexdigest()
             if cache.md5 == md5 and getattr(cache, 'fix7528', False) == bugfix_rev:
-                return Markup(cache.html)
+                return Markup(cache.html)  # noqa: S704
 
         # Convert the markdown and time the result.
         start = time.time()
@@ -152,7 +145,7 @@ class ForgeMarkdown:
         except ValueError:
             threshold = None
             log.warning('Skipping Markdown caching - The value for config param '
-                     '"markdown_cache_threshold" must be a float.')
+                        '"markdown_cache_threshold" must be a float.')
 
         # Check if contains macro and never cache
         if self.uncacheable_macro_regex.search(source_text):
@@ -182,7 +175,7 @@ class ForgeMarkdown:
                 log.exception('Could not get session for %s', artifact)
             else:
                 with utils.skip_mod_date(artifact.__class__), \
-                     utils.skip_last_updated(artifact.__class__):
+                        utils.skip_last_updated(artifact.__class__):
                     sess.flush(artifact)
         return html
 
@@ -207,13 +200,22 @@ class Globals:
         self.solr_server = aslist(config.get('solr.server'), ',')
         # skip empty strings in case of extra commas
         self.solr_server = [s for s in self.solr_server if s]
+        push_auths = zip(aslist(config.get('solr.user'), ','),
+                         aslist(config.get('solr.pass'), ','))
         self.solr_query_server = config.get('solr.query_server')
+        query_auth = (config.get('solr.query_user'), config.get('solr.query_pass'))
         if self.solr_server:
             self.solr = make_solr_from_config(
-                self.solr_server, self.solr_query_server)
+                self.solr_server, self.solr_query_server,
+                push_servers_auths=push_auths,
+                query_server_auth=query_auth,
+            )
             self.solr_short_timeout = make_solr_from_config(
                 self.solr_server, self.solr_query_server,
-                timeout=int(config.get('solr.short_timeout', 10)))
+                push_servers_auths=push_auths,
+                query_server_auth=query_auth,
+                timeout=int(config.get('solr.short_timeout', 10)),
+            )
         else:  # pragma no cover
             log.warning('Solr config not set; using in-memory MockSOLR')
             self.solr = self.solr_short_timeout = MockSOLR()
@@ -472,12 +474,10 @@ class Globals:
             lexer = pygments.lexers.get_lexer_by_name(lexer, encoding='chardet')
 
         if lexer is None or len(text) >= asint(config.get('scm.view.max_syntax_highlight_bytes', 500000)):
-            # no highlighting, but we should escape, encode, and wrap it in
-            # a <pre>
-            text = html.escape(text)
-            return Markup('<pre>' + text + '</pre>')
+            # no highlighting, but we should wrap it in a <pre> safely
+            return Markup('<pre>{}</pre>').format(text)
         else:
-            return Markup(pygments.highlight(text, lexer, formatter))
+            return Markup(pygments.highlight(text, lexer, formatter))  # noqa: S704
 
     @property
     def markdown(self):
@@ -594,7 +594,7 @@ class Globals:
         return asbool(config['user_profile_url_with_profile_path'])
 
     def user_profile_disabled_tools(self):
-        return aslist(config.get('user_prefs.disabled_tools',''), sep=',')
+        return aslist(config.get('user_prefs.disabled_tools', ''), sep=',')
 
     def app_static(self, resource, app=None):
         base = config['static.url_base']
@@ -672,6 +672,7 @@ class Globals:
     def commit_statuses_enabled(self):
         return asbool(config['scm.commit_statuses'])
 
+
 class Icon:
 
     def __init__(self, css, title=None):
@@ -687,10 +688,10 @@ class Icon:
         if tag == 'a':
             attrs['href'] = '#'
         attrs.update(kw)
-        attrs = ew._Jinja2Widget().j2_attrs(attrs)
+        attrs = ew._Jinja2Widget().j2_attrs(attrs)  # this escapes them
         visible_title = ''
         if show_title:
             visible_title = f'&nbsp;{Markup.escape(title)}'
         closing_tag = f'</{tag}>' if closing_tag else ''
         icon = f'<{tag} {attrs}><i class="{self.css}"></i>{visible_title}{closing_tag}'
-        return Markup(icon)
+        return Markup(icon)  # noqa: S704
