@@ -34,7 +34,7 @@ from allura.lib import helpers as h
 from allura.lib.utils import is_ajax
 from allura import model as M
 import allura.model.repository
-from tg import tmpl_context as c, app_globals as g
+from tg import tmpl_context as c
 
 log = logging.getLogger(__name__)
 
@@ -157,14 +157,7 @@ class LoginRedirectMiddleware:
         is_api_request = environ.get('PATH_INFO', '').startswith('/rest/')
         if status[:3] == '401' and not is_api_request and not is_ajax(Request(environ)):
             login_url = tg.config.get('auth.login_url', '/auth/')
-            if environ['REQUEST_METHOD'] == 'GET':
-                return_to = environ['PATH_INFO']
-                if environ.get('QUERY_STRING'):
-                    return_to += '?' + environ['QUERY_STRING']
-                location = tg.url(login_url, dict(return_to=return_to))
-            else:
-                # Don't try to re-post; the body has been lost.
-                location = tg.url(login_url)
+            location = h.url_return_to(login_url, environ=environ)
             r = exc.HTTPFound(location=location, headers={'X-Robots-Tag': 'noindex,follow'})
             return r(environ, start_response)
         start_response(status, headers, exc_info)
@@ -286,7 +279,8 @@ class SetRequestHostFromConfig:
         #   'HTTP_X_FORWARDED_PROTO' == 'https'
         req = Request(environ)
         try:
-            req.params  # check for malformed unicode or POSTs, this is the first middleware that might trip over it.
+            # check for malformed unicode or POSTs, this is the first middleware that might trip over it:
+            req.params  # noqa: B018
             resp = self.app
         except (UnicodeError, ValueError):
             resp = exc.HTTPBadRequest()
@@ -325,20 +319,22 @@ class AlluraTimerMiddleware(TimerMiddleware):
                   debug_each_call=False),
             Timer('ming', ming.odm.odmsession.ODMSession,
                   'insert_now', 'update_now', 'delete_now',
-                  'find', 'find_and_modify', 'remove', 'update', 'update_if_not_modified',
-                  'aggregate', 'group', 'map_reduce', 'inline_map_reduce', 'distinct',
+                  'find', 'find_one_and_update', 'find_one_and_replace', 'find_one_and_delete',
+                  'remove', 'update', 'update_if_not_modified',
+                  'aggregate', 'distinct',
                   ),
             # Timer('ming', ming.schema.Document, 'validate',
             #       debug_each_call=False),
             # Timer('ming', ming.schema.FancySchemaItem, '_validate_required',
             #       '_validate_fast_missing', '_validate_optional',
             #       debug_each_call=False),
-            Timer('mongo', pymongo.collection.Collection, 'count', 'find',
-                  'find_one', 'aggregate', 'group', 'map_reduce',
-                  'inline_map_reduce', 'find_and_modify',
-                  'insert', 'save', 'update', 'remove', 'drop'),
-            Timer('mongo', pymongo.cursor.Cursor, 'count', 'distinct',
-                  '_refresh'),
+            Timer('mongo', pymongo.collection.Collection, 'find', 'find_one', 'drop',
+                  'update_one', 'update_many', 'insert_one', 'insert_many', 'replace_one',
+                  'delete_one', 'delete_many', 'count_documents', 'estimated_document_count',
+                  'find_one_and_update', 'find_one_and_replace', 'find_one_and_delete'),
+            Timer('mongo', pymongo.cursor.Cursor, 'distinct',
+                  'clone', 'rewind', 'close', 'limit', 'batch_size', 'skip', 'max', 'min',
+                  'sort', 'explain', 'where', 'collation', 'comment', 'hint', '_refresh'),
             # urlopen and socket io may or may not overlap partially
             Timer('repo.Blob.{method_name}', allura.model.repository.Blob, '*'),
             Timer('repo.Commit.{method_name}', allura.model.repository.Commit, '*'),
@@ -456,7 +452,7 @@ class MingTaskSessionSetupMiddleware:
 
     def __call__(self, environ, start_response):
         # this is sufficient to ensure an ODM session is always established
-        session(M.MonQTask).impl
+        session(M.MonQTask).impl  # noqa: B018
         return self.app(environ, start_response)
 
 
@@ -485,19 +481,33 @@ class ContentSecurityPolicyMiddleware:
             rules.add('upgrade-insecure-requests')
 
         if self.config.get('csp.frame_sources'):
+            frame_srcs = self.config['csp.frame_sources']
+            if environ.get('csp_frame_domains'):
+                frame_srcs += ' ' + ' '.join(environ['csp_frame_domains'])
             if asbool(self.config.get('csp.frame_sources_enforce', False)):
-                rules.add(f"frame-src {self.config['csp.frame_sources']}")
+                rules.add(f"frame-src {frame_srcs}")
             else:
-                report_rules.add(f"frame-src {self.config['csp.frame_sources']}")
+                report_rules.add(f"frame-src {frame_srcs}")
+
+        if self.config.get('csp.fenced_frame_sources'):
+            fenced_frame_srcs = self.config['csp.fenced_frame_sources']
+            if asbool(self.config.get('csp.fenced_frame_sources_enforce', False)):
+                rules.add(f"fenced-frame-src {fenced_frame_srcs}")
+            else:
+                report_rules.add(f"fenced-frame-src {fenced_frame_srcs}")
 
         if self.config.get('csp.form_action_urls'):
             srcs = self.config['csp.form_action_urls']
             if environ.get('csp_form_actions'):
                 srcs += ' ' + ' '.join(environ['csp_form_actions'])
-            if asbool(self.config.get('csp.form_actions_enforce', False)):
-                rules.add(f"form-action {srcs}")
-            else:
-                report_rules.add(f"form-action {srcs}")
+
+            oauth_endpoints = (
+                '/auth/oauth2/authorize', '/auth/oauth2/do_authorize', '/rest/oauth/authorize', '/rest/oauth/do_authorize')
+            if not req.path.startswith(oauth_endpoints):  # Do not enforce CSP for OAuth1 and OAuth2 authorization
+                if asbool(self.config.get('csp.form_actions_enforce', False)):
+                    rules.add(f"form-action {srcs}")
+                else:
+                    report_rules.add(f"form-action {srcs}")
 
         if self.config.get('csp.script_src'):
             script_srcs = self.config['csp.script_src']
@@ -512,7 +522,8 @@ class ContentSecurityPolicyMiddleware:
             if asbool(self.config.get('csp.script_src_enforce', False)):
                 rules.add(f"script-src {script_srcs} {self.config.get('csp.script_src.extras','')} 'report-sample'")
             else:
-                report_rules.add(f"script-src {script_srcs} {self.config.get('csp.script_src.extras','')} 'report-sample'")
+                report_rules.add(
+                    f"script-src {script_srcs} {self.config.get('csp.script_src.extras', '')} 'report-sample'")
 
         if self.config.get('csp.script_src_attr'):
             if asbool(self.config.get('csp.script_src_attr_enforce', False)):
@@ -544,11 +555,17 @@ class SetHeadersMiddleware:
         req = Request(environ)
         resp = req.get_response(self.app)
         if self.config.get('permissions_policies', ''):
-            resp.headers.add('Permissions-Policy', f"{self.config['permissions_policies']}")
+            resp.headers.add('Permissions-Policy', self.config['permissions_policies'])
         if self.config.get('features_policies', ''):
-            resp.headers.add('Feature-Policy', f"{self.config['features_policies']}")
+            resp.headers.add('Feature-Policy', self.config['features_policies'])
         if self.config.get('referrer_policy'):
-            resp.headers.add('Referrer-Policy', f"{self.config['referrer_policy']}")
+            resp.headers.add('Referrer-Policy', self.config['referrer_policy'])
+        if self.config.get('cross_origin_opener_policy'):
+            resp.headers.add('Cross-Origin-Opener-Policy', self.config['cross_origin_opener_policy'])
+        if self.config.get('cross_origin_embedder_policy'):
+            resp.headers.add('Cross-Origin-Embedder-Policy', self.config['cross_origin_embedder_policy'])
+        if self.config.get('cross_origin_resource_policy'):
+            resp.headers.add('Cross-Origin-Resource-Policy', self.config['cross_origin_resource_policy'])
         return resp(environ, start_response)
 
 
@@ -577,6 +594,7 @@ def _call_wsgi_application(application, environ):
     """
     captured = []
     output = []
+
     def _start_response(status, headers, exc_info=None):
         captured[:] = [status, headers, exc_info]
         return output.append
@@ -603,6 +621,7 @@ class StatusCodeRedirect:
     purposely return a 401), set
     ``environ['tg.status_code_redirect'] = False`` in the application.
     """
+
     def __init__(self, app, errors=(400, 401, 403, 404),
                  path='/error/document'):
         """Initialize the ErrorRedirect
@@ -622,7 +641,7 @@ class StatusCodeRedirect:
     def __call__(self, environ, start_response):
         status, headers, app_iter, exc_info = _call_wsgi_application(self.app, environ)
         if status[:3] in self.errors and \
-            'tg.status_code_redirect' not in environ and self.error_path:
+                'tg.status_code_redirect' not in environ and self.error_path:
             # Create a response object
             environ['tg.original_response'] = Response(status=status, headerlist=headers, app_iter=app_iter)
             environ['tg.original_request'] = Request(environ)
