@@ -16,10 +16,8 @@
 #       under the License.
 
 import inspect
-import sys
 import json
 import logging
-import six
 from http.cookies import SimpleCookie as Cookie
 from collections import defaultdict
 from urllib.parse import unquote
@@ -38,7 +36,6 @@ from tg import response
 from webob.exc import HTTPFound, WSGIHTTPException
 
 from allura.lib import helpers as h
-from allura.lib import utils
 
 
 log = logging.getLogger(__name__)
@@ -142,7 +139,7 @@ def reconfirm_auth(func, *args, **kwargs):
             session.save()
             kwargs.pop('password', None)
         else:
-            request.validation.errors['password'] = 'Invalid password.'
+            request.validation.errors['password'] = 'Invalid password.'  # noqa: S105
 
     allowed_timedelta = timedelta(seconds=asint(config.get('auth.reconfirm.seconds', 60)))
     last_reconfirm = session.get('auth-reconfirmed', datetime.min)
@@ -245,4 +242,4 @@ def memorable_forget():
             forget(None, ex)
             raise ex
 
-    return _inner
\ No newline at end of file
+    return _inner
