@@ -21,7 +21,6 @@ import sys
 import os
 import os.path
 import difflib
-import jinja2
 
 import urllib.request
 import urllib.parse
@@ -32,26 +31,26 @@ import json
 import logging
 import string
 import random
-import pickle as pickle
 from hashlib import sha1
 from datetime import datetime, timedelta
-from collections import defaultdict, OrderedDict
+from collections import defaultdict
 import shlex
 import socket
-from functools import partial
 from io import BytesIO
 import html
+import http.client
 
 import emoji
 import tg
 import six
 import cchardet as chardet
 import pkg_resources
+import webob
 from formencode.validators import FancyValidator
 from dateutil.parser import parse
 from bson import ObjectId
+from bson.errors import InvalidId
 from paste.deploy import appconfig
-from pymongo.errors import InvalidId
 from contextlib import contextmanager
 from tg import tmpl_context as c, app_globals as g
 from tg import response, request
@@ -59,10 +58,12 @@ from tg.decorators import before_validate
 from formencode.variabledecode import variable_decode
 import formencode
 from markupsafe import Markup
-from jinja2.filters import escape, do_filesizeformat
+from jinja2.filters import escape
+from jinja2.filters import do_filesizeformat  # noqa: F401 RUF100
 from jinja2.utils import pass_context, htmlsafe_json_dumps
 from paste.deploy.converters import asbool, aslist, asint
-from webhelpers2 import date, text
+from webhelpers2 import date
+from webhelpers2 import text  # noqa: F401 RUF100
 from webob.exc import HTTPUnauthorized
 
 from allura.lib import exceptions as exc
@@ -71,10 +72,9 @@ from allura.lib import validators
 import urllib.parse as urlparse
 from urllib.parse import urlencode
 import math
-from webob.multidict import MultiDict
 
 # import to make available to templates, don't delete:
-from .security import has_access, is_allowed_by_role, is_site_admin
+from .security import has_access, is_allowed_by_role, is_site_admin  # noqa: F401 RUF100
 
 
 log = logging.getLogger(__name__)
@@ -239,7 +239,7 @@ def _attempt_encodings(s, encodings):
     for enc in encodings:
         try:
             if enc is None:
-                if six.PY3 and isinstance(s, bytes):
+                if isinstance(s, bytes):
                     # special handling for bytes (avoid b'asdf' turning into "b'asfd'")
                     return s.decode('utf-8')
                 return str(s)  # try default encoding, and handle other types like int, etc
@@ -552,6 +552,20 @@ def absurl(url):
     return host + url
 
 
+def url_return_to(url: str, request: webob.Request | None = None, environ: dict | None = None) -> str:
+    if not environ:
+        environ = request.environ
+    if environ['REQUEST_METHOD'] == 'GET':
+        return_to = environ['PATH_INFO']
+        if environ.get('QUERY_STRING'):
+            return_to += '?' + environ['QUERY_STRING']
+        location = tg.url(url, dict(return_to=return_to))
+    else:
+        # Don't try to re-post; the body has been lost.
+        location = tg.url(url)
+    return location
+
+
 def diff_text(t1, t2, differ=None):
     t1_lines = t1.replace('\r', '').split('\n')
     t2_lines = t2.replace('\r', '').split('\n')
@@ -579,7 +593,7 @@ def diff_text(t1, t2, differ=None):
             result += ['<ins>'] + escape_list(t2_words[j1:j2]) + ['</ins>']
         if tag == 'equal':
             result += escape_list(t1_words[i1:i2])
-    return Markup(' '.join(result).replace('\n', '<br/>\n'))
+    return Markup(' '.join(result).replace('\n', '<br/>\n'))  # noqa: S704
 
 
 def gen_message_id(_id=None):
@@ -786,19 +800,35 @@ def render_any_markup(name, txt, code_mode=False, linenumbers_style=TABLE):
                 txt = _add_table_line_numbers_to_text(txt)
             else:
                 txt = '<pre>%s</pre>' % txt
-    return Markup(txt)
+    return Markup(txt)  # noqa: S704
 
 
 @pass_context
-def subrender_jinja_filter(context, value):
-    _template = context.eval_ctx.environment.from_string(value)
-    result = _template.render(**context)
-    return result
+def subrender_jinja_filter(context, html_tmpl: str) -> Markup:
+    # jinja templates can execute potentially dangerous things
+    #   _template = context.eval_ctx.environment.from_string(html_tmpl)
+    #   return _template.render(**context)
+
+    # so instead, support just a few things
+
+    limited_vars = {
+        '{{ c.project.url() }}': lambda: c.project.url(),
+    }
+    for var, fn in limited_vars.items():
+        if var not in html_tmpl:
+            continue
+        try:
+            val = fn()
+        except Exception:
+            log.exception(f'Could not replace {var} in jinja "subrender" for site notification')
+            continue
+        html_tmpl = html_tmpl.replace(var, val)
+    return clean_html(html_tmpl)
 
 
 def nl2br_jinja_filter(value):
     result = '<br>\n'.join(escape(line) for line in value.split('\n'))
-    return Markup(result)
+    return Markup(result)  # noqa: S704
 
 
 def log_if_changed(artifact, attr, new_val, message):
@@ -938,7 +968,6 @@ def ming_config(**conf):
     :param \*\*conf: keyword arguments defining the new ming configuration
 
     """
-    import ming
     from ming.session import Session
     datastores = Session._datastores
     try:
@@ -1030,15 +1059,38 @@ class exceptionless:
         return inner
 
 
-class NoRedirectToInternal(urllib.request.HTTPRedirectHandler):
-    def redirect_request(self, req: urllib.request.Request, fp, code, msg, headers, newurl: str):
+class NoInternalHTTPSHandler(urllib.request.HTTPSHandler):
+    def https_open(self, req):
         if not asbool(tg.config.get('urlopen_allow_internal_hostnames', 'false')):
-            validators.URLIsPrivate().to_python(newurl, None)
-        return super().redirect_request(req, fp, code, msg, headers, newurl)
+            # check on every open, covers redirects
+            validators.NonPrivateUrl().to_python(req.full_url, None)
+        return super().https_open(req)
 
 
-opener = urllib.request.build_opener(NoRedirectToInternal)
-urllib.request.install_opener(opener)
+class UseKnownIPHTTPConnection(http.client.HTTPConnection):
+    # only for http, since https requires a valid cert it should be ok
+    def __init__(self, *a, known_ip_to_use=None, **kw):
+        super().__init__(*a, **kw)
+        self.known_ip_to_use = known_ip_to_use
+
+    def connect(self):
+        self.host = self.known_ip_to_use
+        super().connect()
+
+
+class NotInternalHTTPHandler(urllib.request.HTTPHandler):
+    def http_open(self, req):
+        if not asbool(tg.config.get('urlopen_allow_internal_hostnames', 'false')):
+            # check on every open, covers redirects
+            ipValidator = validators.NonPrivateUrl()
+            ipValidator.to_python(req.full_url, None)
+            # and force the open to use the known IP
+            return self.do_open(UseKnownIPHTTPConnection, req, known_ip_to_use=str(ipValidator.ip))
+        else:
+            return super().http_open(req)
+
+
+urllib.request.install_opener(urllib.request.build_opener(NotInternalHTTPHandler, NoInternalHTTPSHandler))
 
 
 def urlopen(url: str | urllib.request.Request, retries=3, codes=(408, 500, 502, 503, 504), timeout=None):
@@ -1052,19 +1104,16 @@ def urlopen(url: str | urllib.request.Request, retries=3, codes=(408, 500, 502,
 
     """
     if isinstance(url, urllib.request.Request):
-        url_str =  url.full_url
+        url_str = url.full_url
     else:
         url_str = url
     if not url_str.startswith(('http://', 'https://')):
         raise ValueError(f'URL must be http(s), got {url_str}')
-    if not asbool(tg.config.get('urlopen_allow_internal_hostnames', 'false')):
-        # will raise error if hostname resolves to private address space:
-        validators.URLIsPrivate().to_python(url_str, None)
 
     attempts = 0
     while True:
         try:
-            return urllib.request.urlopen(url, timeout=timeout)
+            return urllib.request.urlopen(url, timeout=timeout)  # noqa: S310
         except OSError as e:
             no_retry = isinstance(e, urllib.error.HTTPError) and e.code not in codes
             if attempts < retries and not no_retry:
@@ -1085,7 +1134,7 @@ def urlopen(url: str | urllib.request.Request, retries=3, codes=(408, 500, 502,
                     body = ''
                 log.exception(
                     'Failed after %s retries on url with a timeout of %s: %s: %s',
-                    attempts, timeout, url_string, body[:250])
+                    attempts, timeout, url_string, body[:500])
                 raise e
 
 
@@ -1359,6 +1408,12 @@ def pluralize_tool_name(tool_name: string, count: int):
         return f"{tool_name}{'s'[:count^1]}"
     return tool_name
 
+
 def parse_fediverse_address(username: str):
     pieces = username.split('@')
     return f'https://{pieces[-1]}/@{pieces[1]}'
+
+
+def clean_html(value: str) -> Markup:
+    from allura.lib.markdown_extensions import HTMLSanitizer
+    return Markup(HTMLSanitizer().run(value))  # noqa: S704
