@@ -29,7 +29,6 @@ import six.moves.urllib.request
 import six.moves.urllib.error
 
 import oembed
-import jinja2
 import markupsafe
 from operator import attrgetter
 from urllib.parse import urlparse, urlunparse
@@ -67,7 +66,7 @@ class macro:
     Decorator to declare a function is a custom markdown macro
     """
 
-    def __init__(self, context: str = None, cacheable: bool = False):
+    def __init__(self, context: str | None = None, cacheable: bool = False):
         """
         :param context: either "neighborhood-wiki" or "userproject-wiki" to limit the macro to be used in those contexts
         :param cacheable: indicates if its ok to cache the macro's output permanently
@@ -103,8 +102,8 @@ class parse:
             return response
         except (ValueError, TypeError) as ex:
             log.warning('macro error.  Upwards stack is %s',
-                     ''.join(traceback.format_stack()),
-                     exc_info=True)
+                        ''.join(traceback.format_stack()),
+                        exc_info=True)
             msg = html.escape(f'[[{s}]] ({repr(ex)})')
             return '\n<div class="error"><pre><code>%s</code></pre></div>' % msg
 
@@ -155,8 +154,8 @@ def neighborhood_blog_posts(max_number=5, sort='timestamp', summary=False):
         ago=h.ago(post.timestamp),
         description=summary and '&nbsp;' or g.markdown.cached_convert(post, 'text')))
         for post in posts if post.app and
-        security.has_access(post, 'read', project=post.app.project)() and
-        security.has_access(post.app.project, 'read', project=post.app.project)())
+        security.has_access(post, 'read', project=post.app.project) and
+        security.has_access(post.app.project, 'read', project=post.app.project))
 
     posts = BlogPosts(posts=output)
     g.resource_manager.register(posts)
@@ -183,8 +182,8 @@ def project_blog_posts(max_number=5, sort='timestamp', summary=False, mount_poin
              author=post.author().display_name,
              ago=h.ago(post.timestamp),
              description=summary and '&nbsp;' or g.markdown.cached_convert(post, 'text'))
-        for post in posts if security.has_access(post, 'read', project=post.app.project)() and
-            security.has_access(post.app.project, 'read', project=post.app.project)()
+        for post in posts if security.has_access(post, 'read', project=post.app.project) and
+        security.has_access(post.app.project, 'read', project=post.app.project)
     ]
     posts = BlogPosts(posts=output)
     g.resource_manager.register(posts)
@@ -287,7 +286,7 @@ def get_projects_for_macro(
         if total is None:
             total = 0
             for p in M.Project.query.find(q):
-                if h.has_access(p, 'read')():
+                if h.has_access(p, 'read'):
                     total = total + 1
         response = '<p class="macro_projects_total">%s Projects</p>%s' % \
             (total, response)
@@ -369,7 +368,7 @@ def include_file(repo, path=None, rev=None, **kw):
     app = parse_repo(repo)
     if not app:
         return '[[include repo %s (not found)]]' % repo
-    if not h.has_access(app.repo, 'read')():
+    if not h.has_access(app.repo, 'read'):
         return "[[include: you don't have a read permission for repo %s]]" % repo
 
     rev = app.repo.head if rev is None else rev
@@ -406,7 +405,7 @@ def include(ref=None, repo=None, **kw):
     artifact = link.ref.artifact
     if artifact is None:
         return '[[include (artifact not found)]]' % ref
-    if not h.has_access(artifact, 'read')():
+    if not h.has_access(artifact, 'read'):
         return "[[include: you don't have a read permission for %s]]" % ref
     included = request.environ.setdefault('allura.macro.included', set())
     if artifact in included:
@@ -506,6 +505,6 @@ def embed(url=None):
                 embed_url = embed_url.geturl()
             embed_url = embed_url.replace('www.youtube.com', 'www.youtube-nocookie.com')
             html.find('iframe')['src'] = embed_url
-        return markupsafe.Markup('<p>%s</p>' % html)
+        return markupsafe.Markup('<p>%s</p>' % html)  # noqa: S704
 
     return '[[embed url=%s]]' % url
