@@ -15,15 +15,16 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
+from __future__ import annotations
 import re
 import logging
-from typing import List
+import warnings
 import xml.etree.ElementTree as etree
 
 from urllib.parse import urljoin
 
 from tg import config
-from bs4 import BeautifulSoup
+from bs4 import BeautifulSoup, MarkupResemblesLocatorWarning
 import html5lib
 import html5lib.serializer
 import html5lib.filters.alphabeticalattributes
@@ -35,7 +36,6 @@ from . import macro
 from . import helpers as h
 from allura import model as M
 from allura.lib.utils import ForgeHTMLSanitizerFilter, is_nofollow_url
-import six
 
 log = logging.getLogger(__name__)
 
@@ -58,7 +58,7 @@ FORGE_LINK_RE = markdown.inlinepatterns.NOIMG + BRK + \
     r'''\(\s*(<.*?>|((?:(?:\(.*?\))|[^\(\)]))*?)\s*((['"])(.*?)\12\s*)?\)'''
 
 
-def clear_markdown_registry(reg: markdown.util.Registry, keep: List[str] = []):
+def clear_markdown_registry(reg: markdown.util.Registry, keep: list[str] = []):
     keep_items = {}
     for name in keep:
         keep_items[name] = reg[name]
@@ -343,7 +343,7 @@ class UserMentionInlinePattern(markdown.inlinepatterns.Pattern):
         if user and not user.pending and not user.disabled:
             result = etree.Element('a')
             result.text = "@%s" % user_name
-            result.set('href', user.url())
+            result.set('href', h.username_project_url(user))
             result.set('class', 'user-mention')
         else:
             result = "@%s" % user_name
@@ -459,7 +459,7 @@ class ForgeLinkTreeProcessor(markdown.treeprocessors.Treeprocessor):
 class MarkAsSafe(markdown.postprocessors.Postprocessor):
 
     def run(self, text):
-        return Markup(text)
+        return Markup(text)  # noqa: S704
 
 
 class AddCustomClass(markdown.postprocessors.Postprocessor):
@@ -473,17 +473,21 @@ class RelativeLinkRewriter(markdown.postprocessors.Postprocessor):
     def __init__(self, make_absolute=False):
         self._make_absolute = make_absolute
 
-    def run(self, text):
-        soup = BeautifulSoup(text,
-                             'html5lib')  # 'html.parser' parser gives weird </li> behaviour with test_macro_members
+    def run(self, text: str):
+        with warnings.catch_warnings():
+            # sometimes short snippets of code (especially escaped html) can trigger this
+            warnings.filterwarnings('ignore', category=MarkupResemblesLocatorWarning)
+
+            soup = BeautifulSoup(text,
+                                 'html5lib')  # 'html.parser' parser gives weird </li> behaviour with test_macro_members
 
         if self._make_absolute:
             rewrite = self._rewrite_abs
         else:
             rewrite = self._rewrite
-        for link in soup.findAll('a'):
+        for link in soup.find_all('a'):
             rewrite(link, 'href')
-        for link in soup.findAll('img'):
+        for link in soup.find_all('img'):
             rewrite(link, 'src')
 
         # html5lib parser adds html/head/body tags, so output <body> without its own tags
