@@ -21,7 +21,6 @@ import html
 import json
 
 import requests
-import jinja2
 import markupsafe
 
 from allura.lib.phone import PhoneService
@@ -58,11 +57,11 @@ class NexmoPhoneService(PhoneService):
             msg = 'Failed sending request to Nexmo'
         if str(code) == '3' and msg.endswith(' number'):
             msg = markupsafe.Markup(
-                '{}{}{}'.format(
-                    html.escape(msg),  # escape it just in case Nexmo sent some HTML we don't want through
-                    '<br>Make sure you include the country code (see examples above)',
-                    '. For US numbers, you must include <code>1-</code> before the area code.' if len(number) == 10 else '',
-                ))
+                '{}{}{}').format(
+                    msg,
+                    markupsafe.Markup('<br>Make sure you include the country code (see examples above)'),
+                    markupsafe.Markup('. For US numbers, you must include <code>1-</code> before the area code.') if len(number) == 10 else '',
+                )
 
         return {'status': 'error', 'error': msg}
 
@@ -75,13 +74,13 @@ class NexmoPhoneService(PhoneService):
         url = urljoin(url, 'json')
         headers = {'Content-Type': 'application/json'}
         params = self.add_common_params(params)
-        log_params = dict(params, api_key='...', api_secret='...')
+        log_params = dict(params, api_key='...', api_secret='...')  # noqa: S106
         if 'number' in log_params:
             log_params['number'] = phone_number_hash(log_params['number'])
         post_params = json.dumps(params, sort_keys=True)
         log.info('PhoneService (nexmo) request: %s %s', url, log_params)
         try:
-            resp = requests.post(url, data=post_params, headers=headers)
+            resp = requests.post(url, data=post_params, headers=headers, timeout=30)
             log.info('PhoneService (nexmo) response: %s', resp.content)
             resp = resp.json()
         except Exception:
@@ -89,7 +88,7 @@ class NexmoPhoneService(PhoneService):
             return self.error()
         if resp.get('status') == '0':
             return self.ok(request_id=resp.get('request_id'))
-        return self.error(code=resp.get('status'), msg=resp.get('error_text'), number=params.get('number',''))
+        return self.error(code=resp.get('status'), msg=resp.get('error_text'), number=params.get('number', ''))
 
     def verify(self, number):
         url = urljoin(self.BASE_URL, 'verify')
