@@ -18,22 +18,27 @@
 '''
 Allura plugins for authentication and project registration
 '''
+from __future__ import annotations
 import re
 import os
 import logging
 import subprocess
 import string
-import crypt
-import random
-from urllib.request import urlopen
+import warnings
+from contextlib import contextmanager
 from urllib.parse import urlparse
 from io import BytesIO
 from random import randint
 from hashlib import sha256
 from base64 import b64encode
 from datetime import datetime, timedelta
+import typing
 import calendar
+
+import passlib.ifc
+import requests
 import six
+from passlib.context import CryptContext
 
 try:
     import ldap
@@ -42,11 +47,12 @@ except ImportError:
     ldap = modlist = None
 import pkg_resources
 import tg
-from tg import config, request, redirect, response, flash
+from tg import config, request, redirect, response
 from tg import tmpl_context as c, app_globals as g
 from webob import exc, Request
-from paste.deploy.converters import asbool, asint
+from paste.deploy.converters import asbool, asint, aslist
 from formencode import validators as fev
+from passlib.registry import get_crypt_handler
 
 from ming.utils import LazyProperty
 from ming.odm import state
@@ -59,6 +65,10 @@ from allura.lib import utils
 from allura.tasks import activity_tasks
 from allura.tasks.index_tasks import solr_del_project_artifacts
 
+if typing.TYPE_CHECKING:
+    from allura.app import SitemapEntry
+    from allura import model as M
+
 log = logging.getLogger(__name__)
 
 
@@ -85,6 +95,16 @@ class AuthenticationProvider:
     multifactor_allowed_urls = [
         '/auth/multifactor',
         '/auth/do_multifactor',
+        '/auth/logout',
+    ]
+    cfg_prefix_pwds = 'auth.password.'
+    default_pwd_algo = 'scrypt'  # noqa: S105
+
+    # for dev only.  these are some of the bootstrap.py users
+    auth_code_bypass_users = [
+        'root',
+        'admin1',
+        'test-user',
     ]
 
     def __init__(self, request):
@@ -115,15 +135,19 @@ class AuthenticationProvider:
         else:
             user = None
 
-        if 'multifactor-username' in self.session and request.path not in self.multifactor_allowed_urls:
-            # ensure any partially completed multifactor login is not left open, if user goes to any other pages
+        if user and not user.is_anonymous() and 'multifactor-username' in self.session:
+            # already logged-in, get rid of the multifactor-username field that'll mess things up later
             del self.session['multifactor-username']
             self.session.save()
+        if 'multifactor-username' in self.session and request.path not in self.multifactor_allowed_urls:
+            # ensure any partially completed multifactor login is not left open, if user goes to any other pages
+            redirect(h.url_return_to(self.multifactor_allowed_urls[0], self.request))
         if user is None:
             return M.User.anonymous()
         if user.disabled or user.pending:
             self.logout()
             return M.User.anonymous()
+
         session_create_date = datetime.utcfromtimestamp(self.session.created)
         if user.is_anonymous():
             sessions_need_reauth = False
@@ -139,15 +163,18 @@ class AuthenticationProvider:
             return M.User.anonymous()
 
         if self.session.get('pwd-expired') and request.path not in self.pwd_expired_allowed_urls:
-            if self.request.environ['REQUEST_METHOD'] == 'GET':
-                return_to = self.request.environ['PATH_INFO']
-                if self.request.environ.get('QUERY_STRING'):
-                    return_to += '?' + self.request.environ['QUERY_STRING']
-                location = tg.url(self.pwd_expired_allowed_urls[0], dict(return_to=return_to))
-            else:
-                # Don't try to re-post; the body has been lost.
-                location = tg.url(self.pwd_expired_allowed_urls[0])
-            redirect(location)
+            redirect(h.url_return_to(self.pwd_expired_allowed_urls[0], self.request))
+
+        # track session for already logged-in users to prevent them from being logged out
+        if user and not user.is_anonymous() and not user.has_active_sessions():
+            user.track_session(self.session.id)
+
+        if asbool(config.get('auth.reject_untracked_sessions', False)) and not user.validate_session(self.session.id):
+            # calling self.logout() would break csrf so we just need to invalidate the session?
+            log.info(f'Session ID is not tracked: {self.session.id}')
+            self.session.invalidate()
+            self.session.save()
+            return M.User.anonymous()
 
         return user
 
@@ -169,13 +196,13 @@ class AuthenticationProvider:
         '''
         raise NotImplementedError('_login')
 
-    def after_login(self, user, request):
+    def after_login(self, user: M.User, request):
         '''
         This is a hook so that custom AuthenticationProviders can do things after a successful login.
         '''
         pass
 
-    def login(self, user=None, multifactor_success=False):
+    def login(self, user: M.User = None, multifactor_success: bool = False) -> M.User | None:
         from allura import model as M
         if user is None:
             try:
@@ -194,13 +221,28 @@ class AuthenticationProvider:
 
         login_details = self.get_login_detail(self.request, user)
 
+        # check if the user doesn't have mfa enabled but is logging in from an unknown location
+        # they'll get an authentication code via email
+        skip_after_login = False
+        if asbool(config.get('auth.email_auth_code.enabled', False)) and not user.get_pref('multifactor') and not self.trusted_login_source(user, login_details) and not multifactor_success:
+            h.auditlog_user('User without MFA attempted to login from untrusted location', user=user)
+            self.session['multifactor-username'] = user.username
+            self.session['mode'] = 'email_code'
+            self.session.save()
+            user.send_email_auth_code()
+            return None
+        else:
+            # Validate if we used an auth code to skip the `after_login` which sends a foreign login email
+            skip_after_login = self.session.get('mode') == 'email_code'
+            self.session.pop('multifactor-username', None)
+            self.session.pop('mode', None)
+
         expire_reason = None
         if self.is_password_expired(user):
             h.auditlog_user('Successful login; Password expired', user=user)
             expire_reason = 'via expiration process'
-        if not expire_reason and 'password' in self.request.params:
-            # password not present with multifactor token; or if login directly after registering is enabled
-            expire_reason = self.login_check_password_change_needed(user, self.request.params['password'],
+        if not expire_reason:
+            expire_reason = self.login_check_password_change_needed(user, self.request.params.get('password'),
                                                                     login_details)
         if expire_reason:
             self.session['pwd-expired'] = True
@@ -209,7 +251,9 @@ class AuthenticationProvider:
         else:
             self.session['username'] = user.username
             h.auditlog_user('Successful login', user=user)
-        self.after_login(user, self.request)
+
+        if not skip_after_login:
+            self.after_login(user, self.request)
 
         if 'rememberme' in self.request.params:
             remember_for = int(config.get('auth.remember_for', 365))
@@ -220,32 +264,52 @@ class AuthenticationProvider:
         g.statsUpdater.addUserLogin(user)
         user.add_login_detail(login_details)
         user.track_login(self.request)
+        user.track_session(self.session.id)
         return user
 
-    def login_check_password_change_needed(self, user, password, login_details):
-        if not self.hibp_password_check_enabled() \
-                or not asbool(tg.config.get('auth.hibp_failure_force_pwd_change', False)):
-            return
+    def login_check_password_change_needed(self, user: M.User, password: str | None, login_details: M.UserLoginDetails) -> str | None:
+        reason = reason_code = None
 
-        try:
-            security.HIBPClient.check_breached_password(password)
-        except security.HIBPClientError as ex:
-            log.error("Error invoking HIBP API", exc_info=ex)
-        except security.HIBPCompromisedCredentials:
-            trusted = False
+        # check setting to force pwd changes after date
+        before = asint(config.get('auth.force_pwd_change_after', 0))
+        if before and self.get_last_password_updated(user) < datetime.utcfromtimestamp(before):
+            reason = 'requiring a password change'
+            reason_code = 'force_pwd_change'
+
+        # check HIBP
+        if (
+            self.hibp_password_check_enabled()
+            and asbool(tg.config.get('auth.hibp_failure_force_pwd_change', False))
+            and password  # not present with multifactor token; or if login directly after registering is enabled
+        ):
             try:
-                trusted = self.trusted_login_source(user, login_details)
+                security.HIBPClient.check_breached_password(password)
+            except security.HIBPClientError as ex:
+                log.error("Error invoking HIBP API", exc_info=ex)
+            except security.HIBPCompromisedCredentials:
+                reason = 'password in HIBP breach database'
+                reason_code = 'hibp'
+
+        # do it
+        if reason:
+
+            # check if we can trust current login
+            trusted: str | False = False
+            if user.get_pref('multifactor'):
+                trusted = 'multifactor success'
+            try:
+                trusted = trusted or self.trusted_login_source(user, login_details)
             except Exception:
                 log.exception('Error checking if login is trusted: %s %s', user.username, login_details)
 
             if trusted:
                 # current user must change password
-                h.auditlog_user('Successful login with password in HIBP breach database, '
-                                'from trusted source (reason: {})'.format(trusted), user=user)
-                return 'hibp'  # reason
+                h.auditlog_user(f'Successful login but {reason}, '
+                                f'from trusted source (reason: {trusted})', user=user)
+                return reason_code
             else:
                 # current user may not continue, must reset password via email
-                h.auditlog_user('Attempted login from untrusted location with password in HIBP breach database',
+                h.auditlog_user(f'Attempted login from untrusted location with {reason}',
                                 user=user)
                 user.send_password_reset_email(subject_tmpl='Update your {site_name} password')
                 raise exc.HTTPBadRequest('To ensure account security, you must reset your password via email.'
@@ -253,16 +317,35 @@ class AuthenticationProvider:
                                          'Please check your email to continue.')
 
     def logout(self):
+        try:
+            user = c.user
+        except AttributeError:
+            pass
+        else:
+            user.untrack_session(self.session.id)
         self.session.invalidate()
         self.session.save()
         response.set_cookie('memorable_forget', '/', secure=request.environ['beaker.session'].secure)
+        # signal to browser to clear saved data
+        response.headers['Clear-Site-Data'] = '"cookies", "storage"'
 
-    def validate_password(self, user, password):
+    def validate_password(self, user: M.User, password: str) -> bool:
+        ok = self._validate_password(user, password)
+        if ok:
+            self.rehash_password_if_needed(user, password)
+        return ok
+
+    def rehash_password_if_needed(self, user: M.User, password: str) -> None:
+        if user.password_algorithm != self._password_algorithm():
+            self.set_password(user, None, password, set_timestamp=False)
+            h.auditlog_user('Rehashed password automatically', user=user)
+
+    def _validate_password(self, user: M.User, password: str) -> bool:
         '''Check that provided password matches actual user password
 
         :rtype: bool
         '''
-        raise NotImplementedError('validate_password')
+        raise NotImplementedError('_validate_password')
 
     def disable_user(self, user, **kw):
         '''Disable user account'''
@@ -288,13 +371,15 @@ class AuthenticationProvider:
         '''
         raise NotImplementedError('by_username')
 
-    def set_password(self, user, old_password, new_password):
+    def set_password(self, user: M.User, old_password: str | None, new_password: str, set_timestamp=True):
         '''
         Set a user's password.
 
-        A provider implementing this method should store the timestamp of this change, either
+        A provider implementing this method should store the timestamp of this change when set_timestamp=True, either
         on ``user.last_password_updated`` or somewhere else that a custom ``get_last_password_updated`` method uses.
 
+        Also should set user.password_algorithm to the password algorithm used.
+
         :param user: a :class:`User <allura.model.auth.User>`
         :rtype: None
         :raises: HTTPUnauthorized if old_password is not valid
@@ -403,7 +488,7 @@ class AuthenticationProvider:
         '''
         return {}
 
-    def is_password_expired(self, user):
+    def is_password_expired(self, user: M.User) -> bool:
         days = asint(config.get('auth.pwdexpire.days', 0))
         before = asint(config.get('auth.pwdexpire.before', 0))
         now = datetime.utcnow()
@@ -474,9 +559,14 @@ class AuthenticationProvider:
             ua=request.headers.get('User-Agent'),
         )
 
-    def trusted_login_source(self, user, login_details):
+    def trusted_login_source(self, user, login_details) -> str | False:
         # TODO: could also factor in User-Agent but hard to know what parts of the UA are meaningful to check here
         from allura import model as M
+
+        if asbool(config['debug']) and (not user.has_active_sessions() or user.username in self.auth_code_bypass_users):
+            # make it easier for dev: if never logged-in, or certain test users, allow.
+            return 'dev access'
+
         for prev_login in M.UserLoginDetails.query.find({'user_id': user._id}):
             if prev_login['ip'] == login_details['ip']:
                 return 'exact ip'
@@ -497,12 +587,54 @@ class AuthenticationProvider:
             validator._messages['invalid'] = 'Usernames only include small letters, numbers, and dashes'
         return validator
 
+    def _passlib_crypt_by_id(self, algorithm: str) -> passlib.ifc.PasswordHash:
+        return get_crypt_handler(algorithm)
+
+    def _encode_password_legacy_sha256(self, password: str, salt: str) -> str:
+        from allura import model as M
+
+        if salt is None:
+            salt = ''.join(chr(randint(1, 0x7f))
+                           for i in range(M.User.SALT_LEN))
+        hashpass = sha256((salt + password).encode('utf-8')).digest()
+        return 'sha256' + salt + six.ensure_text(b64encode(hashpass))
+
+    def _password_algorithm(self) -> str:
+        return config.get(self.cfg_prefix_pwds + 'algorithm', self.default_pwd_algo)
+
+    def _encode_password(self, password: str, salt=None) -> tuple[str, str]:
+        algorithm = self._password_algorithm()
+
+        if algorithm == 'allura_sha256':
+            return self._encode_password_legacy_sha256(password, salt), algorithm
+
+        crypt = self._passlib_crypt_by_id(algorithm)
+
+        passlib_kwargs = dict()
+        if crypt.name.startswith('bcrypt'):
+            passlib_kwargs['truncate_error'] = True
+
+        rounds = config.get(self.cfg_prefix_pwds + 'rounds')
+        if rounds:
+            if int(rounds) < getattr(crypt, 'default_rounds', 0):
+                warnings.warn(f'rounds for {crypt.name} should be at least {crypt.default_rounds}', stacklevel=1)
+            passlib_kwargs['rounds'] = rounds
+
+        salt_len = config.get(self.cfg_prefix_pwds + 'salt_len')
+        if salt_len:
+            passlib_kwargs['salt_size'] = int(salt_len)
+        if salt:
+            if crypt._salt_is_bytes:
+                salt = salt.encode()  # must be bytes
+            passlib_kwargs['salt'] = salt
+        encrypted = crypt.using(**passlib_kwargs).hash(password)
+        return encrypted, algorithm
+
 
 class LocalAuthenticationProvider(AuthenticationProvider):
 
     '''
-    Stores user passwords on the User model, in mongo.  Uses per-user salt and
-    SHA-256 encryption.
+    Stores user password hashes on the User model, in mongo.
     '''
 
     forgotten_password_process = True
@@ -518,7 +650,7 @@ class LocalAuthenticationProvider(AuthenticationProvider):
 
     def _login(self):
         user = self.by_username(self.request.params['username'])
-        if not self._validate_password(user, self.request.params['password']):
+        if not self.validate_password(user, self.request.params['password']):
             raise exc.HTTPUnauthorized()
         return user
 
@@ -546,19 +678,27 @@ class LocalAuthenticationProvider(AuthenticationProvider):
         if kw.get('audit', True):
             h.auditlog_user('Account changed to pending', user=user)
 
-    def validate_password(self, user, password):
-        return self._validate_password(user, password)
-
-    def _validate_password(self, user, password):
+    def _validate_password(self, user: M.User, password) -> bool:
         if user is None:
             return False
         if not user.password:
             return False
-        salt = str(user.password[6:6 + user.SALT_LEN])
-        check = self._encode_password(password, salt)
-        if check != user.password:
-            return False
-        return True
+
+        algorithm = config.get('auth.password.algorithm', self.default_pwd_algo)
+        old_algos = aslist(config.get('auth.password.algorithm.old', 'allura_sha256'))
+
+        if user.password.startswith('sha256') and 'allura_sha256' in old_algos:
+            # legacy.  'allura_sha256' is a custom name for our old logic
+            salt = str(user.password[6:6 + user.SALT_LEN])
+            check = self._encode_password_legacy_sha256(password, salt)
+            return check == user.password
+        else:
+            # https://passlib.readthedocs.io/en/stable/narr/context-tutorial.html#deprecation-hash-migration
+            crypt = CryptContext(
+                schemes=[self._passlib_crypt_by_id(algorithm)],
+                deprecated=[self._passlib_crypt_by_id(algo) for algo in old_algos if algo != 'allura_sha256'],
+            )
+            return crypt.verify(password, user.password)
 
     def by_username(self, username):
         from allura import model as M
@@ -566,25 +706,19 @@ class LocalAuthenticationProvider(AuthenticationProvider):
         escaped_underscore = re.escape('_')  # changes in py3.x versions # https://docs.python.org/3/library/re.html#re.escape
         un = un.replace(escaped_underscore, '[-_]')
         un = un.replace(r'\-', '[-_]')
-        rex = re.compile('^' + un + '$')
-        return M.User.query.get(username=rex, disabled=False, pending=False)
+        rex = r'^' + un + '$'
+        return M.User.query.get(username={'$regex': rex}, disabled=False, pending=False)
 
-    def set_password(self, user, old_password, new_password):
+    def set_password(self, user, old_password, new_password, set_timestamp=True):
         if old_password is not None and not self.validate_password(user, old_password):
             raise exc.HTTPUnauthorized()
         else:
-            user.password = self._encode_password(new_password)
-            user.last_password_updated = datetime.utcnow()
+            user.password, algorithm = self._encode_password(new_password)
+            user.password_algorithm = algorithm
+            if set_timestamp:
+                user.last_password_updated = datetime.utcnow()
             session(user).flush(user)
 
-    def _encode_password(self, password, salt=None):
-        from allura import model as M
-        if salt is None:
-            salt = ''.join(chr(randint(1, 0x7f))
-                           for i in range(M.User.SALT_LEN))
-        hashpass = sha256((salt + password).encode('utf-8')).digest()
-        return 'sha256' + salt + six.ensure_text(b64encode(hashpass))
-
     def user_project_shortname(self, user):
         # "_" isn't valid for subdomains (which project names are used with)
         # so if a username has a "_" we change it to "-"
@@ -629,10 +763,9 @@ class LocalAuthenticationProvider(AuthenticationProvider):
         return d
 
 
-def ldap_conn(who=None, cred=None):
+def ldap_conn_staysopen(who=None, cred=None):
     '''
-    Init & bind a connection with the given creds, or the admin creds if not
-    specified. Remember to unbind the connection when done.
+    You must call .unbind_s() when done with this
     '''
     con = ldap.initialize(config['auth.ldap.server'])
     con.simple_bind_s(who or config['auth.ldap.admin_dn'],
@@ -640,6 +773,19 @@ def ldap_conn(who=None, cred=None):
     return con
 
 
+@contextmanager
+def ldap_conn(who=None, cred=None):
+    '''
+    Init & bind a connection with the given creds, or the admin creds if not
+    specified.
+    '''
+    con = ldap_conn_staysopen(who, cred)
+    try:
+        yield con
+    finally:
+        con.unbind_s()
+
+
 def ldap_user_dn(username):
     'return a Distinguished Name for a given username'
     if not username:
@@ -652,9 +798,13 @@ def ldap_user_dn(username):
 class LdapAuthenticationProvider(AuthenticationProvider):
 
     forgotten_password_process = True
+    cfg_prefix_pwds = 'auth.ldap.password.'
+    default_pwd_algo = 'ldap_pbkdf2_sha512'  # noqa: S105
 
     def register_user(self, user_doc):
         from allura import model as M
+        pwd_hash, algorithm = self._encode_password(user_doc['password'])
+        user_doc['password_algorithm'] = algorithm
         result = M.User(**user_doc)
         if asbool(config.get('auth.ldap.autoregister', True)):
             if asbool(config.get('auth.allow_user_registration', True)):
@@ -667,12 +817,11 @@ class LdapAuthenticationProvider(AuthenticationProvider):
 
         # full registration into LDAP
         uid = str(M.AuthGlobals.get_next_uid()).encode('utf-8')
-        con = ldap_conn()
         uname = user_doc['username'].encode('utf-8')
         display_name = user_doc['display_name'].encode('utf-8')
         ldif_u = modlist.addModlist(dict(
             uid=uname,
-            userPassword=self._encode_password(user_doc['password']),
+            userPassword=pwd_hash,
             objectClass=[b'account', b'posixAccount'],
             cn=display_name,
             uidNumber=uid,
@@ -681,12 +830,12 @@ class LdapAuthenticationProvider(AuthenticationProvider):
             loginShell=b'/bin/bash',
             gecos=uname,
             description=b'SCM user account'))
-        try:
-            con.add_s(ldap_user_dn(user_doc['username']), ldif_u)
-        except ldap.ALREADY_EXISTS:
-            log.exception('Trying to create existing user %s', uname)
-            raise
-        con.unbind_s()
+        with ldap_conn() as con:
+            try:
+                con.add_s(ldap_user_dn(user_doc['username']), ldif_u)
+            except ldap.ALREADY_EXISTS:
+                log.exception('Trying to create existing user %s', uname)
+                raise
 
         if asbool(config.get('auth.ldap.use_schroot', True)):
             argv = ('schroot -d / -c {} -u root /ldap-userconfig.py init {}'.format(
@@ -714,40 +863,43 @@ class LdapAuthenticationProvider(AuthenticationProvider):
                           username, errmsg)
             raise AssertionError(errmsg)
 
-    def _get_salt(self, length):
-        def random_char():
-            return random.choice(string.ascii_uppercase + string.digits)
-        return ''.join(random_char() for i in range(length))
-
-    def _encode_password(self, password, salt=None):
-        cfg_prefix = 'auth.ldap.password.'
-        salt_len = asint(config.get(cfg_prefix + 'salt_len', 16))
-        algorithm = config.get(cfg_prefix + 'algorithm', 6)
-        rounds = asint(config.get(cfg_prefix + 'rounds', 6000))
-        salt = self._get_salt(salt_len) if salt is None else salt
-        encrypted = crypt.crypt(
-            six.ensure_str(password),
-            f'${algorithm}$rounds={rounds}${salt}')
-        return b'{CRYPT}%s' % encrypted.encode('utf-8')
-
     def by_username(self, username):
         from allura import model as M
         return M.User.query.get(username=username, disabled=False, pending=False)
 
-    def set_password(self, user, old_password, new_password):
+    def _passlib_crypt_by_id(self, algorithm: str) -> passlib.ifc.PasswordHash:
+        try:
+            crypt = get_crypt_handler(algorithm)
+        except KeyError:
+            # handle a few old system "crypt" ids.  https://passlib.readthedocs.io/en/stable/modular_crypt_format.html#mcf-identifiers
+            crypt = get_crypt_handler(
+                {
+                    # '1': 'ldap_md5_crypt',   # could support this, but it is super weak
+                    '2b': 'ldap_bcrypt',
+                    '5': 'ldap_sha256_crypt',
+                    '6': 'ldap_sha512_crypt',
+                }[algorithm]
+            )
+        else:
+            if not algorithm.startswith('ldap_'):
+                raise ValueError(f'LDAP algorithms should always start with ldap_ (got {algorithm})')
+        return crypt
+
+    def set_password(self, user, old_password, new_password, set_timestamp=True):
         dn = ldap_user_dn(user.username)
-        if old_password:
+        if old_password is not None:
             ldap_ident = dn
             ldap_pass = old_password.encode('utf-8')
         else:
             ldap_ident = ldap_pass = None
         try:
-            con = ldap_conn(ldap_ident, ldap_pass)
-            new_password = self._encode_password(new_password)
-            con.modify_s(
-                dn, [(ldap.MOD_REPLACE, 'userPassword', new_password)])
-            con.unbind_s()
-            user.last_password_updated = datetime.utcnow()
+            new_password, algorithm = self._encode_password(new_password)
+            with ldap_conn(ldap_ident, ldap_pass) as con:
+                con.modify_s(
+                    dn, [(ldap.MOD_REPLACE, 'userPassword', new_password.encode('utf-8'))])
+            if set_timestamp:
+                user.last_password_updated = datetime.utcnow()
+            user.password_algorithm = algorithm
             session(user).flush(user)
         except ldap.INVALID_CREDENTIALS:
             raise exc.HTTPUnauthorized()
@@ -761,7 +913,7 @@ class LdapAuthenticationProvider(AuthenticationProvider):
             username = str(self.request.params['username'])
         except UnicodeEncodeError:
             raise exc.HTTPBadRequest('Unicode is not allowed in usernames')
-        if not self._validate_password(username, self.request.params['password']):
+        if not self._validate_password_username(username, self.request.params['password']):
             raise exc.HTTPUnauthorized()
         user = M.User.query.get(username=username)
         if user is None:
@@ -775,25 +927,25 @@ class LdapAuthenticationProvider(AuthenticationProvider):
             else:
                 log.debug(f'LdapAuth: no user {username} found in local mongo')
                 raise exc.HTTPUnauthorized()
-        elif user.disabled or user.pending:
+        else:
+            self.rehash_password_if_needed(user, self.request.params['password'])
+        if user.disabled or user.pending:
             log.debug(f'LdapAuth: user {username} is disabled or pending in Allura')
             raise exc.HTTPUnauthorized()
         return user
 
-    def validate_password(self, user, password):
-        '''by user'''
-        return self._validate_password(user.username, password)
+    def _validate_password(self, user: M.User, password: str) -> bool:
+        return self._validate_password_username(user.username, password)
 
-    def _validate_password(self, username, password):
-        '''by username'''
+    def _validate_password_username(self, username: str, password: str) -> bool:
         password = h.really_unicode(password).encode('utf-8')
         try:
             ldap_user = ldap_user_dn(username)
         except ValueError:
             return False
         try:
-            con = ldap_conn(ldap_user, password)
-            con.unbind_s()
+            with ldap_conn(ldap_user, password):
+                pass
             return True
         except (ldap.INVALID_CREDENTIALS, ldap.UNWILLING_TO_PERFORM, ldap.NO_SUCH_OBJECT):
             log.debug(f'LdapAuth: could not authenticate {username}', exc_info=True)
@@ -871,7 +1023,7 @@ class ProjectRegistrationProvider:
         limits, and if any are exceeded, raise ProjectRatelimitError.
 
         """
-        if security.has_access(neighborhood, 'admin', user=user)():
+        if security.has_access(neighborhood, 'admin', user=user):
             return
         opt = 'project.rate_limits'
         project_count = len(list(user.my_projects()))
@@ -895,7 +1047,7 @@ class ProjectRegistrationProvider:
         """
         if not asbool(config.get('project.verify_phone')):
             return True
-        if security.has_access(neighborhood, 'admin', user=user)():
+        if security.has_access(neighborhood, 'admin', user=user):
             return True
         admin_in = [p for p in user.my_projects_by_role_name('Admin')
                     if p.neighborhood_id == neighborhood._id]
@@ -991,22 +1143,24 @@ class ProjectRegistrationProvider:
                 "You can't create private projects in the %s neighborhood" %
                 neighborhood.name)
 
-        # Check for project limit creation
-        nb_max_projects = neighborhood.get_max_projects()
-        if nb_max_projects is not None:
-            count = M.Project.query.find(dict(
-                neighborhood_id=neighborhood._id,
-                deleted=False,
-                is_nbhd_project=False,
-            )).count()
-            if count >= nb_max_projects:
-                log.exception('Error registering project %s' % project_name)
-                raise forge_exc.ProjectOverlimitError()
+        if not user_project:  # user-projects should not be subject to these limits
 
-        self.rate_limit(user, neighborhood)
+            # Check for project limit creation
+            nb_max_projects = neighborhood.get_max_projects()
+            if nb_max_projects is not None:
+                count = M.Project.query.find(dict(
+                    neighborhood_id=neighborhood._id,
+                    deleted=False,
+                    is_nbhd_project=False,
+                )).count()
+                if count >= nb_max_projects:
+                    log.exception('Error registering project %s' % project_name)
+                    raise forge_exc.ProjectOverlimitError()
 
-        if not self.phone_verified(user, neighborhood) and not user_project:
-            raise forge_exc.ProjectPhoneVerificationError()
+            self.rate_limit(user, neighborhood)
+
+            if not self.phone_verified(user, neighborhood):
+                raise forge_exc.ProjectPhoneVerificationError()
 
         if user_project and shortname.startswith('u/'):
             check_shortname = shortname.replace('u/', '', 1)
@@ -1115,7 +1269,7 @@ class ProjectRegistrationProvider:
                     troves.append(
                         M.TroveCategory.query.get(trove_cat_id=trove_id)._id)
         if 'icon' in project_template:
-            icon_file = BytesIO(urlopen(project_template['icon']['url']).read())
+            icon_file = BytesIO(requests.get(project_template['icon']['url'], timeout=30).content)
             p.save_icon(project_template['icon']['filename'], icon_file)
 
         if user_project:
@@ -1740,13 +1894,11 @@ class LdapUserPreferencesProvider(UserPreferencesProvider):
             return LocalUserPreferencesProvider().get_pref(user, pref_name)
 
     def _get_pref(self, username, pref_name, multi=False):
-        con = ldap_conn()
-        try:
-            rs = con.search_s(ldap_user_dn(username), ldap.SCOPE_BASE)
-        except ldap.NO_SUCH_OBJECT:
-            rs = []
-        else:
-            con.unbind_s()
+        with ldap_conn() as con:
+            try:
+                rs = con.search_s(ldap_user_dn(username), ldap.SCOPE_BASE)
+            except ldap.NO_SUCH_OBJECT:
+                rs = []
         if not rs:
             log.warning(f'LdapUserPref: No user record found for: {username}')
             return ''
@@ -1767,10 +1919,9 @@ class LdapUserPreferencesProvider(UserPreferencesProvider):
                 ldap_val = [v.encode('utf-8', errors='replace') for v in pref_value]
             else:
                 ldap_val = pref_value.encode('utf-8', errors='replace')
-            con = ldap_conn()
-            con.modify_s(ldap_user_dn(user.username),
-                         [(ldap.MOD_REPLACE, ldap_attr, ldap_val)])
-            con.unbind_s()
+            with ldap_conn() as con:
+                con.modify_s(ldap_user_dn(user.username),
+                             [(ldap.MOD_REPLACE, ldap_attr, ldap_val)])
         else:
             return LocalUserPreferencesProvider().set_pref(user, pref_name, pref_value)
 
@@ -1794,7 +1945,7 @@ class AdminExtension:
 
     project_admin_controllers = {}
 
-    def update_project_sidebar_menu(self, sidebar_links):
+    def update_project_sidebar_menu(self, sidebar_links: list[SitemapEntry]) -> list[SitemapEntry]:
         """
         Implement this function to modify the project sidebar.
         Check `c.project` if you want to limit when this displays
@@ -1805,7 +1956,7 @@ class AdminExtension:
 
         :rtype: ``None``
         """
-        pass
+        return sidebar_links
 
 
 class SiteAdminExtension:
