@@ -18,13 +18,11 @@
 
 import ast
 import re
-import socket
 from logging import getLogger
 
 
 import bson
 import markdown
-import jinja2
 import markupsafe
 from tg import redirect, url
 from tg import tmpl_context as c, app_globals as g
@@ -34,7 +32,6 @@ from pysolr import SolrError
 from allura.lib import helpers as h
 from allura.lib.solr import escape_solr_arg
 from allura.lib.utils import urlencode
-import six
 
 log = getLogger(__name__)
 
@@ -225,7 +222,7 @@ def site_admin_search(model, q, field, **kw):
         # escaping spaces with '\ ' isn't sufficient for display_name_t since its stored as text_general (why??)
         # and wouldn't handle foo@bar.com split on @ either
         # This should work, but doesn't for unknown reasons: q = u'{!term f=%s}%s' % (field, q)
-        q = q.replace(':', r'\:') # Must escape the colon for IPv6 addresses
+        q = q.replace(':', r'\:')  # Must escape the colon for IPv6 addresses
         q = obj.translate_query(f'{field}:({q})', fields)
         kw['q.op'] = 'AND'  # so that all terms within the () are required
     fq = ['type_s:%s' % model.type_s]
@@ -314,12 +311,12 @@ def search_app(q='', fq=None, app=True, **kw):
                 text = h.get_first(m, 'text')
                 if title:
                     title = (markupsafe.escape(title)
-                                   .replace('#ALLURA-HIGHLIGHT-START#', markupsafe.Markup('<strong>'))
-                                   .replace('#ALLURA-HIGHLIGHT-END#', markupsafe.Markup('</strong>')))
+                             .replace('#ALLURA-HIGHLIGHT-START#', markupsafe.Markup('<strong>'))
+                             .replace('#ALLURA-HIGHLIGHT-END#', markupsafe.Markup('</strong>')))
                 if text:
                     text = (markupsafe.escape(text)
-                                  .replace('#ALLURA-HIGHLIGHT-START#', markupsafe.Markup('<strong>'))
-                                  .replace('#ALLURA-HIGHLIGHT-END#', markupsafe.Markup('</strong>')))
+                            .replace('#ALLURA-HIGHLIGHT-START#', markupsafe.Markup('<strong>'))
+                            .replace('#ALLURA-HIGHLIGHT-END#', markupsafe.Markup('</strong>')))
                 doc['title_match'] = title
                 doc['text_match'] = text or h.get_first(doc, 'text')
                 return doc
@@ -409,4 +406,4 @@ def mapped_artifacts_from_index_ids(index_ids, model, objectid_id=True):
     map = {}
     for m in models:
         map[str(m._id)] = m
-    return map
\ No newline at end of file
+    return map
