@@ -14,17 +14,18 @@
 #       KIND, either express or implied.  See the License for the
 #       specific language governing permissions and limitations
 #       under the License.
-
+from __future__ import annotations
 
 import json
 import logging
+from itertools import zip_longest
+from collections.abc import Iterable
 
 from tg import config
 from webob.exc import HTTPRequestEntityTooLarge
 from paste.deploy.converters import asbool
 import pysolr
 from pysolr import SolrError
-import six
 
 from allura.lib.helpers import shlex_split
 
@@ -61,7 +62,10 @@ def escape_solr_arg(term):
     return term
 
 
-def make_solr_from_config(push_servers, query_server=None, **kwargs):
+def make_solr_from_config(push_servers: Iterable[str], query_server: str | None = None,
+                          push_servers_auths: Iterable[tuple[str, str] | None] = (),
+                          query_server_auth: tuple[str, str] | None = None,
+                          **kwargs):
     """
     Make a :class:`Solr <Solr>` instance from config defaults.  Use
     `**kwargs` to override any value
@@ -72,7 +76,7 @@ def make_solr_from_config(push_servers, query_server=None, **kwargs):
         timeout=int(config.get('solr.long_timeout', 60)),
     )
     solr_kwargs.update(kwargs)
-    return Solr(push_servers, query_server, **solr_kwargs)
+    return Solr(push_servers, query_server, push_servers_auths, query_server_auth, **solr_kwargs)
 
 
 class Solr:
@@ -87,13 +91,18 @@ class Solr:
     unless explicitly overridden.
     """
 
-    def __init__(self, push_servers, query_server=None,
+    def __init__(self, push_servers: Iterable[str], query_server: str | None = None,
+                 push_servers_auths: Iterable[tuple[str, str] | None] = (),
+                 query_server_auth: tuple[str, str] | None = None,
                  commit=True, commitWithin=None, **kw):
-        self.push_pool = [pysolr.Solr(s, **kw) for s in push_servers]
+        self.push_pool = [pysolr.Solr(s, auth=auth, **kw)
+                          for s, auth in zip_longest(push_servers, push_servers_auths)]
         if query_server:
-            self.query_server = pysolr.Solr(query_server, **kw)
+            self.query_server = pysolr.Solr(query_server, auth=query_server_auth, **kw)
         else:
             self.query_server = self.push_pool[0]
+            if query_server_auth:
+                self.query_server.auth = query_server_auth
         self._commit = commit
         self.commitWithin = commitWithin
 
@@ -154,6 +163,13 @@ class MockSOLR:
         for o in objects:
             o['text'] = ''.join(o['text'])
             json.dumps(o)  # ensure no errors (since pysolr 3.9+ uses json API to solr)
+            for k in o.keys():
+                if k.endswith(('_i', '_s', '_l', '_t', '_b', '_f', '_d', '_dt', '_ws')):
+                    continue
+                elif k in ('id', 'text', 'title'):
+                    continue
+                else:
+                    raise ValueError(f'Unexpected solr field {k!r}, probably not in schema.xml')
             self.db[o['id']] = o
 
     def commit(self):
