@@ -16,6 +16,7 @@
 #       under the License.
 
 import logging
+import os
 
 from tg import request
 from tg import tmpl_context as c
@@ -25,6 +26,10 @@ from allura.lib import utils
 from allura.lib.spam import SpamFilter
 
 try:
+    if not os.environ.get('PYTHON_AKISMET_TIMEOUT'):
+        # default would be 1 otherwise.  Must be set before import akismet
+        os.environ['PYTHON_AKISMET_TIMEOUT'] = '3'
+
     import akismet
     AKISMET_AVAILABLE = True
 except ImportError:
@@ -35,11 +40,16 @@ log = logging.getLogger(__name__)
 
 
 if AKISMET_AVAILABLE:
-    class AkismetWithoutStartupVerify(akismet.Akismet):
+    class AkismetWithoutStartupVerify(akismet.SyncClient):
         def __init__(self, key=None, blog_url=None):
             # avoid possible errors at instantiation time, will encounter them later
             self.api_key = key
             self.blog_url = blog_url
+            self._config = akismet.Config(key=key, url=blog_url)
+            akismet_client = akismet.SyncClient(config=self._config)
+            self._http_client = akismet_client._http_client
+            if not akismet_client.verify_key(self._config.key, self._config.url):
+                raise Exception('Akismet key verification failed')
 
 
 class AkismetSpamFilter(SpamFilter):
@@ -95,9 +105,6 @@ class AkismetSpamFilter(SpamFilter):
                 except IndexError:
                     log.debug("couldn't get Snapshot for this artifact %s", artifact)
 
-        # kw will be urlencoded, need to utf8-encode
-        for k, v in list(kw.items()):
-            kw[k] = h.really_unicode(v).encode('utf8')
         return kw
 
     def check(self, text, artifact=None, user=None, content_type='comment', **kw):
@@ -107,7 +114,8 @@ class AkismetSpamFilter(SpamFilter):
                                                          content_type=content_type,
                                                          request=request,
                                                          ))
-        self.record_result(res, artifact, user)
+        spam = res != akismet.CheckResponse.HAM
+        self.record_result(spam, artifact, user)
         return res
 
     def submit_spam(self, text, artifact=None, user=None, content_type='comment'):
