@@ -20,7 +20,6 @@ import base64
 from collections.abc import Iterable, Mapping, MutableMapping
 from contextlib import contextmanager
 import time
-import string
 import hashlib
 import binascii
 import logging.handlers
@@ -29,11 +28,10 @@ import datetime
 import random
 import mimetypes
 import re
-from typing import Type, TypeVar
+from typing import TypeVar
 import magic
 from itertools import groupby
 import operator as op
-import collections
 import ming
 from urllib.parse import urlparse
 import six.moves.urllib.request
@@ -153,9 +151,14 @@ class CustomWatchedFileHandler(logging.handlers.WatchedFileHandler):
         context of a taskd process that is currently processing a task.
 
         """
-        title = getproctitle()
-        if title.startswith('taskd:'):
-            record.name = f"{title}:{record.name}"
+        try:
+            title = getproctitle()
+        except SystemError:
+            # can happen when logging happens during process shutdown
+            pass
+        else:
+            if title.startswith('taskd:'):
+                record.name = f"{title}:{record.name}"
         return super().format(record)
 
 
@@ -201,9 +204,9 @@ def chunked_list(l, n):
 
 
 def chunked_iter(iterable, max_size):
-    '''return iterable 'chunks' from the iterable of max size max_size'''
+    """return iterable 'chunks' from the iterable of max size max_size"""
     eiter = enumerate(iterable)
-    keyfunc = lambda i_x: i_x[0] // max_size
+    def keyfunc(i_x): return i_x[0] // max_size
     for _, chunk in groupby(eiter, keyfunc):
         yield (x for i, x in chunk)
 
@@ -211,10 +214,10 @@ def chunked_iter(iterable, max_size):
 class AntiSpam:
 
     '''Helper class for bot-protecting forms'''
-    honey_field_template = string.Template('''<p class="$honey_class">
-    <label for="$fld_id">You seem to have CSS turned off.
+    honey_field_template = '''<p class="{honey_class}">
+    <label for="{fld_id}">You seem to have CSS turned off.
         Please don't fill out this field.</label><br>
-    <input id="$fld_id" name="$fld_name" type="text"><br></p>''')
+    <input id="{fld_id}" name="{fld_name}" type="text"><br></p>'''
 
     def __init__(self, request=None, num_honey=2, timestamp=None, spinner=None):
         self.num_honey = num_honey
@@ -247,11 +250,11 @@ class AntiSpam:
 
     @staticmethod
     def _wrap(s):
-        '''Encode bytes to make it HTML id-safe (starts with alpha, includes
+        """Encode bytes to make it HTML id-safe (starts with alpha, includes
         only digits, hyphens, underscores, colons, and periods).  Luckily, base64
         encoding doesn't use hyphens, underscores, colons, nor periods, so we'll
         use these characters to replace its plus, slash, equals, and newline.
-        '''
+        """
         s = base64.b64encode(six.ensure_binary(s))
         s = s.rstrip(b'=\n')
         s = s.replace(b'+', b'-').replace(b'/', b'_')
@@ -307,10 +310,10 @@ class AntiSpam:
         for fldno in range(self.num_honey):
             fld_name = self.enc('honey%d' % (fldno))
             fld_id = self.enc('honey%d%d' % (self.counter, fldno))
-            yield Markup(self.honey_field_template.substitute(
+            yield Markup(self.honey_field_template).format(  # noqa: S704
                 honey_class=self.honey_class,
                 fld_id=fld_id,
-                fld_name=fld_name))
+                fld_name=fld_name)
         self.counter += 1
 
     def make_spinner(self, timestamp=None):
@@ -337,7 +340,7 @@ class AntiSpam:
         if params is None:
             params = request.params
         new_params = dict(params)
-        if not request.method == 'GET':
+        if request.method != 'GET':
             obj = None
             try:
                 new_params.pop('timestamp', None)
@@ -396,31 +399,6 @@ class AntiSpam:
         return before_validate(antispam_hook)
 
 
-class TruthyCallable:
-    '''
-    Wraps a callable to make it truthy in a boolean context.
-
-    Assumes the callable returns a truthy value and can be called with no args.
-    '''
-
-    def __init__(self, callable):
-        self.callable = callable
-
-    def __call__(self, *args, **kw):
-        return self.callable(*args, **kw)
-
-    def __bool__(self):
-        return self.callable()
-
-    def __eq__(self, other):
-        if other is True and bool(self):
-            return True
-        elif other is False and not bool(self):
-            return True
-        else:
-            return NotImplemented
-
-
 class TransformedDict(MutableMapping):
 
     """
@@ -461,7 +439,7 @@ class CaseInsensitiveDict(TransformedDict):
 
 def postmortem_hook(etype, value, tb):  # pragma no cover
     import sys
-    import pdb
+    import pdb  # noqa: T100
     import traceback
     sys.stderr.write('Entering post-mortem PDB shell\n')
     traceback.print_exception(etype, value, tb)
@@ -731,6 +709,12 @@ def unique_attachments(attachments):
 def is_ajax(request):
     if request.headers.get('X-Requested-With', None) == 'XMLHttpRequest':
         return True
+    # fetch - see https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-Fetch-Mode
+    if (
+        request.headers.get('Sec-Fetch-Mode', None) in ('cors', 'no-cors', 'same-origin')
+        and request.headers.get('Sec-Fetch-Dest', None) == 'empty'
+    ):
+        return True
     return False
 
 
