@@ -23,7 +23,6 @@ from formencode import validators as fev
 from tg import tmpl_context as c
 from . import helpers as h
 from datetime import datetime
-import six
 from urllib.parse import urlsplit
 from ipaddress import ip_address
 import socket
@@ -48,22 +47,24 @@ class URL(fev.URL):
     ''', re.I | re.VERBOSE)
 
 
-class URLIsPrivate(URL):
-
+class NonPrivateUrl(URL):
+    # prevents private IPs
     def _convert_to_python(self, value, state):
         value = super()._convert_to_python(value, state)
         url_components = urlsplit(value)
         try:
-            host_ip = socket.gethostbyname(url_components.netloc)
+            host_ip = socket.gethostbyname(url_components.hostname)
         except socket.gaierror:
             raise fev.Invalid("Invalid URL.", value, state)
         parse_ip = ip_address(host_ip)
         if parse_ip and parse_ip.is_private:
             raise fev.Invalid("Invalid URL.", value, state)
+        self.ip = parse_ip
         return value
 
 
 class NonHttpUrl(URL):
+    # allows other schemes like svn:// since fev.URL only does http(s)
     messages = {
         'noScheme': 'You must start your URL with a scheme',
     }
@@ -84,6 +85,16 @@ class NonHttpUrl(URL):
     ''', re.I | re.VERBOSE)
 
 
+class HttpsUrl(URL):
+    add_http = False
+
+    def _convert_to_python(self, value, state):
+        value = super()._convert_to_python(value, state)
+        if not value.startswith('https://'):
+            raise fev.Invalid("Must be https://", value, state)
+        return value
+
+
 class UnicodeString(fev.UnicodeString):
     """
     Override UnicodeString to fix bytes handling.
@@ -228,10 +239,11 @@ class UserValidator(fev.FancyValidator):
         return user
 
 
-class AnonymousValidator(fev.FancyValidator):
+class AnonymousValidator(fev.StringBool):
 
     def _convert_to_python(self, value, state):
         from allura.model import User
+        value = super()._convert_to_python(value, state)
         if value:
             if c.user == User.anonymous():
                 raise fe.Invalid('Log in to Mark as Private', value, state)
@@ -334,8 +346,8 @@ class UserMapJsonFile(JsonFile):
         value = super(self.__class__, self)._convert_to_python(value, state)
         try:
             for k, v in value.items():
-                if not(isinstance(k, str) and isinstance(v, str)):
-                    raise
+                if not (isinstance(k, str) and isinstance(v, str)):
+                    raise  # noqa: PLE0704
             return json.dumps(value) if self.as_string else value
         except Exception:
             raise fe.Invalid(
@@ -488,13 +500,15 @@ class IconValidator(fev.FancyValidator):
 
         return value
 
+
 FEDIVERSE_REGEX = r'^@[\w-]+@[\w-]+(\.[\w-]+)+$'
 
+
 class LinkedinValidator(fev.FancyValidator):
     def _convert_to_python(self, value, state):
         if value.startswith('@') and not re.match(FEDIVERSE_REGEX, value):
             value = f'https://linkedin.com/in/{value.replace("@", "")}/'
-        elif 'linkedin.com' not in value:
+        elif not value.startswith('http') or 'linkedin.com' not in value:
             raise fe.Invalid('Invalid Linkedin address', value, state)
         return value
 
@@ -503,7 +517,7 @@ class TwitterValidator(fev.FancyValidator):
     def _convert_to_python(self, value, state):
         if value.startswith('@') and not re.match(FEDIVERSE_REGEX, value):
             value = f'https://twitter.com/{value.replace("@", "")}'
-        elif 'twitter.com' not in value:
+        elif not value.startswith('http') or 'twitter.com' not in value:
             raise fe.Invalid('Invalid Twitter address', value, state)
         return value
 
@@ -512,7 +526,7 @@ class InstagramValidator(fev.FancyValidator):
     def _convert_to_python(self, value, state):
         if value.startswith('@') and not re.match(FEDIVERSE_REGEX, value):
             value = f'https://instagram.com/{value.replace("@", "")}'
-        elif 'instagram.com' not in value:
+        elif not value.startswith('http') or 'instagram.com' not in value:
             raise fe.Invalid('Invalid Instagram address', value, state)
         return value
 
@@ -521,7 +535,7 @@ class FacebookValidator(fev.FancyValidator):
     def _convert_to_python(self, value, state):
         if value.startswith('@') and not re.match(FEDIVERSE_REGEX, value):
             value = f'https://facebook.com/{value.replace("@", "")}'
-        elif 'facebook.com' not in value:
+        elif not value.startswith('http') or 'facebook.com' not in value:
             raise fe.Invalid('Invalid Facebook address', value, state)
         return value
 
@@ -533,7 +547,6 @@ class FediverseValidator(fev.FancyValidator):
             value = f'{url.path.replace("/", "")}@{url.netloc}'
             if not re.match(FEDIVERSE_REGEX, value):
                 raise fe.Invalid('Invalid Mastodon address', value, state)
-        elif not re.match(FEDIVERSE_REGEX , value):
+        elif not re.match(FEDIVERSE_REGEX, value):
             raise fe.Invalid('Invalid Mastodon address', value, state)
         return value
-
