@@ -14,6 +14,7 @@
 #       KIND, either express or implied.  See the License for the
 #       specific language governing permissions and limitations
 #       under the License.
+from __future__ import annotations
 
 from formencode import validators as fev
 
@@ -85,7 +86,7 @@ class ModeratePosts(ew.SimpleForm):
       (function($){
           var tbl = $('form table');
           var checkboxes = $('input[type=checkbox]', tbl);
-          $('a[href=#]', tbl).click(function () {
+          $('a[href="#"]', tbl).click(function () {
               checkboxes.each(function () {
                   if(this.checked) { this.checked = false; }
                   else { this.checked = true; }
@@ -110,17 +111,17 @@ class PostFilter(ff.ForgeForm):
             name='page',
             validator=fev.Int()),
         ew.SingleSelectField(
-                name='status',
-                label='Filter By Status',
-                options=[
-                    ew.Option(py_value='-', label='Any'),
-                    ew.Option(py_value='spam', label='Spam'),
-                    ew.Option(py_value='pending',
-                                label='Pending moderation'),
-                    ew.Option(py_value='ok', label='Ok')],
-                if_missing='pending'),
+            name='status',
+            label='Filter By Status',
+            options=[
+                ew.Option(py_value='-', label='Any'),
+                ew.Option(py_value='spam', label='Spam'),
+                ew.Option(py_value='pending',
+                          label='Pending moderation'),
+                ew.Option(py_value='ok', label='Ok')],
+            if_missing='pending'),
         ew.InputField(name='username',
-                        label='Filter by Username'),
+                      label='Filter by Username'),
         ew.SubmitButton(label='Filter Posts')
     ]
 
