@@ -23,12 +23,10 @@ from tg import request, url
 import json
 import logging
 
-from formencode import validators as fev
 import paginate
 
 import ew as ew_core
 import ew.jinja2_ew as ew
-import six
 
 from allura.lib import validators as v
 
@@ -76,7 +74,7 @@ class LabelEdit(ew.InputField):
             return ','.join(value)
 
     def resources(self):
-        yield ew.JSLink('allura/js/jquery-ui-1.13.2.min.js', location='body_top_js')
+        yield ew.JSLink('allura/js/jquery-ui.min.js', location='body_top_js')
         yield ew.JSLink('js/jquery.tagsinput.js')
         yield ew.CSSLink('css/jquery.tagsinput.css')
         yield onready('''
@@ -123,7 +121,7 @@ class ProjectUserSelect(ew.InputField):
 
     def resources(self):
         yield from super().resources()
-        yield ew.JSLink('allura/js/jquery-ui-1.13.2.min.js', location='body_top_js')
+        yield ew.JSLink('allura/js/jquery-ui.min.js', location='body_top_js')
         yield ew.CSSLink('css/autocomplete.css')  # customized in [6b78ed] so we can't just use jquery-ui.min.css
         yield onready('''
           $('input.project_user_select').autocomplete({
@@ -157,7 +155,7 @@ class ProjectUserCombo(ew.SingleSelectField):
 
     def resources(self):
         yield from super().resources()
-        yield ew.JSLink('allura/js/jquery-ui-1.13.2.min.js', location='body_top_js')
+        yield ew.JSLink('allura/js/jquery-ui.min.js', location='body_top_js')
         yield ew.CSSLink('css/autocomplete.css')  # customized in [6b78ed] so we can't just use jquery-ui.min.css
         yield ew.CSSLink('css/combobox.css')
         yield ew.JSLink('js/combobox.js')
@@ -187,7 +185,7 @@ class NeighborhoodProjectSelect(ew.InputField):
 
     def resources(self):
         yield from super().resources()
-        yield ew.JSLink('allura/js/jquery-ui-1.13.2.min.js', location='body_top_js')
+        yield ew.JSLink('allura/js/jquery-ui.min.js', location='body_top_js')
         yield ew.CSSLink('css/autocomplete.css')  # customized in [6b78ed] so we can't just use jquery-ui.min.css
         yield onready('''
           $('input.neighborhood-project-select').autocomplete({
@@ -380,10 +378,10 @@ class JQueryMixin:
             k: getattr(self, k)
             for k in self.js_params}
         yield onready('''
-$(document).on('clone', function () {
-    $('.%s').%s(%s); });
+$(document).on('clone', function () {{
+    $('.{}').{}({}); }});
 $(document).trigger('clone');
-            ''' % (self.container_cls, self.js_widget_name, json.dumps(opts)))
+            '''.format(self.container_cls, self.js_widget_name, json.dumps(opts)))
 
 
 class SortableRepeatedMixin(JQueryMixin):
@@ -464,8 +462,8 @@ class DateField(JQueryMixin, ew.TextField):
 
     def resources(self):
         yield from super().resources()
-        yield ew.JSLink('allura/js/jquery-ui-1.13.2.min.js', location='body_top_js')
-        yield ew.CSSLink('allura/css/smoothness/jquery-ui-1.13.2.min.css', compress=False)  # compress will also serve from a different location, breaking image refs
+        yield ew.JSLink('allura/js/jquery-ui.min.js', location='body_top_js')
+        yield ew.CSSLink('allura/css/smoothness/jquery-ui.min.css', compress=False)  # compress will also serve from a different location, breaking image refs
 
 
 class FieldCluster(ew.CompoundField):
@@ -503,16 +501,16 @@ class Lightbox(ew_core.Widget):
     def resources(self):
         yield ew.JSLink('js/jquery.lightbox_me.js')
         yield onready('''
-            var $lightbox = $('#lightbox_%s');
-            $('body').on('click', '%s', function(e) {
+            var $lightbox = $('#lightbox_{}');
+            $('body').on('click', '{}', function(e) {{
                 e.preventDefault();
-                $lightbox.lightbox_me(%s);
-            });
-            $lightbox.on('click', '.close', function(e) {
+                $lightbox.lightbox_me({});
+            }});
+            $lightbox.on('click', '.close', function(e) {{
                 e.preventDefault();
                 $lightbox.trigger('close');
-            });
-        ''' % (self.name, self.trigger, self.options))
+            }});
+        '''.format(self.name, self.trigger, self.options))
 
 
 class DisplayOnlyField(ew.HiddenField):
