@@ -16,8 +16,8 @@
 #       under the License.
 
 import logging
-import warnings
 
+import html
 from tg import app_globals as g, tmpl_context as c
 from formencode import validators as fev
 import formencode
@@ -35,8 +35,6 @@ from allura.lib import plugin
 from allura.lib.widgets import form_fields as ffw
 from allura.lib import exceptions as forge_exc
 from allura import model as M
-import six
-from functools import reduce
 
 
 log = logging.getLogger(__name__)
@@ -104,9 +102,7 @@ class ForgeForm(ew.SimpleForm):
             or ctx.get('label')
             or getattr(field, 'label', None)
             or ctx['name'])
-        html = '<label for="{}">{}</label>'.format(
-            ctx['id'], label_text)
-        return Markup(html)
+        return Markup('<label for="{}">{}</label>').format(ctx['id'], label_text)
 
     def context_for(self, field):
         ctx = super().context_for(field)
@@ -118,9 +114,8 @@ class ForgeForm(ew.SimpleForm):
         ctx = self.context_for(field)
         display = field.display(**ctx)
         if ctx['errors'] and field.show_errors and not ignore_errors:
-            display = "{}<div class='error'>{}</div>".format(display,
-                                                             ctx['errors'])
-        return Markup(display)
+            display += Markup("<div class='error'>{}</div>").format(ctx['errors'])
+        return display
 
 
 class ForgeFormResponsive(ForgeForm):
@@ -261,7 +256,7 @@ class PersonalDataForm(ForgeForm):
                         [ew.Option(py_value=c, label=n, selected=False)
                          for c, n in sorted(list(country_names.items()),
                                             key=lambda k_v: k_v[1])],
-                ),
+            ),
             ew.TextField(
                 name='city',
                 label='City of residence',
@@ -621,7 +616,7 @@ class RemoveTroveCategoryForm(ForgeForm):
                         text=cat.fullname,
                         href="/categories/%s" % cat.trove_cat_id),
                     ew.HTMLField(
-                        text=cat.shortname,
+                        text=html.escape(cat.shortname),
                         attrs={'disabled': True, 'value': cat.shortname}),
                     ew.SubmitButton(
                         show_errors=False,
@@ -781,8 +776,8 @@ class RegistrationForm(ForgeForm):
         fields += [
             ew.PasswordField(
                 name='pw',
-                label='New Password',
-                attrs=dict(minlength=asint(tg.config.get('auth.min_password_len', 6)), maxlength=asint(tg.config.get('auth.max_password_len', 30))),
+                label='New Password', attrs=dict(minlength=asint(tg.config.get('auth.min_password_len', 6)),
+                                                 maxlength=asint(tg.config.get('auth.max_password_len', 30))),
                 validator=V.UnicodeString(
                     not_empty=True,
                     min=asint(tg.config.get('auth.min_password_len', 6)),
@@ -840,7 +835,7 @@ class NeighborhoodOverviewForm(ForgeForm):
             validator=V.JsonValidator(if_empty=''))
         icon = ew.FileField(attrs={'accept': 'image/*'})
         tracking_id = ew.TextField(attrs=(dict(placeholder='UA-123456-0', pattern='UA-[0-9]+-[0-9]+')))
-        project_list_url = ew.TextField()
+        project_list_url = ew.TextField(validator=fev.URL(), attrs=dict(type='url'))
         anchored_tools = ffw.AutoResizeTextarea()
         prohibited_tools = ffw.AutoResizeTextarea()
 
@@ -855,32 +850,31 @@ class NeighborhoodOverviewForm(ForgeForm):
 
     def display_field(self, field, ignore_errors=False):
         if field.name == "css" and self.list_color_inputs:
-            display = '<table class="table_class">'
+            display = Markup('<table class="table_class">')
             ctx = self.context_for(field)
             for inp in self.color_inputs:
                 additional_inputs = inp.get('additional', '')
                 empty_val = False
                 if inp['value'] is None or inp['value'] == '':
                     empty_val = True
-                display += '<tr><td class="left"><label>%(label)s</label></td>' \
-                           '<td><input type="checkbox" name="%(ctx_name)s-%(inp_name)s-def" %(def_checked)s>default</td>' \
-                           '<td class="right"><div class="%(ctx_name)s-%(inp_name)s-inp"><table class="input_inner">' \
-                           '<tr><td><input type="text" class="%(inp_type)s" name="%(ctx_name)s-%(inp_name)s" ' \
-                           'value="%(inp_value)s"></td><td>%(inp_additional)s</td></tr></table></div></td></tr>\n' % {
-                               'ctx_name': ctx['name'],
-                               'inp_name': inp['name'],
-                               'inp_value': inp['value'],
-                               'label': inp['label'],
-                               'inp_type': inp['type'],
-                               'def_checked': 'checked="checked"' if empty_val else '',
-                               'inp_additional': additional_inputs}
-            display += '</table>'
+                display += Markup('<tr><td class="left"><label>%(label)s</label></td>'
+                                  '<td><input type="checkbox" name="%(ctx_name)s-%(inp_name)s-def" %(def_checked)s>default</td>'
+                                  '<td class="right"><div class="%(ctx_name)s-%(inp_name)s-inp"><table class="input_inner">'
+                                  '<tr><td><input type="text" class="%(inp_type)s" name="%(ctx_name)s-%(inp_name)s" '
+                                  'value="%(inp_value)s"></td><td>%(inp_additional)s</td></tr></table></div></td></tr>\n') % {
+                    'ctx_name': ctx['name'],
+                    'inp_name': inp['name'],
+                    'inp_value': inp['value'],
+                    'label': inp['label'],
+                    'inp_type': inp['type'],
+                    'def_checked': 'checked="checked"' if empty_val else '',
+                    'inp_additional': additional_inputs}
+            display += Markup('</table>')
 
             if ctx['errors'] and field.show_errors and not ignore_errors:
-                display = "{}<div class='error'>{}</div>".format(display,
-                                                                 ctx['errors'])
+                display += Markup("<div class='error'>{}</div>").format(ctx['errors'])
 
-            return Markup(display)
+            return display
         else:
             return super().display_field(field, ignore_errors)
 
@@ -1116,12 +1110,12 @@ class CsrfForm(ew.SimpleForm):
 
     @property
     def hidden_fields(self):
-        return [ew.HiddenField(name='_session_id')]
+        return [ew.HiddenField(name='_csrf_token')]
 
     def context_for(self, field):
         ctx = super().context_for(field)
-        if field.name == '_session_id':
-            ctx['value'] = tg.request.cookies.get('_session_id') or tg.request.environ['_session_id']
+        if field.name == '_csrf_token':
+            ctx['value'] = tg.request.cookies.get('_csrf_token') or tg.request.environ['_csrf_token']
         return ctx
 
 
