@@ -132,7 +132,7 @@ class SectionBase:
             tmpl = g.jinja2_env.get_template(self.template)
             if not self.context:
                 self.setup_context()
-            return Markup(tmpl.render(self.context))
+            return Markup(tmpl.render(self.context))  # noqa: S704
         except Exception as e:
             log.exception('Error rendering section %s: %s', type(self).__name__, e)
             if asbool(tg.config.get('debug')):
@@ -148,9 +148,9 @@ class ProjectsSectionBase(SectionBase):
             project
             for project in self.user.my_projects()
             if project != c.project
-               and (self.user == c.user or h.has_access(project, 'read'))
-               and not project.is_nbhd_project
-               and not project.is_user_project]
+            and (self.user == c.user or h.has_access(project, 'read'))
+            and not project.is_nbhd_project
+            and not project.is_user_project]
 
     def prepare_context(self, context):
         context['projects'] = self.get_projects()
