@@ -18,14 +18,13 @@
 from __future__ import annotations
 
 import logging
-import calendar
 import typing
 
-import six
 from markupsafe import Markup
 from urllib.parse import urlparse
 from email import header
 from hashlib import sha256
+from collections import deque
 from datetime import timedelta, datetime, time
 import os
 import re
@@ -38,7 +37,6 @@ from tg import config
 from tg import tmpl_context as c, app_globals as g
 from tg import request
 from ming import schema as S
-from ming import Field
 from ming.odm import session, state
 from ming.odm import FieldProperty, RelationProperty, ForeignIdProperty
 from ming.odm.declarative import MappedClass
@@ -50,9 +48,9 @@ from allura.lib import helpers as h
 from allura.lib import plugin
 from allura.lib import utils
 from allura.lib.decorators import memoize
+from allura.lib.multifactor import EmailCodeAuthenticationService
 from allura.lib.search import SearchIndexable
 from .session import main_orm_session, main_explicitflush_orm_session
-from .session import project_orm_session
 from .timeline import ActivityNode, ActivityObject
 
 
@@ -172,14 +170,14 @@ class EmailAddress(MappedClass):
         self.set_nonce_hash()
         log.info('Sending verification link to %s', self.email)
         text = '''
-To verify the email address %s belongs to the user %s,
+To verify the email address {} belongs to the user {},
 please visit the following URL:
 
-%s
-''' % (self.email,
+{}
+'''.format(self.email,
             self.claimed_by_user(include_pending=True).username,
             h.absurl(f'/auth/verify_addr?a={h.urlquote(self.nonce)}'),
-       )
+           )
         log.info('Verification email:\n%s', text)
         allura.tasks.mail_tasks.sendsimplemail.post(
             fromaddr=g.noreply,
@@ -217,9 +215,9 @@ class AuthGlobals(MappedClass):
     @classmethod
     def get_next_uid(cls):
         cls.upsert()
-        g = cls.query.find_and_modify(
-            query={}, update={'$inc': {'next_uid': 1}},
-            new=True)
+        g = cls.query.find_one_and_update(
+            {}, update={'$inc': {'next_uid': 1}},
+            return_document=True)
         return g.next_uid
 
 
@@ -259,8 +257,9 @@ class User(MappedClass, ActivityNode, ActivityObject, SearchIndexable):
     sfx_userid = FieldProperty(S.Deprecated)
     username = FieldProperty(str)
     email_addresses = FieldProperty([str])
-    password = FieldProperty(str)
+    password = FieldProperty(str)  # hashed
     last_password_updated = FieldProperty(datetime)  # to access, use AuthProvider's get_last_password_updated
+    password_algorithm = FieldProperty(str)
     reg_date = FieldProperty(datetime)  # to access, use user.registration_date()
     projects = FieldProperty(S.Deprecated)
     # full mount point: prefs dict
@@ -389,6 +388,29 @@ class User(MappedClass, ActivityNode, ActivityObject, SearchIndexable):
             self.last_access['session_ua'] = user_agent
             session(self).flush(self)
 
+    def track_session(self, session_id):
+        session_ids = deque(self.get_tool_data('web_session', 'ids', []), maxlen=100)
+        if session_id not in session_ids:
+            session_ids.appendleft(session_id)
+            self.set_tool_data('web_session', ids=list(session_ids))
+
+    def untrack_session(self, session_id):
+        session_ids = self.get_tool_data('web_session', 'ids', [])
+        if session_id in session_ids:
+            session_ids.remove(session_id)
+            self.set_tool_data('web_session', ids=session_ids)
+
+    def validate_session(self, session_id):
+        session_ids = self.get_tool_data('web_session', 'ids', [])
+        return session_id in session_ids
+
+    def has_active_sessions(self):
+        """
+        Check if the user has any tracked sessions.
+        """
+        session_ids = self.get_tool_data('web_session', 'ids', [])
+        return bool(session_ids)
+
     def add_login_detail(self, detail):
         try:
             session(detail).flush(detail)
@@ -432,6 +454,17 @@ class User(MappedClass, ActivityNode, ActivityObject, SearchIndexable):
         reset_url = h.absurl(f'/auth/forgotten_password/{hash}')
         return reset_url
 
+    def send_email_auth_code(self, subject_tmpl='{site_name} Authentication Code'):
+        email_address = self.get_pref('email_address')
+        email_auth_code = EmailCodeAuthenticationService().generate_code(self)
+        subject = subject_tmpl.format(site_name=config['site_name'])
+        text = g.jinja2_env.get_template('allura:templates/mail/authentication_code.txt').render(dict(
+            user=self,
+            config=config,
+            email_auth_code=email_auth_code,
+        ))
+        allura.tasks.mail_tasks.send_system_mail_to_user(email_address, subject, text)
+
     def can_send_user_message(self):
         """Return true if User is permitted to send a mesage to another user.
 
@@ -865,6 +898,11 @@ class User(MappedClass, ActivityNode, ActivityObject, SearchIndexable):
         p = plugin.AuthenticationProvider.get(request)
         return p.user_registration_date(self)
 
+    # overriding since the old and new values are not being tracked for changes within a dictionary like preferences
+    #  This will ensure any changes get indexed by solr.
+    def should_update_index(self, old_doc, new_doc):
+        return True
+
 
 class ProjectRole(MappedClass):
     """
@@ -1049,7 +1087,7 @@ class AuditLog(MappedClass):
             for line in
             with_br.split('<br>\n')
         ])
-        return Markup(message_bold)
+        return Markup(message_bold)  # noqa: S704
 
     @property
     def url_str(self):
