@@ -17,15 +17,14 @@
 from __future__ import annotations
 import os
 import logging
+from cgi import FieldStorage
 from datetime import datetime
 import typing
 
-import jinja2
 import markupsafe
 import pymongo
 from pymongo.errors import DuplicateKeyError
 from tg import tmpl_context as c, app_globals as g
-import tg
 
 from ming import schema
 from ming.odm.base import session
@@ -33,10 +32,11 @@ from ming.odm.property import (FieldProperty, RelationProperty,
                                ForeignIdProperty)
 from ming.utils import LazyProperty
 from bson import ObjectId
+from webob import exc
 
 from allura.lib import helpers as h
 from allura.lib import security
-from allura.lib.security import require_access, has_access
+from allura.lib.security import require_access, has_access, is_denied
 from allura.lib import utils
 from allura.model.notification import Notification, Mailbox
 from .artifact import Artifact, ArtifactReference, VersionedArtifact, Snapshot, Message, Feed, ReactableArtifact
@@ -56,7 +56,7 @@ class Discussion(Artifact, ActivityObject):
     class __mongometa__:
         name = 'discussion'
 
-    query: 'Query[Discussion]'
+    query: Query[Discussion]
 
     type_s = 'Discussion'
 
@@ -167,7 +167,7 @@ class Thread(Artifact, ActivityObject):
             ('discussion_id',),
         ]
 
-    query: 'Query[Thread]'
+    query: Query[Thread]
 
     type_s = 'Thread'
 
@@ -335,6 +335,9 @@ class Thread(Artifact, ActivityObject):
              is_meta=False, subscribe=False, **kw):
         if not ignore_security:
             require_access(self, 'post')
+            # check app-level for Blocked Users, in addition to the standard `self` check above
+            if is_denied(self.app, 'post', c.user, self.project):
+                raise exc.HTTPForbidden
         if subscribe:
             self.primary().subscribe()
         if message_id is None:
@@ -403,7 +406,7 @@ class Thread(Artifact, ActivityObject):
             if (has_access(self, 'moderate', u)
                 and Mailbox.subscribed(user_id=u._id,
                                        app_config_id=post.app_config_id)):
-                    n.send_direct(str(u._id))
+                n.send_direct(str(u._id))
 
     def update_stats(self):
         self.num_replies = self.post_class().query.find(
@@ -488,7 +491,7 @@ class PostHistory(Snapshot):
     class __mongometa__:
         name = 'post_history'
 
-    query: 'Query[PostHistory]'
+    query: Query[PostHistory]
 
     artifact_id = ForeignIdProperty('Post')
 
@@ -536,7 +539,7 @@ class Post(Message, VersionedArtifact, ActivityObject, ReactableArtifact):
             ('deleted', 'discussion_id', 'thread_id', 'full_slug'),
         ]
 
-    query: 'Query[Post]'
+    query: Query[Post]
 
     type_s = 'Post'
 
@@ -652,14 +655,14 @@ class Post(Message, VersionedArtifact, ActivityObject, ReactableArtifact):
                     subject = getattr(artifact, 'email_subject', '')
         return subject or '(no subject)'
 
-    def add_multiple_attachments(self, file_info):
+    def add_multiple_attachments(self, file_info: FieldStorage | list[FieldStorage]):
         if isinstance(file_info, list):
             for fi in file_info:
                 self.add_attachment(fi)
         else:
             self.add_attachment(file_info)
 
-    def add_attachment(self, file_info):
+    def add_attachment(self, file_info: FieldStorage):  # webob provides attachments as FieldStorage via legacy-cgi
         if hasattr(file_info, 'file'):
             mime_type = file_info.type
             if not mime_type or '/' not in mime_type:
@@ -858,7 +861,7 @@ class DiscussionAttachment(BaseAttachment):
         polymorphic_identity = 'DiscussionAttachment'
         indexes = ['filename', 'discussion_id', 'thread_id', 'post_id']
 
-    query: 'Query[DiscussionAttachment]'
+    query: Query[DiscussionAttachment]
 
     discussion_id = FieldProperty(schema.ObjectId)
     thread_id = FieldProperty(str)
