@@ -39,7 +39,6 @@ from allura.lib import helpers as h
 
 from .session import main_orm_session
 from .project import Project
-import six
 
 if typing.TYPE_CHECKING:
     from ming.odm.mapper import Query
@@ -93,7 +92,7 @@ class ArtifactReference(MappedClass):
         '''Look up the artifact referenced'''
         aref = self.artifact_reference
         try:
-            cls = loads(bytes(aref.cls))
+            cls = loads(bytes(aref.cls))  # noqa: S301
             with h.push_context(aref.project_id):
                 return cls.query.get(_id=aref.artifact_id)
         except Exception:
@@ -167,11 +166,11 @@ class Shortlink(MappedClass):
     @classmethod
     def from_links(cls, *links):
         '''Convert a sequence of shortlinks to the matching Shortlink objects'''
-        if len(links):
+        if links:
             result = {}
             # Parse all the links
             parsed_links = {link: cls._parse_link(link)
-                                for link in links}
+                            for link in links}
             links_by_artifact = defaultdict(list)
             project_ids = set()
             for link, d in list(parsed_links.items()):
