@@ -27,7 +27,7 @@ from ming.odm.declarative import MappedClass
 from ming.utils import LazyProperty
 
 from tg import request
-from tg import tmpl_context as c, app_globals as g
+from tg import tmpl_context as c
 
 from allura.lib import plugin
 
@@ -145,7 +145,7 @@ class Neighborhood(MappedClass):
         total = 0
 
         for p in M.Project.query.find(q):
-            if h.has_access(p, 'read')():
+            if h.has_access(p, 'read'):
                 total = total + 1
                 if total == 100:
                     return total
