@@ -47,6 +47,9 @@ class OAuthToken(MappedClass):
         session = main_orm_session
         name = 'oauth_token'
         unique_indexes = ['api_key']
+        indexes = [
+            ('user_id'),
+        ]
         polymorphic_on = 'type'
         polymorphic_identity = None
 
@@ -151,6 +154,109 @@ class OAuthAccessToken(OAuthToken):
         return False
 
 
+class OAuth2ClientApp(MappedClass):
+    class __mongometa__:
+        session = main_orm_session
+        name = 'oauth2_client_app'
+        unique_indexes = [
+            ('client_id', 'user_id'),
+            ('client_id')
+        ]
+        indexes = [
+            ('user_id'),
+        ]
+
+    query: 'Query[OAuth2ClientApp]'
+
+    _id = FieldProperty(S.ObjectId)
+    client_id = FieldProperty(str, if_missing=lambda: h.nonce(20))
+    client_secret = FieldProperty(str, if_missing=h.cryptographic_nonce)
+    name = FieldProperty(str)
+    description = FieldProperty(str, if_missing='')
+    description_cache = FieldProperty(MarkdownCache)
+    user_id: ObjectId = AlluraUserProperty(if_missing=lambda: c.user._id)
+    grant_type = FieldProperty(str, if_missing='authorization_code')
+    response_type = FieldProperty(str, if_missing='code')
+    scopes = FieldProperty([str])
+    redirect_uris = FieldProperty([str])
+
+    user = RelationProperty('User')
+
+    @classmethod
+    def for_user(cls, user=None):
+        if user is None:
+            user = c.user
+        return cls.query.find(dict(user_id=user._id)).all()
+
+    @property
+    def description_html(self):
+        return g.markdown.cached_convert(self, 'description')
+
+    def __repr__(self):
+        return f'<{self.__class__.__name__} _id={self._id} client_id={self.client_id} {self.name}>'
+
+
+class OAuth2AuthorizationCode(MappedClass):
+    class __mongometa__:
+        session = main_orm_session
+        name = 'oauth2_authorization_code'
+        unique_indexes = [
+            ('authorization_code', 'client_id', 'user_id'),
+            ('authorization_code')
+        ]
+        indexes = [
+            ('user_id'),
+        ]
+
+    query: 'Query[OAuth2AuthorizationCode]'
+
+    _id = FieldProperty(S.ObjectId)
+    client_id = FieldProperty(str)
+    user_id: ObjectId = AlluraUserProperty(if_missing=lambda: c.user._id)
+    scopes = FieldProperty([str])
+    redirect_uri = FieldProperty(str)
+    authorization_code = FieldProperty(str)
+    expires_at = FieldProperty(S.DateTime)
+    # For PKCE support
+    code_challenge = FieldProperty(str)
+    code_challenge_method = FieldProperty(str)
+
+    user = RelationProperty('User')
+
+
+class OAuth2AccessToken(MappedClass):
+    class __mongometa__:
+        session = main_orm_session
+        name = 'oauth2_access_token'
+        unique_indexes = [
+            ('access_token', 'client_id', 'user_id'),
+            ('access_token')
+        ]
+        custom_indexes = [
+            dict(fields=('refresh_token',), partialFilterExpression={'refresh_token': {'$gt': None}}, unique=True),
+        ]
+        indexes = [
+            ('user_id'),
+        ]
+
+    query: 'Query[OAuth2AccessToken]'
+
+    _id = FieldProperty(S.ObjectId)
+    client_id = FieldProperty(str)
+    user_id: ObjectId = AlluraUserProperty(if_missing=lambda: c.user._id)
+    scopes = FieldProperty([str])
+    access_token = FieldProperty(str)
+    refresh_token = FieldProperty(str)
+    is_bearer = FieldProperty(bool, if_missing=False)
+    expires_at = FieldProperty(S.DateTime)
+    last_access = FieldProperty(datetime)
+
+    user = RelationProperty('User')
+
+    def __repr__(self):
+        return f'<{self.__class__.__name__} _id={self._id} client_id={self.client_id} user_id={self.user_id}>'
+
+
 def dummy_oauths():
     from allura.controllers.rest import Oauth1Validator
     # oauthlib implementation NEEDS these "dummy" values.  If a request comes in with an invalid param, it runs
@@ -172,4 +278,4 @@ def dummy_oauths():
         api_key=Oauth1Validator().dummy_access_token,
         user_id=None,
     )
-    session(dummy_access_tok).flush(dummy_access_tok)
\ No newline at end of file
+    session(dummy_access_tok).flush(dummy_access_tok)
