@@ -161,7 +161,7 @@ class TroveCategory(MappedClass):
 
     @property
     def children(self):
-        return sorted(self.query.find({'fullpath': re.compile('^' + re.escape(self.fullpath) + ' ::')}).all(),
+        return sorted(self.query.find({'fullpath': {'$regex': '^' + re.escape(self.fullpath) + ' ::'}}).all(),
                       key=lambda t: t.fullpath.lower())
 
     @property
@@ -199,6 +199,7 @@ class ProjectNameFieldProperty(FieldProperty):
     Particularly nice if the username and user-project name don't match exactly.
     (This is a python "descriptor")
     """
+
     def __get__(self, instance, cls=None):
         if instance:
             owning_user = instance.user_project_of
@@ -462,6 +463,8 @@ class Project(SearchIndexable, MappedClass, ActivityNode, ActivityObject):
 
     @LazyProperty
     def icon_timestamp(self):
+        if not self.icon:
+            return None
         return timegm(self.icon._id.generation_time.timetuple())
 
     @property
@@ -548,7 +551,7 @@ class Project(SearchIndexable, MappedClass, ActivityNode, ActivityObject):
         return result
 
     def sitemap(self, excluded_tools=None, included_tools=None,
-            tools_only=False, per_tool_limit=SITEMAP_PER_TOOL_LIMIT, xml=False):
+                tools_only=False, per_tool_limit=SITEMAP_PER_TOOL_LIMIT, xml=False):
         """
         Return the project sitemap.
 
@@ -658,7 +661,7 @@ class Project(SearchIndexable, MappedClass, ActivityNode, ActivityObject):
                     'Moderate',
                     "%s_moderate/" % self.neighborhood.url(),
                     ui_icon="tool-admin")
-                })
+            })
             max_ordinal += 1
 
         entries = sorted(entries, key=lambda e: e['ordinal'])
@@ -1441,7 +1444,7 @@ class AppConfig(MappedClass, ActivityObject):
         '''ACL processing should terminate at the AppConfig'''
         return None
 
-    def load(self) -> typing.Type[Application]:
+    def load(self) -> type[Application]:
         """
         :returns: the related :class:`Application <allura.app.Application>` class
         """
