@@ -22,9 +22,9 @@ import bson
 import tg
 import jinja2
 from paste.deploy.converters import asint
-from tg import tmpl_context as c, app_globals as g
+from tg import app_globals as g
 
-from ming.odm import mapper, session, ThreadLocalODMSession
+from ming.odm import session
 from ming.odm.base import ObjectState, state
 
 from allura.lib import utils
@@ -92,7 +92,7 @@ def refresh_repo(repo, all_commits=False, notify=True, new_clone=False, commits_
             if user is not None:
                 g.statsUpdater.newCommit(new, repo.app_config.project, user)
             actor = user or TransientActor(
-                    activity_name=new.committed.name or new.committed.email)
+                activity_name=new.committed.name or new.committed.email)
             g.director.create_activity(actor, 'committed', new, target=repo.app,
                                        related_nodes=[repo.app_config.project],
                                        tags=['commit', repo.tool.lower()])
