@@ -48,7 +48,7 @@ from ming import schema as S
 from ming.odm import session
 from ming import Field, collection, Index
 from ming.utils import LazyProperty
-from ming.odm import FieldProperty, session, Mapper, mapper, MappedClass, RelationProperty
+from ming.odm import FieldProperty, session, Mapper, MappedClass, RelationProperty
 from ming.base import Object
 
 from allura.lib import helpers as h
@@ -747,7 +747,7 @@ class Repository(Artifact, ActivityObject):
     def forks(self):
         all_forks = self.query.find({'upstream_repo.name': self.url()}).all()
         return [fork for fork in all_forks if fork.app_config is not None
-                      and fork.app_config.project is not None]
+                and fork.app_config.project is not None]
 
     def tarball(self, revision, path=None):
         if path:
@@ -861,12 +861,12 @@ class MergeRequest(VersionedArtifact, ActivityObject):
     @LazyProperty
     def downstream_url(self):
         with self.push_downstream_context():
-            return c.app.url
+            return c.app.url if c.app else None
 
     @LazyProperty
     def downstream_repo(self):
         with self.push_downstream_context():
-            return c.app.repo
+            return c.app.repo if c.app else None
 
     def push_downstream_context(self):
         return h.push_context(self.downstream.project_id, self.downstream.mount_point)
@@ -1072,10 +1072,10 @@ class CommitStatus(MappedClass):
 
     @classmethod
     def upsert(cls, **kw):
-        obj = cls.query.find_and_modify(
-            query=dict(commit_id=kw.get('commit_id'), context=kw.get('context')),
+        obj = cls.query.find_one_and_update(
+            dict(commit_id=kw.get('commit_id'), context=kw.get('context')),
             update={'$set': kw},
-            new=True,
+            return_document=True,
             upsert=True,
         )
         return obj
@@ -1610,6 +1610,15 @@ class EmptyBlob(Blob):
     def __bool__(self):
         return False
 
+    def content_type(self):
+        return None
+
+    def content_encoding(self):
+        return None
+
+    def has_html_view(self):
+        return False
+
 
 class Symlink(Blob):
     # maybe this shouldn't inherit from Blob, but its handy for now and works well with git (where symlinks are blobs)
