@@ -179,8 +179,8 @@ class Stats(MappedClass):
             return {}
         entry = self.general[i].messages
         by_type = {el.messagetype: dict(created=el.created,
-                                              modified=el.modified)
-                        for el in entry}
+                                        modified=el.modified)
+                   for el in entry}
         return by_type
 
     def getTicketsByCategory(self):
@@ -506,8 +506,8 @@ class Stats(MappedClass):
 
 def getElementIndex(el_list, **kw):
     for i in range(len(el_list)):
-        for k in kw:
-            if el_list[i].get(k) != kw[k]:
+        for k, v in kw.items():
+            if el_list[i].get(k) != v:
                 break
         else:
             return i
