@@ -209,7 +209,7 @@ $(function(){
     });
 
     $('#site-notification .btn-close').click(function(e) {
-        var $note = $(this).parent();
+        var $note = $(this).parents('section:first');
         $note.hide();
         var note_id = $note.attr('data-notification-id');
         var cookie = $.cookie('site-notification');
@@ -255,7 +255,7 @@ $(function(){
                 url: uri + 'update_markdown',
                 data: {
                     'text' : markdown,
-                    '_session_id' : $.cookie('_session_id')
+                    '_csrf_token' : $.cookie('_csrf_token')
                 },
                 success: callback
             });
