@@ -55,47 +55,23 @@
         $(message).animate({ opacity: 0 }, { duration: 250, queue: false, complete: fadeComplete });
     }
 
-    function scanMessages(container, o) {
-        function helper() {
-            var selector = '.' + o.newClass + '.' + o.messageClass,
-                $msg;
-            // Special support for persistent messages, such as sitewide
-            // notifications; note that this requires the cookie plugin.
-            // Persistent messages are assumed sticky.
-            if ($.cookie && $.cookie(o.persistentCookie)){
-                $msg = $(selector, container).not(o.persistentClass);
-            } else {
-                $msg = $(selector, container);
-            }
-            if ($msg.length) {
-                $msg.prepend(o.closeIcon);
-                $msg.click(function(e) {
-                    if ($.cookie && $msg.hasClass(o.persistentClass)) {
-                        $.cookie(o.persistentCookie, 1, { path: '/' });
-                    }
-                    closer(this, o);
-                });
-                $msg.removeClass(o.newClass).addClass(o.activeClass);
-                $msg.each(function() {
-                    var self = this;
-                    if (!$(self).hasClass(o.stickyClass) && !$(self).hasClass(o.persistentClass)) {
-                        var timer = $(self).attr('data-timer') || o.timer;
-                        setTimeout(function() {
-                            closer($(self), o);
-                        }, timer);
-                    }
-                    $(self).fadeIn(500);
-                });
-            }
-            setTimeout(helper, o.interval);
-        }
-        helper();
-    }
-
     function sanitize(str) {
         return str.replace(/</g, '&lt;').replace(/>/g, '&gt;');
     }
 
+    function displayNotification(el, o){
+        var $el = $(el);
+        $el.addClass(o.activeClass);
+        $el.prepend('<div class="message-closer" aria-label="Close">&times;</div>');
+        $el.fadeIn(500);
+        if (!$el.hasClass(o.persistentClass) && !$el.hasClass(o.stickyClass) && !$el.hasClass('error')) {
+            var timer = $el.attr('data-timer') || o.timer;
+            setTimeout(function() {
+                closer(el, o);
+            }, timer);
+        }
+    }
+
     $.fn.notifier = function(options){
         var opts = $.extend({}, $.fn.notify.defaults, options);
         return $(this).each(function() {
@@ -107,7 +83,11 @@
                 });
             }
             $('.' + o.messageClass, self).addClass(o.newClass);
-            scanMessages(self, o);
+            var selector = '.' + o.newClass + '.' + o.messageClass;
+            $('body').on("click", selector + ' .message-closer', function(e) {
+              closer(this.parentNode, o);
+            });
+            displayNotification($(selector).get(0), o);
         });
     };
 
@@ -136,6 +116,8 @@
                 }
                 var html = tmpl(o.tmpl, o);
                 $(this).append(html);
+                var newMsgEl = $('.message:last-child', this).get(0);
+                displayNotification(newMsgEl, o);
             } else {
                 if (window.console) {
                     //#JSCOVERAGE_IF window.console
@@ -161,7 +143,6 @@
         activeClass: 'notify-active',
         inactiveClass: 'notify-inactive',
         messageClass: 'message',
-        closeIcon: '<b title="Close" class="fa fa-close" style="float:right;"></b>'
     };
 
 }(jQuery));
