@@ -117,8 +117,8 @@ class CreateSitemapFiles(ScriptTask):
                                      'date': p.last_updated.strftime("%Y-%m-%d")})
 
                 except Exception as e:
-                    print("Error creating sitemap for project '%s': %s" %\
-                        (p.shortname, e))
+                    print("Error creating sitemap for project '%s': %s" %
+                          (p.shortname, e))
                 creds.clear()
                 if len(locs) >= options.urls_per_file:
                     write_sitemap(locs[:options.urls_per_file], file_count)
