@@ -19,7 +19,7 @@ import argparse
 import logging
 
 from pymongo.errors import InvalidDocument
-from tg import tmpl_context as c, app_globals as g
+from tg import tmpl_context as c
 
 from allura.scripts import ScriptTask
 from allura import model as M
