@@ -132,7 +132,6 @@ else:
                     pass
             return stderr.getvalue()
 
-
     class DefOptScriptTask(metaclass=MetaDefOpt):
         """Base class for a command-line script that is also executable as a task."""
 
@@ -150,10 +149,12 @@ else:
 
         @classmethod
         def main(cls, **extra_kwargs):
-            return defopt.run(cls.execute, no_negated_flags=True, **extra_kwargs)
+            defopt_params = dict(
+                no_negated_flags=True,
+            ) | extra_kwargs
+            return defopt.run(cls.execute, **defopt_params)
 
         @classmethod
         def execute(cls, *args, **kwargs):
             """User code goes here, using defopt kwargs with type annotations"""
             raise NotImplementedError
-
