@@ -143,7 +143,7 @@ class TracExport:
 
     def csvopen(self, url):
         self.log_url(url)
-        f = urlopen(url)
+        f = urlopen(url)  # noqa: S310
         # Trac doesn't throw 403 error, just shows normal 200 HTML page
         # telling that access denied. So, we'll emulate 403 ourselves.
         # TODO: currently, any non-csv result treated as 403.
@@ -166,14 +166,14 @@ class TracExport:
         html2text.BODY_WIDTH = 0
         url = self.full_url(self.TICKET_URL % id)
         self.log_url(url)
-        d = BeautifulSoup(urlopen(url))
+        d = BeautifulSoup(urlopen(url))  # noqa: S310
         self.clean_missing_wiki_links(d)
         desc = d.find('div', 'description').find('div', 'searchable')
         ticket['description'] = html2text.html2text(
             desc.renderContents('utf8').decode('utf8')) if desc else ''
         comments = []
         relative_base_url = six.moves.urllib.parse.urlparse(self.full_url(self.TICKET_URL % '')).path
-        for comment in d.findAll('form', action='#comment'):
+        for comment in d.find_all('form', action='#comment'):
             c = {}
             c['submitter'] = re.sub(
                 r'.* by ', '', comment.find('h3', 'change').text).strip()
@@ -195,7 +195,7 @@ class TracExport:
         # Scrape HTML to get ticket attachments
         url = self.full_url(self.ATTACHMENT_LIST_URL % id)
         self.log_url(url)
-        f = urlopen(url)
+        f = urlopen(url)  # noqa: S310
         soup = BeautifulSoup(f)
         attach = soup.find('div', id='attachments')
         list = []
@@ -210,7 +210,7 @@ class TracExport:
             d['size'] = int(self.match_pattern(SIZE_PATTERN, size_s))
             timestamp_s = attach.find('a', {'class': 'timeline'})['title']
             d['date'] = self.trac2z_date(self.match_pattern(TIMESTAMP_PATTERN, timestamp_s))
-            d['by'] = attach.find(text=re.compile('added by')).nextSibling.text
+            d['by'] = attach.find(string=re.compile('added by')).nextSibling.text
             d['description'] = ''
             # Skip whitespace
             while attach.nextSibling and isinstance(attach.nextSibling, NavigableString):
@@ -222,7 +222,7 @@ class TracExport:
                 if desc_el:
                     # TODO: Convert to Allura link syntax as needed
                     d['description'] = ''.join(
-                        desc_el.findAll(string=True)).strip()
+                        desc_el.find_all(string=True)).strip()
             list.append(d)
         return list
 
@@ -295,7 +295,7 @@ class TracExport:
     __next__ = next
 
     def clean_missing_wiki_links(self, doc):
-        for link in doc.findAll('a', 'missing wiki'):
+        for link in doc.find_all('a', 'missing wiki'):
             link.string = link.string.rstrip('?')
 
 
