@@ -24,7 +24,6 @@ from ming.odm import session
 
 from allura.lib.decorators import task
 from allura.lib.repository import RepositoryApp
-from allura.lib.utils import skip_mod_date
 import git
 from git import SymbolicReference
 
@@ -179,7 +178,7 @@ def can_merge(merge_request_id):
 def determine_mr_commits(merge_request_id):
     from allura import model as M
     mr = M.MergeRequest.query.get(_id=merge_request_id)
-    mr.commits  # build & cache the commits
+    mr.commits  # noqa: B018  build & cache the commits
 
 
 @task
@@ -192,8 +191,7 @@ def update_head_reference(fs_path, branch_name):
     else:
         # it is detached there's no refs in repo.refs default to first
         repo.head.reference = repo.refs[0]
-        #lookup for new default branch
+        # lookup for new default branch
         new_branch = [ref for ref in repo.refs if ref.name == branch_name]
         _ref = SymbolicReference.create(repo, 'HEAD', repo.head.reference)
         _ref.reference = new_branch[0]
-
