@@ -17,11 +17,13 @@
 
 
 import json
+from datetime import datetime, timedelta
 
-import tg
 from bson import ObjectId
 from tg import app_globals as g
 import mock
+import pytest
+import webtest
 from ming.odm import ThreadLocalODMSession
 from tg import config
 
@@ -46,6 +48,7 @@ class TestRestHome(TestRestApiBase):
         request.params = {'access_token': 'foo'}
         request.scheme = 'https'
         request.path = '/rest/p/test/wiki'
+        request.url = 'https://localhost/rest/p/test/wiki'
         self._patch_token(OAuthAccessToken)
         access_token = OAuthAccessToken.query.get.return_value
         access_token.is_bearer = False
@@ -59,6 +62,7 @@ class TestRestHome(TestRestApiBase):
         request.params = {'access_token': 'foo'}
         request.scheme = 'https'
         request.path = '/rest/p/test/wiki'
+        request.url = 'https://localhost/rest/p/test/wiki'
         self._patch_token(OAuthAccessToken)
         OAuthAccessToken.query.get.return_value = None
         r = self.api_post('/rest/p/test/wiki', access_token='foo', status=401)
@@ -89,6 +93,7 @@ class TestRestHome(TestRestApiBase):
         request.params = {'access_token': access_token.api_key}
         request.scheme = 'https'
         request.path = '/rest/p/test/wiki'
+        request.url = 'https://localhost/rest/p/test/wiki'
         r = self.api_post('/rest/p/test/wiki', access_token='foo')
         assert r.status_int == 200
 
@@ -100,6 +105,7 @@ class TestRestHome(TestRestApiBase):
         }
         request.scheme = 'https'
         request.path = '/rest/p/test/wiki'
+        request.url = 'https://localhost/rest/p/test/wiki'
         self._patch_token(OAuthAccessToken)
         access_token = OAuthAccessToken.query.get.return_value
         access_token.is_bearer = False
@@ -114,6 +120,7 @@ class TestRestHome(TestRestApiBase):
         }
         request.scheme = 'https'
         request.path = '/rest/p/test/wiki'
+        request.url = 'https://localhost/rest/p/test/wiki'
         self._patch_token(OAuthAccessToken)
         OAuthAccessToken.query.get.return_value = None
         r = self.api_post('/rest/p/test/wiki', access_token='foo', status=401)
@@ -147,6 +154,7 @@ class TestRestHome(TestRestApiBase):
         }
         request.scheme = 'https'
         request.path = '/rest/p/test/wiki'
+        request.url = 'https://localhost/rest/p/test/wiki'
         r = self.api_post('/rest/p/test/wiki', access_token='foo', status=200)
         # reverse proxy situation
         request.scheme = 'http'
@@ -322,7 +330,7 @@ class TestRestHome(TestRestApiBase):
                 'title': 'tést'.encode(),
                 'text': 'sometext',
                 'labels': '',
-                })
+            })
         r = self.api_get(h.urlquote('/rest/p/test/wiki/tést/'))
         assert r.status_int == 200
         assert r.json['title'] == 'tést', r.json
@@ -413,6 +421,53 @@ class TestRestHome(TestRestApiBase):
         r = self.app.get('/rest/notification')
         assert r.json == {}
 
+    @td.with_wiki
+    @mock.patch.dict(config, {'auth.oauth2.enabled': True})
+    def test_oauth2_token_authentication(self):
+        # Create a valid access token
+        user = M.User.by_username('test-admin')
+        token = M.OAuth2AccessToken(
+            client_id='client_12345',
+            access_token='ULy1kNFFSCYCscfcoS2oF5Z8i61Mx8',
+            refresh_token='QuoBOJ6CWJlrg0CSXMKDyTezQQHPOP',
+            scopes=[],
+            expires_at=datetime.utcnow() + timedelta(days=1),
+            user_id=user._id
+        )
+        ThreadLocalODMSession.flush_all()
+
+        self.set_api_token(token)
+        r = self.api_get('/rest/p/test/wiki/Home')
+        params = dict(text=r.json['text'])
+        r = self.api_post('/rest/p/test/wiki/Home', params=params)
+        assert r.status_int == 200
+
+        r = self.app.get('/rest/p/test/wiki/Home', params={'access_token': token.access_token}, status=401)
+        assert b'Do not use tokens in URL' in r.body
+
+    @td.with_wiki
+    @mock.patch.dict(config, {'auth.oauth2.enabled': True})
+    def test_oauth2_expired_token_authentication(self):
+        # Create an expired access token
+        user = M.User.by_username('test-admin')
+        token = M.OAuth2AccessToken(
+            client_id='client_12345',
+            access_token='ULy1kNFFSCYCscfcoS2oF5Z8i61Mx8',
+            refresh_token='QuoBOJ6CWJlrg0CSXMKDyTezQQHPOP',
+            scopes=[],
+            expires_at=datetime.utcnow() - timedelta(days=1),
+            user_id=user._id
+        )
+        ThreadLocalODMSession.flush_all()
+
+        self.set_api_token(token)
+        with pytest.raises(webtest.app.AppError) as ex:
+            r = self.api_get('/rest/p/test/wiki/Home')
+            params = dict(text=r.json['text'])
+            r = self.api_post('/rest/p/test/wiki/Home', params=params)
+
+        assert '401 Unauthorized' in str(ex.value)
+
 
 class TestRestNbhdAddProject(TestRestApiBase):
 
@@ -422,9 +477,9 @@ class TestRestNbhdAddProject(TestRestApiBase):
         M.TroveCategory(fullname="Root", trove_cat_id=1, trove_parent_id=0)
         M.TroveCategory(fullname="License", trove_cat_id=2, trove_parent_id=1)
         M.TroveCategory(fullname="Apache License V2.0", fullpath="License :: Apache License V2.0",
-                                     trove_cat_id=4, trove_parent_id=2)
+                        trove_cat_id=4, trove_parent_id=2)
         M.TroveCategory(fullname="Public Domain", fullpath="License :: Public Domain",
-                                      trove_cat_id=5, trove_parent_id=2)
+                        trove_cat_id=5, trove_parent_id=2)
         p_nbhd = M.Neighborhood.query.get(url_prefix='/p/')
         p_nbhd.features['private_projects'] = False
 
@@ -586,7 +641,7 @@ class TestDoap(TestRestApiBase):
         assert user.find(self.foaf + 'name').text == 'Test Admin'
         assert user.find(self.foaf + 'nick').text == 'test-admin'
         assert (list(user.find(self.foaf + 'homepage').items())[0][1] ==
-                     'http://localhost/u/test-admin/')
+                'http://localhost/u/test-admin/')
 
     @td.with_tool('test', 'Tickets', 'bugs')
     @td.with_tool('test', 'Tickets', 'private-bugs')
