@@ -18,7 +18,6 @@
 import json
 import datetime as dt
 import bson
-import pytest
 
 from mock import patch, MagicMock
 from ming.odm import ThreadLocalODMSession
@@ -37,12 +36,10 @@ from allura.lib.plugin import LocalAuthenticationProvider
 class TestSiteAdmin(TestController):
 
     def test_access(self):
-        r = self.app.get('/nf/admin/', extra_environ=dict(
-            username='test-user'), status=403)
+        r = self.app.get('/nf/admin/', extra_environ=dict(username='test-user'), status=403)
 
-        r = self.app.get('/nf/admin/', extra_environ=dict(
-            username='*anonymous'), status=302)
-        r = r.follow()
+        r = self.app.get('/nf/admin/', extra_environ=dict(username='*anonymous'), status=302)
+        r = r.follow(extra_environ=dict(username='*anonymous'))
         assert 'Login' in r
 
     def test_home(self):
@@ -56,7 +53,7 @@ class TestSiteAdmin(TestController):
         assert 'Forge Site Admin' in r.html.find(
             'h2', {'class': 'dark title'}).find('span').contents[0]
         stats_table = r.html.find('table')
-        cells = stats_table.findAll('td')
+        cells = stats_table.find_all('td')
         assert cells[0].contents[0] == 'Adobe', cells[0].contents[0]
 
     def test_tickets_access(self):
@@ -66,14 +63,15 @@ class TestSiteAdmin(TestController):
     def test_new_projects_access(self):
         self.app.get('/nf/admin/new_projects', extra_environ=dict(
             username='test_user'), status=403)
-        r = self.app.get('/nf/admin/new_projects', extra_environ=dict(
-            username='*anonymous'), status=302).follow()
+
+        self.app.extra_environ = {'username': '*anonymous'}
+        r = self.app.get('/nf/admin/new_projects', status=302).follow()
         assert 'Login' in r
 
     def test_new_projects(self):
         r = self.app.get('/nf/admin/new_projects', extra_environ=dict(
             username='root'))
-        headers = r.html.find('table').findAll('th')
+        headers = r.html.find('table').find_all('th')
         assert headers[1].contents[0] == 'Created'
         assert headers[2].contents[0] == 'Shortname'
         assert headers[3].contents[0] == 'Name'
@@ -86,30 +84,30 @@ class TestSiteAdmin(TestController):
         '''Deleted projects should not be visible here'''
         r = self.app.get('/nf/admin/new_projects', extra_environ=dict(
             username='root'))
-        count = len(r.html.find('table').findAll('tr'))
+        count = len(r.html.find('table').find_all('tr'))
         p = M.Project.query.get(shortname='test')
         p.deleted = True
         ThreadLocalODMSession.flush_all()
         r = self.app.get('/nf/admin/new_projects', extra_environ=dict(
             username='root'))
-        assert len(r.html.find('table').findAll('tr')) == count - 1
+        assert len(r.html.find('table').find_all('tr')) == count - 2
 
     def test_new_projects_daterange_filtering(self):
         r = self.app.get('/nf/admin/new_projects', extra_environ=dict(
             username='root'))
-        count = len(r.html.find('table').findAll('tr'))
-        assert count == 7
+        count = len(r.html.find('table').find_all('tr'))
+        assert count == 1 + (6 * 2)   # header, 6 projects with 2 rows each
 
         filtr = r.forms[0]
         filtr['start-dt'] = '2000/01/01 10:10:10'
         filtr['end-dt'] = '2000/01/01 09:09:09'
         r = filtr.submit()
-        count = len(r.html.find('table').findAll('tr'))
+        count = len(r.html.find('table').find_all('tr'))
         assert count == 1  # only row with headers - no results
 
     def test_reclone_repo_access(self):
-        r = self.app.get('/nf/admin/reclone_repo', extra_environ=dict(
-            username='*anonymous'), status=302).follow()
+        self.app.extra_environ = dict(username='*anonymous')
+        r = self.app.get('/nf/admin/reclone_repo', status=302).follow()
         assert 'Login' in r
 
     def test_reclone_repo(self):
@@ -169,7 +167,7 @@ class TestSiteAdmin(TestController):
             user='root',
             path='/p/test/admin',
         ), status=302)
-        task = next(M.MonQTask.query.find({}).sort('_id', -1))
+        task = next(M.MonQTask.query.find({}).sort('_id', 1))
         assert str(task._id) in r.location
         assert task.context['project_id'] == project._id
         assert task.context['app_config_id'] == app.config._id
@@ -181,15 +179,22 @@ class TestSiteAdmin(TestController):
         r = self.app.get('/nf/admin/task_manager/task_doc', params=dict(
             task_name='allura.tests.functional.test_site_admin.test_task'))
         assert json.loads(r.text)['doc'] == 'test_task doc string'
-
+    
+    def test_project_note(self):
+        note_content = 'this is a test note for project'
+        r = self.app.post('/nf/admin/save_project_note', params=dict(shortname='test', note=note_content), status=200)
+        project = M.Project.query.get(shortname='test')
+        assert note_content == project.get_tool_data('notes', 'note')
+        
 
 class TestSiteAdminNotifications(TestController):
 
     def test_site_notifications_access(self):
         self.app.get('/nf/admin/site_notifications', extra_environ=dict(
             username='test_user'), status=403)
-        r = self.app.get('/nf/admin/site_notifications', extra_environ=dict(
-            username='*anonymous'), status=302).follow()
+
+        self.app.extra_environ = dict(username='*anonymous')
+        r = self.app.get('/nf/admin/site_notifications', status=302).follow()
         assert 'Login' in r
 
     def test_site_notifications(self):
@@ -205,8 +210,8 @@ class TestSiteAdminNotifications(TestController):
         r = self.app.get('/nf/admin/site_notifications/', extra_environ=dict(
             username='root'))
         table = r.html.find('table')
-        headers = table.findAll('th')
-        row = table.findAll('td')
+        headers = table.find_all('th')
+        row = table.find_all('td')
 
         assert headers[0].contents[0] == 'Active'
         assert headers[1].contents[0] == 'Impressions'
@@ -332,7 +337,7 @@ class TestSiteAdminNotifications(TestController):
         count = M.notification.SiteNotification.query.find().count()
 
         self.app.post(f'/nf/admin/site_notifications/{note._id}/delete')
-        assert M.notification.SiteNotification.query.find().count() == count -1
+        assert M.notification.SiteNotification.query.find().count() == count - 1
         assert M.notification.SiteNotification.query.get(_id=bson.ObjectId(note._id)) is None
 
 
@@ -373,9 +378,9 @@ class TestProjectsSearch(TestController):
     def test_default_fields(self, search):
         search.site_admin_search.return_value = self.TEST_HIT
         r = self.app.get('/nf/admin/search_projects?q=fake&f=shortname')
-        options = [o['value'] for o in r.html.findAll('option')]
+        options = [o['value'] for o in r.html.find_all('option')]
         assert options == ['shortname', 'name', '__custom__']
-        ths = [th.text for th in r.html.findAll('th')]
+        ths = [th.text for th in r.html.find_all('th')]
         assert ths == ['Short name', 'Full name', 'Registered', 'Deleted?', 'Details']
 
     @patch('allura.controllers.site_admin.search')
@@ -384,9 +389,9 @@ class TestProjectsSearch(TestController):
         with h.push_config(config, **{'search.project.additional_search_fields': 'private, url',
                                       'search.project.additional_display_fields': 'url'}):
             r = self.app.get('/nf/admin/search_projects?q=fake&f=shortname')
-        options = [o['value'] for o in r.html.findAll('option')]
+        options = [o['value'] for o in r.html.find_all('option')]
         assert options == ['shortname', 'name', 'private', 'url', '__custom__']
-        ths = [th.text for th in r.html.findAll('th')]
+        ths = [th.text for th in r.html.find_all('th')]
         assert ths == ['Short name', 'Full name', 'Registered', 'Deleted?', 'url', 'Details']
 
 
@@ -426,11 +431,11 @@ class TestUsersSearch(TestController):
     def test_default_fields(self, site_admin_search):
         site_admin_search.return_value = self.TEST_HIT
         r = self.app.get('/nf/admin/search_users?q=fake&f=username')
-        options = [o['value'] for o in r.html.findAll('option')]
+        options = [o['value'] for o in r.html.find_all('option')]
         assert options == ['username', 'display_name', '__custom__']
-        ths = [th.text for th in r.html.findAll('th')]
+        ths = [th.text for th in r.html.find_all('th')]
         assert ths == ['Username', 'Display name', 'Email', 'Registered',
-                           'Status', 'Details']
+                       'Status', 'Details']
 
     @patch('allura.controllers.site_admin.search.site_admin_search')
     def test_additional_fields(self, site_admin_search):
@@ -438,11 +443,11 @@ class TestUsersSearch(TestController):
         with h.push_config(config, **{'search.user.additional_search_fields': 'email_addresses, url',
                                       'search.user.additional_display_fields': 'url'}):
             r = self.app.get('/nf/admin/search_users?q=fake&f=username')
-        options = [o['value'] for o in r.html.findAll('option')]
+        options = [o['value'] for o in r.html.find_all('option')]
         assert options == ['username', 'display_name', 'email_addresses', 'url', '__custom__']
-        ths = [th.text for th in r.html.findAll('th')]
+        ths = [th.text for th in r.html.find_all('th')]
         assert ths == ['Username', 'Display name', 'Email', 'Registered',
-                           'Status', 'url', 'Details']
+                       'Status', 'url', 'Details']
 
 
 class TestUserDetails(TestController):
@@ -472,8 +477,8 @@ class TestUserDetails(TestController):
         assert 'IP: 7.7.7.7' in r
         assert 'UA: browser of the future 1.1' in r
         # list of projects
-        projects = r.html.findAll('fieldset')[-1]
-        projects = [e.getText() for e in projects.findAll('li')]
+        projects = r.html.find_all('fieldset')[-1]
+        projects = [e.getText() for e in projects.find_all('li')]
         assert 'Test 2\n\u2013\nAdmin\n' in projects
         assert 'Test Project\n\u2013\nAdmin\n' in projects
         assert 'Adobe project 1\n\u2013\nAdmin\n' in projects
@@ -720,9 +725,9 @@ class TestUserDetails(TestController):
         hash = user.get_tool_data('AuthPasswordReset', 'hash')
         text = '''Your username is test-user
 
-To update your password on %s, please visit the following URL:
+To update your password on {}, please visit the following URL:
 
-%s/auth/forgotten_password/%s''' % (config['site_name'], config['base_url'], hash)
+{}/auth/forgotten_password/{}'''.format(config['site_name'], config['base_url'], hash)
         sendmail.post.assert_called_once_with(
             sender='noreply@localhost',
             toaddr='test-user@example.org',
@@ -771,7 +776,7 @@ class TestDeleteProjects(TestController):
             assert confirm_form[f].value == form[f].value
         assert confirm_form['projects'].value == 'p/test    # OK: /p/test/\ndne/dne    # Neighborhood not found'
 
-        confirm_data = r.html.find('table').findAll('td')
+        confirm_data = r.html.find('table').find_all('td')
         assert len(confirm_data) == 4  # 2 projects == 2 rows (2 columns each)
         assert confirm_data[0].getText() == 'p/test'
         assert confirm_data[1].find('a').get('href') == '/p/test/'
@@ -788,7 +793,7 @@ class TestDeleteProjects(TestController):
         r = form.submit()
         expected_href = './?projects=p/test++++%23+OK:+/p/test%0Ap/dne++++%23+Project not found'
         expected_href += '&reason=The+Reason%0AMultiline&disable_users=True'
-        assert r.html.findAll('a', {'href': expected_href}) is not None
+        assert r.html.find_all('a', {'href': expected_href}) is not None
 
     @patch('allura.controllers.site_admin.DeleteProjects', autospec=True)
     def test_reason_passed_to_task(self, dp):
