@@ -21,8 +21,8 @@ Model tests for artifact
 import re
 from datetime import datetime
 
-from tg import tmpl_context as c
-from mock import patch
+from tg import tmpl_context as c, app_globals as g
+from mock import patch, Mock
 import pytest
 from ming.odm.odmsession import ThreadLocalODMSession
 from ming.odm import Mapper
@@ -51,6 +51,8 @@ class Checkmessage(M.Message):
         super().__init__(**kw)
         if self.slug is not None and self.full_slug is None:
             self.full_slug = datetime.utcnow().strftime('%Y%m%d%H%M%S%f') + ':' + self.slug
+
+
 Mapper.compile_all()
 
 
@@ -85,13 +87,13 @@ class TestArtifact:
         pr = M.ProjectRole.by_user(u, upsert=True)
         ThreadLocalODMSession.flush_all()
         REGISTRY.register(allura.credentials, allura.lib.security.Credentials())
-        assert not security.has_access(pg, 'delete')(user=u)
+        assert not security.has_access(pg, 'delete', u)
         pg.acl.append(M.ACE.allow(pr._id, 'delete'))
         ThreadLocalODMSession.flush_all()
-        assert security.has_access(pg, 'delete')(user=u)
+        assert security.has_access(pg, 'delete', u)
         pg.acl.pop()
         ThreadLocalODMSession.flush_all()
-        assert not security.has_access(pg, 'delete')(user=u)
+        assert not security.has_access(pg, 'delete', u)
 
     def test_artifact_index(self):
         pg = WM.Page(title='TestPage1')
@@ -145,6 +147,7 @@ class TestArtifact:
         assert re.match(r'%s.wiki@test.p.localhost' %
                         str(p._id), p.message_id())
 
+    @patch('allura.tasks.mail_tasks.sendmail', Mock())
     def test_versioning(self):
         pg = WM.Page(title='TestPage3')
         with patch('allura.model.artifact.request', Request.blank('/', remote_addr='1.1.1.1')):
@@ -164,13 +167,32 @@ class TestArtifact:
         assert ss.shorthand_id() == pg.shorthand_id() + '#2'
         assert ss.title == pg.title
         assert ss.text == pg.text
-        pytest.raises(IndexError, pg.get_version, 42)
+        with pytest.raises(IndexError):
+            pg.get_version(42)
         pg.revert(1)
         pg.commit()
         ThreadLocalODMSession.flush_all()
         assert ss.text != pg.text
         assert pg.history().count() == 3
 
+        _id = pg._id
+        M.MonQTask.run_ready()
+        assert g.solr.search('id:' + pg.index_id()).hits == 1
+        ph = WM.PageHistory.query.find({'artifact_id': _id, 'version': 2}).first()
+        assert ph
+        ph_index = ph.index_id()
+        solr_hist = g.solr.search('id:' + ph_index)
+        if not solr_hist:  # sometimes history doesn't get added to solr
+            g.solr.add([ph.solarize()])
+            g.solr.commit()
+        assert g.solr.search('id:' + ph_index).hits == 1
+        pg.delete()
+        ThreadLocalODMSession.flush_all()
+        M.MonQTask.run_ready()
+        assert WM.PageHistory.query.find({'artifact_id': _id}).count() == 0
+        # history should be deleted from solr
+        assert g.solr.search('id:' + ph_index).hits == 0
+
     def test_messages_unknown_lookup(self):
         from bson import ObjectId
         m = Checkmessage()
