@@ -33,7 +33,7 @@ from allura import model as M
 from allura.lib import helpers as h
 from allura.lib import plugin
 from allura.tests import decorators as td
-from alluratest.controller import setup_basic_test, setup_global_objects, setup_functional_test, setup_unit_test
+from alluratest.controller import setup_basic_test, setup_global_objects, setup_functional_test
 
 
 class TestAuth:
@@ -87,19 +87,19 @@ class TestAuth:
 
     def test_email_address_canonical(self):
         assert M.EmailAddress.canonical('nobody@EXAMPLE.COM') == \
-               'nobody@example.com'
+            'nobody@example.com'
         assert M.EmailAddress.canonical('nobody@example.com') == \
-               'nobody@example.com'
+            'nobody@example.com'
         assert M.EmailAddress.canonical('I Am Nobody <nobody@example.com>') == \
-               'nobody@example.com'
+            'nobody@example.com'
         assert M.EmailAddress.canonical('  nobody@example.com\t') == \
-               'nobody@example.com'
+            'nobody@example.com'
         assert M.EmailAddress.canonical('I Am@Nobody <nobody@example.com> ') == \
-               'nobody@example.com'
+            'nobody@example.com'
         assert M.EmailAddress.canonical(' No@body <no@body@example.com> ') == \
-               'no@body@example.com'
+            'no@body@example.com'
         assert M.EmailAddress.canonical('no@body@example.com') == \
-               'no@body@example.com'
+            'no@body@example.com'
         assert M.EmailAddress.canonical('invalid') is None
 
     def test_email_address_send_verification_link(self):
@@ -135,11 +135,11 @@ class TestAuth:
         assert len(roles) == 3, roles
         u.set_password('foo')
         provider = plugin.LocalAuthenticationProvider(Request.blank('/'))
-        assert provider._validate_password(u, 'foo')
-        assert not provider._validate_password(u, 'foobar')
+        assert provider.validate_password(u, 'foo')
+        assert not provider.validate_password(u, 'foobar')
         u.set_password('foobar')
-        assert provider._validate_password(u, 'foobar')
-        assert not provider._validate_password(u, 'foo')
+        assert provider.validate_password(u, 'foobar')
+        assert not provider.validate_password(u, 'foo')
 
     def test_user_project_creates_on_demand(self):
         u = M.User.register(dict(username='foobar123'), make_project=False)
@@ -236,7 +236,7 @@ class TestAuth:
         roles = M.ProjectRole.query.find({'_id': {'$in': roles_ids}})
         for pr in roles:
             assert pr.display()
-            pr.special
+            assert pr.special
             assert pr.user in (c.user, None, M.User.anonymous())
 
     def test_default_project_roles(self):
