@@ -16,26 +16,24 @@
 #       under the License.
 
 import pprint
-from nose.tools import with_setup
 
-from ming.orm import ThreadLocalORMSession
+from ming.odm import ThreadLocalODMSession
 
 from alluratest.controller import setup_basic_test, setup_global_objects
 from allura import model as M
 
 
-def setUp():
+def setup_module():
     setup_basic_test()
-    ThreadLocalORMSession.close_all()
+    ThreadLocalODMSession.close_all()
     setup_global_objects()
     M.MonQTask.query.remove({})
 
 
-@with_setup(setUp)
 def test_basic_task():
     task = M.MonQTask.post(pprint.pformat, ([5, 6],))
-    ThreadLocalORMSession.flush_all()
-    ThreadLocalORMSession.close_all()
+    ThreadLocalODMSession.flush_all()
+    ThreadLocalODMSession.close_all()
     task = M.MonQTask.get()
     assert task
     task()
