@@ -15,10 +15,10 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-import unittest
 from datetime import timedelta
 import collections
 
+import pytest
 from tg import tmpl_context as c, app_globals as g
 from ming.odm import ThreadLocalODMSession
 import mock
@@ -32,7 +32,7 @@ from allura.tests import decorators as td
 from forgewiki import model as WM
 
 
-class TestNotification(unittest.TestCase):
+class TestNotification:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -163,7 +163,7 @@ class TestNotification(unittest.TestCase):
         )
 
 
-class TestPostNotifications(unittest.TestCase):
+class TestPostNotifications:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -220,7 +220,7 @@ class TestPostNotifications(unittest.TestCase):
         ThreadLocalODMSession.flush_all()
 
         assert (M.Notification.query.get()
-                     ['from_address'] == '"Test Admin" <test-admin@users.localhost>')
+                ['from_address'] == '"Test Admin" <test-admin@users.localhost>')
         assert M.Mailbox.query.find().count() == 2
 
         # sends the notification out into "mailboxes", and from mailboxes into
@@ -241,13 +241,13 @@ class TestPostNotifications(unittest.TestCase):
         assert str(c.user._id) in first_destinations
         assert str(user2._id) in first_destinations
         assert (email_tasks[0].kwargs['fromaddr'] ==
-                     '"Test Admin" <test-admin@users.localhost>')
+                '"Test Admin" <test-admin@users.localhost>')
         assert (email_tasks[1].kwargs['fromaddr'] ==
-                     '"Test Admin" <test-admin@users.localhost>')
+                '"Test Admin" <test-admin@users.localhost>')
         assert (email_tasks[0].kwargs['sender'] ==
-                     'wiki@test.p.in.localhost')
+                'wiki@test.p.in.localhost')
         assert (email_tasks[1].kwargs['sender'] ==
-                     'wiki@test.p.in.localhost')
+                'wiki@test.p.in.localhost')
         assert email_tasks[0].kwargs['text'].startswith(
             'Home modified by Test Admin')
         assert 'you indicated interest in ' in email_tasks[0].kwargs['text']
@@ -260,14 +260,9 @@ class TestPostNotifications(unittest.TestCase):
         self._subscribe(user=u)
         # Simulate a permission check failure.
 
-        def patched_has_access(*args, **kw):
-            def predicate(*args, **kw):
-                return False
-            return predicate
-        from allura.model.notification import security
-        orig = security.has_access
-        security.has_access = patched_has_access
-        try:
+        with mock.patch('allura.model.notification.security.has_access') as patched_has_access:
+            patched_has_access.return_value = False
+
             # this will create a notification task
             self._post_notification()
             ThreadLocalODMSession.flush_all()
@@ -278,8 +273,6 @@ class TestPostNotifications(unittest.TestCase):
             # ...but in this case it doesn't create a mail task since we
             # forced the perm check to fail
             assert M.MonQTask.get() is None
-        finally:
-            security.has_access = orig
 
     def test_footer(self):
         footer = MailFooter.monitored(
@@ -289,8 +282,7 @@ class TestPostNotifications(unittest.TestCase):
         assert 'test@mail.com is subscribed to http://test1.com' in footer
         assert 'admin can change settings at http://test2.com' in footer
         footer = MailFooter.standard(M.Notification())
-        self.assertIn('Sent from localhost because you indicated interest',
-                      footer)
+        assert 'Sent from localhost because you indicated interest' in footer
 
     def _subscribe(self, **kw):
         self.pg.subscribe(type='direct', **kw)
@@ -301,7 +293,7 @@ class TestPostNotifications(unittest.TestCase):
         return M.Notification.post(self.pg, 'metadata')
 
 
-class TestSubscriptionTypes(unittest.TestCase):
+class TestSubscriptionTypes:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -348,7 +340,8 @@ class TestSubscriptionTypes(unittest.TestCase):
         M.notification.MAILBOX_QUIESCENT = timedelta(minutes=1)
         # will raise "assert msg is not None" since the new message is not 1
         # min old:
-        self.assertRaises(AssertionError, self._test_message)
+        with pytest.raises(AssertionError):
+            self._test_message()
 
     def _test_message(self):
         self._subscribe()
@@ -474,7 +467,7 @@ class TestSubscriptionTypes(unittest.TestCase):
         assert count == 1
 
 
-class TestSiteNotification(unittest.TestCase):
+class TestSiteNotification:
     def setup_method(self, method):
         self.note = M.SiteNotification(
             active=True,
