@@ -41,12 +41,12 @@ class TestProjectModel:
         setup_global_objects()
 
     def test_project(self):
-        assert type(c.project.sidebar_menu()) == list
+        assert isinstance(c.project.sidebar_menu(), list)
         assert c.project.script_name in c.project.url()
         old_proj = c.project
         h.set_context('test/sub1', neighborhood='Projects')
-        assert type(c.project.sidebar_menu()) == list
-        assert type(c.project.sitemap()) == list
+        assert isinstance(c.project.sidebar_menu(), list)
+        assert isinstance(c.project.sitemap(), list)
         assert c.project.sitemap()[1].label == 'Admin'
         assert old_proj in list(c.project.parent_iter())
         h.set_context('test', 'wiki', neighborhood='Projects')
@@ -120,12 +120,11 @@ class TestProjectModel:
 
     def test_subproject(self):
         project = M.Project.query.get(shortname='test')
-        with td.raises(ToolError):
-            with patch('allura.lib.plugin.ProjectRegistrationProvider') as Provider:
-                Provider.get().shortname_validator.to_python.side_effect = Invalid(
-                    'name', 'value', {})
-                # name doesn't validate
-                sp = project.new_subproject('test-proj-nose')
+        with td.raises(ToolError), patch('allura.lib.plugin.ProjectRegistrationProvider') as Provider:
+            Provider.get().shortname_validator.to_python.side_effect = Invalid(
+                'name', 'value', {})
+            # name doesn't validate
+            sp = project.new_subproject('test-proj-nose')
         sp = project.new_subproject('test-proj-nose')
         spp = sp.new_subproject('spp')
         ThreadLocalODMSession.flush_all()
@@ -142,8 +141,8 @@ class TestProjectModel:
 
     def test_set_ordinal_to_admin_tool(self):
         with h.push_config(c,
-                        user=M.User.by_username('test-admin'),
-                        project=M.Project.query.get(shortname='test')):
+                           user=M.User.by_username('test-admin'),
+                           project=M.Project.query.get(shortname='test')):
             sm = c.project.sitemap()
             assert sm[-1].tool_name == 'admin'
 
