@@ -53,8 +53,8 @@ def test_script():
     cmd = script.ScriptCommand('script')
     cmd.run(
         [test_config, pkg_resources.resource_filename('allura', 'tests/tscript.py')])
-    pytest.raises(ValueError, cmd.run,
-                  [test_config, pkg_resources.resource_filename('allura', 'tests/tscript_error.py')])
+    with pytest.raises(ValueError):
+        cmd.run([test_config, pkg_resources.resource_filename('allura', 'tests/tscript_error.py')])
 
 
 def test_set_neighborhood_max_projects():
@@ -74,10 +74,10 @@ def test_set_neighborhood_max_projects():
     assert neighborhood.features['max_projects'] is None
 
     # check validation
-    pytest.raises(InvalidNBFeatureValueError, cmd.run,
-                  [test_config, str(n_id), 'max_projects', 'string'])
-    pytest.raises(InvalidNBFeatureValueError, cmd.run,
-                  [test_config, str(n_id), 'max_projects', '2.8'])
+    with pytest.raises(InvalidNBFeatureValueError):
+        cmd.run([test_config, str(n_id), 'max_projects', 'string'])
+    with pytest.raises(InvalidNBFeatureValueError):
+        cmd.run([test_config, str(n_id), 'max_projects', '2.8'])
 
 
 def test_set_neighborhood_private():
@@ -97,12 +97,12 @@ def test_set_neighborhood_private():
     assert not neighborhood.features['private_projects']
 
     # check validation
-    pytest.raises(InvalidNBFeatureValueError, cmd.run,
-                  [test_config, str(n_id), 'private_projects', 'string'])
-    pytest.raises(InvalidNBFeatureValueError, cmd.run,
-                  [test_config, str(n_id), 'private_projects', '1'])
-    pytest.raises(InvalidNBFeatureValueError, cmd.run,
-                  [test_config, str(n_id), 'private_projects', '2.8'])
+    with pytest.raises(InvalidNBFeatureValueError):
+        cmd.run([test_config, str(n_id), 'private_projects', 'string'])
+    with pytest.raises(InvalidNBFeatureValueError):
+        cmd.run([test_config, str(n_id), 'private_projects', '1'])
+    with pytest.raises(InvalidNBFeatureValueError):
+        cmd.run([test_config, str(n_id), 'private_projects', '2.8'])
 
 
 def test_set_neighborhood_google_analytics():
@@ -122,12 +122,12 @@ def test_set_neighborhood_google_analytics():
     assert not neighborhood.features['google_analytics']
 
     # check validation
-    pytest.raises(InvalidNBFeatureValueError, cmd.run,
-                  [test_config, str(n_id), 'google_analytics', 'string'])
-    pytest.raises(InvalidNBFeatureValueError, cmd.run,
-                  [test_config, str(n_id), 'google_analytics', '1'])
-    pytest.raises(InvalidNBFeatureValueError, cmd.run,
-                  [test_config, str(n_id), 'google_analytics', '2.8'])
+    with pytest.raises(InvalidNBFeatureValueError):
+        cmd.run([test_config, str(n_id), 'google_analytics', 'string'])
+    with pytest.raises(InvalidNBFeatureValueError):
+        cmd.run([test_config, str(n_id), 'google_analytics', '1'])
+    with pytest.raises(InvalidNBFeatureValueError):
+        cmd.run([test_config, str(n_id), 'google_analytics', '2.8'])
 
 
 def test_set_neighborhood_css():
@@ -152,16 +152,16 @@ def test_set_neighborhood_css():
     assert neighborhood.features['css'] == 'custom'
 
     # check validation
-    pytest.raises(InvalidNBFeatureValueError, cmd.run,
-                  [test_config, str(n_id), 'css', 'string'])
-    pytest.raises(InvalidNBFeatureValueError, cmd.run,
-                  [test_config, str(n_id), 'css', '1'])
-    pytest.raises(InvalidNBFeatureValueError, cmd.run,
-                  [test_config, str(n_id), 'css', '2.8'])
-    pytest.raises(InvalidNBFeatureValueError, cmd.run,
-                  [test_config, str(n_id), 'css', 'None'])
-    pytest.raises(InvalidNBFeatureValueError, cmd.run,
-                  [test_config, str(n_id), 'css', 'True'])
+    with pytest.raises(InvalidNBFeatureValueError):
+        cmd.run([test_config, str(n_id), 'css', 'string'])
+    with pytest.raises(InvalidNBFeatureValueError):
+        cmd.run([test_config, str(n_id), 'css', '1'])
+    with pytest.raises(InvalidNBFeatureValueError):
+        cmd.run([test_config, str(n_id), 'css', '2.8'])
+    with pytest.raises(InvalidNBFeatureValueError):
+        cmd.run([test_config, str(n_id), 'css', 'None'])
+    with pytest.raises(InvalidNBFeatureValueError):
+        cmd.run([test_config, str(n_id), 'css', 'True'])
 
 
 def test_update_neighborhood():
@@ -197,9 +197,9 @@ class TestEnsureIndexCommand:
                  index_options={'unique': False, 'sparse': False}),
         ]
         cmd = show_models.EnsureIndexCommand('ensure_index')
-        cmd.options = Object(clean=False)
+        cmd.options = Object(clean=False, delete_dupes=False)
         cmd._update_indexes(collection, indexes)
-        assert collection.ensure_index.called
+        assert collection.create_index.called
         assert not collection.drop_index.called
 
     def test_update_indexes_order(self):
@@ -213,20 +213,20 @@ class TestEnsureIndexCommand:
                  index_options={'unique': False, 'sparse': False}),
         ]
         cmd = show_models.EnsureIndexCommand('ensure_index')
-        cmd.options = Object(clean=True)
+        cmd.options = Object(clean=True, delete_dupes=False)
         cmd._update_indexes(collection, indexes)
 
         collection_call_order = {}
         for i, call_ in enumerate(collection.mock_calls):
             method_name = call_[0]
             collection_call_order[method_name] = i
-        assert collection_call_order['ensure_index'] < collection_call_order['drop_index'], collection.mock_calls
+        assert collection_call_order['create_index'] < collection_call_order['drop_index'], collection.mock_calls
 
     def test_update_indexes_unique_changes(self):
         collection = Mock(name='collection')
         # expecting these ensure_index calls, we'll make their return values normal
         # for easier assertions later
-        collection.ensure_index.side_effect = [
+        collection.create_index.side_effect = [
             '_foo_bar_temporary_extra_field_for_indexing',
             '_foo_bar',
             '_foo_baz_temporary_extra_field_for_indexing',
@@ -251,18 +251,16 @@ class TestEnsureIndexCommand:
 
         assert collection.mock_calls == [
             call.index_information(),
-            call.ensure_index(
-                [('foo', 1), ('bar', 1), ('temporary_extra_field_for_indexing', 1)]),
+            call.create_index([('foo', 1), ('bar', 1), ('temporary_extra_field_for_indexing', 1)]),
             call.drop_index('_foo_bar'),
-            call.ensure_index([('foo', 1), ('bar', 1)], unique=False),
+            call.create_index([('foo', 1), ('bar', 1)], unique=False),
             call.drop_index('_foo_bar_temporary_extra_field_for_indexing'),
-            call.ensure_index(
-                [('foo', 1), ('baz', 1), ('temporary_extra_field_for_indexing', 1)]),
+            call.create_index([('foo', 1), ('baz', 1), ('temporary_extra_field_for_indexing', 1)]),
             call.drop_index('_foo_baz'),
-            call.ensure_index([('foo', 1), ('baz', 1)], unique=True),
+            call.create_index([('foo', 1), ('baz', 1)], unique=True),
             call.drop_index('_foo_baz_temporary_extra_field_for_indexing'),
-            call.ensure_index([('foo', 1), ('baz', 1)], unique=True, sparse=False),
-            call.ensure_index([('foo', 1), ('bar', 1)], unique=False, sparse=False, background=True)
+            call.create_index([('foo', 1), ('baz', 1)], unique=True, sparse=False),
+            call.create_index([('foo', 1), ('bar', 1)], unique=False, sparse=False, background=True)
         ]
 
 
@@ -435,14 +433,14 @@ def test_status_log_retries():
     cmd._taskd_status.return_value = ''
     cmd.options = Mock(num_retry=10)
     cmd._check_taskd_status(123)
-    expected_calls = [call(123, False if i == 0 else True) for i in range(10)]
+    expected_calls = [call(123, i != 0) for i in range(10)]
     assert cmd._taskd_status.mock_calls == expected_calls
 
     cmd._taskd_status = Mock()
     cmd._taskd_status.return_value = ''
     cmd.options = Mock(num_retry=3)
     cmd._check_task(123, Mock())
-    expected_calls = [call(123, False if i == 0 else True) for i in range(3)]
+    expected_calls = [call(123, i != 0) for i in range(3)]
     assert cmd._taskd_status.mock_calls == expected_calls
 
 
@@ -457,6 +455,7 @@ class TestShowModels:
          - <FieldProperty content>
         ''' in output.captured
 
+
 class TestReindexAsTask:
 
     cmd = 'allura.command.show_models.ReindexCommand'
@@ -521,7 +520,7 @@ class TestReindexCommand:
         assert (
             {Solr.call_args_list[0][0][0], Solr.call_args_list[1][0][0]} ==
             {'http://blah.com/solr/forge',
-                 'https://other.net/solr/forge'})
+             'https://other.net/solr/forge'})
 
     @patch('allura.command.show_models.utils')
     def test_project_regex(self, utils):
@@ -533,7 +532,7 @@ class TestReindexCommand:
     @patch('allura.command.show_models.add_artifacts')
     def test_chunked_add_artifacts(self, add_artifacts):
         cmd = show_models.ReindexCommand('reindex')
-        cmd.options = Mock(tasks=True, max_chunk=10 * 1000, ming_config=None)
+        cmd.options = Mock(tasks=True, max_chunk=10 * 1000, ming_config=None, solr_creds='')
         ref_ids = list(range(10 * 1000 * 2 + 20))
         cmd._chunked_add_artifacts(ref_ids)
         assert len(add_artifacts.post.call_args_list) == 3
@@ -576,7 +575,7 @@ class TestReindexCommand:
             raise pymongo.errors.InvalidDocument("Cannot encode object...")
         add_artifacts.post.side_effect = on_post
         cmd = show_models.ReindexCommand('reindex')
-        cmd.options = Mock(ming_config=None)
+        cmd.options = Mock(ming_config=None, solr_creds='')
         with td.raises(pymongo.errors.InvalidDocument):
             cmd._post_add_artifacts(list(range(5)))
 
