@@ -15,16 +15,15 @@
 #       specific language governing permissions and limitations
 #       under the License.
 import inspect
-from unittest import TestCase
 from mock import patch
 import random
 import gc
 
 from allura.lib.decorators import task, memoize
-from alluratest.controller import setup_basic_test, setup_global_objects
+from alluratest.controller import setup_basic_test
 
 
-class TestTask(TestCase):
+class TestTask:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -33,13 +32,13 @@ class TestTask(TestCase):
         @task
         def func():
             pass
-        self.assertTrue(hasattr(func, 'post'))
+        assert hasattr(func, 'post')
 
     def test_with_params(self):
         @task(disable_notifications=True)
         def func():
             pass
-        self.assertTrue(hasattr(func, 'post'))
+        assert hasattr(func, 'post')
 
     @patch('allura.lib.decorators.c')
     @patch('allura.model.MonQTask')
@@ -49,12 +48,12 @@ class TestTask(TestCase):
             pass
 
         def mock_post(f, args, kw, delay=None):
-            self.assertTrue(c.project.notifications_disabled)
-            self.assertFalse('delay' in kw)
-            self.assertEqual(delay, 1)
-            self.assertEqual(kw, dict(foo=2))
-            self.assertEqual(args, ('test',))
-            self.assertEqual(f, func)
+            assert c.project.notifications_disabled
+            assert 'delay' not in kw
+            assert delay == 1
+            assert kw == dict(foo=2)
+            assert args == ('test',)
+            assert f == func
 
         c.project.notifications_disabled = False
         MonQTask.post.side_effect = mock_post
