@@ -16,7 +16,7 @@
 #       under the License.
 
 import io
-from unittest import TestCase, skipIf
+from unittest import skipIf
 from os import path
 from datetime import datetime, timedelta
 import time
@@ -24,12 +24,15 @@ import time
 import PIL
 from mock import Mock, patch
 from tg import tmpl_context as c
+from tg import config
+
 from alluratest.tools import module_not_available
 from webob import Request
 from webob.exc import HTTPUnauthorized
 from ming.odm import ThreadLocalODMSession
 from markupsafe import Markup
 import pytest
+from formencode import validators as fev
 
 from allura import model as M
 from allura.lib import exceptions as exc
@@ -39,41 +42,44 @@ from allura.lib.security import has_access
 from allura.lib.security import Credentials
 from allura.tests import decorators as td
 from alluratest.controller import setup_basic_test
-import six
+
+# httpbin.org should work, but lately has been unreliable
+# httpbin.io does not allow /redirect-to to localhost
+httpbin_domain = 'httpbin.dev'
 
 
 def setup_module():
     setup_basic_test()
 
 
-class TestMakeSafePathPortion(TestCase):
+class TestMakeSafePathPortion:
 
     def setup_method(self, method):
         self.f = h.make_safe_path_portion
 
     def test_no_ascii_chars(self):
         s = self.f('Задачи', relaxed=False)
-        self.assertEqual(s, '')
+        assert s == ''
 
     def test_some_ascii_chars(self):
         s = self.f('aßbƒ', relaxed=False)
-        self.assertEqual(s, 'ab')
+        assert s == 'ab'
 
     def test_strict_mount_point_names(self):
         s = self.f('1this+is.illegal', relaxed=False)
-        self.assertEqual(s, 'this-is-illegal')
+        assert s == 'this-is-illegal'
         s = self.f('this-1-is-legal', relaxed=False)
-        self.assertEqual(s, 'this-1-is-legal')
+        assert s == 'this-1-is-legal'
         s = self.f('THIS-IS-Illegal', relaxed=False)
-        self.assertEqual(s, 'this-is-illegal')
+        assert s == 'this-is-illegal'
 
     def test_relaxed_mount_point_names(self):
         s = self.f('1_this+is.legal')
-        self.assertEqual(s, '1_this+is.legal')
+        assert s == '1_this+is.legal'
         s = self.f('not*_legal')
-        self.assertEqual(s, 'not-legal')
+        assert s == 'not-legal'
         s = self.f('THIS-IS-Illegal')
-        self.assertEqual(s, 'THIS-IS-Illegal')
+        assert s == 'THIS-IS-Illegal'
 
 
 def test_escape_json():
@@ -140,24 +146,24 @@ def test_make_app_admin_only():
     c.project.add_user(dev, ['Developer'])
     ThreadLocalODMSession.flush_all()
     Credentials.get().clear()
-    assert has_access(c.app, 'read', user=anon)()
-    assert has_access(c.app, 'read', user=dev)()
-    assert has_access(c.app, 'read', user=admin)()
-    assert not has_access(c.app, 'create', user=anon)()
-    assert has_access(c.app, 'create', user=dev)()
-    assert has_access(c.app, 'create', user=admin)()
+    assert has_access(c.app, 'read', user=anon)
+    assert has_access(c.app, 'read', user=dev)
+    assert has_access(c.app, 'read', user=admin)
+    assert not has_access(c.app, 'create', user=anon)
+    assert has_access(c.app, 'create', user=dev)
+    assert has_access(c.app, 'create', user=admin)
     assert c.app.is_visible_to(anon)
     assert c.app.is_visible_to(dev)
     assert c.app.is_visible_to(admin)
     h.make_app_admin_only(c.app)
     ThreadLocalODMSession.flush_all()
     Credentials.get().clear()
-    assert not has_access(c.app, 'read', user=anon)()
-    assert not has_access(c.app, 'read', user=dev)()
-    assert has_access(c.app, 'read', user=admin)()
-    assert not has_access(c.app, 'create', user=anon)()
-    assert not has_access(c.app, 'create', user=dev)()
-    assert has_access(c.app, 'create', user=admin)()
+    assert not has_access(c.app, 'read', user=anon)
+    assert not has_access(c.app, 'read', user=dev)
+    assert has_access(c.app, 'read', user=admin)
+    assert not has_access(c.app, 'create', user=anon)
+    assert not has_access(c.app, 'create', user=dev)
+    assert has_access(c.app, 'create', user=admin)
     assert not c.app.is_visible_to(anon)
     assert not c.app.is_visible_to(dev)
     assert c.app.is_visible_to(admin)
@@ -346,6 +352,23 @@ def test_nl2br_jinja_filter():
             Markup('foo&lt;script&gt;alert(1)&lt;/script&gt;<br>\nbar<br>\nbaz'))
 
 
+def test_subrender_jinja_filter():
+    # if we need a real ctx, have to do all this which probably isn't even quite right
+    # from allura.config.app_cfg import AlluraJinjaRenderer
+    # j2env = AlluraJinjaRenderer.create(config, None)['jinja'].jinja2_env
+    # from jinja2.runtime import new_context
+    # j_ctx = new_context(j2env, template_name=None, blocks={})
+    j_ctx = None
+
+    # HTML, but no jinja:
+    assert h.subrender_jinja_filter(j_ctx, '<b>hi</b>{% foo %}') == '<b>hi</b>{% foo %}'
+    # var does not error if no `c.project`
+    assert h.subrender_jinja_filter(j_ctx, '<a href="{{ c.project.url() }}"></a>') == '<a href="{{ c.project.url() }}"></a>'
+    # with `c.project` set, replacement of this var works:
+    with h.push_context('test', neighborhood='Projects'):
+        assert h.subrender_jinja_filter(j_ctx, '<a href="{{ c.project.url() }}"></a>') == '<a href="/p/test/"></a>'
+
+
 def test_split_select_field_options():
     assert (h.split_select_field_options('"test message" test2') ==
             ['test message', 'test2'])
@@ -452,15 +475,38 @@ back\\\-slash escaped
         r'tab before \(stuff\)'
 
 
-class TestUrlOpen(TestCase):
+class TestUrlOpen:
+
+    @pytest.mark.parametrize('url', [
+        'http://127.0.0.1/',
+        'http://::1/',  # ipv6
+        'http://localhost/',
+        'https://localhost/',
+        'http://localhost:8080',
+        f'https://{httpbin_domain}/redirect-to?url=http://localhost',
+        f'https://{httpbin_domain}/redirect-to?url=https://localhost',
+    ])
+    def test_internal_invalid(self, url):
+        with pytest.raises(fev.Invalid):
+            h.urlopen(url)
+
+    @pytest.mark.parametrize('url', [
+        f'http://{httpbin_domain}/status/200',
+        f'https://{httpbin_domain}/status/200',
+        f'http://{httpbin_domain}:80/status/200',
+    ])
+    def test_ok(self, url):
+        h.urlopen(url)
 
     @patch('urllib.request.urlopen')
+    @patch.dict(config, {'urlopen_allow_internal_hostnames': 'true'})
     def test_no_error(self, urlopen):
         r = h.urlopen('http://example.com')
-        self.assertEqual(r, urlopen.return_value)
+        assert r == urlopen.return_value
         urlopen.assert_called_once_with('http://example.com', timeout=None)
 
     @patch('urllib.request.urlopen')
+    @patch.dict(config, {'urlopen_allow_internal_hostnames': 'true'})
     def test_socket_timeout(self, urlopen):
         import socket
 
@@ -468,10 +514,12 @@ class TestUrlOpen(TestCase):
             raise socket.timeout()
 
         urlopen.side_effect = side_effect
-        self.assertRaises(socket.timeout, h.urlopen, 'http://example.com')
-        self.assertEqual(urlopen.call_count, 4)
+        with pytest.raises(socket.timeout):
+            h.urlopen('http://example.com')
+        assert urlopen.call_count == 4
 
     @patch('urllib.request.urlopen')
+    @patch.dict(config, {'urlopen_allow_internal_hostnames': 'true'})
     def test_socket_reset(self, urlopen):
         import socket
         import errno
@@ -480,10 +528,12 @@ class TestUrlOpen(TestCase):
             raise OSError(errno.ECONNRESET, 'Connection reset by peer')
 
         urlopen.side_effect = side_effect
-        self.assertRaises(socket.error, h.urlopen, 'http://example.com')
-        self.assertEqual(urlopen.call_count, 4)
+        with pytest.raises(socket.error):
+            h.urlopen('http://example.com')
+        assert urlopen.call_count == 4
 
     @patch('urllib.request.urlopen')
+    @patch.dict(config, {'urlopen_allow_internal_hostnames': 'true'})
     def test_handled_http_error(self, urlopen):
         from urllib.error import HTTPError
 
@@ -491,10 +541,12 @@ class TestUrlOpen(TestCase):
             raise HTTPError('url', 408, 'timeout', None, io.BytesIO())
 
         urlopen.side_effect = side_effect
-        self.assertRaises(HTTPError, h.urlopen, 'http://example.com')
-        self.assertEqual(urlopen.call_count, 4)
+        with pytest.raises(HTTPError):
+            h.urlopen('http://example.com')
+        assert urlopen.call_count == 4
 
     @patch('urllib.request.urlopen')
+    @patch.dict(config, {'urlopen_allow_internal_hostnames': 'true'})
     def test_unhandled_http_error(self, urlopen):
         from urllib.error import HTTPError
 
@@ -502,8 +554,9 @@ class TestUrlOpen(TestCase):
             raise HTTPError('url', 404, 'timeout', None, io.BytesIO())
 
         urlopen.side_effect = side_effect
-        self.assertRaises(HTTPError, h.urlopen, 'http://example.com')
-        self.assertEqual(urlopen.call_count, 1)
+        with pytest.raises(HTTPError):
+            h.urlopen('http://example.com')
+        assert urlopen.call_count == 1
 
 
 def test_absurl():
@@ -523,12 +576,11 @@ def test_login_overlay():
         raise HTTPUnauthorized()
     with h.login_overlay(exceptions=['foo']):
         raise HTTPUnauthorized()
-    with td.raises(HTTPUnauthorized):
-        with h.login_overlay(exceptions=['foobar']):
-            raise HTTPUnauthorized()
+    with td.raises(HTTPUnauthorized), h.login_overlay(exceptions=['foobar']):
+        raise HTTPUnauthorized()
 
 
-class TestIterEntryPoints(TestCase):
+class TestIterEntryPoints:
 
     def _make_ep(self, name, cls):
         m = Mock()
@@ -541,7 +593,7 @@ class TestIterEntryPoints(TestCase):
     def test_disabled(self, pkg_resources):
         pkg_resources.iter_entry_points.return_value = [
             self._make_ep('myapp', object)]
-        self.assertEqual([], list(h.iter_entry_points('allura')))
+        assert [] == list(h.iter_entry_points('allura'))
 
     @patch('allura.lib.helpers.pkg_resources')
     def test_subclassed_ep(self, pkg_resources):
@@ -556,8 +608,8 @@ class TestIterEntryPoints(TestCase):
             self._make_ep('myapp', BetterApp)]
 
         eps = list(h.iter_entry_points('allura'))
-        self.assertEqual(len(eps), 1)
-        self.assertEqual(BetterApp, eps[0].load())
+        assert len(eps) == 1
+        assert BetterApp == eps[0].load()
 
     @patch('allura.lib.helpers.pkg_resources')
     def test_ambiguous_eps(self, pkg_resources):
@@ -575,10 +627,9 @@ class TestIterEntryPoints(TestCase):
             self._make_ep('myapp', BetterApp),
             self._make_ep('myapp', BestApp)]
 
-        self.assertRaisesRegex(ImportError,
-                               r'Ambiguous \[allura\] entry points detected. '
-                               'Multiple entry points with name "myapp".',
-                               list, h.iter_entry_points('allura'))
+        with pytest.raises(ImportError, match=r'Ambiguous \[allura\] entry points detected. '
+                                              'Multiple entry points with name "myapp".'):
+            list(h.iter_entry_points('allura'))
 
 
 def test_get_user_status():
@@ -632,7 +683,7 @@ def test_slugify():
     assert h.slugify('Foo.Bar', True)[0] == 'Foo.Bar'
 
 
-class TestRateLimit(TestCase):
+class TestRateLimit:
     rate_limits = '{"60": 1, "120": 3, "900": 5, "1800": 7, "3600": 10, "7200": 15, "86400": 20, "604800": 50, "2592000": 200}'
     key_comment = 'allura.rate_limits_per_user'
 
@@ -670,7 +721,7 @@ def test_hide_private_info():
     assert h.hide_private_info('foo bar baz@bing.com') == 'foo bar baz@...'
     assert h.hide_private_info('some <1@2.com>\nor asdf+asdf.f@g.f.x') == 'some <1@...>\nor asdf+asdf.f@...'
     safe_markup_converted = h.hide_private_info(Markup('foo bar baz@bing.com'))
-    assert type(safe_markup_converted) == Markup
+    assert type(safe_markup_converted) is Markup
     assert safe_markup_converted == Markup('foo bar baz@...')
 
     with h.push_config(h.tg.config, hide_private_info=False):
@@ -688,3 +739,9 @@ def test_querystring():
             'https://mysite.com/p/test/foobar/p/test/foobar?page=2&limit=5&count=100')
     assert (h.querystring(req, dict(page=5, limit=2, count=None)) ==
             'https://mysite.com/p/test/foobar/p/test/foobar?page=5&limit=2')
+
+
+def test_clean_html():
+    assert h.clean_html('<script>alert(1)</script>') == '&lt;script&gt;alert(1)&lt;/script&gt;'
+    assert h.clean_html('<b style="color: red; right: 0">ok</b>') == '<b style="color: red;">ok</b>'
+    assert isinstance(h.clean_html('foo'), Markup)
