@@ -15,7 +15,6 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-import unittest
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 
@@ -23,9 +22,8 @@ import mock
 import pytest
 from ming.odm import ThreadLocalODMSession
 from tg import config as tg_config
-
+from smtplib import SMTP as SMTPClient
 from alluratest.controller import setup_basic_test, setup_global_objects
-from allura.command.smtp_server import MailServer
 from allura.lib.utils import ConfigProxy
 from allura.app import Application
 from allura.lib.mail_util import (
@@ -35,17 +33,20 @@ from allura.lib.mail_util import (
     is_autoreply,
     identify_sender,
     _parse_message_id,
+    email_policy,
 )
 from allura.lib.exceptions import AddressException
 from allura.tests import decorators as td
-
+from paste.deploy.converters import asint
+from allura.command.smtp_server import MailServer
+from aiosmtpd.controller import Controller
 
 config = ConfigProxy(
     common_suffix='forgemail.domain',
     return_path='forgemail.return_path')
 
 
-class TestReactor(unittest.TestCase):
+class TestReactor:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -91,7 +92,8 @@ class TestReactor(unittest.TestCase):
 Толпой со всех концов земли
 К богатым пристаням стремятся;'''.encode(charset),
                         'plain',
-                        charset)
+                        charset,
+                        policy=email_policy)
         msg1['Message-ID'] = '<foo@bar.com>'
         s_msg = msg1.as_string()
         msg2 = parse_message(s_msg)
@@ -189,15 +191,17 @@ Content-Type: text/html; charset="utf-8"
 Толпой со всех концов земли
 К богатым пристаням стремятся;'''.encode(charset),
                       'plain',
-                      charset)
+                      charset,
+                      policy=email_policy)
         p2 = MIMEText('''<p>По оживлённым берегам
 Громады стройные теснятся
 Дворцов и башен; корабли
 Толпой со всех концов земли
 К богатым пристаням стремятся;</p>'''.encode(charset),
                       'plain',
-                      charset)
-        msg1 = MIMEMultipart()
+                      charset,
+                      policy=email_policy)
+        msg1 = MIMEMultipart(policy=email_policy)
         msg1['Message-ID'] = '<foo@bar.com>'
         msg1.attach(p1)
         msg1.attach(p2)
@@ -214,20 +218,19 @@ class TestHeader:
     def test_bytestring(self):
         with pytest.raises(TypeError):
             our_header = Header(b'[asdf2:wiki] Discussion for Home page')
-            assert our_header.encode() == '[asdf2:wiki] Discussion for Home page'
+            assert our_header == '[asdf2:wiki] Discussion for Home page'
 
     def test_ascii(self):
         our_header = Header('[asdf2:wiki] Discussion for Home page')
-        assert our_header.encode() == '[asdf2:wiki] Discussion for Home page'
+        assert our_header == '[asdf2:wiki] Discussion for Home page'
 
     def test_utf8(self):
         our_header = Header('теснятся')
-        assert our_header.encode() == '=?utf-8?b?0YLQtdGB0L3Rj9GC0YHRjw==?='
+        assert our_header == 'теснятся'
 
     def test_name_addr(self):
         our_header = Header('"теснятся"', '<dave@b.com>')
-        assert (our_header.encode() ==
-                     '=?utf-8?b?ItGC0LXRgdC90Y/RgtGB0Y8i?= <dave@b.com>')
+        assert our_header == '"теснятся" <dave@b.com>'
 
 
 class TestIsAutoreply:
@@ -282,7 +285,7 @@ class TestIdentifySender:
     def test_arg(self, EA):
         EA.canonical = lambda e: e
         EA.get.side_effect = [
-            mock.Mock(claimed_by_user_id=True, claimed_by_user=lambda:'user')]
+            mock.Mock(claimed_by_user_id=True, claimed_by_user=lambda: 'user')]
         assert identify_sender(None, 'arg', None, None) == 'user'
         EA.get.assert_called_once_with(email='arg', confirmed=True)
 
@@ -290,11 +293,11 @@ class TestIdentifySender:
     def test_header(self, EA):
         EA.canonical = lambda e: e
         EA.get.side_effect = [
-            None, mock.Mock(claimed_by_user_id=True, claimed_by_user=lambda:'user')]
+            None, mock.Mock(claimed_by_user_id=True, claimed_by_user=lambda: 'user')]
         assert (
             identify_sender(None, 'arg', {'From': 'from'}, None) == 'user')
         assert (EA.get.call_args_list ==
-                     [mock.call(email='arg', confirmed=True), mock.call(email='from')])
+                [mock.call(email='arg', confirmed=True), mock.call(email='from')])
 
     @mock.patch('allura.model.User')
     @mock.patch('allura.model.EmailAddress')
@@ -302,7 +305,7 @@ class TestIdentifySender:
         anon = User.anonymous()
         EA.canonical = lambda e: e
         EA.get.side_effect = [
-            None, mock.Mock(claimed_by_user_id=True, claimed_by_user=lambda:'user')]
+            None, mock.Mock(claimed_by_user_id=True, claimed_by_user=lambda: 'user')]
         assert identify_sender(None, 'arg', {}, None) == anon
         assert EA.get.call_args_list == [mock.call(email='arg', confirmed=True)]
 
@@ -315,7 +318,7 @@ class TestIdentifySender:
         assert (
             identify_sender(None, 'arg', {'From': 'from'}, None) == anon)
         assert (EA.get.call_args_list ==
-                     [mock.call(email='arg', confirmed=True), mock.call(email='from')])
+                [mock.call(email='arg', confirmed=True), mock.call(email='from')])
 
 
 def test_parse_message_id():
@@ -332,9 +335,29 @@ class TestMailServer:
 
     @mock.patch('allura.command.base.log', autospec=True)
     def test(self, log):
-        listen_port = ('0.0.0.0', 8825)
-        mailserver = MailServer(listen_port, None)
-        mailserver.process_message('127.0.0.1', 'foo@bar.com', ['1234@tickets.test.p.localhost'],
-                                   'this is the email body with headers and everything ÎÅ¸'.encode())
-        assert [] == log.exception.call_args_list
-        assert log.info.call_args[0][0].startswith('Msg passed along as task '), log.info.call_args
+        hostname = tg_config.get('forgemail.host', '0.0.0.0')
+        port = asint(tg_config.get('forgemail.port', 8827))
+        handler = MailServer()
+        controller = Controller(handler, hostname=hostname, port=port)
+        controller.start()
+        
+        with SMTPClient(hostname, port, timeout=0.1) as client:
+            code, msg = client.ehlo("example.com")
+            assert code == 250
+            mailfrom = client.docmd("MAIL FROM: <from@example.com>")
+            assert mailfrom == (250, b'OK')
+            rcpt = client.docmd("RCPT TO: <to@example.com>")
+            assert rcpt == (250, b'OK')
+            data = client.docmd("DATA")
+            assert data == (354, b'End data with <CR><LF>.<CR><LF>')
+            
+        with SMTPClient(hostname, port, timeout=0.1) as client:
+            client.sendmail('from@example.com', ['to@example.com'],"""
+            From: From Person <from@example.com>
+            To: To Person <to@example.com>
+            Subject: A test
+            Hi Bart, this is Anne.
+            """)
+            
+        controller.stop()
+            
