@@ -15,13 +15,12 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-import unittest
 import mock
 
 from allura.scripts.scripttask import ScriptTask
 
 
-class TestScriptTask(unittest.TestCase):
+class TestScriptTask:
 
     def setup_method(self, method):
         class TestScriptTask(ScriptTask):
