@@ -14,11 +14,11 @@
 #       KIND, either express or implied.  See the License for the
 #       specific language governing permissions and limitations
 #       under the License.
-
+import email.parser
+import email.iterators
 import operator
 import shutil
 from textwrap import dedent
-import unittest
 
 import six
 from base64 import b64encode
@@ -28,6 +28,7 @@ import pkg_resources
 import tg
 import mock
 from tg import tmpl_context as c, app_globals as g
+import pytest
 
 from ming.odm import FieldProperty, Mapper
 from ming.odm import ThreadLocalODMSession
@@ -38,7 +39,7 @@ from alluratest.controller import setup_basic_test, setup_global_objects, TestCo
 from allura import model as M
 from allura.command.taskd import TaskdCommand
 from allura.lib import helpers as h
-from allura.lib.mail_util import MAX_MAIL_LINE_OCTETS
+from allura.lib.mail_util import MAX_MAIL_LINE_OCTETS, email_policy
 from allura.tasks import event_tasks
 from allura.tasks import index_tasks
 from allura.tasks import mail_tasks
@@ -51,7 +52,7 @@ from allura.tests.exclude_from_rewrite_hook import raise_compound_exception
 from allura.lib.decorators import event_handler, task
 
 
-class TestRepoTasks(unittest.TestCase):
+class TestRepoTasks:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -100,7 +101,7 @@ def _task_that_creates_event(event_name,):
     assert not M.MonQTask.query.get(task_name='allura.tasks.event_tasks.event', args=[event_name])
 
 
-class TestEventTasks(unittest.TestCase):
+class TestEventTasks:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -158,7 +159,7 @@ class TestEventTasks(unittest.TestCase):
             assert ('assert %d' % x) in t.result
 
 
-class TestIndexTasks(unittest.TestCase):
+class TestIndexTasks:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -243,7 +244,7 @@ class TestIndexTasks(unittest.TestCase):
         solr.delete.assert_called_once_with(q=solr_query)
 
 
-class TestMailTasks(unittest.TestCase):
+class TestMailTasks:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -265,7 +266,7 @@ class TestMailTasks(unittest.TestCase):
                 message_id=h.gen_message_id())
             assert _client.sendmail.call_count == 1
             return_path, rcpts, body = _client.sendmail.call_args[0]
-            body = body.split('\n')
+            body = body.split(email_policy.linesep)
 
             assert rcpts == [c.user.get_pref('email_address')]
             assert 'Reply-To: %s' % g.noreply in body
@@ -288,14 +289,13 @@ class TestMailTasks(unittest.TestCase):
                 message_id=h.gen_message_id())
             assert _client.sendmail.call_count == 1
             return_path, rcpts, body = _client.sendmail.call_args[0]
-            body = body.split('\n')
+            body = body.split(email_policy.linesep)
 
             assert rcpts == ['blah@blah.com']
             assert 'Reply-To: %s' % g.noreply in body
 
             # The address portion must not be encoded, only the name portion can be.
-            # Also py2 and py3 vary in handling of double-quote separators when the name portion is encoded
-            unquoted_cyrillic_No = '=?utf-8?b?0J/Qvg==?='  # По
+            unquoted_cyrillic_No = '=?utf-8?q?=D0=9F=D0=BE?='  # По
             quoted_cyrillic_No = '=?utf-8?b?ItCf0L4i?='  # "По"
             assert (f'From: {quoted_cyrillic_No} <foo@bar.com>' in body or
                     f'From: {unquoted_cyrillic_No} <foo@bar.com>' in body), body
@@ -321,7 +321,7 @@ class TestMailTasks(unittest.TestCase):
                 message_id=h.gen_message_id())
             assert _client.sendmail.call_count == 1
             return_path, rcpts, body = _client.sendmail.call_args[0]
-            body = body.split('\n')
+            body = body.split(email_policy.linesep)
             assert 'From: %s' % g.noreply in body
 
     def test_send_email_with_disabled_destination_user(self):
@@ -352,7 +352,7 @@ class TestMailTasks(unittest.TestCase):
                 message_id=h.gen_message_id())
             assert _client.sendmail.call_count == 1
             return_path, rcpts, body = _client.sendmail.call_args[0]
-            body = body.split('\n')
+            body = body.split(email_policy.linesep)
             assert 'From: "Test Admin" <test-admin@users.localhost>' in body
 
             c.user.disabled = True
@@ -366,7 +366,7 @@ class TestMailTasks(unittest.TestCase):
                 message_id=h.gen_message_id())
             assert _client.sendmail.call_count == 2
             return_path, rcpts, body = _client.sendmail.call_args[0]
-            body = body.split('\n')
+            body = body.split(email_policy.linesep)
             assert 'From: %s' % g.noreply in body
 
     def test_email_sender_to_headers(self):
@@ -382,7 +382,7 @@ class TestMailTasks(unittest.TestCase):
                 message_id=h.gen_message_id())
             assert _client.sendmail.call_count == 1
             return_path, rcpts, body = _client.sendmail.call_args[0]
-            body = body.split('\n')
+            body = body.split(email_policy.linesep)
             assert 'From: "Test Admin" <test-admin@users.localhost>' in body
             assert 'Sender: tickets@test.p.domain.net' in body
             assert 'To: test@mail.com' in body
@@ -398,7 +398,7 @@ class TestMailTasks(unittest.TestCase):
                 message_id=h.gen_message_id())
             assert _client.sendmail.call_count == 1
             return_path, rcpts, body = _client.sendmail.call_args[0]
-            body = body.split('\n')
+            body = body.split(email_policy.linesep)
             assert 'From: "Test Admin" <test-admin@users.localhost>' in body
             assert 'Sender: tickets@test.p.domain.net' in body
             assert 'To: 123@tickets.test.p.domain.net' in body
@@ -416,7 +416,7 @@ class TestMailTasks(unittest.TestCase):
                 message_id=h.gen_message_id())
             assert _client.sendmail.call_count == 1
             return_path, rcpts, body = _client.sendmail.call_args[0]
-            body = body.split('\n')
+            body = body.split(email_policy.linesep)
             assert 'From: "Test Admin" <test-admin@users.localhost>' in body
             assert 'References: <a> <b> <c>' in body
 
@@ -431,7 +431,7 @@ class TestMailTasks(unittest.TestCase):
                 message_id=h.gen_message_id())
             assert _client.sendmail.call_count == 1
             return_path, rcpts, body = _client.sendmail.call_args[0]
-            body = body.split('\n')
+            body = body.split(email_policy.linesep)
             assert 'From: "Test Admin" <test-admin@users.localhost>' in body
             assert 'References: <ref>' in body
 
@@ -465,28 +465,34 @@ class TestMailTasks(unittest.TestCase):
             return_path, rcpts, body = _client.sendmail.call_args[0]
             assert 'From: "Test Admin" <test-admin@users.localhost>' in body
 
-    def test_send_email_long_lines_use_quoted_printable(self):
+    @pytest.mark.parametrize('bodychars', [
+        '0123456789',  # plain ascii is handled different since it doesn't necessarily need to be encoded
+        'Громады стро ',
+    ])
+    def test_send_email_long_lines(self, bodychars):
         with mock.patch.object(mail_tasks.smtp_client, '_client') as _client:
             mail_tasks.sendsimplemail(
                 fromaddr='"По" <foo@bar.com>',
                 toaddr='blah@blah.com',
-                text=('0123456789' * 100) + '\n\n' + ('Громады стро ' * 100),
+                text=bodychars * 100,
                 reply_to=g.noreply,
-                subject='По оживлённым берегам',
+                subject='123451234512345' * 100,
                 references=['foo@example.com'] * 100,  # needs to handle really long headers as well
                 message_id=h.gen_message_id())
             return_path, rcpts, body = _client.sendmail.call_args[0]
-            body = body.split('\n')
+            body_lines = body.split(email_policy.linesep)
 
-            for line in body:
+            for line in body_lines:
                 assert len(line) <= MAX_MAIL_LINE_OCTETS
 
-            # plain text
-            assert '012345678901234567890123456789012345678901234567890123456789012345678901234=' in body
-            assert '=D0=93=D1=80=D0=BE=D0=BC=D0=B0=D0=B4=D1=8B =D1=81=D1=82=D1=80=D0=BE =D0=93=' in body
-            # html
-            assert '<div class=3D"markdown_content"><p>0123456789012345678901234567890123456789=' in body
-            assert '<p>=D0=93=D1=80=D0=BE=D0=BC=D0=B0=D0=B4=D1=8B =D1=81=D1=82=D1=80=D0=BE =D0=' in body
+            msg = email.parser.Parser().parsestr(body)
+            plain_subpart = next(email.iterators.typed_subpart_iterator(msg, 'text', 'plain'))
+            plain = plain_subpart.get_payload(decode=True).decode('utf-8')
+            html_subpart = next(email.iterators.typed_subpart_iterator(msg, 'text', 'html')).get_payload(decode=True)
+            html = html_subpart.decode('utf-8')
+
+            assert (bodychars + bodychars) in plain
+            assert f'<div class="markdown_content"><p>{bodychars}{bodychars}' in html
 
     @td.with_wiki
     def test_receive_email_ok(self):
@@ -570,18 +576,18 @@ class TestUserNotificationTasks(TestController):
         assert 'auth/subscriptions#notifications' in text
 
 
-class TestNotificationTasks(unittest.TestCase):
+class TestNotificationTasks:
 
     def setup_method(self, method):
         setup_basic_test()
         setup_global_objects()
 
     def test_delivers_messages(self):
-        with mock.patch.object(M.Mailbox, 'deliver') as deliver:
-            with mock.patch.object(M.Mailbox, 'fire_ready') as fire_ready:
-                notification_tasks.notify('42', ['52'], 'none')
-                deliver.assert_called_with('42', ['52'], 'none')
-                fire_ready.assert_called_with()
+        with mock.patch.object(M.Mailbox, 'deliver') as deliver, \
+                mock.patch.object(M.Mailbox, 'fire_ready') as fire_ready:
+            notification_tasks.notify('42', ['52'], 'none')
+            deliver.assert_called_with('42', ['52'], 'none')
+            fire_ready.assert_called_with()
 
 
 @event_handler('my_event')
@@ -605,7 +611,7 @@ class _TestArtifact(M.Artifact):
             text=self.text)
 
 
-class TestExportTasks(unittest.TestCase):
+class TestExportTasks:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -621,13 +627,11 @@ class TestExportTasks(unittest.TestCase):
         exportable = mock.Mock(exportable=True)
         not_exportable = mock.Mock(exportable=False)
         BE = export_tasks.BulkExport()
-        self.assertEqual(
-            BE.filter_exportable([None, exportable, not_exportable]), [exportable])
+        assert BE.filter_exportable([None, exportable, not_exportable]) == [exportable]
 
     def test_bulk_export_filter_successful(self):
         BE = export_tasks.BulkExport()
-        self.assertEqual(
-            BE.filter_successful(['foo', None, '0']), ['foo', '0'])
+        assert BE.filter_successful(['foo', None, '0']) == ['foo', '0']
 
     @mock.patch('allura.tasks.export_tasks.shutil')
     @mock.patch('allura.tasks.export_tasks.zipdir')
@@ -659,7 +663,7 @@ class TestExportTasks(unittest.TestCase):
         assert c.project.bulk_export_status() == 'busy'
 
 
-class TestAdminTasks(unittest.TestCase):
+class TestAdminTasks:
 
     def test_install_app_docstring(self):
         assert 'ep_name, mount_point=None' in admin_tasks.install_app.__doc__
