@@ -17,11 +17,9 @@
 
 import json
 import time
-import unittest
 import datetime as dt
 from os import path
 
-import six
 import ming
 from ming.odm import session
 from bson import ObjectId
@@ -42,27 +40,27 @@ from allura.lib import helpers as h
 
 
 @patch.dict('allura.lib.utils.tg.config', clear=True, foo='bar', baz='true')
-class TestConfigProxy(unittest.TestCase):
+class TestConfigProxy:
 
     def setup_method(self, method):
         self.cp = utils.ConfigProxy(mybaz="baz")
 
     def test_getattr(self):
-        self.assertEqual(self.cp.foo, "bar")
-        self.assertEqual(self.cp.mybaz, "true")
+        assert self.cp.foo == "bar"
+        assert self.cp.mybaz == "true"
 
     def test_get(self):
-        self.assertEqual(self.cp.get("foo"), "bar")
-        self.assertEqual(self.cp.get("mybaz"), "true")
-        self.assertEqual(self.cp.get("fake"), None)
-        self.assertEqual(self.cp.get("fake", "default"), "default")
+        assert self.cp.get("foo") == "bar"
+        assert self.cp.get("mybaz") == "true"
+        assert self.cp.get("fake") is None
+        assert self.cp.get("fake", "default") == "default"
 
     def test_get_bool(self):
-        self.assertEqual(self.cp.get_bool("mybaz"), True)
-        self.assertEqual(self.cp.get_bool("fake"), False)
+        assert self.cp.get_bool("mybaz") is True
+        assert self.cp.get_bool("fake") is False
 
 
-class TestChunkedIterator(unittest.TestCase):
+class TestChunkedIterator:
 
     def setup_method(self, method):
         setup_unit_test()
@@ -75,8 +73,8 @@ class TestChunkedIterator(unittest.TestCase):
 
     def test_can_iterate(self):
         chunks = list(utils.chunked_find(M.User, {}, 2))
-        assert len(chunks) > 1, chunks
-        assert len(chunks[0]) == 2, chunks[0]
+        assert len(chunks) > 1
+        assert len(chunks[0]) == 2
 
     def test_filter_on_sort_key(self):
         query = {'username':
@@ -85,25 +83,25 @@ class TestChunkedIterator(unittest.TestCase):
                                          query,
                                          2,
                                          sort_key='username'))
-        assert len(chunks) == 2, chunks
-        assert len(chunks[0]) == 2, chunks[0]
-        assert len(chunks[1]) == 1, chunks[1]
+        assert len(chunks) == 2
+        assert len(chunks[0]) == 2
+        assert len(chunks[1]) == 1
         assert chunks[0][0].username == 'sample-user-1'
         assert chunks[0][1].username == 'sample-user-2'
         assert chunks[1][0].username == 'sample-user-3'
 
 
-class TestChunkedList(unittest.TestCase):
+class TestChunkedList:
 
     def test_chunked_list(self):
         l = list(range(10))
         chunks = list(utils.chunked_list(l, 3))
-        self.assertEqual(len(chunks), 4)
-        self.assertEqual(len(chunks[0]), 3)
-        self.assertEqual([el for sublist in chunks for el in sublist], l)
+        assert len(chunks) == 4
+        assert len(chunks[0]) == 3
+        assert [el for sublist in chunks for el in sublist] == l
 
 
-class TestAntispam(unittest.TestCase):
+class TestAntispam:
 
     def setup_method(self, method):
         setup_unit_test()
@@ -111,17 +109,15 @@ class TestAntispam(unittest.TestCase):
 
     def test_generate_fields(self):
         fields = '\n'.join(self.a.extra_fields())
-        assert 'name="timestamp"' in fields, fields
-        assert 'name="spinner"' in fields, fields
-        assert ('class="%s"' % self.a.honey_class) in fields, fields
+        assert 'name="timestamp"' in fields
+        assert 'name="spinner"' in fields
+        assert ('class="%s"' % self.a.honey_class) in fields
 
     def test_invalid_old(self):
         form = dict(a='1', b='2')
         r = Request.blank('/', POST=self._encrypt_form(**form))
-        self.assertRaises(
-            ValueError,
-            utils.AntiSpam.validate_request,
-            r, now=time.time() + 24 * 60 * 60 * 4 + 1)
+        with pytest.raises(ValueError):
+            utils.AntiSpam.validate_request(r, now=time.time() + 24 * 60 * 60 * 4 + 1)
 
     def test_valid_submit(self):
         form = dict(a='1', b='2')
@@ -129,35 +125,36 @@ class TestAntispam(unittest.TestCase):
                           environ={'remote_addr': '127.0.0.1'}
                           )
         validated = utils.AntiSpam.validate_request(r)
-        assert dict(a='1', b='2') == validated, validated
+        assert dict(a='1', b='2') == validated
 
     def test_invalid_future(self):
         form = dict(a='1', b='2')
         r = Request.blank('/', POST=self._encrypt_form(**form))
-        self.assertRaises(
-            ValueError,
-            utils.AntiSpam.validate_request,
-            r, now=time.time() - 10)
+        with pytest.raises(ValueError):
+            utils.AntiSpam.validate_request(r, now=time.time() - 10)
 
     def test_invalid_spinner(self):
         form = dict(a='1', b='2')
         eform = self._encrypt_form(**form)
         eform['spinner'] += 'a'
         r = Request.blank('/', POST=eform)
-        self.assertRaises(ValueError, utils.AntiSpam.validate_request, r)
+        with pytest.raises(ValueError):
+            utils.AntiSpam.validate_request(r)
 
     def test_invalid_honey(self):
         form = dict(a='1', b='2', honey0='a')
         eform = self._encrypt_form(**form)
         r = Request.blank('/', POST=eform)
-        self.assertRaises(ValueError, utils.AntiSpam.validate_request, r)
+        with pytest.raises(ValueError):
+            utils.AntiSpam.validate_request(r)
 
     def test_missing_honey(self):
         form = dict(a='1', b='2')
         eform = self._encrypt_form(**form)
         del eform[self.a.enc('honey0')]
         r = Request.blank('/', POST=eform)
-        self.assertRaises(ValueError, utils.AntiSpam.validate_request, r)
+        with pytest.raises(ValueError):
+            utils.AntiSpam.validate_request(r)
 
     def _encrypt_form(self, **kwargs):
         encrypted_form = {
@@ -169,28 +166,7 @@ class TestAntispam(unittest.TestCase):
         return encrypted_form
 
 
-class TestTruthyCallable(unittest.TestCase):
-
-    def test_everything(self):
-        def wrapper_func(bool_flag):
-            def predicate(bool_flag=bool_flag):
-                return bool_flag
-            return utils.TruthyCallable(predicate)
-        true_predicate = wrapper_func(True)
-        false_predicate = wrapper_func(False)
-        assert true_predicate(True) is True
-        assert false_predicate(False) is False
-        assert true_predicate() is True
-        assert false_predicate() is False
-        assert bool(true_predicate) is True
-        assert bool(false_predicate) is False
-
-        t, f = True, False  # use variables because '== True' would generate warnings, and we do want '==' not 'is'
-        assert true_predicate == t
-        assert false_predicate == f
-
-
-class TestCaseInsensitiveDict(unittest.TestCase):
+class TestCaseInsensitiveDict:
 
     def test_everything(self):
         d = utils.CaseInsensitiveDict(Foo=5)
@@ -200,7 +176,7 @@ class TestCaseInsensitiveDict(unittest.TestCase):
         d['bar'] = 7
         assert d['bar'] == d['bAr'] == 7
         del d['bar']
-        assert len(d) == 1, d
+        assert len(d) == 1
         assert d.get('foo') == 5
         d.update(foo=1, Bar=2)
         assert d.get('FOO') == 1
@@ -209,7 +185,7 @@ class TestCaseInsensitiveDict(unittest.TestCase):
         assert d == utils.CaseInsensitiveDict(Foo=1, bar=2)
 
 
-class TestLineAnchorCodeHtmlFormatter(unittest.TestCase):
+class TestLineAnchorCodeHtmlFormatter:
 
     def test_render(self):
         code = '#!/usr/bin/env python\n'\
@@ -229,7 +205,7 @@ class TestLineAnchorCodeHtmlFormatter(unittest.TestCase):
             assert '<span class="linenos">1</span>' in hl_code
 
 
-class TestIsTextFile(unittest.TestCase):
+class TestIsTextFile:
 
     def test_is_text_file(self):
         here_dir = path.dirname(__file__)
@@ -239,7 +215,7 @@ class TestIsTextFile(unittest.TestCase):
         assert not utils.is_text_file(open(bin_file, 'rb').read())
 
 
-class TestCodeStats(unittest.TestCase):
+class TestCodeStats:
 
     def setup_method(self, method):
         setup_unit_test()
@@ -263,7 +239,7 @@ class TestCodeStats(unittest.TestCase):
         assert stats['code_size'] == len(blob.text)
 
 
-class TestHTMLSanitizer(unittest.TestCase):
+class TestHTMLSanitizer:
 
     def walker_from_text(self, text):
         parsed = html5lib.parseFragment(text)
@@ -313,8 +289,7 @@ def test_ip_address():
     req = Mock()
     req.remote_addr = '1.2.3.4'
     req.headers = {}
-    assert (utils.ip_address(req) ==
-            '1.2.3.4')
+    assert utils.ip_address(req) == '1.2.3.4'
 
 
 def test_ip_address_header():
@@ -322,8 +297,7 @@ def test_ip_address_header():
     req.remote_addr = '1.2.3.4'
     req.headers = {'X_FORWARDED_FOR': '5.6.7.8'}
     with h.push_config(config, **{'ip_address_header': 'X_FORWARDED_FOR'}):
-        assert (utils.ip_address(req) ==
-                '5.6.7.8')
+        assert utils.ip_address(req) == '5.6.7.8'
 
 
 def test_ip_address_header_not_set():
@@ -331,8 +305,7 @@ def test_ip_address_header_not_set():
     req.remote_addr = '1.2.3.4'
     req.headers = {}
     with h.push_config(config, **{'ip_address_header': 'X_FORWARDED_FOR'}):
-        assert (utils.ip_address(req) ==
-                '1.2.3.4')
+        assert utils.ip_address(req) == '1.2.3.4'
 
 
 def test_empty_cursor():
@@ -347,9 +320,12 @@ def test_empty_cursor():
     assert cursor.hint('index') == cursor
     assert cursor.extensions == []
     assert cursor.options(arg1='val1', arg2='val2') == cursor
-    pytest.raises(ValueError, cursor.one)
-    pytest.raises(StopIteration, cursor.next)
-    pytest.raises(StopIteration, cursor._next_impl)
+    with pytest.raises(ValueError):
+        cursor.one()
+    with pytest.raises(StopIteration):
+        cursor.next()
+    with pytest.raises(StopIteration):
+        cursor._next_impl()
 
 
 def test_DateJSONEncoder():
@@ -357,7 +333,7 @@ def test_DateJSONEncoder():
             'date': dt.datetime(2015, 1, 30, 13, 13, 13)}
     result = json.dumps(data, cls=utils.DateJSONEncoder)
     assert result in ['{"date": "2015-01-30T13:13:13Z", "message": "Hi!"}',
-                      '{"message": "Hi!", "date": "2015-01-30T13:13:13Z"}'], result
+                      '{"message": "Hi!", "date": "2015-01-30T13:13:13Z"}']
 
 
 def test_clean_phone_number():
