@@ -15,7 +15,7 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-import unittest
+import pytest
 import formencode as fe
 from mock import Mock, patch
 
@@ -35,23 +35,23 @@ def dummy_task(*args, **kw):
     pass
 
 
-class TestJsonConverter(unittest.TestCase):
+class TestJsonConverter:
     val = v.JsonConverter
 
     def setup_method(self, method):
         _setup_method()
 
     def test_valid(self):
-        self.assertEqual({}, self.val.to_python('{}'))
+        assert {} == self.val.to_python('{}')
 
     def test_invalid(self):
-        with self.assertRaises(fe.Invalid):
+        with pytest.raises(fe.Invalid):
             self.val.to_python('{')
-        with self.assertRaises(fe.Invalid):
+        with pytest.raises(fe.Invalid):
             self.val.to_python('3')
 
 
-class TestJsonFile(unittest.TestCase):
+class TestJsonFile:
 
     def setup_method(self, method):
         _setup_method()
@@ -64,14 +64,14 @@ class TestJsonFile(unittest.TestCase):
             self.value = content
 
     def test_valid(self):
-        self.assertEqual({}, self.val.to_python(self.FieldStorage('{}')))
+        assert {} == self.val.to_python(self.FieldStorage('{}'))
 
     def test_invalid(self):
-        with self.assertRaises(fe.Invalid):
+        with pytest.raises(fe.Invalid):
             self.val.to_python(self.FieldStorage('{'))
 
 
-class TestUserMapFile(unittest.TestCase):
+class TestUserMapFile:
     val = v.UserMapJsonFile()
 
     def setup_method(self, method):
@@ -83,36 +83,35 @@ class TestUserMapFile(unittest.TestCase):
             self.value = content
 
     def test_valid(self):
-        self.assertEqual({"user_old": "user_new"}, self.val.to_python(
-            self.FieldStorage('{"user_old": "user_new"}')))
+        assert {"user_old": "user_new"} == self.val.to_python(
+            self.FieldStorage('{"user_old": "user_new"}'))
 
     def test_invalid(self):
-        with self.assertRaises(fe.Invalid):
+        with pytest.raises(fe.Invalid):
             self.val.to_python(self.FieldStorage('{"user_old": 1}'))
 
     def test_as_string(self):
         val = v.UserMapJsonFile(as_string=True)
-        self.assertEqual('{"user_old": "user_new"}', val.to_python(
-            self.FieldStorage('{"user_old": "user_new"}')))
+        assert '{"user_old": "user_new"}' == val.to_python(
+            self.FieldStorage('{"user_old": "user_new"}'))
 
 
-class TestUserValidator(unittest.TestCase):
+class TestUserValidator:
     val = v.UserValidator
 
     def setup_method(self, method):
         _setup_method()
 
     def test_valid(self):
-        self.assertEqual(M.User.by_username('root'),
-                         self.val.to_python('root'))
+        assert M.User.by_username('root') == self.val.to_python('root')
 
     def test_invalid(self):
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python('fakeuser')
-        self.assertEqual(str(cm.exception), "Invalid username")
+        assert str(cm.value) == "Invalid username"
 
 
-class TestAnonymousValidator(unittest.TestCase):
+class TestAnonymousValidator:
     val = v.AnonymousValidator
 
     def setup_method(self, method):
@@ -121,17 +120,17 @@ class TestAnonymousValidator(unittest.TestCase):
     @patch('allura.lib.validators.c')
     def test_valid(self, c):
         c.user = M.User.by_username('root')
-        self.assertEqual(True, self.val.to_python(True))
+        assert self.val.to_python(True)
 
     @patch('allura.lib.validators.c')
     def test_invalid(self, c):
         c.user = M.User.anonymous()
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python(True)
-        self.assertEqual(str(cm.exception), "Log in to Mark as Private")
+        assert str(cm.value) == "Log in to Mark as Private"
 
 
-class TestMountPointValidator(unittest.TestCase):
+class TestMountPointValidator:
 
     def setup_method(self, method):
         _setup_method()
@@ -143,7 +142,7 @@ class TestMountPointValidator(unittest.TestCase):
         App.validate_mount_point.return_value = True
         c.project.app_instance.return_value = None
         val = v.MountPointValidator(App)
-        self.assertEqual('mymount', val.to_python('Mymount'))
+        assert 'mymount' == val.to_python('Mymount')
 
     @patch('allura.lib.validators.c')
     def test_invalid(self, c):
@@ -152,7 +151,7 @@ class TestMountPointValidator(unittest.TestCase):
         App.validate_mount_point.return_value = False
         c.project.app_instance.return_value = False
         val = v.MountPointValidator(App)
-        with self.assertRaises(fe.Invalid):
+        with pytest.raises(fe.Invalid):
             val.to_python('mymount')
 
     @patch('allura.lib.validators.c')
@@ -162,7 +161,7 @@ class TestMountPointValidator(unittest.TestCase):
         App.validate_mount_point.return_value = True
         c.project.app_instance.return_value = None
         val = v.MountPointValidator(App)
-        self.assertEqual('Mymount', val.to_python('Mymount'))
+        assert 'Mymount' == val.to_python('Mymount')
 
     @patch('allura.lib.validators.c')
     def test_in_use(self, c):
@@ -171,7 +170,7 @@ class TestMountPointValidator(unittest.TestCase):
         App.validate_mount_point.return_value = True
         c.project.app_instance.return_value = True
         val = v.MountPointValidator(App)
-        with self.assertRaises(fe.Invalid):
+        with pytest.raises(fe.Invalid):
             val.to_python('mymount')
 
     @patch('allura.lib.validators.c')
@@ -181,7 +180,7 @@ class TestMountPointValidator(unittest.TestCase):
         App.validate_mount_point.return_value = True
         c.project.app_instance.return_value = False
         val = v.MountPointValidator(App)
-        with self.assertRaises(fe.Invalid):
+        with pytest.raises(fe.Invalid):
             val.to_python('feed')
 
     @patch('allura.lib.validators.c')
@@ -190,44 +189,41 @@ class TestMountPointValidator(unittest.TestCase):
         App.default_mount_point = 'wiki'
         c.project.app_instance.side_effect = lambda mp: None if mp != 'wiki' else True
         val = v.MountPointValidator(App)
-        self.assertEqual('wiki-0', val.to_python(''))
-        self.assertEqual('wiki-0', val.to_python(None))
+        assert 'wiki-0' == val.to_python('')
+        assert 'wiki-0' == val.to_python(None)
 
 
-class TestTaskValidator(unittest.TestCase):
+class TestTaskValidator:
     val = v.TaskValidator
 
     def setup_method(self, method):
         _setup_method()
 
     def test_valid(self):
-        self.assertEqual(
-            dummy_task, self.val.to_python('allura.tests.test_validators.dummy_task'))
+        assert dummy_task == self.val.to_python('allura.tests.test_validators.dummy_task')
 
     def test_invalid_name(self):
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python('badname')
-        self.assertTrue(str(cm.exception).startswith('Invalid task name'))
+        assert str(cm.value).startswith('Invalid task name')
 
     def test_import_failure(self):
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python('allura.does.not.exist')
-        self.assertEqual(str(cm.exception),
-                         'Could not import "allura.does.not.exist"')
+        assert str(cm.value) == 'Could not import "allura.does.not.exist"'
 
     def test_attr_lookup_failure(self):
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python('allura.tests.test_validators.typo')
-        self.assertEqual(str(cm.exception), 'Module has no attribute "typo"')
+        assert str(cm.value) == 'Module has no attribute "typo"'
 
     def test_not_a_task(self):
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python('allura.tests.test_validators._setup_method')
-        self.assertEqual(str(cm.exception),
-                         '"allura.tests.test_validators._setup_method" is not a task.')
+        assert str(cm.value) == '"allura.tests.test_validators._setup_method" is not a task.'
 
 
-class TestPathValidator(unittest.TestCase):
+class TestPathValidator:
     val = v.PathValidator(strip=True, if_missing={}, if_empty={})
 
     def setup_method(self, method):
@@ -236,91 +232,91 @@ class TestPathValidator(unittest.TestCase):
     def test_valid_project(self):
         project = M.Project.query.get(shortname='test')
         d = self.val.to_python('/p/test')
-        self.assertEqual(d['project'], project)
-        self.assertTrue('app' not in d)
+        assert d['project'] == project
+        assert 'app' not in d
 
     def test_project_in_nbhd_with_prefix(self):
         create_user('myuser', make_project=True)
         project = M.Project.query.get(shortname='u/myuser')
         d = self.val.to_python('/u/myuser')
-        self.assertEqual(d['project'], project)
-        self.assertTrue('app' not in d)
+        assert d['project'] == project
+        assert 'app' not in d
 
     def test_valid_app(self):
         project = M.Project.query.get(shortname='test')
         app = project.app_instance('admin')
         d = self.val.to_python('/p/test/admin/')
-        self.assertEqual(d['project'], project)
-        self.assertEqual(d['app'].config._id, app.config._id)
+        assert d['project'] == project
+        assert d['app'].config._id == app.config._id
 
     def test_invalid_format(self):
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python('test')
-        self.assertTrue(str(cm.exception).startswith(
-            'You must specify at least a neighborhood and project'))
+        assert str(cm.value).startswith(
+            'You must specify at least a neighborhood and project')
 
     def test_invalid_neighborhood(self):
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python('/q/test')
-        self.assertEqual(str(cm.exception), 'Invalid neighborhood: /q/')
+        assert str(cm.value) == 'Invalid neighborhood: /q/'
 
     def test_invalid_project(self):
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python('/p/badproject')
-        self.assertEqual(str(cm.exception), 'Invalid project: badproject')
+        assert str(cm.value) == 'Invalid project: badproject'
 
     def test_invalid_app_mount_point(self):
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python('/p/test/badapp')
-        self.assertEqual(str(cm.exception), 'Invalid app mount point: badapp')
+        assert str(cm.value) == 'Invalid app mount point: badapp'
 
     def test_no_input(self):
-        self.assertEqual({}, self.val.to_python(''))
+        assert {} == self.val.to_python('')
 
 
-class TestUrlValidator(unittest.TestCase):
+class TestUrlValidator:
     val = v.URL
 
     def setup_method(self, method):
         _setup_method()
 
     def test_valid(self):
-        self.assertEqual('http://192.168.0.1', self.val.to_python('192.168.0.1'))
-        self.assertEqual('http://url', self.val.to_python('url'))
+        assert 'http://192.168.0.1' == self.val.to_python('192.168.0.1')
+        assert 'http://url' == self.val.to_python('url')
 
     def test_invalid_ip(self):
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python('192.168.0')
-        self.assertEqual(str(cm.exception), 'That is not a valid URL')
+        assert str(cm.value) == 'That is not a valid URL'
 
     def test_invalid_url(self):
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python('u"rl')
-        self.assertEqual(str(cm.exception), 'That is not a valid URL')
+        assert str(cm.value) == 'That is not a valid URL'
 
 
-class TestNonHttpUrlValidator(unittest.TestCase):
+class TestNonHttpUrlValidator:
     val = v.NonHttpUrl
 
     def setup_method(self, method):
         _setup_method()
 
     def test_valid(self):
-        self.assertEqual('svn://192.168.0.1', self.val.to_python('svn://192.168.0.1'))
-        self.assertEqual('ssh+git://url', self.val.to_python('ssh+git://url'))
+        assert 'svn://192.168.0.1' == self.val.to_python('svn://192.168.0.1')
+        assert 'ssh+git://url' == self.val.to_python('ssh+git://url')
 
     def test_invalid(self):
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python('http://u"rl')
-        self.assertEqual(str(cm.exception), 'That is not a valid URL')
+        assert str(cm.value) == 'That is not a valid URL'
 
     def test_no_scheme(self):
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python('url')
-        self.assertEqual(str(cm.exception), 'You must start your URL with a scheme')
+        assert str(cm.value) == 'You must start your URL with a scheme'
 
 
-class TestIconValidator(unittest.TestCase):
+class TestIconValidator:
     val = v.IconValidator
 
     def _mock(self, val):
@@ -333,21 +329,21 @@ class TestIconValidator(unittest.TestCase):
 
     def test_valid(self):
         input = self._mock('foo.png')
-        self.assertEqual(input, self.val.to_python(input))
+        assert input == self.val.to_python(input)
 
         input = self._mock('foo.jpg')
-        self.assertEqual(input, self.val.to_python(input))
+        assert input == self.val.to_python(input)
 
         input = self._mock('svg.jpg')
-        self.assertEqual(input, self.val.to_python(input))
+        assert input == self.val.to_python(input)
 
     def test_invalid(self):
         input = self._mock('foo.svg')
-        with self.assertRaises(fe.Invalid) as cm:
+        with pytest.raises(fe.Invalid) as cm:
             self.val.to_python(input)
-        self.assertEqual(str(cm.exception), 'Project icons must be PNG, GIF, JPG, or BMP format.')
+        assert str(cm.value) == 'Project icons must be PNG, GIF, JPG, or BMP format.'
 
         input = self._mock('foogif.svg')
-        with self.assertRaises(fe.Invalid) as cm:
-            self.assertEqual(input, self.val.to_python(input))
-        self.assertEqual(str(cm.exception), 'Project icons must be PNG, GIF, JPG, or BMP format.')
+        with pytest.raises(fe.Invalid) as cm:
+            assert input == self.val.to_python(input)
+        assert str(cm.value) == 'Project icons must be PNG, GIF, JPG, or BMP format.'
