@@ -21,7 +21,7 @@ from allura import model as M
 
 log = logging.getLogger(__name__)
 
-print 'In a script'
+print('In a script')
 log.info('in a script')
 
 for p in M.Project.query.find():
