@@ -18,6 +18,8 @@
 import json
 from mock import patch
 
+import markupsafe
+
 from allura.lib.phone.nexmo import NexmoPhoneService
 
 
@@ -70,6 +72,12 @@ class TestPhoneService:
         assert 'country code' in res['error']
         assert 'US' not in res['error']
 
+        # markupsafe testing
+        res = self.phone.error(code='3', msg='nexmo msg 3 > 4 number', number='123<script>foo</script>')
+        assert res['status'] == 'error'
+        assert isinstance(res['error'], markupsafe.Markup)
+        assert res['error'] == 'nexmo msg 3 &gt; 4 number<br>Make sure you include the country code (see examples above)'
+
     def test_ok(self):
         res = self.phone.ok(request_id='123', other='smth')
         expected = {'status': 'ok', 'request_id': '123', 'other': 'smth'}
@@ -95,7 +103,9 @@ class TestPhoneService:
         req.post.assert_called_once_with(
             'https://api.nexmo.com/verify/json',
             data=data,
-            headers=headers)
+            headers=headers,
+            timeout=30,
+        )
 
         req.post.reset_mock()
         req.post.return_value.json.return_value = {
@@ -108,7 +118,9 @@ class TestPhoneService:
         req.post.assert_called_once_with(
             'https://api.nexmo.com/verify/json',
             data=data,
-            headers=headers)
+            headers=headers,
+            timeout=30,
+        )
 
     @patch('allura.lib.phone.nexmo.requests', autospec=True)
     def test_verify_exception(self, req):
@@ -138,7 +150,9 @@ class TestPhoneService:
         req.post.assert_called_once_with(
             'https://api.nexmo.com/verify/check/json',
             data=data,
-            headers=headers)
+            headers=headers,
+            timeout=30,
+        )
 
         req.post.reset_mock()
         req.post.return_value.json.return_value = {
@@ -151,7 +165,9 @@ class TestPhoneService:
         req.post.assert_called_once_with(
             'https://api.nexmo.com/verify/check/json',
             data=data,
-            headers=headers)
+            headers=headers,
+            timeout=30,
+        )
 
     @patch('allura.lib.phone.nexmo.requests', autospec=True)
     def test_check_exception(self, req):
