@@ -17,7 +17,7 @@
 
 
 import mock
-import unittest
+import pytest
 import six.moves.urllib.request
 import six.moves.urllib.parse
 import six.moves.urllib.error
@@ -28,17 +28,21 @@ from bson import ObjectId
 from allura.lib.spam.akismetfilter import AKISMET_AVAILABLE, AkismetSpamFilter
 
 
-@unittest.skipIf(not AKISMET_AVAILABLE, "Akismet not available")
-class TestAkismet(unittest.TestCase):
+@pytest.mark.skipif(not AKISMET_AVAILABLE, reason="Akismet not available")
+class TestAkismet:
 
     @mock.patch('allura.lib.spam.akismetfilter.akismet')
     def setup_method(self, method, akismet_lib):
+        from akismet import CheckResponse
+
         self.akismet = AkismetSpamFilter({'spam.key': 'example', 'base_url': 'http://localhost/'})
 
         def side_effect(*args, **kw):
             # side effect to test that data being sent to
             # akismet can be successfully urlencoded
             six.moves.urllib.parse.urlencode(kw.get('data', {}))
+            return CheckResponse.HAM  # relevant to comment_check()
+
         self.akismet.service.comment_check = mock.Mock(side_effect=side_effect)
         self.akismet.service.submit_spam = mock.Mock(side_effect=side_effect)
         self.akismet.service.submit_ham = mock.Mock(side_effect=side_effect)
@@ -64,11 +68,11 @@ class TestAkismet(unittest.TestCase):
             REFERER='some url')
         self.content = 'spåm text'
         self.expected_data = dict(
-            comment_content=self.content.encode('utf8'),
-            comment_type=b'comment',
-            user_ip=b'some ip',
-            user_agent=b'some browser',
-            referrer=b'some url')
+            comment_content=self.content,
+            comment_type='comment',
+            user_ip='some ip',
+            user_agent='some browser',
+            referrer='some url')
 
     @mock.patch('allura.lib.spam.akismetfilter.c')
     @mock.patch('allura.lib.spam.akismetfilter.request')
@@ -87,7 +91,7 @@ class TestAkismet(unittest.TestCase):
         request.remote_addr = 'some ip'
         c.user = None
         self.akismet.check(self.content, content_type='some content type')
-        self.expected_data['comment_type'] = b'some content type'
+        self.expected_data['comment_type'] = 'some content type'
         self.akismet.service.comment_check.assert_called_once_with(**self.expected_data)
 
     @mock.patch('allura.lib.spam.akismetfilter.c')
@@ -98,9 +102,9 @@ class TestAkismet(unittest.TestCase):
         c.user = None
         self.akismet.check(self.content, artifact=self.fake_artifact)
         expected_data = self.expected_data
-        expected_data['permalink'] = b'http://localhost/artifact-url'
-        expected_data['comment_date_gmt'] = b'2019-05-17T00:00:00'
-        expected_data['comment_post_modified_gmt'] = b'2019-05-17T00:05:01'
+        expected_data['permalink'] = 'http://localhost/artifact-url'
+        expected_data['comment_date_gmt'] = '2019-05-17T00:00:00'
+        expected_data['comment_post_modified_gmt'] = '2019-05-17T00:05:01'
         self.akismet.service.comment_check.assert_called_once_with(**expected_data)
 
     @mock.patch('allura.lib.spam.akismetfilter.c')
@@ -111,8 +115,8 @@ class TestAkismet(unittest.TestCase):
         c.user = None
         self.akismet.check(self.content, user=self.fake_user)
         expected_data = self.expected_data
-        expected_data.update(comment_author='Søme User'.encode(),
-                             comment_author_email=b'user@domain')
+        expected_data.update(comment_author='Søme User',
+                             comment_author_email='user@domain')
         self.akismet.service.comment_check.assert_called_once_with(**expected_data)
 
     @mock.patch('allura.lib.spam.akismetfilter.c')
@@ -123,8 +127,8 @@ class TestAkismet(unittest.TestCase):
         c.user = self.fake_user
         self.akismet.check(self.content)
         expected_data = self.expected_data
-        expected_data.update(comment_author='Søme User'.encode(),
-                             comment_author_email=b'user@domain')
+        expected_data.update(comment_author='Søme User',
+                             comment_author_email='user@domain')
         self.akismet.service.comment_check.assert_called_once_with(**expected_data)
 
     @mock.patch('allura.lib.spam.akismetfilter.c')
@@ -134,10 +138,10 @@ class TestAkismet(unittest.TestCase):
         self.akismet.submit_spam(self.content)
 
         # no IP addr, UA, etc, since this isn't the original request
-        expected_data = dict(comment_content='spåm text'.encode(),
-                             comment_type=b'comment',
-                             user_ip=b'',
-                             user_agent=b'',
+        expected_data = dict(comment_content='spåm text',
+                             comment_type='comment',
+                             user_ip=None,
+                             user_agent=None,
                              )
         self.akismet.service.submit_spam.assert_called_once_with(**expected_data)
 
@@ -148,10 +152,10 @@ class TestAkismet(unittest.TestCase):
         self.akismet.submit_ham(self.content)
 
         # no IP addr, UA, etc, since this isn't the original request
-        expected_data = dict(comment_content='spåm text'.encode(),
-                             comment_type=b'comment',
-                             user_ip=b'',
-                             user_agent=b'',
+        expected_data = dict(comment_content='spåm text',
+                             comment_type='comment',
+                             user_ip=None,
+                             user_agent=None,
                              )
         self.akismet.service.submit_ham.assert_called_once_with(**expected_data)
 
@@ -161,12 +165,12 @@ class TestAkismet(unittest.TestCase):
 
         self.akismet.submit_ham(self.content, artifact=self.fake_artifact)
 
-        expected_data = dict(comment_content='spåm text'.encode(),
-                             comment_type=b'comment',
-                             user_ip=b'33.4.5.66',
-                             user_agent=b'',
-                             permalink=b'http://localhost/artifact-url',
-                             comment_date_gmt=b'2019-05-17T00:00:00',
-                             comment_post_modified_gmt=b'2019-05-17T00:05:01',
+        expected_data = dict(comment_content='spåm text',
+                             comment_type='comment',
+                             user_ip='33.4.5.66',
+                             user_agent=None,
+                             permalink='http://localhost/artifact-url',
+                             comment_date_gmt='2019-05-17T00:00:00',
+                             comment_post_modified_gmt='2019-05-17T00:05:01',
                              )
         self.akismet.service.submit_ham.assert_called_once_with(**expected_data)
