@@ -16,7 +16,6 @@
 #       under the License.
 
 import mock
-import unittest
 
 from ming.odm import ThreadLocalODMSession
 
@@ -45,23 +44,23 @@ class MockFilter2(SpamFilter):
         return True
 
 
-class TestSpamFilter(unittest.TestCase):
+class TestSpamFilter:
 
     def test_check(self):
         # default no-op impl always returns False
-        self.assertFalse(SpamFilter({}).check('foo'))
+        assert not SpamFilter({}).check('foo')
 
     def test_get_default(self):
         config = {}
         entry_points = None
         checker = SpamFilter.get(config, entry_points)
-        self.assertTrue(isinstance(checker, SpamFilter))
+        assert isinstance(checker, SpamFilter)
 
     def test_get_method(self):
         config = {'spam.method': 'mock'}
         entry_points = {'mock': MockFilter}
         checker = SpamFilter.get(config, entry_points)
-        self.assertTrue(isinstance(checker, MockFilter))
+        assert isinstance(checker, MockFilter)
 
     @mock.patch('allura.lib.spam.log')
     def test_exceptionless_check(self, log):
@@ -69,8 +68,8 @@ class TestSpamFilter(unittest.TestCase):
         entry_points = {'mock': MockFilter}
         checker = SpamFilter.get(config, entry_points)
         result = checker.check('this is our text')
-        self.assertFalse(result)
-        self.assertTrue(log.exception.called)
+        assert not result
+        assert log.exception.called
 
 
 class TestSpamFilterFunctional:
