@@ -17,7 +17,6 @@
 
 
 from collections import OrderedDict
-from unittest import TestCase
 
 import jinja2
 import mock
@@ -27,7 +26,7 @@ from tg import config
 from allura.lib.package_path_loader import PackagePathLoader
 
 
-class TestPackagePathLoader(TestCase):
+class TestPackagePathLoader:
 
     @mock.patch('pkg_resources.resource_filename')
     @mock.patch('pkg_resources.iter_entry_points')
@@ -50,7 +49,7 @@ class TestPackagePathLoader(TestCase):
             ['ep2', 'path:eps.ep2'],
             ['allura', '/'],
         ]
-        assert type(paths[0]) == list
+        assert isinstance(paths[0], list)
         assert resource_filename.call_args_list == [
             mock.call('eps.ep0', ''),
             mock.call('eps.ep1', ''),
@@ -79,7 +78,8 @@ class TestPackagePathLoader(TestCase):
         for ep in eps:
             ep.name = ep.ep_name
             ep.load.return_value.template_path_rules = ep.rules
-        pytest.raises(jinja2.TemplateError, PackagePathLoader()._load_rules)
+        with pytest.raises(jinja2.TemplateError):
+            PackagePathLoader()._load_rules()
 
     def test_replace_signposts(self):
         ppl = PackagePathLoader()
@@ -217,14 +217,12 @@ class TestPackagePathLoader(TestCase):
         ppl.init_paths = mock.Mock()
         fs_loader().get_source.side_effect = jinja2.TemplateNotFound('test')
 
-        pytest.raises(
-            jinja2.TemplateError,
-            ppl.get_source, 'env', 'allura.ext.admin:templates/audit.html')
+        with pytest.raises(jinja2.TemplateError):
+            ppl.get_source('env', 'allura.ext.admin:templates/audit.html')
         assert fs_loader().get_source.call_count == 1
         fs_loader().get_source.reset_mock()
 
-        with mock.patch.dict(config, {'disable_template_overrides': False}):
-            pytest.raises(
-                jinja2.TemplateError,
-                ppl.get_source, 'env', 'allura.ext.admin:templates/audit.html')
+        with mock.patch.dict(config, {'disable_template_overrides': False}), \
+                pytest.raises(jinja2.TemplateError):
+            ppl.get_source('env', 'allura.ext.admin:templates/audit.html')
             assert fs_loader().get_source.call_count == 2
