@@ -15,7 +15,6 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-import unittest
 from mock import Mock
 
 from tg import config
@@ -25,7 +24,7 @@ from allura.lib import helpers as h
 from allura.app import SitemapEntry
 
 
-class TestProject(unittest.TestCase):
+class TestProject:
 
     def test_grouped_navbar_entries(self):
         p = M.Project()
@@ -50,8 +49,8 @@ class TestProject(unittest.TestCase):
         ]
         expected_ticket_urls = ['bugs url', 'features url', 'support url']
         actual = [(e.label, e.url, len(e.matching_urls)) for e in entries]
-        self.assertEqual(expected, actual)
-        self.assertEqual(entries[0].matching_urls, expected_ticket_urls)
+        assert expected == actual
+        assert entries[0].matching_urls == expected_ticket_urls
 
     def test_grouped_navbar_threshold(self):
         p = M.Project()
@@ -78,37 +77,36 @@ class TestProject(unittest.TestCase):
         ]
         expected_ticket_urls = ['bugs url', 'features url', 'support url']
         actual = [(e.label, e.url, len(e.matching_urls)) for e in entries]
-        self.assertEqual(expected, actual)
-        self.assertEqual(entries[0].matching_urls, expected_ticket_urls)
+        assert expected == actual
+        assert entries[0].matching_urls == expected_ticket_urls
 
     def test_social_account(self):
         p = M.Project()
-        self.assertIsNone(p.social_account('Twitter'))
+        assert p.social_account('Twitter') is None
 
         p.set_social_account('Twitter', 'http://twitter.com/allura')
-        self.assertEqual(p.social_account('Twitter')
-                         .accounturl, 'http://twitter.com/allura')
-        self.assertEqual(p.twitter_handle, 'http://twitter.com/allura')
+        assert p.social_account('Twitter').accounturl == 'http://twitter.com/allura'
+        assert p.twitter_handle == 'http://twitter.com/allura'
 
     def test_should_update_index(self):
         p = M.Project()
-        self.assertFalse(p.should_update_index({}, {}))
+        assert not p.should_update_index({}, {})
         old = {'last_updated': 1}
         new = {'last_updated': 2}
-        self.assertFalse(p.should_update_index(old, new))
+        assert not p.should_update_index(old, new)
         old = {'last_updated': 1, 'a': 1}
         new = {'last_updated': 2, 'a': 1}
-        self.assertFalse(p.should_update_index(old, new))
+        assert not p.should_update_index(old, new)
         old = {'last_updated': 1, 'a': 1}
         new = {'last_updated': 2, 'a': 2}
-        self.assertTrue(p.should_update_index(old, new))
+        assert p.should_update_index(old, new)
 
     def test_icon_url(self):
         p = M.Project(
             shortname='myproj',
-            neighborhood = M.Neighborhood(url_prefix='/nbhd/'),
+            neighborhood=M.Neighborhood(url_prefix='/nbhd/'),
         )
-        self.assertEqual(p.icon_url(), '/nbhd/myproj/icon')
+        assert p.icon_url() == '/nbhd/myproj/icon'
 
         with h.push_config(config, **{'static.icon_base': 'https://mycdn.com/mysite'}):
-            self.assertEqual(p.icon_url(), 'https://mycdn.com/mysite/nbhd/myproj/icon')
+            assert p.icon_url() == 'https://mycdn.com/mysite/nbhd/myproj/icon'
