@@ -16,9 +16,8 @@
 #       under the License.
 
 import datetime
-import unittest
 
-import six
+import pytest
 from mock import patch, Mock, MagicMock, call
 
 from tg import tmpl_context as c
@@ -31,7 +30,7 @@ from allura.model.repo_refresh import (
 )
 
 
-class TestTopoSort(unittest.TestCase):
+class TestTopoSort:
 
     def test_commit_dates_out_of_order(self):
         """Commits should be sorted by their parent/child relationships,
@@ -60,8 +59,7 @@ class TestTopoSort(unittest.TestCase):
             'master':     datetime.datetime(2012, 5, 1),
             'dev':        datetime.datetime(2012, 6, 1)}
         result = topo_sort(children, parents, dates, head_ids)
-        self.assertEqual(list(result), ['dev', 'dev@{1}', 'master',
-                                        'master@{1}', 'master@{2}', 'master@{3}'])
+        assert list(result) == ['dev', 'dev@{1}', 'master', 'master@{1}', 'master@{2}', 'master@{3}']
 
 
 def tree(name, id, trees=None, blobs=None):
@@ -83,7 +81,7 @@ def blob(name, id):
     return b
 
 
-class TestTree(unittest.TestCase):
+class TestTree:
 
     @patch('allura.model.repository.Tree.__getitem__')
     def test_get_obj_by_path(self, getitem):
@@ -100,7 +98,7 @@ class TestTree(unittest.TestCase):
         getitem().__getitem__().__getitem__.assert_called_with('file.txt')
 
 
-class TestBlob(unittest.TestCase):
+class TestBlob:
 
     def test_pypeline_view(self):
         blob = M.repository.Blob(MagicMock(), 'INSTALL.mdown', 'blob1')
@@ -140,14 +138,14 @@ class TestBlob(unittest.TestCase):
         assert blob.has_html_view is True
 
 
-class TestCommit(unittest.TestCase):
+class TestCommit:
 
     def test_activity_extras(self):
         commit = M.repository.Commit()
         commit.shorthand_id = MagicMock(return_value='abcdef')
         commit.message = 'commit msg'
-        self.assertIn('allura_id', commit.activity_extras)
-        self.assertEqual(commit.activity_extras['summary'], commit.summary)
+        assert 'allura_id' in commit.activity_extras
+        assert commit.activity_extras['summary'] == commit.summary
 
     def test_get_path_no_create(self):
         commit = M.repository.Commit()
@@ -155,7 +153,7 @@ class TestCommit(unittest.TestCase):
         commit.get_path('foo/', create=False)
         commit.get_tree.assert_called_with(False)
         commit.get_tree().__getitem__.assert_called_with('foo')
-        self.assertNotIn(call(''), commit.get_tree().__getitem__.call_args_list)
+        assert (call('') not in commit.get_tree().__getitem__.call_args_list)
 
     def test_get_tree_no_create(self):
         c.model_cache = Mock()
@@ -241,7 +239,7 @@ class TestCommit(unittest.TestCase):
         commit.get_tree.assert_called_with(create=True)
 
 
-class TestZipDir(unittest.TestCase):
+class TestZipDir:
 
     @patch('allura.model.repository.Popen')
     @patch('allura.model.repository.tg')
@@ -272,34 +270,33 @@ class TestZipDir(unittest.TestCase):
         popen.return_value.returncode = 1
         src = '/fake/path/to/repo'
         zipfile = '/fake/zip/file.tmp'
-        with self.assertRaises(Exception) as cm:
+        with pytest.raises(Exception) as cm:
             zipdir(src, zipfile)
-        emsg = str(cm.exception)
-        self.assertIn(
-            "Command: " +
-            ("['/bin/zip', '-y', '-q', '-r', '/fake/zip/file.tmp', b'repo'] " if six.PY3 else
-             "[u'/bin/zip', u'-y', u'-q', u'-r', u'/fake/zip/file.tmp', 'repo'] ") +
-            "returned non-zero exit code 1", emsg)
-        self.assertTrue("STDOUT: 1" in emsg)
-        self.assertTrue("STDERR: 2" in emsg)
+        emsg = str(cm.value)
+        assert \
+            "Command: " + \
+            "['/bin/zip', '-y', '-q', '-r', '/fake/zip/file.tmp', b'repo'] " + \
+            "returned non-zero exit code 1" in emsg
+        assert "STDOUT: 1" in emsg
+        assert "STDERR: 2" in emsg
 
 
-class TestPrefixPathsUnion(unittest.TestCase):
+class TestPrefixPathsUnion:
 
     def test_disjoint(self):
         a = {'a1', 'a2', 'a3'}
         b = {'b1', 'b1/foo', 'b2'}
-        self.assertEqual(prefix_paths_union(a, b), set())
+        assert prefix_paths_union(a, b) == set()
 
     def test_exact(self):
         a = {'a1', 'a2', 'a3'}
         b = {'b1', 'a2', 'a3'}
-        self.assertEqual(prefix_paths_union(a, b), {'a2', 'a3'})
+        assert prefix_paths_union(a, b) == {'a2', 'a3'}
 
     def test_prefix(self):
         a = {'a1', 'a2', 'a3'}
         b = {'b1', 'a2/foo', 'b3/foo'}
-        self.assertEqual(prefix_paths_union(a, b), {'a2'})
+        assert prefix_paths_union(a, b) == {'a2'}
 
 
 class TestGroupCommits:
