@@ -18,7 +18,6 @@
 import pymongo
 import mock
 
-from unittest import TestCase
 
 import allura
 from allura.tests import decorators as td
@@ -46,14 +45,13 @@ def test_extensions_cm():
 def test_extensions_cm_raises():
     session = mock.Mock(_kwargs=dict(extensions=[]))
     extension = mock.Mock()
-    with td.raises(ValueError):
-        with substitute_extensions(session, [extension]) as sess:
-            session.flush.side_effect = AttributeError
-            assert session.flush.call_count == 1
-            assert session.close.call_count == 1
-            assert sess == session
-            assert sess._kwargs['extensions'] == [extension]
-            raise ValueError('test')
+    with td.raises(ValueError), substitute_extensions(session, [extension]) as sess:
+        session.flush.side_effect = AttributeError
+        assert session.flush.call_count == 1
+        assert session.close.call_count == 1
+        assert sess == session
+        assert sess._kwargs['extensions'] == [extension]
+        raise ValueError('test')
     assert session.flush.call_count == 1
     assert session.close.call_count == 1
     assert session._kwargs['extensions'] == []
@@ -62,19 +60,18 @@ def test_extensions_cm_raises():
 def test_extensions_cm_flush_raises():
     session = mock.Mock(_kwargs=dict(extensions=[]))
     extension = mock.Mock()
-    with td.raises(AttributeError):
-        with substitute_extensions(session, [extension]) as sess:
-            session.flush.side_effect = AttributeError
-            assert session.flush.call_count == 1
-            assert session.close.call_count == 1
-            assert sess == session
-            assert sess._kwargs['extensions'] == [extension]
+    with td.raises(AttributeError), substitute_extensions(session, [extension]) as sess:
+        session.flush.side_effect = AttributeError
+        assert session.flush.call_count == 1
+        assert session.close.call_count == 1
+        assert sess == session
+        assert sess._kwargs['extensions'] == [extension]
     assert session.flush.call_count == 2
     assert session.close.call_count == 1
     assert session._kwargs['extensions'] == []
 
 
-class TestSessionExtension(TestCase):
+class TestSessionExtension:
 
     def _mock_indexable(self, **kw):
         m = mock.Mock(**kw)
@@ -150,7 +147,7 @@ class TestArtifactSessionExtension(TestSessionExtension):
         assert index_tasks.add_artifacts.post.call_count == 0
 
 
-class TestBatchIndexer(TestCase):
+class TestBatchIndexer:
 
     def setup_method(self, method):
         session = mock.Mock()
@@ -169,17 +166,17 @@ class TestBatchIndexer(TestCase):
         arefs = [m(_id=i) for i in (4, 5, 6)]
         find.return_value = [m(_id=i) for i in (7, 8, 9)]
         self.ext.update_index(objs_deleted, arefs)
-        self.assertEqual(self.ext.to_delete,
-                         {o.index_id() for o in objs_deleted})
-        self.assertEqual(self.ext.to_add, {4, 5, 6})
+        assert self.ext.to_delete == \
+            {o.index_id() for o in objs_deleted}
+        assert self.ext.to_add == {4, 5, 6}
 
         # test deleting something that was previously added
         objs_deleted += [m(_id=4)]
         find.return_value = [m(_id=4)]
         self.ext.update_index(objs_deleted, [])
-        self.assertEqual(self.ext.to_delete,
-                         {o.index_id() for o in objs_deleted})
-        self.assertEqual(self.ext.to_add, {5, 6})
+        assert self.ext.to_delete == \
+            {o.index_id() for o in objs_deleted}
+        assert self.ext.to_add == {5, 6}
 
     @mock.patch('allura.model.session.index_tasks')
     def test_flush(self, index_tasks):
@@ -191,34 +188,32 @@ class TestBatchIndexer(TestCase):
         index_tasks.del_artifacts.post.assert_called_once_with(
             list(del_index_ids))
         index_tasks.add_artifacts.post.assert_called_once_with([4, 5, 6])
-        self.assertEqual(self.ext.to_delete, set())
-        self.assertEqual(self.ext.to_add, set())
+        assert self.ext.to_delete == set()
+        assert self.ext.to_add == set()
 
     @mock.patch('allura.model.session.index_tasks')
     def test_flush_chunks_huge_lists(self, index_tasks):
         self.extcls.to_delete = set(range(100 * 1000 + 1))
         self.extcls.to_add = set(range(1000 * 1000 + 1))
         self.ext.flush()
-        self.assertEqual(
-            len(index_tasks.del_artifacts.post.call_args_list[0][0][0]),
-            100 * 1000)
-        self.assertEqual(
-            len(index_tasks.del_artifacts.post.call_args_list[1][0][0]), 1)
-        self.assertEqual(
-            len(index_tasks.add_artifacts.post.call_args_list[0][0][0]),
-            1000 * 1000)
-        self.assertEqual(
-            len(index_tasks.add_artifacts.post.call_args_list[1][0][0]), 1)
-        self.assertEqual(self.ext.to_delete, set())
-        self.assertEqual(self.ext.to_add, set())
+        assert \
+            len(index_tasks.del_artifacts.post.call_args_list[0][0][0]) == 100 * 1000
+        assert \
+            len(index_tasks.del_artifacts.post.call_args_list[1][0][0]) == 1
+        assert \
+            len(index_tasks.add_artifacts.post.call_args_list[0][0][0]) == 1000 * 1000
+        assert \
+            len(index_tasks.add_artifacts.post.call_args_list[1][0][0]) == 1
+        assert self.ext.to_delete == set()
+        assert self.ext.to_add == set()
 
     @mock.patch('allura.tasks.index_tasks')
     def test_flush_noop(self, index_tasks):
         self.ext.flush()
-        self.assertEqual(0, index_tasks.del_artifacts.post.call_count)
-        self.assertEqual(0, index_tasks.add_artifacts.post.call_count)
-        self.assertEqual(self.ext.to_delete, set())
-        self.assertEqual(self.ext.to_add, set())
+        assert 0 == index_tasks.del_artifacts.post.call_count
+        assert 0 == index_tasks.add_artifacts.post.call_count
+        assert self.ext.to_delete == set()
+        assert self.ext.to_add == set()
 
     @mock.patch('allura.tasks.index_tasks')
     def test__post_too_large(self, index_tasks):
@@ -242,8 +237,8 @@ class TestBatchIndexer(TestCase):
             mock.call([3]),
             mock.call([4])
         ]
-        self.assertEqual(
-            expected, index_tasks.add_artifacts.post.call_args_list)
+        assert \
+            expected == index_tasks.add_artifacts.post.call_args_list
 
     @mock.patch('allura.tasks.index_tasks')
     def test__post_other_error(self, index_tasks):
