@@ -15,7 +15,6 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-import unittest
 
 import mock
 from markupsafe import Markup
@@ -30,7 +29,7 @@ from allura.lib.solr import Solr, escape_solr_arg
 from allura.lib.search import search_app, SearchIndexable
 
 
-class TestSolr(unittest.TestCase):
+class TestSolr:
 
     def setup_method(self, method):
         # need to create the "test" project so @td.with_wiki works
@@ -39,15 +38,18 @@ class TestSolr(unittest.TestCase):
     @mock.patch('allura.lib.solr.pysolr')
     def test_init(self, pysolr):
         servers = ['server1', 'server2']
-        solr = Solr(servers, commit=False, commitWithin='10000')
-        calls = [mock.call('server1'), mock.call('server2')]
+        auths = [('u', 'pwd'),]
+        solr = Solr(servers, push_servers_auths=auths, commit=False, commitWithin='10000')
+        calls = [mock.call('server1', auth=('u', 'pwd')), mock.call('server2', auth=None)]
         pysolr.Solr.assert_has_calls(calls)
         assert len(solr.push_pool) == 2
 
         pysolr.reset_mock()
         solr = Solr(servers, 'server3', commit=False, commitWithin='10000')
-        calls = [mock.call('server1'), mock.call('server2'),
-                 mock.call('server3')]
+        calls = [mock.call('server1', auth=None),
+                 mock.call('server2', auth=None),
+                 mock.call('server3', auth=None),
+                 ]
         pysolr.Solr.assert_has_calls(calls)
         assert len(solr.push_pool) == 2
 
@@ -137,7 +139,7 @@ class TestSolr(unittest.TestCase):
             r'registration_ip:(2601\:404\:c300\:a560\:598f\:9336\:d2bb\:9e32)', fq=fq, ignore_errors=False, **{'q.op': 'AND'})
 
 
-class TestSearchIndexable(unittest.TestCase):
+class TestSearchIndexable:
 
     def setup_method(self, method):
         self.obj = SearchIndexable()
@@ -161,7 +163,7 @@ class TestSearchIndexable(unittest.TestCase):
         assert self.obj.solarize() == dict(text='<script>a(1)</script>')
 
 
-class TestSearch_app(unittest.TestCase):
+class TestSearch_app:
 
     def setup_method(self, method):
         # need to create the "test" project so @td.with_wiki works
