@@ -17,9 +17,8 @@
 
 """Setup the allura application"""
 import os
-import sys
 import logging
-import shutil
+from datetime import datetime
 from textwrap import dedent
 
 import tg
@@ -41,7 +40,6 @@ from allura.command import CreateTroveCategoriesCommand
 from allura.websetup.schema import REGISTRY
 
 from forgewiki import model as WM
-import six
 
 log = logging.getLogger(__name__)
 
@@ -56,7 +54,7 @@ def bootstrap(command, conf, vars):
         REGISTRY.register(ew.widget_context,
                           ew.core.WidgetContext('http', ew.ResourceManager()))
 
-    create_test_data = asbool(os.getenv('ALLURA_TEST_DATA', True))
+    create_test_data = asbool(os.getenv('ALLURA_TEST_DATA', 'true'))
 
     # if this is a test_run, skip user project creation to save time
     make_user_projects = not test_run
@@ -178,7 +176,7 @@ def bootstrap(command, conf, vars):
 
     if create_test_data:
         # Add some test users
-        for unum in range(10):
+        for unum in range(4):
             make_user('Test User %d' % unum)
 
     log.info('Creating basic project categories')
@@ -205,7 +203,7 @@ def bootstrap(command, conf, vars):
             u_admin = make_user('Test Admin')
             u_admin.preferences = dict(email_address='test-admin@users.localhost')
             u_admin.email_addresses = ['test-admin@users.localhost']
-            u_admin.set_password('foo')
+            fast_set_pwd(u_admin, 'foo')
             u_admin.claim_address('test-admin@users.localhost')
             ThreadLocalODMSession.flush_all()
 
@@ -279,15 +277,15 @@ def wipe_database():
     conn = M.main_doc_session.bind.conn
     if isinstance(conn, mim.Connection):
         clear_all_database_tables()
-        for db in conn.database_names():
+        for db in conn.list_database_names():
             db = conn[db]
     else:
-        for database in conn.database_names():
+        for database in conn.list_database_names():
             if database not in ('allura', 'pyforge', 'project-data'):
                 continue
             log.info('Wiping database %s', database)
             db = conn[database]
-            for coll in list(db.collection_names()):
+            for coll in list(db.list_collection_names()):
                 if coll.startswith('system.'):
                     continue
                 log.info('Dropping collection %s:%s', database, coll)
@@ -299,15 +297,28 @@ def wipe_database():
 
 def clear_all_database_tables():
     conn = M.main_doc_session.bind.conn
-    for db in conn.database_names():
+    for db in conn.list_database_names():
         db = conn[db]
-        for coll in list(db.collection_names()):
+        for coll in list(db.list_collection_names()):
             if coll == 'system.indexes':
                 continue
             db.drop_collection(coll)
 
 
-def create_user(display_name, username=None, password='foo', make_project=False):
+# this re-uses hashes for the same pwd, which gives a huge speedup during tests.  Not good for real usage, since salting is the same.
+user_pwd_hash_speedup_cache = {}
+
+
+def fast_set_pwd(user: M.User, password: str):
+    if password in user_pwd_hash_speedup_cache:
+        user.password, user.password_algorithm = user_pwd_hash_speedup_cache[password]
+        user.last_password_updated = datetime.utcnow()
+    else:
+        user.set_password(password)
+        user_pwd_hash_speedup_cache[password] = (user.password, user.password_algorithm)
+
+
+def create_user(display_name, username=None, password='foo', make_project=False):  # noqa: S107
     if not username:
         username = display_name.lower().replace(' ', '-')
     user = M.User.register(dict(username=username,
@@ -320,8 +331,8 @@ def create_user(display_name, username=None, password='foo', make_project=False)
     em = EmailAddress.get(**kw)
     em.confirmed = True
     em.set_nonce_hash()
-    user.set_pref('email_address',email)
-    user.set_password(password)
+    user.set_pref('email_address', email)
+    fast_set_pwd(user, password)
     return user
 
 
