@@ -95,7 +95,7 @@ def get_value(key, default):
 
 
 def run(command):
-    rc = os.system(command)
+    rc = os.system(command)  # noqa: S605
     if rc != 0:
         log.error('Error running %s', command)
     assert rc == 0
@@ -110,6 +110,7 @@ def tempfile(template, values):
     yield name
     os.remove(name)
 
+
 backend_ldif = string.Template('''
 # Load dynamic backend modules
 dn: cn=module,cn=config
