@@ -26,7 +26,11 @@ import grp
 def main():
     command = sys.argv[1]
     uname = sys.argv[2]
-    eval(command)(uname, *sys.argv[3:])
+    fn = {
+        'init': init,
+        'upload': upload,
+    }[command]
+    fn(uname, *sys.argv[3:])
 
 
 def init(uname):
@@ -51,5 +55,6 @@ def upload(uname, pubkey):
     os.chown(keyfile, u.pw_uid, g.gr_gid)
     os.chmod(keyfile, 0o600)
 
+
 if __name__ == '__main__':
     main()
