@@ -25,13 +25,11 @@ import six.moves.urllib.error
 import json
 
 import mock
-import beaker.session
 from formencode import variabledecode
 from paste.deploy import loadapp
 from paste.deploy.converters import asbool
 from paste.script.appinstall import SetupCommand
-from tg import tmpl_context as c, app_globals as g
-from tg import url, request, response, session
+from tg import tmpl_context as c
 import tg
 from tg.wsgiapp import RequestLocals
 from webob import Response, Request
@@ -48,7 +46,7 @@ import allura.lib.security
 from allura.lib.app_globals import Globals
 from allura.lib import helpers as h
 from allura.websetup.schema import REGISTRY
-#from allura.lib.custom_middleware import environ as ENV, MagicalC
+# from allura.lib.custom_middleware import environ as ENV, MagicalC
 from .validation import ValidatingTestApp
 import six
 
@@ -162,8 +160,8 @@ def setup_global_objects():
 
 def setup_trove_categories():
     create_trove_categories = CreateTroveCategoriesCommand('create_trove_categories')
-    with mock.patch.object(M.project.TroveCategoryMapperExtension, 'after_insert'),\
-            mock.patch.object(M.project.TroveCategoryMapperExtension, 'after_update'),\
+    with mock.patch.object(M.project.TroveCategoryMapperExtension, 'after_insert'), \
+            mock.patch.object(M.project.TroveCategoryMapperExtension, 'after_update'), \
             mock.patch.object(M.project.TroveCategoryMapperExtension, 'after_delete'):
         create_trove_categories.run([''])
 
@@ -175,8 +173,10 @@ class TestController:
 
     def setup_method(self, method=None):
         pkg = self.__module__.split('.')[0]
-        self.app = ValidatingTestApp(
-            setup_functional_test(app_name=self.application_under_test, current_pkg=pkg))
+        self.app = ValidatingTestApp(  # inherits from webtest.TestApp ultimately
+            setup_functional_test(app_name=self.application_under_test, current_pkg=pkg),
+            parser_features='lxml',  # fastest parser (WebTest defaults to html.parser)
+        )
         self.app.extra_environ = {'REMOTE_ADDR': '127.0.0.1'}  # remote_addr needed by AntiSpam
         if self.validate_skip:
             self.app.validate_skip = self.validate_skip
@@ -198,7 +198,7 @@ class TestController:
         component from the <script> tag
         """
         script = None
-        for s in response.html.findAll('script'):
+        for s in response.html.find_all('script'):
             if s.getText().strip().startswith('document.SUBSCRIPTION_OPTIONS'):
                 script = s
                 break
@@ -252,21 +252,24 @@ class TestRestApiBase(TestController):
 
         return self._token_cache[username]
 
-    def _api_call(self, method, path, wrap_args=None, user='test-admin', status=None, **params):
+    def _api_call(self, method, path, user='test-admin', status=None, **params):
         '''
         If you need to use one of the method kwargs as a URL parameter,
         pass params={...} as a dict instead of **kwargs
         '''
         if 'params' in params:
             params = params['params']
-        if wrap_args:
-            params = {wrap_args: params}
         if status is None:
             status = [200, 201, 301, 302]
         if not isinstance(params, str):
             params = variabledecode.variable_encode(params, add_repetitions=False)
 
-        token = self.token(user).api_key
+        bearer_token = self.token(user)
+        try:
+            token = bearer_token.api_key
+        except AttributeError:
+            token = bearer_token.access_token
+
         headers = {
             'Authorization': str(f'Bearer {token}')
         }
@@ -283,14 +286,14 @@ class TestRestApiBase(TestController):
         else:
             return response
 
-    def api_get(self, path, wrap_args=None, user='test-admin', status=None, **params):
-        return self._api_call('GET', path, wrap_args, user, status, **params)
+    def api_get(self, path, user='test-admin', status=None, **params):
+        return self._api_call('GET', path, user, status, **params)
 
-    def api_post(self, path, wrap_args=None, user='test-admin', status=None, **params):
-        return self._api_call('POST', path, wrap_args, user, status, **params)
+    def api_post(self, path, user='test-admin', status=None, **params):
+        return self._api_call('POST', path, user, status, **params)
 
-    def api_delete(self, path, wrap_args=None, user='test-admin', status=None, **params):
-        return self._api_call('DELETE', path, wrap_args, user, status, **params)
+    def api_delete(self, path, user='test-admin', status=None, **params):
+        return self._api_call('DELETE', path, user, status, **params)
 
 
 def oauth1_webtest(url: str, oauth_kwargs: dict, method='GET') -> tuple[str, dict, dict, dict]:
