@@ -15,11 +15,24 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-from smtpd import DebuggingServer
+import tg
+from aiosmtpd.handlers import Debugging, Sink
+from aiosmtpd.controller import Controller
+from io import StringIO
+from paste.deploy.converters import asint
 
 
-class BetterDebuggingServer(DebuggingServer):
+class BetterDebuggingServer:
+    
 
-    def process_message(self, peer, mailfrom, rcpttos, data, **kwargs):
-        print('TO: ' + ', '.join(rcpttos))
-        super().process_message(peer, mailfrom, rcpttos, data)
\ No newline at end of file
+    async def handle_DATA(self,  server, session, envelope):
+        try:
+            rcpttos = envelope.rcpt_tos
+            message = envelope.content.decode("utf-8")
+            message = "\n".join(message.split("\r\n"))
+            print('TO: ' + ', '.join(rcpttos))
+            print('FROM: ' + envelope.mail_from)
+            print(message)
+        except Exception as error:
+            return f'500 Could not process your message. Error {error}'
+        return '250 OK'
\ No newline at end of file
