@@ -18,22 +18,17 @@
 """
 Functions to syntax-validate output content
 """
-from os import path
 import os
 import sys
 import logging
 import tempfile
 import subprocess
 import json
-import six.moves.urllib.parse
-import six.moves.urllib.request
-import six.moves.urllib.error
 import re
 import pkg_resources
-import six
 
 import webtest
-from webtest import TestApp
+from webtest import TestApp, TestResponse
 from ming.utils import LazyProperty
 import requests
 
@@ -214,7 +209,7 @@ def validate_page(html_or_response):
 
 class AntiSpamTestApp(TestApp):
 
-    def post(self, *args, **kwargs):
+    def post(self, *args, **kwargs) -> TestResponse:
         antispam = utils.AntiSpam()
         if kwargs.pop('antispam', False):
             params = {
@@ -225,7 +220,7 @@ class AntiSpamTestApp(TestApp):
             }
             for k, v in kwargs['params'].items():
                 params[antispam.enc(k)] = v
-            params['_session_id'] = kwargs['params'].get('_session_id')  # exclude csrf token from encryption
+            params['_csrf_token'] = kwargs['params'].get('_csrf_token')  # exclude csrf token from encryption
             kwargs['params'] = params
         return super().post(*args, **kwargs)
 
@@ -271,10 +266,10 @@ class PostParamCheckingTestApp(AntiSpamTestApp):
                 self._validate_val(k, vv, method)
         elif not isinstance(v, (str, bytes, webtest.forms.File, webtest.forms.Upload)):
             raise TypeError(
-                '%s key %s has value %s of type %s, not str. ' %
-                (method, k, v, type(v)))
+                '%s key %r has value %s of type %s, not str. ' %
+                (method.upper(), k, v, type(v)))
 
-    def get(self, *args, **kwargs):
+    def get(self, *args, **kwargs) -> TestResponse:
         params = None
         if 'params' in kwargs:
             params = kwargs['params']
@@ -283,7 +278,7 @@ class PostParamCheckingTestApp(AntiSpamTestApp):
         self._validate_params(params, 'get')
         return super().get(*args, **kwargs)
 
-    def post(self, *args, **kwargs):
+    def post(self, *args, **kwargs) -> TestResponse:
         params = None
         if 'params' in kwargs:
             params = kwargs['params']
@@ -333,37 +328,28 @@ class ValidatingTestApp(PostParamCheckingTestApp):
             params[k] = kw.pop(k, False)
         return params, kw
 
-    def get(self, *args, **kw):
-        '''
-        :rtype: webtest.app.TestResponse
-        '''
+    def get(self, *args, **kw) -> TestResponse:
         val_params, kw = self._get_validation_params(kw)
         resp = super().get(*args, **kw)
         if not self.validate_skip and not val_params['validate_skip']:
             self._validate(resp, 'get', val_params)
         return resp
 
-    def post(self, *args, **kw):
-        '''
-        :rtype: webtest.app.TestResponse
-        '''
+    def post(self, *args, **kw) -> TestResponse:
         val_params, kw = self._get_validation_params(kw)
         resp = super().post(*args, **kw)
         if not self.validate_skip and not val_params['validate_skip']:
             self._validate(resp, 'post', val_params)
         return resp
 
-    def delete(self, *args, **kw):
-        '''
-        :rtype: webtest.app.TestResponse
-        '''
+    def delete(self, *args, **kw) -> TestResponse:
         val_params, kw = self._get_validation_params(kw)
         resp = super().delete(*args, **kw)
         if not self.validate_skip and not val_params['validate_skip']:
             self._validate(resp, 'delete', val_params)
         return resp
 
-    def do_request(self, *args, **kwargs):
+    def do_request(self, *args, **kwargs) -> TestResponse:
         # middleware should do this already, but be sure that no global c/config/request etc remains between tests
         resp = super().do_request(*args, **kwargs)
         tgGlobalsRegistry = resp.request.environ['paste.registry']
