@@ -15,23 +15,8 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-from setuptools import setup, find_packages
+from setuptools import setup
 
 setup(name='AlluraTest',
       version='0.1',
-      description="Allura testing support",
-      long_description="""\
-""",
-      # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
-      classifiers=[],
-      keywords='',
-      author='',
-      author_email='',
-      url='',
-      license='',
-      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
-      include_package_data=True,
-      zip_safe=False,
-      install_requires=[
-      ]
-      )
+)
