@@ -15,4 +15,4 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-from main import ForgeActivityApp
+from .main import ForgeActivityApp
