@@ -54,7 +54,7 @@ class TestActivityController(TestController):
     def test_anon_read(self):
         r = self.app.get('/u/test-user-1',
                          extra_environ={'username': '*anonymous'}).follow()
-        assert r.html.select('div.profile-section.tools a[href="/u/test-user-1/activity/"]'),\
+        assert r.html.select('div.profile-section.tools a[href="/u/test-user-1/activity/"]'), \
             'No Activity tool in top nav'
 
     @td.with_tool('test', 'activity')
@@ -94,7 +94,7 @@ class TestActivityController(TestController):
         })]
         r = self.app.get('/p/test/activity/')
         timeline = r.html.find('ul', 'timeline')
-        assert 1 == len(timeline.findAll('li'))
+        assert 1 == len(timeline.find_all('li'))
         activity = timeline.find('li')
         assert activity.time['title'] == "2013-12-04 21:48:19"
         h1 = """\
