@@ -15,4 +15,4 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-from root import RootController, RootRestController
+from .root import RootController, RootRestController
