@@ -22,7 +22,6 @@ import pymongo
 from allura.lib.search import mapped_artifacts_from_index_ids
 
 from tg import expose, validate, redirect
-from tg import request
 from tg import tmpl_context as c, app_globals as g
 from webob import exc
 from formencode import validators
@@ -136,7 +135,7 @@ class ForumController(DiscussionController):
                 user_id=c.user._id,
                 project_id=c.project._id,
                 app_config_id=c.app.config._id,
-                artifact_index_id=re.compile('^' + re.escape(forumthread_index_prefix)),
+                artifact_index_id={'$regex': '^' + re.escape(forumthread_index_prefix)},
             )).all()
             # get the ForumThread objects from the subscriptions
             thread_index_ids = [mbox.artifact_index_id for mbox in thread_mboxes]
@@ -165,7 +164,7 @@ class ForumThreadController(ThreadController):
     @validate(dict(page=validators.Int(if_empty=0, if_invalid=0),
                    limit=validators.Int(if_empty=25, if_invalid=25)))
     def index(self, limit=25, page=0, count=0, **kw):
-        if self.thread.discussion.deleted and not has_access(c.app, 'configure')():
+        if self.thread.discussion.deleted and not has_access(c.app, 'configure'):
             raise exc.HTTPNotFound()
         c.thread_subscription_form = self.W.subscribe_form
         return super().index(limit=limit, page=page, count=count, show_moderate=True, **kw)
@@ -176,7 +175,7 @@ class ForumThreadController(ThreadController):
     @validate(pass_validator, index)
     def moderate(self, **kw):
         require_access(self.thread, 'moderate')
-        if self.thread.discussion.deleted and not has_access(c.app, 'configure')():
+        if self.thread.discussion.deleted and not has_access(c.app, 'configure'):
             raise exc.HTTPNotFound()
         args = self.W.moderate_thread.validate(kw, None)
         tasks.calc_forum_stats.post(self.thread.discussion.shortname)
@@ -218,7 +217,7 @@ class ForumPostController(PostController):
     @validate(pass_validator)
     @utils.AntiSpam.validate('Spambot protection engaged')
     def index(self, **kw):
-        if self.thread.discussion.deleted and not has_access(c.app, 'configure')():
+        if self.thread.discussion.deleted and not has_access(c.app, 'configure'):
             raise exc.HTTPNotFound()
         return super().index(**kw)
 
@@ -227,7 +226,7 @@ class ForumPostController(PostController):
     @validate(pass_validator, error_handler=index)
     def moderate(self, **kw):
         require_access(self.post.thread, 'moderate')
-        if self.thread.discussion.deleted and not has_access(c.app, 'configure')():
+        if self.thread.discussion.deleted and not has_access(c.app, 'configure'):
             raise exc.HTTPNotFound()
         tasks.calc_thread_stats.post(self.post.thread._id)
         tasks.calc_forum_stats(self.post.discussion.shortname)
