@@ -33,7 +33,7 @@ from formencode import validators
 from webob import exc
 import pymongo
 
-from allura.lib.security import require_access, has_access, require_authenticated
+from allura.lib.security import require_access, has_access
 from allura.lib.search import search_app
 from allura.lib import helpers as h
 from allura.lib import validators as v
@@ -86,7 +86,7 @@ class RootController(BaseController, DispatchIndex, FeedController):
         forums = model.Forum.query.find(dict(
             app_config_id=c.app.config._id,
             parent_id=None, deleted=False)).all()
-        forums = [f for f in forums if h.has_access(f, 'read')()]
+        forums = [f for f in forums if h.has_access(f, 'read')]
         noindex = all([f.num_topics == 0 for f in forums])
         return dict(forums=forums,
                     announcements=announcements,
@@ -110,9 +110,13 @@ class RootController(BaseController, DispatchIndex, FeedController):
     @with_trailing_slash
     @expose('jinja:forgediscussion:templates/discussionforums/create_topic.html')
     def create_topic(self, forum_name=None, new_forum=False, **kw):
-        forums = model.Forum.query.find(dict(app_config_id=c.app.config._id,
-                                             parent_id=None,
-                                             deleted=False))
+        # check app-level access to guarantee enforcement of Block Users.  In addition to per-forum checks below
+        if has_access(c.app, 'post'):
+            forums = model.Forum.query.find(dict(app_config_id=c.app.config._id,
+                                                 parent_id=None,
+                                                 deleted=False))
+        else:
+            forums = []
         c.new_topic = self.W.new_topic
         my_forums = []
         forum_name = h.really_unicode(unquote(forum_name)) if forum_name else None
@@ -120,7 +124,7 @@ class RootController(BaseController, DispatchIndex, FeedController):
         for f in forums:
             if forum_name == f.shortname:
                 current_forum = f
-            if has_access(f, 'post')():
+            if has_access(f, 'post'):
                 my_forums.append(f)
         return dict(forums=my_forums,
                     current_forum=current_forum,
@@ -139,7 +143,7 @@ class RootController(BaseController, DispatchIndex, FeedController):
         discussion = model.Forum.query.get(
             app_config_id=c.app.config._id,
             shortname=forum)
-        if discussion.deleted and not has_access(c.app, 'configure')():
+        if discussion.deleted and not has_access(c.app, 'configure'):
             flash('This forum has been removed.')
             redirect(six.ensure_text(request.referer or '/'))
         require_access(discussion, 'post')
