@@ -15,9 +15,7 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-import re
 import logging
-from itertools import chain
 import typing
 
 import pymongo
@@ -163,7 +161,7 @@ class ForumThread(M.Thread):
 
     discussion = RelationProperty(Forum)
     posts = RelationProperty('ForumPost', via='thread_id')
-    first_post = RelationProperty('ForumPost', via='first_post_id')
+    first_post: 'ForumPost' = RelationProperty('ForumPost', via='first_post_id')
 
     @property
     def type_name(self):
