@@ -25,7 +25,6 @@ from email.mime.multipart import MIMEMultipart
 
 import pkg_resources
 import pymongo
-import webtest
 
 from ming.odm import ThreadLocalODMSession
 from tg import tmpl_context as c
@@ -34,6 +33,7 @@ from tg import config
 import feedparser
 
 from allura import model as M
+from allura.lib.mail_util import email_policy
 from allura.tasks import mail_tasks
 from alluratest.controller import TestController
 from allura.lib import helpers as h
@@ -61,7 +61,7 @@ class TestForumEmail(TestController):
         self.forum = FM.Forum.query.get(shortname='testforum')
 
     def test_simple_email(self):
-        msg = MIMEText('This is a test message')
+        msg = MIMEText('This is a test message', policy=email_policy)
         self._post_email(
             self.email_address,
             [self.forum.email_address],
@@ -74,8 +74,9 @@ class TestForumEmail(TestController):
         msg = MIMEMultipart(
             'alternative',
             _subparts=[
-                MIMEText('This is a test message'),
-                MIMEText('This is a <em>test</em> message', 'html')])
+                MIMEText('This is a test message', policy=email_policy),
+                MIMEText('This is a <em>test</em> message', 'html', policy=email_policy)],
+            policy=email_policy)
         self._post_email(
             self.email_address,
             [self.forum.email_address],
@@ -83,8 +84,8 @@ class TestForumEmail(TestController):
             msg)
         r = self.app.get('/p/test/discussion/testforum/')
         assert 'Test Simple Thread' in str(r), r
-        assert len(r.html.findAll('tr')) == 2
-        href = r.html.findAll('tr')[1].find('a')['href']
+        assert len(r.html.find_all('tr')) == 2
+        href = r.html.find_all('tr')[1].find('a')['href']
         r = self.app.get(href)
         assert 'alternate' in str(r)
 
@@ -94,13 +95,17 @@ class TestForumEmail(TestController):
                 MIMEMultipart(
                     'alternative',
                     _subparts=[
-                        MIMEText('This is a test message'),
-                        MIMEText('This is a <em>test</em> message', 'html')
-                    ])
-            ])
+                        MIMEText('This is a test message', policy=email_policy),
+                        MIMEText('This is a <em>test</em> message', 'html', policy=email_policy)
+                    ],
+                    policy=email_policy
+                ),
+            ],
+            policy=email_policy
+        )
         with open(pkg_resources.resource_filename(
                 'forgediscussion', 'tests/data/python-logo.png'), 'rb') as fp:
-            img = MIMEImage(fp.read())
+            img = MIMEImage(fp.read(), policy=email_policy)
             img.add_header('Content-Disposition', 'attachment',
                            filename='python-logo.png')
             msg.attach(img)
@@ -111,8 +116,8 @@ class TestForumEmail(TestController):
             msg)
         r = self.app.get('/p/test/discussion/testforum/')
         assert 'Test Simple Thread' in str(r)
-        assert len(r.html.findAll('tr')) == 2
-        href = r.html.findAll('tr')[1].find('a')['href']
+        assert len(r.html.find_all('tr')) == 2
+        href = r.html.find_all('tr')[1].find('a')['href']
         r = self.app.get(href)
         assert 'alternate' in str(r)
         assert 'python-logo.png' in str(r)
@@ -225,7 +230,7 @@ class TestForumMessageHandling(TestController):
         url = '/discussion/testforum/thread/%s/' % thd._id
         self.app.get(url)
         resp = self.app.get('/discussion/testforum/thread/foobar/', status=301)
-        assert('/discussion/testforum/' in resp.location)
+        assert ('/discussion/testforum/' in resp.location)
 
     def test_posts(self):
         # not sure why this fails when set to root (to match self.user_id)
@@ -239,7 +244,7 @@ class TestForumMessageHandling(TestController):
         r = self.app.get(url)
         f = r.html.find('form', {'action': '/p/test' + url})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -250,7 +255,7 @@ class TestForumMessageHandling(TestController):
         r = self.app.get(url, params=dict(version='1'))
         post_form = r.html.find('form', {'action': '/p/test' + url + 'reply'})
         params = dict()
-        inputs = post_form.findAll('input')
+        inputs = post_form.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -273,7 +278,7 @@ class TestForumMessageHandling(TestController):
         r = self.app.get(url)
         assert "test1.txt" in r
         assert "test2.txt" in r
-        for link in r.html.findAll('a.btn'):
+        for link in r.html.find_all('a.btn'):
             if 'attachment' in link.get('href', ''):
                 self.app.get(str(link['href']))
                 self.app.post(str(link['href']), params=dict(delete='on'))
@@ -367,7 +372,7 @@ class TestForum(TestController):
         form['add_forum.description'] = '<a href="http://cnn.com">This is CNN</a>'
         form.submit()
         r = self.app.get('/discussion/')
-        assert len(r.html.findAll('a', rel='nofollow')) == 2
+        assert len(r.html.find_all('a', rel='nofollow')) == 2
 
     def test_forum_search(self):
         self.app.get('/discussion/search')
@@ -391,7 +396,7 @@ class TestForum(TestController):
             f = r.html.find(
                 'form', {'action': '/p/test/discussion/save_new_topic'})
             params = dict()
-            inputs = f.findAll('input')
+            inputs = f.find_all('input')
             for field in inputs:
                 if field.has_attr('name'):
                     params[field['name']] = field.get('value') or ''
@@ -450,7 +455,7 @@ class TestForum(TestController):
             f = r.html.find(
                 'form', {'action': '/p/test/discussion/save_new_topic'})
             params = dict()
-            inputs = f.findAll('input')
+            inputs = f.find_all('input')
             for field in inputs:
                 if field.has_attr('name'):
                     params[field['name']] = field.get('value') or ''
@@ -471,7 +476,7 @@ class TestForum(TestController):
         r = self.app.get('/discussion/create_topic/')
         f = r.html.find('form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -496,7 +501,7 @@ class TestForum(TestController):
             self.test_posting()
 
             # second should fail
-            with pytest.raises(Exception):
+            with pytest.raises(AssertionError, match='Message posted'):
                 self.test_posting()
 
     def test_notifications_escaping(self):
@@ -504,7 +509,7 @@ class TestForum(TestController):
         f = r.html.find(
             'form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -519,9 +524,9 @@ class TestForum(TestController):
     def _set_anon_allowed(self):
         r = self.app.get('/admin/discussion/permissions')
         select = r.html.find('select', {'name': 'card-3.new'})
-        opt_anon = select.find(text='*anonymous').parent
-        opt_auth = select.find(text='*authenticated').parent
-        opt_admin = select.find(text='Admin').parent
+        opt_anon = select.find(string='*anonymous').parent
+        opt_auth = select.find(string='*authenticated').parent
+        opt_admin = select.find(string='Admin').parent
         r = self.app.post('/admin/discussion/update', params={
             'card-0.id': 'admin',
             'card-0.value': opt_admin['value'],
@@ -539,7 +544,7 @@ class TestForum(TestController):
         r = self.app.get('/discussion/create_topic/')
         f = r.html.find('form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -564,7 +569,7 @@ class TestForum(TestController):
         f = r.html.find('div', {'class': 'comment-row reply_post_form'}).find('form')
         rep_url = f.get('action')
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -614,8 +619,6 @@ class TestForum(TestController):
         btn_edit = post_container.find('a', {'title': 'Edit'})
         assert not btn_edit
 
-
-
     @td.with_tool('test2', 'Discussion', 'discussion')
     @mock.patch('allura.model.discuss.g.spam_checker')
     def test_is_spam(self, spam_checker):
@@ -634,7 +637,7 @@ class TestForum(TestController):
         f = r.html.find(
             'form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -648,7 +651,7 @@ class TestForum(TestController):
         f = thread.html.find('div', {'class': 'comment-row reply_post_form'}).find('form')
         rep_url = f.get('action')
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -656,9 +659,9 @@ class TestForum(TestController):
         thread = self.app.post(str(rep_url), params=params)
         thread = self.app.get(url)
         # beautiful soup is getting some unicode error here - test without it
-        assert thread.html.findAll(
+        assert thread.html.find_all(
             'div', {'class': 'display_post'})[0].find('p').string == 'aaa'
-        assert thread.html.findAll(
+        assert thread.html.find_all(
             'div', {'class': 'display_post'})[1].find('p').string == 'bbb'
         assert thread.response.text.count(
             '<div class="comment-row reply_post_form') == 2
@@ -670,7 +673,7 @@ class TestForum(TestController):
         reply_form = r.html.find('div', {'class': 'edit_post_form reply'}).find('form')
         post_link = str(reply_form['action'])
         params = dict()
-        inputs = reply_form.findAll('input')
+        inputs = reply_form.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -684,7 +687,7 @@ class TestForum(TestController):
         r = self.app.get('/discussion/create_topic/')
         f = r.html.find('form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -698,7 +701,7 @@ class TestForum(TestController):
         f = r.html.find('form', {'class': 'follow_form'})
         subscribe_url = f.get('action')
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -707,7 +710,7 @@ class TestForum(TestController):
         f = thread.html.find('div', {'class': 'comment-row reply_post_form'}).find('form')
         rep_url = f.get('action')
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -718,21 +721,21 @@ class TestForum(TestController):
 
     def get_table_rows(self, response, closest_id):
         tbody = response.html.find('div', {'id': closest_id}).find('tbody')
-        rows = tbody.findAll('tr')
+        rows = tbody.find_all('tr')
         return rows
 
     def check_announcement_table(self, response, topic_name):
-        assert response.html.find(text='Announcements')
+        assert response.html.find(string='Announcements')
         rows = self.get_table_rows(response, 'announcements')
         assert len(rows) == 1
-        cell = rows[0].findAll('td', {'class': 'topic'})
+        cell = rows[0].find_all('td', {'class': 'topic'})
         assert topic_name in str(cell)
 
     def test_thread_announcement(self):
         r = self.app.get('/discussion/create_topic/')
         f = r.html.find('form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -785,7 +788,7 @@ class TestForum(TestController):
         r = self.app.get('/discussion/create_topic/')
         f = r.html.find('form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -799,7 +802,7 @@ class TestForum(TestController):
         r = self.app.get('/discussion/create_topic/')
         f = r.html.find('form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -850,7 +853,7 @@ class TestForum(TestController):
         r = self.app.get('/discussion/create_topic/')
         f = r.html.find('form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -865,7 +868,7 @@ class TestForum(TestController):
             'div', {'class': 'comment-row reply_post_form'}).find('form')
         rep_url = f.get('action')
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -873,7 +876,7 @@ class TestForum(TestController):
         thread = self.app.post(str(rep_url), params=params)
         thread = self.app.get(url)
         # make sure the posts are in the original thread
-        posts = thread.html.find('div', {'id': 'comment'}).findAll(
+        posts = thread.html.find('div', {'id': 'comment'}).find_all(
             'div', {'class': 'discussion-post'})
         assert len(posts) == 2
         # move the thread
@@ -881,7 +884,7 @@ class TestForum(TestController):
             flags='',
             discussion='general')).follow()
         # make sure all the posts got moved
-        posts = r.html.find('div', {'id': 'comment'}).findAll(
+        posts = r.html.find('div', {'id': 'comment'}).find_all(
             'div', {'class': 'discussion-post'})
         assert len(posts) == 2
 
@@ -890,7 +893,7 @@ class TestForum(TestController):
         r = self.app.get('/discussion/create_topic/')
         f = r.html.find('form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -905,8 +908,8 @@ class TestForum(TestController):
 
         assert 'first subject' in resp
 
-        f = resp.html.find('div', {'id':'mod_thread_form'}).find('form')
-        params=dict(
+        f = resp.html.find('div', {'id': 'mod_thread_form'}).find('form')
+        params = dict(
             flags='',
             discussion='general',
             subject='changed subject')
@@ -920,7 +923,7 @@ class TestForum(TestController):
         r = self.app.get('/discussion/')
         sidebar = r.html.find('div', {'id': 'sidebar'})
         sidebar_menu = str(sidebar)
-        sidebar_links = [i['href'] for i in sidebar.findAll('a')]
+        sidebar_links = [i['href'] for i in sidebar.find_all('a')]
         assert "/p/test/discussion/create_topic/" in sidebar_links
         assert "/p/test/discussion/new_forum" in sidebar_links
         assert '<h3 class="">Help</h3>' in sidebar_menu
@@ -929,7 +932,7 @@ class TestForum(TestController):
         r = self.app.get('/discussion/create_topic/')
         f = r.html.find('form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -944,7 +947,7 @@ class TestForum(TestController):
         r = self.app.get('/discussion/')
         sidebar = r.html.find('div', {'id': 'sidebar'})
         sidebar_menu = str(sidebar)
-        sidebar_links = [i['href'] for i in sidebar.findAll('a')]
+        sidebar_links = [i['href'] for i in sidebar.find_all('a')]
         assert "/p/test/discussion/create_topic/" in sidebar_links
         assert "/p/test/discussion/new_forum" in sidebar_links
         assert '<h3 class="">Help</h3>' in sidebar_menu
@@ -953,7 +956,7 @@ class TestForum(TestController):
         r = self.app.get('/discussion/create_topic/')
         f = r.html.find('form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -998,7 +1001,7 @@ class TestForum(TestController):
             if field.id is None:
                 continue
             if 'attachment' in field.id:
-                form[field.name] = ('myfile.txt', b'foo bar baz')  # webtest.Upload dooesn't work here
+                form[field.name] = [('myfile.txt', b'foo bar baz')]  # webtest.Upload dooesn't work here
         r = form.submit().follow()
         assert 'myfile.txt' in r, r
 
