@@ -140,7 +140,7 @@ class TestForumAdmin(TestController):
         r = form.submit()
         r = self.app.get('/admin/discussion/forums')
         soup_form = r.html.find('form', action='update_forums')
-        assert len(soup_form.findAll('input', {'value': 'Delete'})) == 2
+        assert len(soup_form.find_all('input', {'value': 'Delete'})) == 2
         h.set_context('test', 'Forum', neighborhood='Projects')
         frm = FM.Forum.query.get(shortname='testforum')
 
@@ -151,7 +151,7 @@ class TestForumAdmin(TestController):
                                   'forum-0.description': 'My desc'})
         r = self.app.get('/admin/discussion/forums')
         soup_form = r.html.find('form', action='update_forums')
-        assert len(soup_form.findAll('input', {'value': 'Delete'})) == 1
+        assert len(soup_form.find_all('input', {'value': 'Delete'})) == 1
         audit_log = M.AuditLog.query.find({'project_id': project._id}).sort('_id', -1).first()
         assert 'deleted forum "Test Forum"' in audit_log.message
         r = self.app.post('/admin/discussion/update_forums',
@@ -161,7 +161,7 @@ class TestForumAdmin(TestController):
                                   'forum-0.description': 'My desc'})
         r = self.app.get('/admin/discussion/forums')
         soup_form = r.html.find('form', action='update_forums')
-        assert len(soup_form.findAll('input', {'value': 'Delete'})) == 2
+        assert len(soup_form.find_all('input', {'value': 'Delete'})) == 2
         audit_log = M.AuditLog.query.find({'project_id': project._id}).sort('_id', -1).first()
         assert 'undeleted forum "Test Forum"' in audit_log.message
 
@@ -182,7 +182,7 @@ class TestForumAdmin(TestController):
         f = r.html.find(
             'form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -234,10 +234,9 @@ class TestForumAdmin(TestController):
         form.submit()
         # try to post in the forum and get a 403
         r = self.app.get('/discussion/create_topic/')
-        f = r.html.find(
-            'form', {'action': '/p/test/discussion/save_new_topic'})
+        f = r.html.find('form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -262,7 +261,7 @@ class TestForumAdmin(TestController):
         f = r.html.find(
             'form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -272,6 +271,19 @@ class TestForumAdmin(TestController):
         r = self.app.post('/discussion/save_new_topic', params=params)
         assert 'http://localhost/p/test/discussion/testforum/thread/' in r.location
 
+        # and make sure a blocked user takes priority over anonymous-allowed letting them through
+        r = self.app.post('/admin/discussion/block_user',
+                          params={'username': 'test-user', 'perm': 'post', 'reason': 'They are bad'})
+        # forum not listed on create topic page
+        r = self.app.get('/discussion/create_topic/',
+                         extra_environ=dict(username='test-user'))
+        r.mustcontain('You do not have permission to post in any forums')
+        # if you try to post anyway, not allowed
+        r = self.app.post('/discussion/save_new_topic',
+                          params=params,
+                          extra_environ=dict(username='test-user'),
+                          status=403)
+
     def test_footer_monitoring_email(self):
         r = self.app.get('/admin/discussion/forums')
         form = r.forms['add-forum']
@@ -292,7 +304,7 @@ class TestForumAdmin(TestController):
         f = r.html.find(
             'form', {'action': '/p/test/discussion/save_new_topic'})
         params = dict()
-        inputs = f.findAll('input')
+        inputs = f.find_all('input')
         for field in inputs:
             if field.has_attr('name'):
                 params[field['name']] = field.get('value') or ''
@@ -305,6 +317,6 @@ class TestForumAdmin(TestController):
             dict(task_name='allura.tasks.mail_tasks.sendsimplemail')).all()
         assert 'Sent from localhost because email@monitoring.com is subscribed '\
                'to http://localhost/p/test/discussion/testforum/' in email_tasks[
-            0].kwargs['text'], email_tasks[0].kwargs['text']
+                   0].kwargs['text'], email_tasks[0].kwargs['text']
         assert 'a project admin can change settings at http://localhost/p/test/admin/discussion/forums' in email_tasks[
             0].kwargs['text']
