@@ -56,7 +56,7 @@ class TestImportController(TestRestApiBase):  # TestController):
             r = self.app.get('/p/test/discussion/')
             assert 'Open Discussion' in str(r)
             assert 'Welcome to Open Discussion' in str(r)
-            for link in r.html.findAll('a'):
+            for link in r.html.find_all('a'):
                 if 'Welcome to Open Discussion' in str(link):
                     break
             r = self.app.get(link.get('href'))
@@ -73,7 +73,7 @@ class TestImportController(TestRestApiBase):  # TestController):
             r = self.app.get('/p/test/discussion/')
             assert 'Open Discussion' in str(r)
             assert 'Welcome to Open Discussion' in str(r)
-            for link in r.html.findAll('a'):
+            for link in r.html.find_all('a'):
                 if 'Welcome to Open Discussion' in str(link):
                     break
             r = self.app.get(link.get('href'))
@@ -90,7 +90,7 @@ class TestImportController(TestRestApiBase):  # TestController):
             r = self.app.get('/p/test/discussion/')
             assert 'Open Discussion' in str(r)
             assert 'Welcome to Open Discussion' in str(r)
-            for link in r.html.findAll('a'):
+            for link in r.html.find_all('a'):
                 if 'Welcome to Open Discussion' in str(link):
                     break
             r = self.app.get(link.get('href'))
@@ -109,10 +109,10 @@ class TestImportController(TestRestApiBase):  # TestController):
         assert from_api['summary'] == org['summary']
         assert from_api['ticket_num'] == org['id']
         assert (from_api['created_date'] ==
-                     self.time_normalize(org['date']))
+                self.time_normalize(org['date']))
         assert (from_api['mod_date'] ==
-                     self.time_normalize(org['date_updated']))
+                self.time_normalize(org['date_updated']))
         assert (from_api['custom_fields']
-                     ['_resolution'] == org['resolution'])
+                ['_resolution'] == org['resolution'])
         assert from_api['custom_fields']['_cc'] == org['cc']
         assert from_api['custom_fields']['_private'] == org['private']
