@@ -20,13 +20,4 @@ from setuptools import setup
 
 setup(name='ForgeFiles',
       version='0.1.0',
-      description="",
-      packages=['forgefiles'],
-      include_package_data=True,
-      zip_safe=True,
-      entry_points="""
-      # -*- Entry points: -*-
-      [allura]
-      Files=forgefiles.files_main:FilesApp
-      """,
-      )
+)
