@@ -144,7 +144,7 @@ class Repository(M.Repository):
             tmp_repo.git.checkout(mr.target_branch)
             tmp_repo.git.fetch(mr.downstream_repo.full_fs_path, mr.source_branch)
             author = h.really_unicode(c.user.display_name or c.user.username)
-            tmp_repo.git.config('user.name', author.encode('utf8'))
+            tmp_repo.git.config('user.name', author)
             tmp_repo.git.config('user.email', 'allura@localhost')  # a public email alias could be nice here
             msg = 'Merge {} branch {} into {}\n\n{}'.format(
                 mr.downstream_repo.url(),
@@ -457,7 +457,7 @@ class GitImplementation(M.RepositoryImplementation):
         commit_lines = []
         while True:
             line = six.ensure_text(stream.readline())
-            if '\x00' in line or not(len(line)):
+            if '\x00' in line or not (len(line)):
                 # hash line read, need to yield previous commit
                 # first, cleaning lines a bit
                 commit_lines = [
@@ -484,7 +484,7 @@ class GitImplementation(M.RepositoryImplementation):
                             renamed['from'] = name_stat_parts[1]
                             renamed['to'] = name_stat_parts[2]
                     yield (git.Commit(self._git, gitdb.util.hex_to_bin(hexsha)), refs, renamed)
-                if not(len(line)):
+                if not (len(line)):
                     # if all lines have been read
                     break
                 commit_lines = [line]
@@ -596,7 +596,7 @@ class GitImplementation(M.RepositoryImplementation):
         except ValueError:
             threshold = None
             log.warning('Skipping reference caching - The value for config param '
-                     '"repo_refs_cache_threshold" must be a float.')
+                        '"repo_refs_cache_threshold" must be a float.')
 
         if threshold is not None and time_taken > threshold:
             setattr(self._repo, cache_name, refs)
@@ -815,4 +815,5 @@ class _OpenedGitBlob:
     def close(self):
         pass
 
+
 Mapper.compile_all()
