@@ -19,17 +19,17 @@
 import os
 import shutil
 import stat
-import unittest
 import pkg_resources
 import datetime
 import email.iterators
-
+import pytest
 import mock
 from tg import tmpl_context as c, app_globals as g
 import tg
 from ming.base import Object
 from ming.odm import ThreadLocalODMSession, session
 from testfixtures import TempDirectory
+import pytest
 
 from alluratest.controller import setup_basic_test, setup_global_objects
 from allura.lib import helpers as h
@@ -44,7 +44,7 @@ from forgegit.tests import with_git
 from forgewiki import model as WM
 
 
-class TestNewGit(unittest.TestCase):
+class TestNewGit:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -68,8 +68,8 @@ class TestNewGit(unittest.TestCase):
     def test_commit(self):
         assert self.rev.primary() is self.rev
         assert self.rev.index_id().startswith('allura/model/repo/Commit#')
-        self.rev.author_url
-        self.rev.committer_url
+        assert self.rev.author_url is None
+        assert self.rev.committer_url is None
         assert self.rev.tree._id == self.rev.tree_id
         assert self.rev.summary == self.rev.message.splitlines()[0]
         assert self.rev.shorthand_id() == '[1e146e]'
@@ -90,7 +90,7 @@ class TestNewGit(unittest.TestCase):
             '/p/test/src-git/ci/'
             '1e146e67985dcd71c74de79613719bef7bddca4a/'
             'tree/')
-        self.rev.tree.by_name['README']
+        assert self.rev.tree.by_name['README']
         assert self.rev.tree.is_blob('README') is True
         ThreadLocalODMSession.close_all()
         c.app = None
@@ -122,7 +122,7 @@ class TestNewGit(unittest.TestCase):
                     'committer', 'added', 'removed', 'renamed', 'modified', 'copied']))
 
 
-class TestGitRepo(unittest.TestCase, RepoImplTestBase):
+class TestGitRepo(RepoImplTestBase):
 
     def setup_method(self, method):
         setup_basic_test()
@@ -199,7 +199,7 @@ class TestGitRepo(unittest.TestCase, RepoImplTestBase):
             shutil.rmtree(dirname)
         repo.init()
         repo._impl.clone_from(repo_path)
-        assert len(list(repo.log()))
+        assert list(repo.log())
         assert not os.path.exists(
             os.path.join(g.tmpdir, 'testgit.git/hooks/update'))
         assert not os.path.exists(
@@ -210,9 +210,9 @@ class TestGitRepo(unittest.TestCase, RepoImplTestBase):
             os.path.join(g.tmpdir, 'testgit.git/hooks/post-receive'))[0] & stat.S_IXUSR
         with open(os.path.join(g.tmpdir, 'testgit.git/hooks/post-receive')) as f:
             c = f.read()
-        self.assertIn(
-            'curl -s http://localhost/auth/refresh_repo/p/test/src-git/\n', c)
-        self.assertIn('exec $DIR/post-receive-user\n', c)
+        assert \
+            'curl -s http://localhost/auth/refresh_repo/p/test/src-git/\n' in c
+        assert 'exec $DIR/post-receive-user\n' in c
         shutil.rmtree(dirname)
 
     @mock.patch('forgegit.model.git_repo.git.Repo.clone_from', autospec=True)
@@ -233,7 +233,7 @@ class TestGitRepo(unittest.TestCase, RepoImplTestBase):
             repo.init()
             repo._impl.clone_from(repo_path)
             assert not clone_from.called
-            assert len(list(repo.log()))
+            assert list(repo.log())
             assert os.path.exists(
                 os.path.join(g.tmpdir, 'testgit.git/hooks/update'))
             assert os.path.exists(
@@ -244,9 +244,9 @@ class TestGitRepo(unittest.TestCase, RepoImplTestBase):
                 os.path.join(g.tmpdir, 'testgit.git/hooks/post-receive'))[0] & stat.S_IXUSR
             with open(os.path.join(g.tmpdir, 'testgit.git/hooks/post-receive')) as f:
                 c = f.read()
-            self.assertIn(
-                'curl -s http://localhost/auth/refresh_repo/p/test/src-git/\n', c)
-            self.assertIn('exec $DIR/post-receive-user\n', c)
+            assert \
+                'curl -s http://localhost/auth/refresh_repo/p/test/src-git/\n' in c
+            assert 'exec $DIR/post-receive-user\n' in c
             shutil.rmtree(dirname)
 
     def test_index(self):
@@ -365,10 +365,10 @@ class TestGitRepo(unittest.TestCase, RepoImplTestBase):
         # regenerate the tree
         new_tree = entry.tree
         assert new_tree
-        self.assertEqual(new_tree._id, orig_tree._id)
-        self.assertEqual(new_tree.tree_ids, orig_tree.tree_ids)
-        self.assertEqual(new_tree.blob_ids, orig_tree.blob_ids)
-        self.assertEqual(new_tree.other_ids, orig_tree.other_ids)
+        assert new_tree._id == orig_tree._id
+        assert new_tree.tree_ids == orig_tree.tree_ids
+        assert new_tree.blob_ids == orig_tree.blob_ids
+        assert new_tree.other_ids == orig_tree.other_ids
 
     def test_refresh(self):
         # test results of things that ran during setup_method
@@ -513,16 +513,16 @@ By Dave Brondsema''' in text_body
             '1e146e67985dcd71c74de79613719bef7bddca4a',  # master
             '5c47243c8e424136fd5cdd18cd94d34c66d1955c',  # zz
         ]
-        self.assertIn(cids[0], heads)  # repo head comes first
+        assert cids[0] in heads  # repo head comes first
         for head in heads:
-            self.assertIn(head, cids)  # all branches included
+            assert head in cids  # all branches included
         # repo root comes last
-        self.assertEqual(cids[-1], '9a7df788cf800241e3bb5a849c8870f2f8259d98')
+        assert cids[-1] == '9a7df788cf800241e3bb5a849c8870f2f8259d98'
 
     def test_ls(self):
         c.lcid_cache = {}  # else it'll be a mock
         lcd_map = self.repo.commit('HEAD').tree.ls()
-        self.assertEqual(lcd_map, [{
+        assert lcd_map == [{
             'href': 'README',
             'kind': 'BLOB',
             'last_commit': {
@@ -533,7 +533,7 @@ By Dave Brondsema''' in text_body
                 'href': '/p/test/src-git/ci/1e146e67985dcd71c74de79613719bef7bddca4a/',
                 'shortlink': '[1e146e]',
                 'summary': 'Change README'},
-            'name': 'README'}])
+            'name': 'README'}]
 
     def test_ls_with_prev(self):
         c.lcid_cache = {}  # else it'll be a mock
@@ -618,14 +618,14 @@ By Dave Brondsema''' in text_body
             assert impl._git.head.reference.name == 'master'
 
     def test_default_branch_non_standard_unset(self):
-        with mock.patch.object(self.repo, 'get_branches') as gb,\
+        with mock.patch.object(self.repo, 'get_branches') as gb, \
                 mock.patch.object(self.repo, 'set_default_branch') as set_db:
             gb.return_value = [Object(name='foo')]
             assert self.repo.get_default_branch(('main', 'master')) == 'foo'
             set_db.assert_called_once_with('foo')
 
     def test_default_branch_non_standard_invalid(self):
-        with mock.patch.object(self.repo, 'get_branches') as gb,\
+        with mock.patch.object(self.repo, 'get_branches') as gb, \
                 mock.patch.object(self.repo, 'set_default_branch') as set_db:
             self.repo.default_branch_name = 'zz'
             gb.return_value = [Object(name='foo')]
@@ -633,7 +633,7 @@ By Dave Brondsema''' in text_body
             set_db.assert_called_once_with('foo')
 
     def test_default_branch_invalid(self):
-        with mock.patch.object(self.repo, 'get_branches') as gb,\
+        with mock.patch.object(self.repo, 'get_branches') as gb, \
                 mock.patch.object(self.repo, 'set_default_branch') as set_db:
             self.repo.default_branch_name = 'zz'
             gb.return_value = [Object(name='foo'), Object(name='master')]
@@ -653,7 +653,7 @@ By Dave Brondsema''' in text_body
             assert self.repo.get_default_branch(('main', 'master')) == 'main'
 
     def test_default_branch_main_before_master(self):
-        with mock.patch.object(self.repo, 'get_branches') as gb,\
+        with mock.patch.object(self.repo, 'get_branches') as gb, \
                 mock.patch.object(self.repo, 'set_default_branch') as set_db:
             self.repo.default_branch_name = None
             gb.return_value = [Object(name='master'), Object(name='main')]
@@ -774,7 +774,7 @@ By Dave Brondsema''' in text_body
         tmp_repo.git.checkout.assert_called_once_with('target-branch')
         assert (
             tmp_repo.git.config.call_args_list ==
-            [mock.call('user.name', b'Test Admin'),
+            [mock.call('user.name', 'Test Admin'),
              mock.call('user.email', 'allura@localhost')])
         msg = 'Merge downstream-repo-url branch source-branch into target-branch'
         msg += '\n\nhttp://localhost/merge-request/1/'
@@ -789,8 +789,8 @@ By Dave Brondsema''' in text_body
     @mock.patch('forgegit.model.git_repo.git', autospec=True)
     def test_merge_raise_exception(self, git, shutil, tempfile):
         self.repo._impl._git.git = mock.Mock()
-        git.Repo.clone_from.side_effect = Exception
-        with self.assertRaises(Exception):
+        git.Repo.clone_from.side_effect = ConnectionError
+        with pytest.raises(ConnectionError):
             self.repo.merge(mock.Mock())
         assert shutil.rmtree.called
 
@@ -984,7 +984,7 @@ By Dave Brondsema''' in text_body
             assert rev.cached_tags == tags
 
 
-class TestGitImplementation(unittest.TestCase):
+class TestGitImplementation:
 
     def test_branches(self):
         repo_dir = pkg_resources.resource_filename(
@@ -993,12 +993,12 @@ class TestGitImplementation(unittest.TestCase):
         repo.__ming__ = mock.Mock()
         repo.cached_branches = []
         impl = GM.git_repo.GitImplementation(repo)
-        self.assertEqual(impl.branches, [
+        assert impl.branches == [
             Object(name='master',
                    object_id='1e146e67985dcd71c74de79613719bef7bddca4a'),
             Object(name='zz',
                    object_id='5c47243c8e424136fd5cdd18cd94d34c66d1955c')
-        ])
+        ]
 
     def test_tags(self):
         repo_dir = pkg_resources.resource_filename(
@@ -1007,10 +1007,10 @@ class TestGitImplementation(unittest.TestCase):
         repo.__ming__ = mock.Mock()
         repo.cached_tags = []
         impl = GM.git_repo.GitImplementation(repo)
-        self.assertEqual(impl.tags, [
+        assert impl.tags == [
             Object(name='foo',
                    object_id='1e146e67985dcd71c74de79613719bef7bddca4a'),
-        ])
+        ]
 
     def test_last_commit_ids(self):
         repo_dir = pkg_resources.resource_filename(
@@ -1018,13 +1018,13 @@ class TestGitImplementation(unittest.TestCase):
         repo = mock.Mock(full_fs_path=repo_dir)
         impl = GM.git_repo.GitImplementation(repo)
         def lcd(c, p): return impl.last_commit_ids(mock.Mock(_id=c), p)
-        self.assertEqual(lcd('13951944969cf45a701bf90f83647b309815e6d5', ['f2.txt', 'f3.txt']), {
+        assert lcd('13951944969cf45a701bf90f83647b309815e6d5', ['f2.txt', 'f3.txt']) == {
             'f2.txt': '259c77dd6ee0e6091d11e429b56c44ccbf1e64a3',
             'f3.txt': '653667b582ef2950c1954a0c7e1e8797b19d778a',
-        })
-        self.assertEqual(lcd('259c77dd6ee0e6091d11e429b56c44ccbf1e64a3', ['f2.txt', 'f3.txt']), {
+        }
+        assert lcd('259c77dd6ee0e6091d11e429b56c44ccbf1e64a3', ['f2.txt', 'f3.txt']) == {
             'f2.txt': '259c77dd6ee0e6091d11e429b56c44ccbf1e64a3',
-        })
+        }
 
     def test_last_commit_ids_threaded(self):
         with h.push_config(tg.config, lcd_thread_chunk_size=1):
@@ -1040,10 +1040,10 @@ class TestGitImplementation(unittest.TestCase):
             impl = GM.git_repo.GitImplementation(repo)
             lcds = impl.last_commit_ids(
                 mock.Mock(_id='13951944969cf45a701bf90f83647b309815e6d5'), ['f2.txt', 'f3.txt'])
-            self.assertEqual(lcds, {})
+            assert lcds == {}
 
 
-class TestGitCommit(unittest.TestCase):
+class TestGitCommit:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -1119,7 +1119,7 @@ class TestGitCommit(unittest.TestCase):
         assert commits == []
 
 
-class TestGitHtmlView(unittest.TestCase):
+class TestGitHtmlView:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -1150,7 +1150,7 @@ class TestGitHtmlView(unittest.TestCase):
         assert b.has_html_view
 
 
-class TestGitRename(unittest.TestCase):
+class TestGitRename:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -1173,17 +1173,17 @@ class TestGitRename(unittest.TestCase):
     def test_renamed_file(self):
         # There was a file f.txt, then it was renamed to f2.txt.
         commits = list(self.repo.log(id_only=False, path='/f2.txt'))
-        self.assertEqual(len(commits), 4)
+        assert len(commits) == 4
         rename_commit = commits[1]
-        self.assertEqual(rename_commit['rename_details']['path'], '/f.txt')
-        self.assertEqual(
-            rename_commit['rename_details']['commit_url'],
+        assert rename_commit['rename_details']['path'] == '/f.txt'
+        assert \
+            rename_commit['rename_details']['commit_url'] == \
             '/p/test/src-git/ci/fbb0644603bb6ecee3ebb62efe8c86efc9b84ee6/'
-        )
-        self.assertEqual(rename_commit['size'], 19)
-        self.assertEqual(commits[2]['size'], 19)
+
+        assert rename_commit['size'] == 19
+        assert commits[2]['size'] == 19
 
     def test_merge_commit(self):
         merge_sha = '13951944969cf45a701bf90f83647b309815e6d5'
         commit = next(self.repo.log(revs=merge_sha, id_only=False))
-        self.assertEqual(commit['rename_details'], {})
+        assert commit['rename_details'] == {}
