@@ -14,7 +14,6 @@
 #       KIND, either express or implied.  See the License for the
 #       specific language governing permissions and limitations
 #       under the License.
-import unittest
 import mock
 from testfixtures import LogCapture
 
@@ -32,7 +31,7 @@ from forgegit.tests import with_git
 from forgegit.tests.functional.test_controllers import _TestCase as GitRealDataBaseTestCase
 
 
-class TestGitTasks(unittest.TestCase):
+class TestGitTasks:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -100,4 +99,3 @@ class TestCoreAlluraTasks(GitRealDataBaseTestCase):
 
         # mostly just making sure nothing errored, but here's at least one thing we can assert:
         assert repo.status == 'ready'
-
