@@ -121,7 +121,7 @@ def object_from_path(path):
 def import_tool(importer_path, project_name=None,
                 mount_point=None, mount_label=None, **kw):
     importer = object_from_path(importer_path)()
-    with ImportErrorHandler(importer, project_name, c.project) as handler,\
+    with ImportErrorHandler(importer, project_name, c.project) as handler, \
             M.session.substitute_extensions(M.artifact_orm_session,
                                             [M.session.BatchIndexer]):
         try:
@@ -167,7 +167,7 @@ class ProjectExtractor:
 
     @staticmethod
     def urlopen(url, retries=3, codes=(408, 500, 502, 503, 504), timeout=120, unredirected_hdrs=None, **kw):
-        req = urllib.request.Request(url, **kw)
+        req = urllib.request.Request(url, **kw)  # noqa: S310
         if unredirected_hdrs:
             for key, val in unredirected_hdrs.items():
                 req.add_unredirected_header(key, val)
@@ -376,7 +376,7 @@ class ToolImporterMeta(type):
         if not (hasattr(cls, 'target_app_ep_names')
                 or hasattr(cls, 'target_app')):
             raise AttributeError(f"{name} must define either `target_app` or `target_app_ep_names`")
-        return type.__init__(cls, name, bases, attrs)
+        type.__init__(cls, name, bases, attrs)
 
     def __call__(cls, *args, **kw):
         """ Right before the first instance of cls is created, get
@@ -466,8 +466,8 @@ class ToolImporter(metaclass=ToolImporterMeta):
         """
         limit = config.get('tool_import.rate_limit', 1)
         pending_key = 'tool_data.%s.pending' % self.classname
-        modified_project = M.Project.query.find_and_modify(
-            query={
+        modified_project = M.Project.query.find_one_and_update(
+            {
                 '_id': project._id,
                 '$or': [
                     {pending_key: None},
@@ -475,7 +475,7 @@ class ToolImporter(metaclass=ToolImporterMeta):
                 ],
             },
             update={'$inc': {pending_key: 1}},
-            new=True,
+            return_document=True,
         )
         return modified_project is not None
 
@@ -485,10 +485,10 @@ class ToolImporter(metaclass=ToolImporterMeta):
         to indicate that an import is complete.
         """
         pending_key = 'tool_data.%s.pending' % self.classname
-        M.Project.query.find_and_modify(
-            query={'_id': project._id},
+        M.Project.query.find_one_and_update(
+            {'_id': project._id},
             update={'$inc': {pending_key: -1}},
-            new=True,
+            return_document=True,
         )
 
     def import_tool(self, project, user, project_name=None,
@@ -579,7 +579,7 @@ class ProjectToolsImportController:
         importer_matrix = defaultdict(dict)
         tools_with_importers = set()
         hidden = set(aslist(config.get('hidden_importers'), sep=','))
-        visible = lambda ep: ep.name not in hidden
+        def visible(ep): return ep.name not in hidden
         for ep in filter(visible, h.iter_entry_points('allura.importers')):
             # must instantiate to ensure importer.target_app is populated
             # (see ToolImporterMeta.__call__)
@@ -611,6 +611,7 @@ class ImportAdminExtension(AdminExtension):
         base_url = c.project.url() + 'admin/ext/'
         link = SitemapEntry('Import', base_url + 'import/')
         sidebar_links.append(link)
+        return sidebar_links
 
 
 def bytesio_parser(page):
