@@ -40,6 +40,7 @@ log = logging.getLogger(__name__)
 
 class GitHubURLValidator(fev.FancyValidator):
     regex = r'https?:\/\/github\.com'
+
     def _convert_to_python(self, value, state):
         valid_url = urlparse(value.strip())
         if not bool(valid_url.scheme):
@@ -48,6 +49,7 @@ class GitHubURLValidator(fev.FancyValidator):
             raise fev.Invalid('Invalid Github URL', value, state)
         return value
 
+
 class GitHubProjectNameValidator(fev.FancyValidator):
     not_empty = True
     messages = {
@@ -99,7 +101,7 @@ class GitHubProjectExtractor(base.ProjectExtractor):
         now = datetime.utcnow()
         # 60/hour is for GitHub unauthenticated users.  If you get that, check your auth tokens
         log.warning('Rate limit exceeded (%s requests/hour). '
-                 'Sleeping until %s UTC' % (limit, reset))
+                    'Sleeping until %s UTC' % (limit, reset))
         time.sleep((reset - now).total_seconds() + 2)
 
     def urlopen(self, url, headers=None, use_auth_headers_on_redirects=True, **kw):
@@ -208,7 +210,7 @@ def oauth_app_basic_auth(config):
 
 def valid_access_token(access_token, scopes_required=None):
     tok_details = access_token_details(access_token)
-    if not tok_details.status_code == 200:
+    if tok_details.status_code != 200:
         return False
     if scopes_required and not all(scope_req in tok_details.json()['scopes']
                                    for scope_req in scopes_required):
