@@ -15,7 +15,6 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-from unittest import TestCase
 from mock import Mock, patch
 from ming.odm import ThreadLocalODMSession
 
@@ -33,7 +32,7 @@ test_project_with_repo = 'test2'
 with_git = with_tool(test_project_with_repo, 'git', 'src', 'git')
 
 
-class TestGitHubRepoImporter(TestCase):
+class TestGitHubRepoImporter:
 
     def setup_method(self, method):
         setup_unit_test()
@@ -67,16 +66,16 @@ class TestGitHubRepoImporter(TestCase):
         g.post_event.assert_called_once_with('project_updated')
 
 
-class TestGitHubImportController(TestController, TestCase):
+class TestGitHubImportController(TestController):
 
     @with_git
     def test_index(self):
         r = self.app.get(
             f'/p/{test_project_with_repo}/admin/ext/import/github-repo/')
-        self.assertIsNotNone(r.html.find(attrs=dict(name="gh_user_name")))
-        self.assertIsNotNone(r.html.find(attrs=dict(name="gh_project_name")))
-        self.assertIsNotNone(r.html.find(attrs=dict(name="mount_label")))
-        self.assertIsNotNone(r.html.find(attrs=dict(name="mount_point")))
+        assert r.html.find(attrs=dict(name="gh_user_name")) is not None
+        assert r.html.find(attrs=dict(name="gh_project_name")) is not None
+        assert r.html.find(attrs=dict(name="mount_label")) is not None
+        assert r.html.find(attrs=dict(name="mount_point")) is not None
 
     @with_git
     @patch('forgeimporters.github.requests')
@@ -94,17 +93,17 @@ class TestGitHubImportController(TestController, TestCase):
                 test_project_with_repo),
             params,
             status=302)
-        self.assertEqual(
-            r.location, 'http://localhost/p/{}/admin/'.format(
-                test_project_with_repo))
-        self.assertEqual(
-            'mymount', import_tool.post.call_args[1]['mount_point'])
-        self.assertEqual(
-            'mylabel', import_tool.post.call_args[1]['mount_label'])
-        self.assertEqual(
-            'poop', import_tool.post.call_args[1]['project_name'])
-        self.assertEqual('spooky', import_tool.post.call_args[1]['user_name'])
-        self.assertEqual(requests.head.call_count, 1)
+        assert \
+            r.location == 'http://localhost/p/{}/admin/'.format(
+                test_project_with_repo)
+        assert \
+            'mymount' == import_tool.post.call_args[1]['mount_point']
+        assert \
+            'mylabel' == import_tool.post.call_args[1]['mount_label']
+        assert \
+            'poop' == import_tool.post.call_args[1]['project_name']
+        assert 'spooky' == import_tool.post.call_args[1]['user_name']
+        assert requests.head.call_count == 1
 
     @with_git
     @patch('forgeimporters.github.requests')
@@ -125,12 +124,12 @@ class TestGitHubImportController(TestController, TestCase):
                 test_project_with_repo),
             params,
             status=302).follow()
-        self.assertIn('Please wait and try again', r)
-        self.assertEqual(import_tool.post.call_count, 0)
+        assert 'Please wait and try again' in r
+        assert import_tool.post.call_count == 0
 
     @with_git
     @patch.object(GitHubOAuthMixin, 'oauth_begin')
     def test_oauth(self, oauth_begin):
         self.app.get(
             f'/p/{test_project_with_repo}/admin/ext/import/github-repo/')
-        self.assertEqual(oauth_begin.call_count, 1)
+        assert oauth_begin.call_count == 1
