@@ -15,7 +15,6 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-from unittest import TestCase
 from alluratest.controller import setup_unit_test
 
 from mock import Mock, patch, MagicMock
@@ -25,7 +24,7 @@ from allura.tests import TestController
 from forgeimporters.github import GitHubOAuthMixin
 
 
-class TestGitHubOAuthMixin(TestController, TestCase):
+class TestGitHubOAuthMixin(TestController):
 
     def setup_method(self, method):
         super().setup_method(method)
@@ -34,12 +33,12 @@ class TestGitHubOAuthMixin(TestController, TestCase):
         self.mix = GitHubOAuthMixin()
 
     def test_oauth_has_access_no_scope(self):
-        self.assertFalse(self.mix.oauth_has_access(None))
-        self.assertFalse(self.mix.oauth_has_access(''))
+        assert not self.mix.oauth_has_access(None)
+        assert not self.mix.oauth_has_access('')
 
     def test_oauth_has_access_no_token(self):
         c.user.get_tool_data.return_value = None
-        self.assertFalse(self.mix.oauth_has_access('write:repo_hook'))
+        assert not self.mix.oauth_has_access('write:repo_hook')
 
     @patch.dict(config, {'github_importer.client_id': '123456',
                          'github_importer.client_secret': 'deadbeef'})
@@ -47,12 +46,12 @@ class TestGitHubOAuthMixin(TestController, TestCase):
     def test_oauth_has_access_no(self, req):
         c.user.get_tool_data.return_value = 'some-token'
         req.post.return_value = Mock(status_code=404, json=Mock(return_value={}))
-        self.assertFalse(self.mix.oauth_has_access('write:repo_hook'))
+        assert not self.mix.oauth_has_access('write:repo_hook')
         call_args = req.post.call_args[0]
-        self.assertEqual(call_args, ('https://api.github.com/applications/123456/token',))
+        assert call_args == ('https://api.github.com/applications/123456/token',)
         call_kwargs = req.post.call_args[1]
         assert call_kwargs['auth']
-        self.assertEqual(call_kwargs['json'], {'access_token': 'some-token'})
+        assert call_kwargs['json'] == {'access_token': 'some-token'}
 
     @patch.dict(config, {'github_importer.client_id': '123456',
                          'github_importer.client_secret': 'deadbeef'})
@@ -61,13 +60,13 @@ class TestGitHubOAuthMixin(TestController, TestCase):
         c.user.get_tool_data.return_value = 'some-token'
 
         req.post.return_value.json.return_value = {'scopes': []}
-        self.assertFalse(self.mix.oauth_has_access('write:repo_hook'))
+        assert not self.mix.oauth_has_access('write:repo_hook')
 
         req.post.return_value.json.return_value = {'scopes': ['some', 'other:scopes']}
-        self.assertFalse(self.mix.oauth_has_access('write:repo_hook'))
+        assert not self.mix.oauth_has_access('write:repo_hook')
 
         req.post.return_value.json.return_value = {'scopes': ['write:repo_hook', 'user']}
-        self.assertTrue(self.mix.oauth_has_access('write:repo_hook'))
+        assert self.mix.oauth_has_access('write:repo_hook')
 
     @patch.dict(config, {'github_importer.client_id': '123456',
                          'github_importer.client_secret': 'deadbeef'})
@@ -78,5 +77,5 @@ class TestGitHubOAuthMixin(TestController, TestCase):
         with patch.object(self.mix, 'oauth_callback_complete') as _mock, \
                 patch('forgeimporters.github.redirect') as tg_redir:
             self.mix.handle_oauth_callback()
-        self.assertEqual(_mock.call_count, 1)
-        self.assertEqual(tg_redir.call_count, 1)
+        assert _mock.call_count == 1
+        assert tg_redir.call_count == 1
