@@ -15,7 +15,6 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-from unittest import TestCase
 from mock import patch
 from ming.odm import ThreadLocalODMSession
 
@@ -32,17 +31,17 @@ with_tracker = with_tool(test_project_with_tracker,
                          'tickets', 'spooky-issues', 'tickets')
 
 
-class TestGitHubTrackerImportController(TestController, TestCase):
+class TestGitHubTrackerImportController(TestController):
 
     url = '/p/%s/admin/ext/import/github-tracker/' % test_project_with_tracker
 
     @with_tracker
     def test_index(self):
         r = self.app.get(self.url)
-        self.assertIsNotNone(r.html.find(attrs=dict(name='gh_user_name')))
-        self.assertIsNotNone(r.html.find(attrs=dict(name='gh_project_name')))
-        self.assertIsNotNone(r.html.find(attrs=dict(name='mount_label')))
-        self.assertIsNotNone(r.html.find(attrs=dict(name='mount_point')))
+        assert r.html.find(attrs=dict(name='gh_user_name')) is not None
+        assert r.html.find(attrs=dict(name='gh_project_name')) is not None
+        assert r.html.find(attrs=dict(name='mount_label')) is not None
+        assert r.html.find(attrs=dict(name='mount_point')) is not None
 
     @with_tracker
     @patch('forgeimporters.github.requests')
@@ -55,16 +54,12 @@ class TestGitHubTrackerImportController(TestController, TestCase):
             mount_point='issues',
             mount_label='Issues')
         r = self.app.post(self.url + 'create', params, status=302)
-        self.assertEqual(r.location, 'http://localhost/p/%s/admin/' %
-                         test_project_with_tracker)
-        self.assertEqual(
-            'Issues', import_tool.post.call_args[1]['mount_label'])
-        self.assertEqual(
-            'issues', import_tool.post.call_args[1]['mount_point'])
-        self.assertEqual(
-            'mulder', import_tool.post.call_args[1]['project_name'])
-        self.assertEqual('spooky', import_tool.post.call_args[1]['user_name'])
-        self.assertEqual(requests.head.call_count, 1)
+        assert r.location == 'http://localhost/p/%s/admin/' % test_project_with_tracker
+        assert 'Issues' == import_tool.post.call_args[1]['mount_label']
+        assert 'issues' == import_tool.post.call_args[1]['mount_point']
+        assert 'mulder' == import_tool.post.call_args[1]['project_name']
+        assert 'spooky' == import_tool.post.call_args[1]['user_name']
+        assert requests.head.call_count == 1
 
     @with_tracker
     @patch('forgeimporters.github.requests')
@@ -80,11 +75,11 @@ class TestGitHubTrackerImportController(TestController, TestCase):
             mount_point='issues',
             mount_label='Issues')
         r = self.app.post(self.url + 'create', params, status=302).follow()
-        self.assertIn('Please wait and try again', r)
-        self.assertEqual(import_tool.post.call_count, 0)
+        assert 'Please wait and try again' in r
+        assert import_tool.post.call_count == 0
 
     @with_tracker
     @patch.object(GitHubOAuthMixin, 'oauth_begin')
     def test_oauth(self, oauth_begin):
         self.app.get(self.url)
-        self.assertEqual(oauth_begin.call_count, 1)
+        assert oauth_begin.call_count == 1
