@@ -15,7 +15,7 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-from unittest import TestCase, skipIf
+from unittest import skipIf
 from mock import Mock, patch, call
 from ming.odm import ThreadLocalODMSession
 import git
@@ -36,7 +36,7 @@ test_project_with_wiki = 'test2'
 with_wiki = with_tool(test_project_with_wiki, 'wiki', 'w', 'wiki')
 
 
-class TestGitHubWikiImporter(TestCase):
+class TestGitHubWikiImporter:
 
     def _make_project(self, gh_proj_name=None):
         project = Mock()
@@ -48,8 +48,8 @@ class TestGitHubWikiImporter(TestCase):
     @patch('forgeimporters.github.wiki.g')
     @patch('forgeimporters.github.wiki.GitHubProjectExtractor')
     def test_import_tool_happy_path(self, ghpe, g, tlorms, M):
-        with patch('forgeimporters.github.wiki.GitHubWikiImporter.import_pages'),\
-                patch('forgeimporters.github.wiki.GitHubWikiImporter.has_wiki_repo', return_value=True),\
+        with patch('forgeimporters.github.wiki.GitHubWikiImporter.import_pages'), \
+                patch('forgeimporters.github.wiki.GitHubWikiImporter.has_wiki_repo', return_value=True), \
                 patch('forgeimporters.github.wiki.c'):
             ghpe.return_value.has_wiki.return_value = True
             p = self._make_project(gh_proj_name='myproject')
@@ -546,19 +546,18 @@ some text and **[Tips n\u2019 Tricks]**
         assert i.has_wiki_repo('fake url') is False
 
 
-class TestGitHubWikiImportController(TestController, TestCase):
+class TestGitHubWikiImportController(TestController):
 
     url = '/p/%s/admin/ext/import/github-wiki/' % test_project_with_wiki
 
     @with_wiki
     def test_index(self):
         r = self.app.get(self.url)
-        self.assertIsNotNone(r.html.find(attrs=dict(name='gh_user_name')))
-        self.assertIsNotNone(r.html.find(attrs=dict(name='gh_project_name')))
-        self.assertIsNotNone(r.html.find(attrs=dict(name='mount_label')))
-        self.assertIsNotNone(r.html.find(attrs=dict(name='mount_point')))
-        self.assertIsNotNone(
-            r.html.find(attrs=dict(name='tool_option', value='import_history')))
+        assert r.html.find(attrs=dict(name='gh_user_name')) is not None
+        assert r.html.find(attrs=dict(name='gh_project_name')) is not None
+        assert r.html.find(attrs=dict(name='mount_label')) is not None
+        assert r.html.find(attrs=dict(name='mount_point')) is not None
+        assert r.html.find(attrs=dict(name='tool_option', value='import_history')) is not None
 
     @with_wiki
     @patch('forgeimporters.github.requests')
@@ -572,15 +571,14 @@ class TestGitHubWikiImportController(TestController, TestCase):
             mount_label='GitHub Wiki',
             tool_option='import_history')
         r = self.app.post(self.url + 'create', params, status=302)
-        self.assertEqual(r.location, 'http://localhost/p/%s/admin/' %
-                         test_project_with_wiki)
+        assert r.location == 'http://localhost/p/%s/admin/' % test_project_with_wiki
         args = import_tool.post.call_args[1]
-        self.assertEqual('GitHub Wiki', args['mount_label'])
-        self.assertEqual('gh-wiki', args['mount_point'])
-        self.assertEqual('mulder', args['project_name'])
-        self.assertEqual('spooky', args['user_name'])
-        self.assertEqual('import_history', args['tool_option'])
-        self.assertEqual(requests.head.call_count, 1)
+        assert 'GitHub Wiki' == args['mount_label']
+        assert 'gh-wiki' == args['mount_point']
+        assert 'mulder' == args['project_name']
+        assert 'spooky' == args['user_name']
+        assert 'import_history' == args['tool_option']
+        assert requests.head.call_count == 1
 
     @with_wiki
     @patch('forgeimporters.github.requests')
@@ -594,15 +592,14 @@ class TestGitHubWikiImportController(TestController, TestCase):
             mount_label='GitHub Wiki'
         )
         r = self.app.post(self.url + 'create', params, status=302)
-        self.assertEqual(r.location, 'http://localhost/p/%s/admin/' %
-                         test_project_with_wiki)
+        assert r.location == 'http://localhost/p/%s/admin/' % test_project_with_wiki
         args = import_tool.post.call_args[1]
-        self.assertEqual('GitHub Wiki', args['mount_label'])
-        self.assertEqual('gh-wiki', args['mount_point'])
-        self.assertEqual('mulder', args['project_name'])
-        self.assertEqual('spooky', args['user_name'])
-        self.assertEqual('', args['tool_option'])
-        self.assertEqual(requests.head.call_count, 1)
+        assert 'GitHub Wiki' == args['mount_label']
+        assert 'gh-wiki' == args['mount_point']
+        assert 'mulder' == args['project_name']
+        assert 'spooky' == args['user_name']
+        assert '' == args['tool_option']
+        assert requests.head.call_count == 1
 
     @with_wiki
     @patch('forgeimporters.github.requests')
@@ -618,11 +615,11 @@ class TestGitHubWikiImportController(TestController, TestCase):
             mount_point='gh-wiki',
             mount_label='GitHub Wiki')
         r = self.app.post(self.url + 'create', params, status=302).follow()
-        self.assertIn('Please wait and try again', r)
-        self.assertEqual(import_tool.post.call_count, 0)
+        assert 'Please wait and try again' in r
+        assert import_tool.post.call_count == 0
 
     @with_wiki
     @patch.object(GitHubOAuthMixin, 'oauth_begin')
     def test_oauth(self, oauth_begin):
         self.app.get(self.url)
-        self.assertEqual(oauth_begin.call_count, 1)
+        assert oauth_begin.call_count == 1
