@@ -19,7 +19,6 @@ import re
 import logging
 from datetime import datetime
 from urllib.error import HTTPError
-import six
 from io import BytesIO
 
 from tg import (
@@ -248,7 +247,7 @@ class GitHubTrackerImporter(ToolImporter):
         # at github, attachments are images only and are included into comment's body
         # usual syntax is
         # ![cdbpzjc5ex4](https://f.cloud.github.com/assets/979771/1027411/a393ab5e-0e70-11e3-8a38-b93a3df904cf.jpg)\r\n
-        REGEXP = r'!\[[\w0-9]+?\]\(((?:https?:\/\/)?[\da-z\.-]+\.[a-z\.]{2,6}'\
+        REGEXP = r'!\[[\w]+?\]\(((?:https?:\/\/)?[\da-z\.-]+\.[a-z\.]{2,6}'\
             '[\\/%\\w\\.-]*.(jpg|jpeg|png|gif))\\)[\r\n]*'
         attachments = []
 
