@@ -15,7 +15,6 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-from unittest import TestCase
 import mock
 
 from dateutil.parser import parse
@@ -31,7 +30,7 @@ from forgeimporters.forge import discussion
 from forgediscussion import utils
 
 
-class TestDiscussionImporter(TestCase):
+class TestDiscussionImporter:
 
     def setup_method(self, method):
         self.patcher_g = mock.patch('forgeimporters.base.g', mock.MagicMock())
@@ -114,19 +113,19 @@ class TestDiscussionImporter(TestCase):
 
         utils.create_forum.assert_called_once_with(app, new_forum=new_forum)
         forum.get_discussion_thread(
-              dict(headers=dict(Subject=_json["forums"][0]["threads"][0]["subject"])))
+            dict(headers=dict(Subject=_json["forums"][0]["threads"][0]["subject"])))
         importer.add_posts.assert_called_once_with(
-                                    thread1,
-                                    _json["forums"][0]["threads"][0]["posts"],
-                                    app
+            thread1,
+            _json["forums"][0]["threads"][0]["posts"],
+            app
         )
 
         m.AuditLog.log.assert_called_once_with(
-                        "import tool mount_point from exported Allura JSON",
-                        project=project,
-                        user=user,
-                        url='foo'
-                    )
+            "import tool mount_point from exported Allura JSON",
+            project=project,
+            user=user,
+            url='foo'
+        )
         g.post_event.assert_called_once_with("project_updated")
 
     @mock.patch.object(discussion, 'c')
@@ -161,10 +160,10 @@ class TestDiscussionImporter(TestCase):
                             "slug": "0e0e",
                             "subject": "post with un\u00ef\u00e7\u00f8\u2202\u00e9"
                         }],
-                        "page": None,
-                        "subject": "post with un\u00ef\u00e7\u00f8\u2202\u00e9"
-                    }]
+                    "page": None,
+                    "subject": "post with un\u00ef\u00e7\u00f8\u2202\u00e9"
                 }]
+            }]
         }
 
         importer._load_json = mock.Mock(return_value=_json)
@@ -203,14 +202,14 @@ class TestDiscussionImporter(TestCase):
         utils.create_forum.assert_called_once_with(app, new_forum=new_forum)
         forum.get_discussion_thread.assert_called_once_with(dict(
             headers=dict(Subject=_json["forums"][0]["threads"][0]["subject"])
-            ))
+        ))
 
         importer.get_user.assert_called_once_with('admin1')
 
-        self.assertEqual(h.push_config.call_args_list, [
+        assert h.push_config.call_args_list == [
             mock.call(c, app=app),
             mock.call(c, user=admin, app=app)
-        ])
+        ]
 
         post = _json["forums"][0]["threads"][0]["posts"][0]
         thread1.add_post.assert_called_once_with(
@@ -221,9 +220,9 @@ class TestDiscussionImporter(TestCase):
             parent_id=None
         )
         importer.annotate_text.assert_called_once_with(
-                post["text"],
-                admin,
-                post["author"]
+            post["text"],
+            admin,
+            post["author"]
         )
         p.add_multiple_attachments.assert_called_once_with([])
 
@@ -333,29 +332,29 @@ class TestDiscussionImporter(TestCase):
                             "subject": "Thread0",
                             "posts": []
                         },
-                        {
+                    {
                             "page": None,
                             "subject": "Thread1",
                             "posts": []
-                        },
-                        {
+                            },
+                    {
                             "page": None,
                             "subject": "Thread2",
                             "posts": []
-                        },
-                        {
+                            },
+                    {
                             "page": None,
                             "subject": "Thread3",
                             "posts": []
-                        },
-                        {
+                            },
+                    {
                             "page": None,
                             "subject": "Thread4",
                             "posts": []
-                        }
-                    ]}
-                ]
-            }
+                            }
+                ]}
+            ]
+        }
 
         importer._load_json = mock.Mock(return_value=_json)
         importer.add_posts = mock.Mock()
@@ -381,10 +380,10 @@ class TestDiscussionImporter(TestCase):
         importer.import_tool(project, user, 'mount_point', 'mount_label')
 
         project.install_app.assert_called_once_with(
-                'discussion',
-                'mount_point',
-                'mount_label',
-                import_id={'source': 'Allura'}
+            'discussion',
+            'mount_point',
+            'mount_label',
+            import_id={'source': 'Allura'}
         )
         h.push_config.assert_called_once_with(c, app=app)
 
@@ -399,7 +398,7 @@ class TestDiscussionImporter(TestCase):
             mock.call(dict(headers=dict(Subject=thread_json[4]["subject"])))
         ])
 
-        self.assertEqual(importer.add_posts.call_count, 5)
+        assert importer.add_posts.call_count == 5
         m.AuditLog.log.assert_called_once()
         g.post_event.assert_called_once()
 
@@ -423,7 +422,7 @@ class TestDiscussionImporter(TestCase):
                 "name": "General Discussion",
                 "import_id": import_id,
                 "threads": []
-                }]
+            }]
         }
 
         importer._load_json = mock.Mock(return_value=_json)
@@ -449,7 +448,7 @@ class TestDiscussionImporter(TestCase):
 
         importer.import_tool(project, user, 'mount_point', 'mount_label')
 
-        self.assertEqual(import_id, forum.import_id)
+        assert import_id == forum.import_id
 
         # Test without import id
         _json = {
@@ -468,7 +467,7 @@ class TestDiscussionImporter(TestCase):
 
         importer.import_tool(project, user, 'mount_point', 'mount_label')
 
-        self.assertEqual('', forum.import_id)
+        assert '' == forum.import_id
 
     @mock.patch.object(discussion, 'c')
     @mock.patch.object(discussion, 'g')
@@ -493,8 +492,8 @@ class TestDiscussionImporter(TestCase):
                         "posts": [],
                         "subject": "Thread",
                         "import_id": import_id
-                    }]
                 }]
+            }]
         }
 
         importer._load_json = mock.Mock(return_value=_json)
@@ -521,7 +520,7 @@ class TestDiscussionImporter(TestCase):
 
         importer.import_tool(project, user, 'mount_point', 'mount_label')
 
-        self.assertEqual(import_id, thread.import_id)
+        assert import_id == thread.import_id
 
         # Test with no import id
         _json = {
@@ -533,8 +532,8 @@ class TestDiscussionImporter(TestCase):
                         "limit": None,
                         "posts": [],
                         "subject": "Thread",
-                    }]
                 }]
+            }]
         }
 
         importer._load_json = mock.Mock(return_value=_json)
@@ -545,7 +544,7 @@ class TestDiscussionImporter(TestCase):
 
         importer.import_tool(project, user, 'mount_point', 'mount_label')
 
-        self.assertEqual('', thread.import_id)
+        assert '' == thread.import_id
 
     @mock.patch.object(discussion, 'c')
     @mock.patch.object(discussion, 'g')
@@ -636,7 +635,7 @@ class TestDiscussionImporter(TestCase):
                 "description": "Description of forum",
                 "name": "General Discussion",
                 "threads": [{
-                   "posts": []
+                    "posts": []
                 }]
             }]
         }
@@ -659,7 +658,7 @@ class TestDiscussionImporter(TestCase):
         importer._load_json = mock.Mock(return_value=_json)
         self.__check_missing(project, user, importer, h, g, utils)
 
-        self.assertEqual(h.make_app_admin_only.call_count, 6)
+        assert h.make_app_admin_only.call_count == 6
 
     @mock.patch.object(discussion, 'c')
     @mock.patch.object(discussion, 'h')
@@ -681,11 +680,11 @@ class TestDiscussionImporter(TestCase):
         importer.get_user.assert_called_once_with('admin1')
         h.push_config.assert_called_once_with(c, user=user, app=app)
         thread.add_post.assert_called_once_with(
-                subject=_json[0]['subject'],
-                text='foo',
-                timestamp=parse(_json[0]['timestamp']),
-                ignore_security=True,
-                parent_id=None
+            subject=_json[0]['subject'],
+            text='foo',
+            timestamp=parse(_json[0]['timestamp']),
+            ignore_security=True,
+            parent_id=None
         )
         post.add_multiple_attachments.assert_called_once_with([])
 
@@ -758,10 +757,10 @@ class TestDiscussionImporter(TestCase):
 
         importer.add_posts(thread, _json, app)
 
-        self.assertEqual(8, importer.get_user.call_count)
-        self.assertEqual(8, h.push_config.call_count)
-        self.assertEqual(8, thread.add_post.call_count)
-        self.assertEqual(8, post.add_multiple_attachments.call_count)
+        assert 8 == importer.get_user.call_count
+        assert 8 == h.push_config.call_count
+        assert 8 == thread.add_post.call_count
+        assert 8 == post.add_multiple_attachments.call_count
 
     @mock.patch.object(discussion, 'c')
     @mock.patch.object(discussion, 'h')
@@ -815,7 +814,7 @@ class TestDiscussionImporter(TestCase):
 
         importer.add_posts(thread, _json, app)
 
-        self.assertEqual(post.last_edit_date, parse(_json[0]['last_edited']))
+        assert post.last_edit_date == parse(_json[0]['last_edited'])
 
         # Test with none
         importer, app, thread, user, post = self.__init_add_posts_tests()
@@ -834,7 +833,7 @@ class TestDiscussionImporter(TestCase):
         post.last_edit_date = '-'
         importer.add_posts(thread, _json, app)
 
-        self.assertEqual(post.last_edit_date, '-')
+        assert post.last_edit_date == '-'
 
         # Test with no last edited
         importer, app, thread, user, post = self.__init_add_posts_tests()
@@ -852,7 +851,7 @@ class TestDiscussionImporter(TestCase):
         post.last_edit_date = '-'
         importer.add_posts(thread, _json, app)
 
-        self.assertEqual(post.last_edit_date, '-')
+        assert post.last_edit_date == '-'
 
         # Test with junk last edited
         importer, app, thread, user, post = self.__init_add_posts_tests()
@@ -912,11 +911,11 @@ class TestDiscussionImporter(TestCase):
         importer.add_posts(thread, _json, app)
 
         post.add_multiple_attachments.assert_called_once()
-        self.assertEqual(File.call_args_list, [
+        assert File.call_args_list == [
             mock.call('http://www.foo.com/attachment0'),
             mock.call('http://www.foo.com/attachment1'),
             mock.call('http://www.foo.com/attachment2'),
-        ])
+        ]
 
     @mock.patch.object(discussion, 'File')
     @mock.patch.object(discussion, 'c')
@@ -938,54 +937,54 @@ class TestDiscussionImporter(TestCase):
 
         _json = [
             {
-              "attachments": [],
-              "author": "admin1",
-              "timestamp": "2020-01-29 22:39:31.483000",
-              "text": "hi",
-              "slug": "0d1d",
-              "subject": "topic with lots of replies"
+                "attachments": [],
+                "author": "admin1",
+                "timestamp": "2020-01-29 22:39:31.483000",
+                "text": "hi",
+                "slug": "0d1d",
+                "subject": "topic with lots of replies"
             },
             {
-              "attachments": [],
-              "author": "admin1",
-              "timestamp": "2020-01-29 22:39:43.525000",
-              "text": "hello",
-              "slug": "0d1d/d421",
-              "subject": "topic with lots of replies"
+                "attachments": [],
+                "author": "admin1",
+                "timestamp": "2020-01-29 22:39:43.525000",
+                "text": "hello",
+                "slug": "0d1d/d421",
+                "subject": "topic with lots of replies"
             },
             {
-              "attachments": [],
-              "author": "admin1",
-              "timestamp": "2020-01-29 22:39:50.086000",
-              "text": "goodbye",
-              "slug": "0d1d/d421/f37d",
-              "subject": "topic with lots of replies"
+                "attachments": [],
+                "author": "admin1",
+                "timestamp": "2020-01-29 22:39:50.086000",
+                "text": "goodbye",
+                "slug": "0d1d/d421/f37d",
+                "subject": "topic with lots of replies"
             },
             {
-              "attachments": [],
-              "author": "admin1",
-              "timestamp": "2020-01-29 22:42:13.740000",
-              "text": "hi again",
-              "slug": "012f",
-              "subject": "topic with lots of replies"
+                "attachments": [],
+                "author": "admin1",
+                "timestamp": "2020-01-29 22:42:13.740000",
+                "text": "hi again",
+                "slug": "012f",
+                "subject": "topic with lots of replies"
             },
             {
-              "attachments": [],
-              "author": "user02",
-              "timestamp": "2020-01-29 22:42:51.645000",
-              "text": "hi there",
-              "slug": "012f/211a",
-              "subject": "topic with lots of replies"
+                "attachments": [],
+                "author": "user02",
+                "timestamp": "2020-01-29 22:42:51.645000",
+                "text": "hi there",
+                "slug": "012f/211a",
+                "subject": "topic with lots of replies"
             },
             {
-              "attachments": [],
-              "author": "user02",
-              "timestamp": "2020-01-29 22:42:58.478000",
-              "text": "hi here",
-              "slug": "0d1d/00a0",
-              "subject": "topic with lots of replies"
+                "attachments": [],
+                "author": "user02",
+                "timestamp": "2020-01-29 22:42:58.478000",
+                "text": "hi here",
+                "slug": "0d1d/00a0",
+                "subject": "topic with lots of replies"
             }
-         ]
+        ]
 
         importer.add_posts(thread, _json, app)
 
@@ -1157,7 +1156,7 @@ class TestDiscussionImporter(TestCase):
         user.is_anonymous.return_value = False
         username = "testUser123"
 
-        self.assertEqual(importer.annotate_text('foo', user, username), 'foo')
+        assert importer.annotate_text('foo', user, username) == 'foo'
 
     def test_annotate_text_with_not_existing_user(self):
         """ This test tests the annotate_text method with a not existing user """
@@ -1175,7 +1174,7 @@ class TestDiscussionImporter(TestCase):
         # Text that the method should return
         return_text = f'*Originally created by:* {username}\n\n{text}'
 
-        self.assertEqual(importer.annotate_text(text, user, username), return_text)
+        assert importer.annotate_text(text, user, username) == return_text
 
     def test_annotate_text_with_anonymous_user(self):
         """ This test tests the annotate_text method with an anonymous user """
@@ -1190,8 +1189,8 @@ class TestDiscussionImporter(TestCase):
 
         text = 'foo'
 
-        self.assertEqual(importer.annotate_text(text, user, usernames[0]), text)
-        self.assertEqual(importer.annotate_text(text, user, usernames[1]), text)
+        assert importer.annotate_text(text, user, usernames[0]) == text
+        assert importer.annotate_text(text, user, usernames[1]) == text
 
     def test_annotate_text_with_unicode(self):
         """ This method tests if annotate text can handle unicode characters """
@@ -1236,10 +1235,10 @@ class TestDiscussionImporter(TestCase):
         text = None
         username = None
 
-        self.assertEqual(importer.annotate_text(text, user, username), '')
+        assert importer.annotate_text(text, user, username) == ''
 
         text = 'foo'
-        self.assertEqual(importer.annotate_text(text, user, username), text)
+        assert importer.annotate_text(text, user, username) == text
 
     def __get_forum_dict(self, app, forum_json):
         new_forum = dict(
@@ -1268,7 +1267,7 @@ class TestDiscussionImporter(TestCase):
         g.post_event.assert_not_called()
 
 
-class TestForgeDiscussionController(TestController, TestCase):
+class TestForgeDiscussionController(TestController):
 
     def setup_method(self, method):
         super().setup_method(method)
@@ -1276,9 +1275,9 @@ class TestForgeDiscussionController(TestController, TestCase):
     @with_discussion
     def test_index(self):
         r = self.app.get('/p/test/admin/ext/import/forge-discussion/')
-        self.assertIsNotNone(r.html.find(attrs=dict(name="discussions_json")))
-        self.assertIsNotNone(r.html.find(attrs=dict(name="mount_label")))
-        self.assertIsNotNone(r.html.find(attrs=dict(name="mount_point")))
+        assert r.html.find(attrs=dict(name="discussions_json")) is not None
+        assert r.html.find(attrs=dict(name="mount_label")) is not None
+        assert r.html.find(attrs=dict(name="mount_point")) is not None
 
     @with_discussion
     @mock.patch('forgeimporters.forge.discussion.save_importer_upload')
@@ -1292,13 +1291,13 @@ class TestForgeDiscussionController(TestController, TestCase):
             'mount_point': 'mymount',
         }
         r = self.app.post('/p/test/admin/ext/import/forge-discussion/create', params, status=302)
-        self.assertEqual(r.location, 'http://localhost/p/test/admin/')
+        assert r.location == 'http://localhost/p/test/admin/'
         siu.assert_called_once_with(project,
                                     'discussions.json',
                                     '{"key": "val"}'
                                     )
-        self.assertEqual('mymount', import_tool.post.call_args[1]['mount_point'])
-        self.assertEqual('mylabel', import_tool.post.call_args[1]['mount_label'])
+        assert 'mymount' == import_tool.post.call_args[1]['mount_point']
+        assert 'mylabel' == import_tool.post.call_args[1]['mount_label']
 
     @with_discussion
     @mock.patch('forgeimporters.forge.discussion.save_importer_upload')
@@ -1315,5 +1314,5 @@ class TestForgeDiscussionController(TestController, TestCase):
         r = self.app.post('/p/test/admin/ext/import/forge-discussion/create',
                           params,
                           status=302).follow()
-        self.assertIn('Please wait and try again', r)
-        self.assertEqual(import_tool.post.call_count, 0)
+        assert 'Please wait and try again' in r
+        assert import_tool.post.call_count == 0
