@@ -17,13 +17,12 @@
 import requests
 import tg
 from mock import patch, call, Mock
-from unittest import TestCase
 
 from allura.tests import TestController
 from allura import model as M
 
 
-class TestGitHubImportController(TestController, TestCase):
+class TestGitHubImportController(TestController):
 
     def test_index(self):
         r = self.app.get('/p/import_project/github/')
@@ -36,12 +35,12 @@ class TestGitHubImportController(TestController, TestCase):
     def test_login_overlay(self):
         r = self.app.get('/p/import_project/github/',
                          extra_environ=dict(username='*anonymous'))
-        self.assertIn('GitHub Project Importer', r)
-        self.assertIn('Login Required', r)
+        assert 'GitHub Project Importer' in r
+        assert 'Login Required' in r
 
         r = self.app.post('/p/import_project/github/process',
                           extra_environ=dict(username='*anonymous'), status=302)
-        self.assertIn('/auth/', r.location)
+        assert '/auth/' in r.location
 
 
 class TestGitHubOAuth(TestController):
@@ -92,7 +91,6 @@ class TestGitHubOAuth(TestController):
                                                         json={'access_token': 'abc'},
                                                         timeout=10)
 
-
     def test_project_import_login_required(self):
         r = self.app.get('/p/import_project/github/', extra_environ=dict(username='*anonymous'))
         assert r.location is None
