@@ -16,7 +16,6 @@
 #       under the License.
 
 import json
-from unittest import TestCase
 from io import BytesIO
 import six.moves.urllib.parse
 import six.moves.urllib.request
@@ -27,8 +26,7 @@ from mock import patch, Mock
 from ... import github
 
 
-
-class TestGitHubProjectExtractor(TestCase):
+class TestGitHubProjectExtractor:
     PROJECT_INFO = {
         'description': 'project description',
         'homepage': 'http://example.com',
@@ -89,50 +87,45 @@ class TestGitHubProjectExtractor(TestCase):
         self.extractor.urlopen = self.mocked_urlopen
 
     def test_get_next_page_url(self):
-        self.assertIsNone(self.extractor.get_next_page_url(None))
-        self.assertIsNone(self.extractor.get_next_page_url(''))
+        assert self.extractor.get_next_page_url(None) is None
+        assert self.extractor.get_next_page_url('') is None
         link = '<https://api.github.com/repositories/8560576/issues?state=open&page=2>; rel="next", <https://api.github.com/repositories/8560576/issues?state=open&page=10>; rel="last"'
-        self.assertEqual(self.extractor.get_next_page_url(link),
-                         'https://api.github.com/repositories/8560576/issues?state=open&page=2')
+        assert self.extractor.get_next_page_url(link) == 'https://api.github.com/repositories/8560576/issues?state=open&page=2'
 
         link = '<https://api.github.com/repositories/8560576/issues?state=open&page=2>; rel="next"'
-        self.assertEqual(self.extractor.get_next_page_url(link),
-                         'https://api.github.com/repositories/8560576/issues?state=open&page=2')
+        assert self.extractor.get_next_page_url(link) == 'https://api.github.com/repositories/8560576/issues?state=open&page=2'
 
         link = '<https://api.github.com/repositories/8560576/issues?state=open&page=1>; rel="prev"'
-        self.assertIsNone(self.extractor.get_next_page_url(link))
+        assert self.extractor.get_next_page_url(link) is None
 
     def test_get_summary(self):
-        self.assertEqual(self.extractor.get_summary(), 'project description')
+        assert self.extractor.get_summary() == 'project description'
 
     def test_get_homepage(self):
-        self.assertEqual(self.extractor.get_homepage(), 'http://example.com')
+        assert self.extractor.get_homepage() == 'http://example.com'
 
     def test_iter_issues(self):
         issues = list(self.extractor.iter_issues())
         all_issues = list(zip((1, 2), self.CLOSED_ISSUES_LIST))
         all_issues += list(zip((3, 4, 5), self.OPENED_ISSUES_LIST))
         all_issues += list(zip((6, 7, 8), self.OPENED_ISSUES_LIST_PAGE2))
-        self.assertEqual(issues, all_issues)
+        assert issues == all_issues
 
     def test_iter_comments(self):
         mock_issue = {'comments_url': '/issues/1/comments'}
         comments = list(self.extractor.iter_comments(mock_issue))
-        self.assertEqual(comments, self.ISSUE_COMMENTS +
-                         self.ISSUE_COMMENTS_PAGE2)
+        assert comments == self.ISSUE_COMMENTS + self.ISSUE_COMMENTS_PAGE2
 
     def test_iter_events(self):
         mock_issue = {'events_url': '/issues/1/events'}
         events = list(self.extractor.iter_events(mock_issue))
-        self.assertEqual(events, self.ISSUE_EVENTS +
-                         self.ISSUE_EVENTS_PAGE2[:1])
+        assert events == self.ISSUE_EVENTS + self.ISSUE_EVENTS_PAGE2[:1]
 
     def test_has_wiki(self):
         assert self.extractor.has_wiki()
 
     def test_get_wiki_url(self):
-        self.assertEqual(self.extractor.get_page_url('wiki_url'),
-                         'https://github.com/test_project.wiki')
+        assert self.extractor.get_page_url('wiki_url') == 'https://github.com/test_project.wiki'
 
     @patch('forgeimporters.base.h.urlopen')
     def test_urlopen(self, urlopen):
@@ -140,16 +133,16 @@ class TestGitHubProjectExtractor(TestCase):
         url = 'https://github.com/u/p/'
         e.urlopen(url)
         request = urlopen.call_args[0][0]
-        self.assertEqual(request.get_full_url(), url)
+        assert request.get_full_url() == url
 
         user = Mock()
         user.get_tool_data.return_value = 'abc'
         e = github.GitHubProjectExtractor('test_project', user=user)
         e.urlopen(url)
         request = urlopen.call_args[0][0]
-        self.assertEqual(request.get_full_url(), url)
+        assert request.get_full_url() == url
         assert request.headers['User-agent']
-        self.assertEqual(request.headers['Authorization'], 'Bearer abc')
+        assert request.headers['Authorization'] == 'Bearer abc'
 
     @patch('forgeimporters.base.h.urlopen')
     @patch('forgeimporters.github.time.sleep')
@@ -171,8 +164,8 @@ class TestGitHubProjectExtractor(TestCase):
         urlopen.side_effect = urlopen_side_effect
         e = github.GitHubProjectExtractor('test_project')
         e.get_page('http://example.com/')
-        self.assertEqual(sleep.call_count, 1)
-        self.assertEqual(urlopen.call_count, 2)
+        assert sleep.call_count == 1
+        assert urlopen.call_count == 2
         log.warning.assert_called_once_with(
             'Rate limit exceeded (10 requests/hour). '
             'Sleeping until 2013-10-25 09:32:02 UTC'
