@@ -18,13 +18,15 @@
 import json
 import os
 
-from unittest import TestCase, skipIf
+from unittest import skipIf
+
+import pytest
 from mock import Mock, patch
 from ming.odm import ThreadLocalODMSession
 from tg import tmpl_context as c, config
 
 from allura.tests import TestController
-from allura.tests.decorators import with_tracker, with_wiki
+from allura.tests.decorators import with_tracker
 from alluratest.controller import TestRestApiBase, setup_unit_test
 from alluratest.tools import module_not_available
 
@@ -38,7 +40,7 @@ from forgeimporters.trac.tickets import (
 )
 
 
-class TestTracTicketImporter(TestCase):
+class TestTracTicketImporter:
 
     def setup_method(self, method):
         setup_unit_test()
@@ -65,7 +67,7 @@ class TestTracTicketImporter(TestCase):
                                    trac_url='http://example.com/trac/url',
                                    user_map=json.dumps(user_map),
                                    )
-        self.assertEqual(res, app)
+        assert res == app
         project.install_app.assert_called_once_with(
             'Tickets', mount_point='bugs', mount_label='Bugs',
             open_status_names='new assigned accepted reopened',
@@ -98,17 +100,14 @@ class TestTracTicketImporter(TestCase):
         user = Mock(name='User', _id='id')
         export.side_effect = ValueError
 
-        self.assertRaises(ValueError, importer.import_tool, project, user,
-                          mount_point='bugs',
-                          mount_label='Bugs',
-                          trac_url='http://example.com/trac/url',
-                          user_map=None,
-                          )
+        with pytest.raises(ValueError):
+            importer.import_tool(project, user, mount_point='bugs', mount_label='Bugs',
+                                 trac_url='http://example.com/trac/url', user_map=None)
 
         h.make_app_admin_only.assert_called_once_with(app)
 
 
-class TestTracTicketImportController(TestController, TestCase):
+class TestTracTicketImportController(TestController):
 
     def setup_method(self, method):
         """Mount Trac import controller on the Tracker admin controller"""
@@ -119,9 +118,9 @@ class TestTracTicketImportController(TestController, TestCase):
     @with_tracker
     def test_index(self):
         r = self.app.get('/p/test/admin/bugs/_importer/')
-        self.assertIsNotNone(r.html.find(attrs=dict(name="trac_url")))
-        self.assertIsNotNone(r.html.find(attrs=dict(name="mount_label")))
-        self.assertIsNotNone(r.html.find(attrs=dict(name="mount_point")))
+        assert r.html.find(attrs=dict(name="trac_url")) is not None
+        assert r.html.find(attrs=dict(name="mount_label")) is not None
+        assert r.html.find(attrs=dict(name="mount_point")) is not None
 
     @with_tracker
     @patch('forgeimporters.trac.requests.head')
@@ -137,15 +136,15 @@ class TestTracTicketImportController(TestController, TestCase):
                               'user_map', 'myfile', b'{"orig_user": "new_user"}'
                           )],
                           status=302)
-        self.assertEqual(r.location, 'http://localhost/p/test/admin/')
-        self.assertEqual(
-            'mymount', import_tool.post.call_args[1]['mount_point'])
-        self.assertEqual(
-            'mylabel', import_tool.post.call_args[1]['mount_label'])
-        self.assertEqual('{"orig_user": "new_user"}',
-                         import_tool.post.call_args[1]['user_map'])
-        self.assertEqual('http://example.com/trac/url/',
-                         import_tool.post.call_args[1]['trac_url'])
+        assert r.location == 'http://localhost/p/test/admin/'
+        assert \
+            'mymount' == import_tool.post.call_args[1]['mount_point']
+        assert \
+            'mylabel' == import_tool.post.call_args[1]['mount_label']
+        assert '{"orig_user": "new_user"}' == \
+            import_tool.post.call_args[1]['user_map']
+        assert 'http://example.com/trac/url/' == \
+            import_tool.post.call_args[1]['trac_url']
 
     @with_tracker
     @patch('forgeimporters.trac.requests.head')
@@ -164,8 +163,8 @@ class TestTracTicketImportController(TestController, TestCase):
                               'user_map', 'myfile', b'{"orig_user": "new_user"}'
                           )],
                           status=302).follow()
-        self.assertIn('Please wait and try again', r)
-        self.assertEqual(import_tool.post.call_count, 0)
+        assert 'Please wait and try again' in r
+        assert import_tool.post.call_count == 0
 
     @with_tracker
     @patch('forgeimporters.trac.requests.head')
@@ -180,7 +179,7 @@ class TestTracTicketImportController(TestController, TestCase):
                           upload_files=[(
                               'user_map', 'myfile', b'{"orig_user": "new_user"}'
                           )])
-        self.assertEqual(import_tool.post.call_count, 0)
+        assert import_tool.post.call_count == 0
 
     @with_tracker
     @patch('forgeimporters.trac.requests.head')
@@ -191,9 +190,10 @@ class TestTracTicketImportController(TestController, TestCase):
                       mount_label='mylabel',
                       mount_point='mymount')
         r = self.app.post('/p/test/admin/ext/import/trac-tickets/create', params, status=200)
-        self.assertIn('Invalid URL', r.text)
+        assert 'Invalid URL' in r.text
 
-class TestTracImportSupport(TestCase):
+
+class TestTracImportSupport:
 
     def test_link_processing(self):
         import_support = TracImportSupport()
@@ -222,10 +222,10 @@ class TestTracImportSupport(TestCase):
         }
         for input, expected in cases.items():
             actual = import_support.link_processing(input)
-            self.assertEqual(actual, expected)
+            assert actual == expected
 
 
-class TestTracImportSupportFunctional(TestRestApiBase, TestCase):
+class TestTracImportSupportFunctional(TestRestApiBase):
 
     @with_tracker
     def test_links(self):
@@ -263,10 +263,10 @@ class TestTracImportSupportFunctional(TestRestApiBase, TestCase):
             status={'$in': ['ok', 'pending']})).sort('timestamp').all()
 
         import_support = TracImportSupport()
-        self.assertEqual(
-            import_support.get_slug_by_id('204', '1'), comments[0].slug)
-        self.assertEqual(
-            import_support.get_slug_by_id('204', '2'), comments[1].slug)
+        assert \
+            import_support.get_slug_by_id('204', '1') == comments[0].slug
+        assert \
+            import_support.get_slug_by_id('204', '2') == comments[1].slug
 
     @with_tracker
     @skipIf(module_not_available('html2text'), 'html2text required')
@@ -288,8 +288,8 @@ class TestTracImportSupportFunctional(TestRestApiBase, TestCase):
             '{"user_map": {}}')
         ticket = TM.Ticket.query.get(app_config_id=c.app.config._id,
                                      ticket_num=390)
-        self.assertIn('To reproduce:  \n\\- open an mzML file',
-                      ticket.description)
-        self.assertIn('duplicate of:  \n\\- [#316](316 "defect: SpectraViewWidget is',
-                      ticket.discussion_thread.find_posts()[0].text)
-        self.assertIn('will crash TOPPView.', ticket.description)
+        assert 'To reproduce:  \n\\- open an mzML file' in \
+            ticket.description
+        assert 'duplicate of:  \n\\- [#316](316 "defect: SpectraViewWidget is' in \
+            ticket.discussion_thread.find_posts()[0].text
+        assert 'will crash TOPPView.' in ticket.description
