@@ -36,7 +36,7 @@ import tg
 import pysvn
 from paste.deploy.converters import asbool, asint
 from pymongo.errors import DuplicateKeyError
-from tg import tmpl_context as c, app_globals as g
+from tg import app_globals as g
 
 from ming.base import Object
 from ming.odm import Mapper, FieldProperty
@@ -44,7 +44,6 @@ from ming.utils import LazyProperty
 
 from allura import model as M
 from allura.lib import helpers as h
-from allura.model.auth import User
 from allura.model.repository import zipdir
 from allura.model import repository as RM
 
@@ -304,13 +303,13 @@ class SVNImplementation(M.RepositoryImplementation):
         """
         opts = self._repo.app.config.options
         if not svn_path_exists('file://{}{}/{}'.format(self._repo.fs_path,
-                                                          self._repo.name, opts['checkout_url'])):
+                                                       self._repo.name, opts['checkout_url'])):
             opts['checkout_url'] = ''
 
         if (not opts['checkout_url'] and
                 svn_path_exists(
                     'file://{}{}/trunk'.format(self._repo.fs_path,
-                                                 self._repo.name))):
+                                               self._repo.name))):
             opts['checkout_url'] = 'trunk'
 
     def commit(self, rev):
@@ -450,8 +449,8 @@ class SVNImplementation(M.RepositoryImplementation):
             path = tree_path.strip('/')
             RM.LastCommitDoc.m.update_partial(
                 {'commit_id': commit_id, 'path': path},
-                {'commit_id': commit_id, 'path':
-                 path, 'entries': lcd_entries},
+                {'$set': {'commit_id': commit_id, 'path':
+                 path, 'entries': lcd_entries}},
                 upsert=True)
         return tree_id
 
@@ -535,9 +534,9 @@ class SVNImplementation(M.RepositoryImplementation):
                 path and
                 (len(changed_path['path']) < len(path)) and
                 path.startswith(changed_path['path'])):
-                changed_path['copyfrom_path'] = changed_path['copyfrom_path'] + \
-                    path[len(changed_path['path']):]
-                changed_path['path'] = path
+            changed_path['copyfrom_path'] = changed_path['copyfrom_path'] + \
+                path[len(changed_path['path']):]
+            changed_path['path'] = path
         return changed_path
 
     def _map_log(self, ci, url, path=None):
@@ -812,4 +811,5 @@ class SVNImplementation(M.RepositoryImplementation):
 
         return result
 
+
 Mapper.compile_all()
