@@ -17,7 +17,6 @@
 
 import os
 import shutil
-import unittest
 from unittest import skipUnless
 
 import pkg_resources
@@ -27,6 +26,7 @@ from zipfile import ZipFile
 from io import BytesIO
 from collections import defaultdict
 
+import pytest
 from tg import tmpl_context as c, app_globals as g
 import mock
 import tg
@@ -48,7 +48,7 @@ from forgesvn.tests import with_svn
 from allura.tests.decorators import with_tool
 
 
-class TestNewRepo(unittest.TestCase):
+class TestNewRepo:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -77,8 +77,8 @@ class TestNewRepo(unittest.TestCase):
         latest_rev = 7
         assert self.rev.primary() is self.rev
         assert self.rev.index_id().startswith('allura/model/repo/Commit#')
-        self.rev.author_url
-        self.rev.committer_url
+        assert self.rev.author_url is None
+        assert self.rev.committer_url is None
         assert self.rev.tree._id == self.rev.tree_id
         assert self.rev.shorthand_id() == f'[r{latest_rev}]'
         assert self.rev.symbolic_ids == ([], [])
@@ -89,10 +89,11 @@ class TestNewRepo(unittest.TestCase):
         assert self.rev.tree.readme() == ('README', 'This is readme\nAnother Line\n')
         assert self.rev.tree.path() == '/'
         assert self.rev.tree.url() == f'/p/test/src/{latest_rev}/tree/'
-        self.rev.tree.by_name['README']
+        assert self.rev.tree.by_name['README']
         assert self.rev.tree.is_blob('README') is True
         assert self.rev.tree['a']['b']['c'].ls() == []
-        self.assertRaises(KeyError, lambda: self.rev.tree['a']['b']['d'])
+        with pytest.raises(KeyError):
+            self.rev.tree['a']['b']['d']
 
         assert self.rev.authored_user is None
         assert self.rev.committed_user is None
@@ -102,7 +103,7 @@ class TestNewRepo(unittest.TestCase):
                     'committer', 'added', 'removed', 'renamed', 'modified', 'copied']))
 
 
-class TestSVNRepo(unittest.TestCase, RepoImplTestBase):
+class TestSVNRepo(RepoImplTestBase):
 
     def setup_method(self, method):
         setup_basic_test()
@@ -165,13 +166,12 @@ class TestSVNRepo(unittest.TestCase, RepoImplTestBase):
             os.path.join(g.tmpdir, 'testsvn/hooks/post-commit'), os.X_OK)
         with open(os.path.join(g.tmpdir, 'testsvn/hooks/post-commit')) as f:
             hook_data = f.read()
-        self.assertIn(
-            'curl -s http://localhost/auth/refresh_repo/p/test/src/\n',
-            hook_data)
-        self.assertIn('exec $DIR/post-commit-user "$@"\n', hook_data)
+        assert \
+            'curl -s http://localhost/auth/refresh_repo/p/test/src/\n' in hook_data
+        assert 'exec $DIR/post-commit-user "$@"\n' in hook_data
 
         repo.refresh(notify=False)
-        assert len(list(repo.log(limit=100)))
+        assert list(repo.log(limit=100))
 
         shutil.rmtree(dirname)
 
@@ -217,12 +217,11 @@ class TestSVNRepo(unittest.TestCase, RepoImplTestBase):
             os.path.join(g.tmpdir, 'testsvn/hooks/post-commit'), os.X_OK)
         with open(os.path.join(g.tmpdir, 'testsvn/hooks/post-commit')) as f:
             c = f.read()
-        self.assertIn(
-            'curl -s http://localhost/auth/refresh_repo/p/test/src/\n', c)
-        self.assertIn('exec $DIR/post-commit-user "$@"\n', c)
+        assert 'curl -s http://localhost/auth/refresh_repo/p/test/src/\n' in c
+        assert 'exec $DIR/post-commit-user "$@"\n' in c
 
         repo.refresh(notify=False)
-        assert len(list(repo.log(limit=100)))
+        assert list(repo.log(limit=100))
 
         shutil.rmtree(dirname)
 
@@ -357,50 +356,50 @@ class TestSVNRepo(unittest.TestCase, RepoImplTestBase):
 
     def test_paged_diffs(self):
         entry = self.repo.commit(next(self.repo.log(2, id_only=True, limit=1)))
-        self.assertEqual(entry.diffs, entry.paged_diffs())
-        self.assertEqual(entry.diffs, entry.paged_diffs(start=0))
+        assert entry.diffs == entry.paged_diffs()
+        assert entry.diffs == entry.paged_diffs(start=0)
         added_expected = entry.diffs.added[1:3]
         expected = dict(
             copied=[], changed=[], removed=[], renamed=[],
             added=added_expected, total=4)
         actual = entry.paged_diffs(start=1, end=3)
-        self.assertEqual(expected, actual)
+        assert expected == actual
 
         fake_id = self.repo._impl._oid(100)
         empty = M.repository.Commit(_id=fake_id, repo=self.repo).paged_diffs()
-        self.assertEqual(sorted(actual.keys()), sorted(empty.keys()))
+        assert sorted(actual.keys()) == sorted(empty.keys())
 
     def test_diff_create_file(self):
         entry = self.repo.commit(next(self.repo.log(1, id_only=True, limit=1)))
-        self.assertEqual(
-            entry.diffs, dict(
+        assert \
+            entry.diffs == dict(
                 copied=[], changed=[], renamed=[],
-                removed=[], added=['/README'], total=1))
+                removed=[], added=['/README'], total=1)
 
     def test_diff_create_path(self):
         entry = self.repo.commit(next(self.repo.log(2, id_only=True, limit=1)))
         actual = entry.diffs
         actual.added = sorted(actual.added)
-        self.assertEqual(
-            entry.diffs, dict(
+        assert \
+            entry.diffs == dict(
                 copied=[], changed=[], removed=[], renamed=[],
                 added=sorted([
                     '/a', '/a/b', '/a/b/c',
-                    '/a/b/c/hello.txt']), total=4))
+                    '/a/b/c/hello.txt']), total=4)
 
     def test_diff_modify_file(self):
         entry = self.repo.commit(next(self.repo.log(3, id_only=True, limit=1)))
-        self.assertEqual(
-            entry.diffs, dict(
+        assert \
+            entry.diffs == dict(
                 copied=[], changed=['/README'], renamed=[],
-                removed=[], added=[], total=1))
+                removed=[], added=[], total=1)
 
     def test_diff_delete(self):
         entry = self.repo.commit(next(self.repo.log(4, id_only=True, limit=1)))
-        self.assertEqual(
-            entry.diffs, dict(
+        assert \
+            entry.diffs == dict(
                 copied=[], changed=[], renamed=[],
-                removed=['/a/b/c/hello.txt'], added=[], total=1))
+                removed=['/a/b/c/hello.txt'], added=[], total=1)
 
     def test_diff_copy(self):
         entry = self.repo.commit(next(self.repo.log(5, id_only=True, limit=1)))
@@ -568,7 +567,7 @@ class TestSVNRepo(unittest.TestCase, RepoImplTestBase):
         assert payload == expected_payload
 
 
-class TestSVNRev(unittest.TestCase):
+class TestSVNRev:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -645,7 +644,7 @@ class TestSVNRev(unittest.TestCase):
         assert 'Create readme' in n.text
 
 
-class _Test(unittest.TestCase):
+class _Test:
     idgen = ('obj_%d' % i for i in count())
 
     def _make_tree(self, object_id, **kwargs):
@@ -739,14 +738,13 @@ class TestRepo(_TestWithRepo):
             getattr(self.repo._impl, fn).assert_called_with('foo')
 
     def test_shorthand_for_commit(self):
-        self.assertEqual(
-            self.repo.shorthand_for_commit('a' * 40),
-            '[aaaaaa]')
+        assert \
+            self.repo.shorthand_for_commit('a' * 40) == '[aaaaaa]'
 
     def test_url_for_commit(self):
-        self.assertEqual(
-            self.repo.url_for_commit('a' * 40),
-            '/p/test/test1/ci/aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa/')
+        assert \
+            self.repo.url_for_commit('a' * 40) == \
+            '/p/test/test1/ci/aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa/'
 
     @mock.patch('allura.model.repository.g.post_event')
     def test_init_as_clone(self, post_event):
@@ -1017,7 +1015,7 @@ class TestCommit(_TestWithRepo):
         self.ci.context()
 
 
-class TestRename(unittest.TestCase):
+class TestRename:
 
     def setup_method(self, method):
         setup_basic_test()
