@@ -15,7 +15,6 @@
 #       specific language governing permissions and limitations
 #       under the License.
 
-import unittest
 
 from tg import tmpl_context as c
 from ming.odm import ThreadLocalODMSession
@@ -25,7 +24,7 @@ from allura.lib import helpers as h
 from forgesvn.tests import with_svn
 
 
-class TestSVNApp(unittest.TestCase):
+class TestSVNApp:
 
     def setup_method(self, method):
         setup_basic_test()
