@@ -81,7 +81,7 @@ class ForgeShortUrlApp(Application):
 
     def is_visible_to(self, user):
         '''Whether the user can view the app.'''
-        return has_access(c.project, 'create')(user=user)
+        return has_access(c.project, 'create', user)
 
     @property
     @h.exceptionless([], log)
