@@ -19,7 +19,7 @@ import typing
 import pymongo
 from tg import config
 from tg import tmpl_context as c
-from ming.odm import FieldProperty, ForeignIdProperty, session
+from ming.odm import FieldProperty, session
 from datetime import datetime
 from allura.model.auth import User
 from allura import model as M
