@@ -32,7 +32,6 @@ import pymongo
 from pymongo.errors import OperationFailure
 from tg import tmpl_context as c, app_globals as g
 from paste.deploy.converters import aslist, asbool
-import jinja2
 import markupsafe
 
 from ming import schema
@@ -139,10 +138,10 @@ class Globals(MappedClass):
                                                             })
 
     def next_ticket_num(self):
-        gbl = Globals.query.find_and_modify(
-            query=dict(app_config_id=self.app_config_id),
+        gbl = Globals.query.find_one_and_update(
+            dict(app_config_id=self.app_config_id),
             update={'$inc': {'last_ticket_num': 1}},
-            new=True)
+            return_document=True)
         session(gbl).expunge(gbl)
         return gbl.last_ticket_num
 
@@ -431,7 +430,7 @@ class Globals(MappedClass):
                         getattr(ticket, k))
                 setattr(ticket, k, v)
             for k, v in sorted(custom_values.items()):
-                def cf_val(cf):
+                def cf_val(cf, ticket=ticket):
                     return ticket.get_custom_user(cf.name) \
                         if cf.type == 'user' \
                         else ticket.custom_fields.get(cf.name)
@@ -460,7 +459,7 @@ class Globals(MappedClass):
                 # mark changes text as safe, thus it wouldn't be escaped in plain-text emails
                 # html part of email is handled by markdown and it'll be
                 # properly escaped
-                yield (changed_tickets[t_id], markupsafe.Markup(changes[t_id]))
+                yield (changed_tickets[t_id], markupsafe.Markup(changes[t_id]))  # noqa: S704
         mail = dict(
             sender=c.project.app_instance(self.app_config).email_address,
             fromaddr=str(c.user._id),
@@ -483,7 +482,7 @@ class Globals(MappedClass):
                 v = user.display_name if user else v
             head.append(f'- **{cf.label}**: {v}')
         tmpl_context = {'context': c, 'data':
-                        {'header': markupsafe.Markup('\n'.join(['Mass edit changing:', ''] + head))}}
+                        {'header': markupsafe.Markup('\n'.join(['Mass edit changing:', ''] + head))}}  # noqa: S704
         for user in users:
             tmpl_context['data'].update({'changes': changes_iter(user)})
             mail.update(dict(
@@ -502,7 +501,7 @@ class Globals(MappedClass):
                         self.app_config.options.get('TicketMonitoringType') ==
                         'AllTicketChanges'):
                     visible_changes.append(
-                        (changed_tickets[t_id], markupsafe.Markup(changes[t_id])))
+                        (changed_tickets[t_id], markupsafe.Markup(changes[t_id])))  # noqa: S704
             if visible_changes:
                 tmpl_context['data'].update({'changes': visible_changes})
                 mail.update(dict(
@@ -679,7 +678,7 @@ class Ticket(VersionedArtifact, ActivityObject, VotableArtifact):
     def link_text(self):
         text = super().link_text()
         if self.is_closed:
-            return markupsafe.Markup('<s>') + text + markupsafe.Markup('</s>')
+            return markupsafe.Markup('<s>{}</s>').format(text)
         return text
 
     @property
@@ -1196,7 +1195,7 @@ class Ticket(VersionedArtifact, ActivityObject, VotableArtifact):
     def __json__(self, posts_limit=None, is_export=False):
         parents_json = {}
         for parent in reversed(type(self).mro()):
-            if parent != type(self) and hasattr(parent, '__json__'):
+            if parent is not type(self) and hasattr(parent, '__json__'):
                 kwargs = {}
                 if parent == VersionedArtifact:
                     kwargs['posts_limit'] = posts_limit
