@@ -17,11 +17,11 @@
 from tg import tmpl_context as c
 
 from allura.lib.search import search
-import six
 
 
 FACET_PARAMS = {
     'facet': 'true',
+    # fields used in faceting should have docValues="true" in solr, for faster performance
     'facet.field': ['_milestone_s', 'status_s', 'assigned_to_s', 'reported_by_s'],
     'facet.limit': -1,
     'facet.sort': 'index',
@@ -41,7 +41,7 @@ def query_filter_choices(arg=None, fq=[]):
             'project_id_s:%s' % c.project._id,
             'mount_point_s:%s' % c.app.config.options.mount_point,
             'type_s:Ticket',
-            ] + fq,
+        ] + fq,
         'rows': 0,
     }
     params.update(FACET_PARAMS)
