@@ -44,14 +44,13 @@ class TestTrackerApiBase(TestRestApiBase):
     def create_ticket(self, summary=None, status=None):
         return self.api_post(
             '/rest/p/test/bugs/new',
-            wrap_args='ticket_form',
-            params=dict(
+            params=dict(ticket_form=dict(
                 summary=summary or 'test new ticket',
                 status=self.tracker_globals.open_status_names.split()[0],
                 labels='',
                 description='',
                 assigned_to='',
-                **{'custom_fields._milestone': ''}),
+                **{'custom_fields._milestone': ''})),
             status=status)
 
 
@@ -61,15 +60,14 @@ class TestRestNewTicket(TestTrackerApiBase):
         summary = 'test new ticket'
         ticket_view = self.api_post(
             '/rest/p/test/bugs/new',
-            wrap_args='ticket_form',
-            params=dict(
+            params=dict(ticket_form=dict(
                 summary=summary,
                 status=self.tracker_globals.open_status_names.split()[0],
                 labels='foo,bar',
                 description='descr',
                 assigned_to='',
                 **{'custom_fields._milestone': ''}
-            ))
+            )))
         json = ticket_view.json['ticket']
         assert json['status'] == 'open', json
         assert json['summary'] == 'test new ticket', json
@@ -112,12 +110,13 @@ class TestRestUpdateTicket(TestTrackerApiBase):
             del args[bad_key]
         args['private'] = str(args['private'])
         args['discussion_disabled'] = str(args['discussion_disabled'])
-        ticket_view = self.api_post(
-            '/rest/p/test/bugs/1/save', wrap_args='ticket_form', params=h.encode_keys(args))
+        ticket_view = self.api_post('/rest/p/test/bugs/1/save', params={'ticket_form': args})
         assert ticket_view.status_int == 200, ticket_view.showbrowser()
         json = ticket_view.json['ticket']
         assert int(json['ticket_num']) == 1
         assert json['summary'] == 'test update ticket', json
+        assert json['discussion_disabled'] is False
+        assert json['private'] is False
 
 
 class TestRestIndex(TestTrackerApiBase):
@@ -151,7 +150,7 @@ class TestRestIndex(TestTrackerApiBase):
         ticket_config = M.AppConfig.query.get(
             project_id=c.project._id, tool_name='tickets')
         assert (ticket_config.options.get('TicketMonitoringEmail') ==
-                     'test@localhost')
+                'test@localhost')
 
     @td.with_tool('test', 'Tickets', 'dummy')
     def test_move_ticket_redirect(self):
@@ -177,14 +176,14 @@ class TestRestDiscussion(TestTrackerApiBase):
         thread_id = r.json['ticket']['discussion_thread']['_id']
         post = self.api_post(
             '/rest/p/test/bugs/_discuss/thread/%s/new' % thread_id,
-            text='This is a comment', wrap_args=None)
+            text='This is a comment')
         thread = self.api_get('/rest/p/test/bugs/_discuss/thread/%s/' % thread_id)
         assert len(thread.json['thread']['posts']) == 1, thread.json
         assert post.json['post']['text'] == 'This is a comment', post.json
         reply = self.api_post(
             '/rest/p/test/bugs/_discuss/thread/{}/{}/reply'.format(thread.json['thread']
-                                                               ['_id'], post.json['post']['slug']),
-            text='This is a reply', wrap_args=None)
+                                                                   ['_id'], post.json['post']['slug']),
+            text='This is a reply')
         assert reply.json['post']['text'] == 'This is a reply', reply.json
         thread = self.api_get('/rest/p/test/bugs/_discuss/thread/%s/' % thread_id)
         assert len(thread.json['thread']['posts']) == 2, thread.json
