@@ -17,7 +17,6 @@
 
 from tg import tmpl_context as c
 from datetime import datetime
-from io import BytesIO
 import os
 import six.moves.urllib.parse
 import six.moves.urllib.request
@@ -182,38 +181,38 @@ class TestTicketModel(TrackerTestWithModel):
             ACE.allow(role_creator, 'read'),
             ACE.allow(role_creator, 'unmoderated_post'),
             DENY_ALL]
-        assert has_access(t, 'read', user=admin)()
-        assert has_access(t, 'create', user=admin)()
-        assert has_access(t, 'update', user=admin)()
-        assert has_access(t, 'read', user=creator)()
-        assert has_access(t, 'post', user=creator)()
-        assert has_access(t, 'unmoderated_post', user=creator)()
-        assert has_access(t, 'create', user=creator)()
-        assert not has_access(t, 'update', user=creator)()
-        assert has_access(t, 'read', user=developer)()
-        assert has_access(t, 'create', user=developer)()
-        assert has_access(t, 'update', user=developer)()
-        assert not has_access(t, 'read', user=observer)()
-        assert not has_access(t, 'create', user=observer)()
-        assert not has_access(t, 'update', user=observer)()
-        assert not has_access(t, 'read', user=anon)()
-        assert not has_access(t, 'create', user=anon)()
-        assert not has_access(t, 'update', user=anon)()
+        assert has_access(t, 'read', user=admin)
+        assert has_access(t, 'create', user=admin)
+        assert has_access(t, 'update', user=admin)
+        assert has_access(t, 'read', user=creator)
+        assert has_access(t, 'post', user=creator)
+        assert has_access(t, 'unmoderated_post', user=creator)
+        assert has_access(t, 'create', user=creator)
+        assert not has_access(t, 'update', user=creator)
+        assert has_access(t, 'read', user=developer)
+        assert has_access(t, 'create', user=developer)
+        assert has_access(t, 'update', user=developer)
+        assert not has_access(t, 'read', user=observer)
+        assert not has_access(t, 'create', user=observer)
+        assert not has_access(t, 'update', user=observer)
+        assert not has_access(t, 'read', user=anon)
+        assert not has_access(t, 'create', user=anon)
+        assert not has_access(t, 'update', user=anon)
 
         t.private = False
         assert t.acl == []
-        assert has_access(t, 'read', user=admin)()
-        assert has_access(t, 'create', user=admin)()
-        assert has_access(t, 'update', user=admin)()
-        assert has_access(t, 'read', user=developer)()
-        assert has_access(t, 'create', user=developer)()
-        assert has_access(t, 'update', user=developer)()
-        assert has_access(t, 'read', user=creator)()
-        assert has_access(t, 'unmoderated_post', user=creator)()
-        assert has_access(t, 'create', user=creator)()
-        assert not has_access(t, 'update', user=creator)()
-        assert has_access(t, 'read', user=observer)()
-        assert has_access(t, 'read', user=anon)()
+        assert has_access(t, 'read', user=admin)
+        assert has_access(t, 'create', user=admin)
+        assert has_access(t, 'update', user=admin)
+        assert has_access(t, 'read', user=developer)
+        assert has_access(t, 'create', user=developer)
+        assert has_access(t, 'update', user=developer)
+        assert has_access(t, 'read', user=creator)
+        assert has_access(t, 'unmoderated_post', user=creator)
+        assert has_access(t, 'create', user=creator)
+        assert not has_access(t, 'update', user=creator)
+        assert has_access(t, 'read', user=observer)
+        assert has_access(t, 'read', user=anon)
 
     def test_feed(self):
         t = Ticket(
@@ -231,7 +230,7 @@ class TestTicketModel(TrackerTestWithModel):
         assert f.pubdate == datetime(2012, 10, 29, 9, 57, 21, 465000)
         assert f.title == 'test ticket'
         assert (f.description ==
-                     '<div class="markdown_content"><p>test description</p></div>')
+                '<div class="markdown_content"><p>test description</p></div>')
 
     @td.with_tool('test', 'Tickets', 'bugs', username='test-user')
     @td.with_tool('test', 'Tickets', 'bugs2', username='test-user')
@@ -349,7 +348,7 @@ class TestTicketModel(TrackerTestWithModel):
             ticket.summary = 'test ticket'
             ticket.description = 'test description'
         assert len(ticket.attachments) == 0
-        f = six.moves.urllib.request.urlopen('file://%s' % __file__)
+        f = six.moves.urllib.request.urlopen('file://%s' % __file__)  # noqa: S310
         TicketAttachment.save_attachment(
             'test_ticket_model.py', ResettableStream(f),
             artifact_id=ticket._id)
