@@ -19,6 +19,8 @@ import logging
 import re
 from datetime import datetime, timedelta
 from urllib.parse import urlencode, unquote
+
+from markupsafe import Markup
 from webob import exc
 import json
 import os
@@ -82,6 +84,7 @@ from forgetracker.widgets.bin_form import BinForm
 from forgetracker.widgets.ticket_search import TicketSearchResults, MassEdit, MassEditForm, MassMoveForm
 from forgetracker.widgets.admin_custom_fields import TrackerFieldAdmin, TrackerFieldDisplay
 import six
+from jinja2.filters import do_truncate as truncate
 
 log = logging.getLogger(__name__)
 
@@ -270,7 +273,7 @@ class ForgeTrackerApp(Application):
         return TM.Globals.query.get(app_config_id=self.config._id)
 
     def has_access(self, user, topic):
-        return has_access(c.app, 'post')(user=user)
+        return has_access(c.app, 'post', user)
 
     def handle_message(self, topic, message):
         log.info('Message from %s (%s)',
@@ -355,7 +358,7 @@ class ForgeTrackerApp(Application):
                         className='milestones'))
 
         links = []
-        if has_access(self, 'create')():
+        if has_access(self, 'create'):
             links.append(SitemapEntry('Create Ticket',
                                       self.config.url() + 'new/', ui_icon=g.icons['add']))
         else:
@@ -365,7 +368,7 @@ class ForgeTrackerApp(Application):
                                       extra_html_attrs=extra_attrs,
                                       className='sidebar-disabled',
                                       ui_icon=g.icons['add']))
-        if has_access(self, 'configure')():
+        if has_access(self, 'configure'):
             links.append(SitemapEntry('Edit Milestones', self.config.url()
                          + 'milestones', ui_icon=g.icons['table']))
             links.append(SitemapEntry('Edit Searches', c.project.url() + 'admin/' +
@@ -378,7 +381,7 @@ class ForgeTrackerApp(Application):
             'status': 'pending',
             'deleted': False,
         }).count()
-        if pending_mod_count and has_access(discussion, 'moderate')():
+        if pending_mod_count and has_access(discussion, 'moderate'):
             links.append(
                 SitemapEntry(
                     'Moderate', discussion.url() + 'moderate', ui_icon=g.icons['moderate'],
@@ -386,7 +389,7 @@ class ForgeTrackerApp(Application):
 
         links += milestones
 
-        if len(search_bins):
+        if search_bins:
             links.append(SitemapEntry('Searches'))
             links = links + search_bins
         links.append(SitemapEntry('Help'))
@@ -395,7 +398,7 @@ class ForgeTrackerApp(Application):
         return links
 
     def sidebar_menu_js(self):
-        return """\
+        return Markup("""\
         $(function() {
             $.ajax({
                 url:'%(app_url)sbin_counts',
@@ -425,7 +428,7 @@ class ForgeTrackerApp(Application):
                     }
                 });
             }
-        });""" % {'app_url': c.app.url}
+        });""") % {'app_url': c.app.url}
 
     def has_custom_field(self, field):
         """Checks if given custom field is defined.
@@ -744,8 +747,8 @@ class RootController(BaseController, FeedController):
         result[
             'sortable_custom_fields'] = c.app.globals.sortable_custom_fields_shown_in_search()
         result['subscribed'] = M.Mailbox.subscribed()
-        result['allow_edit'] = has_access(c.app, 'update')()
-        result['allow_move'] = has_access(c.app, 'admin')()
+        result['allow_edit'] = has_access(c.app, 'update')
+        result['allow_move'] = has_access(c.app, 'admin')
         result['help_msg'] = c.app.config.options.get(
             'TicketHelpSearch', '').strip()
         result['url_q'] = c.app.globals.not_closed_query
@@ -831,7 +834,7 @@ class RootController(BaseController, FeedController):
     @validate(validators=search_validators)
     def search(self, q=None, query=None, project=None, columns=None, page=0, sort=None,
                deleted=False, filter=None, **kw):
-        require(has_access(c.app, 'read'))
+        require_access(c.app, 'read')
 
         if deleted and not has_access(c.app, 'delete'):
             deleted = False
@@ -849,8 +852,8 @@ class RootController(BaseController, FeedController):
         result['columns'] = columns or solr_columns()
         result[
             'sortable_custom_fields'] = c.app.globals.sortable_custom_fields_shown_in_search()
-        result['allow_edit'] = has_access(c.app, 'update')()
-        result['allow_move'] = has_access(c.app, 'admin')()
+        result['allow_edit'] = has_access(c.app, 'update')
+        result['allow_move'] = has_access(c.app, 'admin')
         result['bin'] = bin
         result['help_msg'] = c.app.config.options.get(
             'TicketHelpSearch', '').strip()
@@ -1027,7 +1030,7 @@ class RootController(BaseController, FeedController):
         if tracker == c.app.config:
             flash('Ticket already in a selected tracker', 'info')
             redirect('move/' + search)
-        if not has_access(tracker, 'admin')():
+        if not has_access(tracker, 'admin'):
             flash('You should have admin access to destination tracker',
                   'error')
             redirect('move/' + search)
@@ -1108,7 +1111,7 @@ class RootController(BaseController, FeedController):
         if dates is None:
             today = datetime.utcnow()
             dates = "{} to {}".format((today - timedelta(days=61))
-                                  .strftime('%Y-%m-%d'), today.strftime('%Y-%m-%d'))
+                                      .strftime('%Y-%m-%d'), today.strftime('%Y-%m-%d'))
         return dict(
             now=str(now),
             week_ago=str(week_ago),
@@ -1326,7 +1329,7 @@ class changelog:
             if key in self.originals:
                 orig_value = self.originals[key]
                 curr_value = self.data[key]
-                if not orig_value == curr_value:
+                if orig_value != curr_value:
                     t.append((key, (orig_value, curr_value)))
         return t
 
@@ -1384,10 +1387,13 @@ class TicketController(BaseController, FeedController):
             limit, page, _ = g.handle_paging(limit, page)
             limit, page = h.paging_sanitizer(limit, page, post_count)
             voting_enabled = self.ticket.app.config.options.get('EnableVoting')
+            default_title = f'{c.project.name} {c.app.config.options.mount_label}'
+            h1_text = (self.ticket.summary or default_title)
+            h1_text = truncate(None, h1_text, 80, end="...", leeway=3)
             return dict(ticket=self.ticket, globals=c.app.globals,
-                        allow_edit=has_access(self.ticket, 'update')(),
+                        allow_edit=has_access(self.ticket, 'update'),
                         subscribed=subscribed, voting_enabled=voting_enabled,
-                        page=page, limit=limit, count=post_count)
+                        page=page, limit=limit, count=post_count, h1_text=h1_text)
         else:
             raise exc.HTTPNotFound('Ticket #%s does not exist.' % self.ticket_num)
 
@@ -1618,7 +1624,7 @@ class TicketController(BaseController, FeedController):
                 flash('Ticket already in a selected tracker', 'info')
                 redirect(six.ensure_text(request.referer or '/'))
 
-            if not has_access(tracker, 'admin')():
+            if not has_access(tracker, 'admin'):
                 flash('You should have admin access to destination tracker',
                       'error')
                 redirect(six.ensure_text(request.referer or '/'))
@@ -1685,7 +1691,7 @@ class TrackerAdminController(DefaultAdminController):
     def fields(self, **kw):
         c.form = W.field_admin
         columns = {column: get_label(column)
-                       for column in self.app.globals['show_in_search'].keys()}
+                   for column in self.app.globals['show_in_search'].keys()}
         return dict(app=self.app, globals=self.app.globals, columns=columns)
 
     @expose('jinja:forgetracker:templates/tracker/admin_options.html')
@@ -1955,7 +1961,7 @@ class MilestoneController(BaseController):
         deleted=validators.StringBool(if_empty=False)))
     def index(self, q=None, columns=None, page=0, query=None, sort=None,
               deleted=False, filter=None, **kw):
-        require(has_access(c.app, 'read'))
+        require_access(c.app, 'read')
         show_deleted = [False]
         if deleted and has_access(c.app, 'delete'):
             show_deleted = [False, True]
@@ -1972,8 +1978,8 @@ class MilestoneController(BaseController):
         result['columns'] = columns or mongo_columns()
         result[
             'sortable_custom_fields'] = c.app.globals.sortable_custom_fields_shown_in_search()
-        result['allow_edit'] = has_access(c.app, 'update')()
-        result['allow_move'] = has_access(c.app, 'admin')()
+        result['allow_edit'] = has_access(c.app, 'update')
+        result['allow_move'] = has_access(c.app, 'admin')
         result['help_msg'] = c.app.config.options.get(
             'TicketHelpSearch', '').strip()
         result['deleted'] = deleted
