@@ -26,7 +26,6 @@ from allura import model as M
 from allura.lib.widgets import form_fields as ffw
 from allura.lib import helpers as h
 from allura.lib import validators as v
-import six
 
 
 class TicketCustomFields(ew.CompoundField):
@@ -79,7 +78,7 @@ class GenericTicketForm(ew.SimpleForm):
 
         display = field.display(**ctx)
         if ctx['errors'] and field.show_errors and not ignore_errors:
-            display += Markup("<div class='error'>") + ctx['errors'] + Markup("</div>")
+            display += Markup("<div class='error'>{}</div>").format(ctx['errors'])
         return display
 
     def _add_current_value_to_user_field(self, field, user):
@@ -102,7 +101,7 @@ class GenericTicketForm(ew.SimpleForm):
     def fields(self):
         fields = [
             ew.TextField(name='summary', label='Title',
-                         attrs={'style': 'width: 425px', 'class':'memorable',
+                         attrs={'style': 'width: 425px', 'class': 'memorable',
                                 'placeholder': 'Title'},
                          validator=v.UnicodeString(
                              not_empty=True, messages={
@@ -257,7 +256,7 @@ class MilestoneField(ew.SingleSelectField):
             opt for opt in self.options if opt.complete]
 
         # filter closed milestones entirely
-        #value = context['value']
-        #context['options'] = [opt for opt in self.options if not opt.complete or value == opt.py_value]
+        # value = context['value']
+        # context['options'] = [opt for opt in self.options if not opt.complete or value == opt.py_value]
 
         return context
