@@ -15,7 +15,6 @@
 #       specific language governing permissions and limitations
 #       under the License.
 from datetime import datetime
-import re
 
 from tg import expose, validate, redirect
 from tg.decorators import with_trailing_slash
@@ -38,7 +37,7 @@ class ForgeUserStatsCatController(BaseController):
 
     @expose()
     def _lookup(self, category, *remainder):
-        cat = M.TroveCategory.query.get(shortname=category, fullpath=re.compile(r'^Topic :: '))
+        cat = M.TroveCategory.query.get(shortname=category, fullpath={'$regex': r'^Topic :: '})
         if not cat:
             raise exc.HTTPNotFound
         return ForgeUserStatsCatController(category=cat), remainder
