@@ -16,7 +16,6 @@
 #       under the License.
 
 import pkg_resources
-import unittest
 from datetime import datetime, timedelta
 
 from tg import tmpl_context as c
@@ -36,7 +35,7 @@ from forgeuserstats.model import stats as USM
 with_git = td.with_tool('test', 'Git', 'git-userstats-model', 'Git', type='git')
 
 
-class TestUserStats(unittest.TestCase):
+class TestUserStats:
 
     def setup_method(self, method):
         setup_basic_test()
@@ -442,11 +441,11 @@ class TestUserStats(unittest.TestCase):
 
     def test_start_date(self):
         stats = USM.UserStats(registration_date=datetime(2012, 4, 1))
-        self.assertEqual(stats.start_date, datetime(2012, 4, 1))
+        assert stats.start_date == datetime(2012, 4, 1)
         with h.push_config(config, **{'userstats.start_date': '2013-04-01'}):
-            self.assertEqual(stats.start_date, datetime(2013, 4, 1))
+            assert stats.start_date == datetime(2013, 4, 1)
         with h.push_config(config, **{'userstats.start_date': '2011-04-01'}):
-            self.assertEqual(stats.start_date, datetime(2012, 4, 1))
+            assert stats.start_date == datetime(2012, 4, 1)
 
     @mock.patch('allura.model.stats.difflib.unified_diff')
     def test_count_loc(self, unified_diff):
@@ -472,11 +471,11 @@ class TestUserStats(unittest.TestCase):
             trove_language=[],
         )
         stats.addCommit(newcommit, commit_datetime, project)
-        self.assertEqual(stats.general[0].commits[0],
-                         {'lines': 3, 'number': 1, 'language': None})
+        assert stats.general[0].commits[0] == \
+            {'lines': 3, 'number': 1, 'language': None}
         unified_diff.reset_mock()
         with h.push_config(config, **{'userstats.count_lines_of_code': 'false'}):
             stats.addCommit(newcommit, commit_datetime, project)
-        self.assertEqual(stats.general[0].commits[0],
-                         {'lines': 3, 'number': 2, 'language': None})
+        assert stats.general[0].commits[0] == \
+            {'lines': 3, 'number': 2, 'language': None}
         assert not unified_diff.called
