@@ -16,7 +16,6 @@
 #       under the License.
 
 import pkg_resources
-import unittest
 
 from tg import tmpl_context as c
 
@@ -42,7 +41,7 @@ class TestStats(TestController):
         self.app.get('/').follow()  # establish session
         self.app.post('/auth/do_login', antispam=True, params=dict(
             username=user.username, password='foo',
-            _session_id=self.app.cookies['_session_id'],
+            _csrf_token=self.app.cookies['_csrf_token'],
         ))
 
         assert user.stats.tot_logins_count == 1 + init_logins
@@ -183,7 +182,7 @@ class TestStats(TestController):
             'modified'] == initial_tickets_artifacts['modified'] + 3
 
 
-class TestGitCommit(TestController, unittest.TestCase):
+class TestGitCommit(TestController):
 
     def setup_method(self, method):
         super().setup_method(method)
