@@ -23,6 +23,7 @@ from pprint import pformat
 import six
 from urllib.parse import unquote, urlencode
 
+from markupsafe import Markup
 # Non-stdlib imports
 from tg import expose, validate, redirect, flash, jsonify
 from tg.decorators import with_trailing_slash, without_trailing_slash
@@ -129,7 +130,7 @@ class ForgeWikiApp(Application):
         self.admin = WikiAdminController(self)
 
     def has_access(self, user, topic):
-        return has_access(c.app, 'post')(user=user)
+        return has_access(c.app, 'post', user)
 
     def handle_message(self, topic, message):
         log.info('Message from %s (%s)',
@@ -270,7 +271,7 @@ The wiki uses [Markdown](%s) syntax.
             'status': 'pending',
             'deleted': False
         }).count() if discussion else 0
-        if pending_mod_count and h.has_access(discussion, 'moderate')():
+        if pending_mod_count and h.has_access(discussion, 'moderate'):
             links.append(
                 SitemapEntry(
                     'Moderate', discussion.url() + 'moderate', ui_icon=g.icons['moderate'],
@@ -305,12 +306,12 @@ The wiki uses [Markdown](%s) syntax.
         return self.create_common_wiki_menu(has_create_access=has_access(self, 'create'))
 
     def sidebar_menu_js(self):
-        return '''
+        return Markup('''
         $('#sidebar').on('click', 'a[href$="#toggle-subscribe"]', function(e) {
             e.preventDefault();
             var link = this;
             var data = {
-                _session_id: $.cookie('_session_id'),
+                _csrf_token: $.cookie('_csrf_token'),
                 subscribe: '1'
             };
             $.post(this.href, data, function(){
@@ -323,7 +324,7 @@ The wiki uses [Markdown](%s) syntax.
             e.preventDefault();
             var link = this;
             var data = {
-                _session_id: $.cookie('_session_id'),
+                _csrf_token: $.cookie('_csrf_token'),
                 unsubscribe: '1'
             };
             $.post(this.href, data, function(){
@@ -332,7 +333,7 @@ The wiki uses [Markdown](%s) syntax.
                 $(link).attr('href', $(link).attr('href').replace('-unsubscribe','-subscribe'));
             });
         });
-        '''
+        ''')
 
     def install(self, project):
         'Set up any default permissions and roles here'
@@ -469,31 +470,23 @@ class RootController(BaseController, DispatchIndex, FeedController):
         pages = []
         uv_pages = []
         criteria = dict(app_config_id=c.app.config._id)
-        can_delete = has_access(c.app, 'delete')()
+        can_delete = has_access(c.app, 'delete')
         show_deleted = show_deleted and can_delete
         if not can_delete:
             criteria['deleted'] = False
         q = WM.Page.query.find(criteria)
         if sort == 'alpha':
             q = q.sort('title')
+        elif sort == 'recent':
+            q = q.sort('mod_date', -1)
         count = q.count()
         q = q.skip(start).limit(int(limit))
         for page in q:
             recent_edit = page.history().first()
-            p = dict(title=page.title, url=page.url(), deleted=page.deleted)
+            p = dict(title=page.title, url=page.url(), deleted=page.deleted, mod_date=page.mod_date)
             if recent_edit:
-                p['updated'] = recent_edit.timestamp
-                p['user_label'] = recent_edit.author.display_name
                 p['user_name'] = recent_edit.author.username
-                pages.append(p)
-            else:
-                if sort == 'recent':
-                    uv_pages.append(p)
-                else:
-                    pages.append(p)
-        if sort == 'recent':
-            pages.sort(reverse=True, key=lambda x: (x['updated']))
-            pages = pages + uv_pages
+            pages.append(p)
         h1_text = f"{c.project.name} {c.app.config.options.mount_label} - Browse Pages"
         return dict(
             pages=pages, can_delete=can_delete, show_deleted=show_deleted,
@@ -624,7 +617,7 @@ class PageController(BaseController, FeedController):
         hide_left_bar = not (c.app.show_left_bar)
         subscribed_to_page = M.Mailbox.subscribed(artifact=self.page)
         latest_version = self.page.history().limit(1).first()
-        is_latest_version = cur == latest_version.version
+        is_latest_version = not latest_version or cur == latest_version.version
         return dict(
             page=page,
             cur=cur, prev=prev, next=next,
@@ -881,7 +874,7 @@ class RootRestController(BaseController, AppRestControllerMixin):
         pages = WM.Page.query.find(
             dict(app_config_id=c.app.config._id, deleted=False))
         for page in pages:
-            if has_access(page, 'read')():
+            if has_access(page, 'read'):
                 page_titles.append(page.title)
         return dict(pages=page_titles)
 
@@ -919,7 +912,7 @@ class PageRestController(BaseController):
                 require_access(c.app, 'create')
                 if WM.Page.is_limit_exceeded(c.app.config, user=c.user):
                     log.warning('Page create/edit rate limit exceeded. %s',
-                             c.app.config.url())
+                                c.app.config.url())
                     raise forge_exc.HTTPTooManyRequests()
                 self.page = WM.Page.upsert(title)
                 self.page.viewable_by = ['all']
@@ -946,13 +939,13 @@ class WikiAdminController(DefaultAdminController):
     def home(self):
         return dict(app=self.app,
                     home=self.app.root_page_name,
-                    allow_config=has_access(self.app, 'configure')())
+                    allow_config=has_access(self.app, 'configure'))
 
     @without_trailing_slash
     @expose('jinja:forgewiki:templates/wiki/admin_options.html')
     def options(self):
         return dict(app=self.app,
-                    allow_config=has_access(self.app, 'configure')())
+                    allow_config=has_access(self.app, 'configure'))
 
     @without_trailing_slash
     @expose()
